(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    208687,       5631]
NotebookOptionsPosition[    198163,       5322]
NotebookOutlinePosition[    198516,       5338]
CellTagsIndexPosition[    198473,       5335]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["K-theory for the Noncommutative Conifold", "Title",
 CellChangeTimes->{{3.6960781872876596`*^9, 3.696078199275998*^9}}],

Cell[CellGroupData[{

Cell["Preliminaries", "Chapter",
 CellChangeTimes->{{3.696078366398348*^9, 3.696078370909301*^9}, 
   3.6960793702428513`*^9}],

Cell[TextData[{
 "This mathematica notebook contains the computation of the K-theory DT \
partition function for the noncommutative conifold. It consists of two \
independent sections. \n\nThe first \[OpenCurlyDoubleQuote]Determination of \
the fixed points\[CloseCurlyDoubleQuote] computes the fixed points up to a \
certain order (presently (4,4)). This section uses the NCalgebra package \
(this package can be found in ",
 Cell[BoxData[
  TagBox[
   ButtonBox[
    PaneSelectorBox[{False->"\<\"http://math.ucsd.edu/~ncalg/\"\>", True->
     StyleBox["\<\"http://math.ucsd.edu/~ncalg/\"\>", "HyperlinkActive"]}, 
     Dynamic[
      CurrentValue["MouseOver"]],
     BaseStyle->{"Hyperlink"},
     FrameMargins->0,
     ImageSize->Automatic],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["http://math.ucsd.edu/~ncalg/"], None},
    ButtonNote->"http://math.ucsd.edu/~ncalg/"],
   Annotation[#, "http://math.ucsd.edu/~ncalg/", "Hyperlink"]& ]],
  CellChangeTimes->{3.696707538624387*^9}],
 " ).\nThis Section ends creating a file of fixed points, so in principle one \
does not have to run this section every time but can simply load the file.\n\
In this Section we first construct cyclic modules over the path algebra of \
the conifold quiver withouth the superpotential relations. Then we impose the \
superpotential relations to find the cyclic modules of the full quiver Q / <d \
W>. \nOnce the fixed points are classified we translate each fixed point into \
the corresponding isotypical decomposition for the vector spaces {V0,V1} \
corresponding to representations of the conifold quiver.\nThis Section ends \
writing a file with the list of fixed points written as {(d0,d1),(V0,V1)}\n\n\
The second Section performs the localization computation to get the partition \
function. It can be run independently from the previous section, by loading \
the file containing all the fixed points. Then this Section defined the \
virtual tangent space at each fixed point and computes its contribution.\n\
Then we compute a refined limit by taking a particular scaling limit of the \
toric weights\nFinally we write down a conjecture for the closed form of the \
full K-theory partition function, based on trial and error. We check that our \
guess reproduces the localization computation. Then we take the refined and \
unrefined limit and compare them with the literature"
}], "Text",
 CellChangeTimes->{{3.696102613601714*^9, 3.696102618976859*^9}, {
   3.6965321228273697`*^9, 3.696532334162971*^9}, {3.6965324273711653`*^9, 
   3.6965324387965097`*^9}, {3.696532527210615*^9, 3.696532819156501*^9}, {
   3.6965329820944433`*^9, 3.696533063677511*^9}, {3.6965330992538347`*^9, 
   3.6965331013182364`*^9}, {3.696533152483307*^9, 3.6965331776750603`*^9}, 
   3.696707550297139*^9, {3.696707616472803*^9, 3.696707650779158*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Section 1. Determination of the fixed points", "Chapter",
 CellChangeTimes->{{3.6960782194692583`*^9, 3.696078224764042*^9}, {
  3.6965363844533033`*^9, 3.696536390490552*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"<<", "NC`"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "NCAlgebra`"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "NCGB`"}]}], "Input",
 CellChangeTimes->{{3.694436224872714*^9, 3.694436224874627*^9}, {
  3.6944467967574368`*^9, 3.69444680176548*^9}, {3.694510167828004*^9, 
  3.694510174074333*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"You are using the version of NCAlgebra which is found in:\"\
\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689109333712*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"/Users/michelebackup/Documents/Wolfram \
Mathematica/NC\"\>"}],
  SequenceForm["  ", "/Users/michelebackup/Documents/Wolfram Mathematica/NC"],
  
  Editable->False]], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689109341494*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"You can now use \\\"<< NCAlgebra`\\\" to load NCAlgebra or \
\"\>", "\[InvisibleSpace]", "\<\"\\\"<< NCGB`\\\" to load NCGB.\"\>"}],
  SequenceForm[
  "You can now use \"<< NCAlgebra`\" to load NCAlgebra or ", 
   "\"<< NCGB`\" to load NCGB."],
  Editable->False]], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689109347157*^9}],

Cell[BoxData["\<\"NCMultiplication.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689109380157*^9}],

Cell[BoxData["\<\"NC1SetCommands.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.6966891093866167`*^9}],

Cell[BoxData["\<\"NCInverses.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.6966891093924217`*^9}],

Cell[BoxData["\<\"NCTransposes.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689109398079*^9}],

Cell[BoxData["\<\"NCAdjoints.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.69668910940388*^9}],

Cell[BoxData["\<\"NCCo.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689109409869*^9}],

Cell[BoxData["\<\"NCRoots.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689109415574*^9}],

Cell[BoxData["\<\"NC2SetCommands.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689109421629*^9}],

Cell[BoxData["\<\"NCCollect.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689109427774*^9}],

Cell[BoxData["\<\"NCSubstitute.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689109433638*^9}],

Cell[BoxData["\<\"NCMonomial.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689109439354*^9}],

Cell[BoxData["\<\"NCSolve.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689109444972*^9}],

Cell[BoxData["\<\"NCTools.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.6966891094506807`*^9}],

Cell[BoxData["\<\"NC2SimplifyRational.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689109456534*^9}],

Cell[BoxData["\<\"NC1SimplifyRational.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689109462472*^9}],

Cell[BoxData["\<\"NCSimplifyRational.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689109468293*^9}],

Cell[BoxData["\<\"NCComplex.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689109474268*^9}],

Cell[BoxData["\<\"NCMatMult.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.6966891096648417`*^9}],

Cell[BoxData["\<\"NCDiff.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.6966891096958714`*^9}],

Cell[BoxData["\<\"NCSchur.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.6966891097028713`*^9}],

Cell[BoxData["\<\"NCAlias.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689109708969*^9}],

Cell[BoxData["\<\"Grabs.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.6966891097145853`*^9}],

Cell[BoxData["\<\"NCTaylorCoeff.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689109720283*^9}],

Cell[BoxData["\<\"NCConvexity.m and NCGuts.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689109725947*^9}],

Cell[BoxData["\<\"NCRealizationFunctions.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.6966891097318783`*^9}],

Cell[BoxData["\<\"NCTeXForm.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.69668910973804*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"NCTeX::Using '\"\>", "\[InvisibleSpace]", "\<\"open\"\>", 
   "\[InvisibleSpace]", "\<\"' as PDFViewer.\"\>"}],
  SequenceForm["NCTeX::Using '", "open", "' as PDFViewer."],
  Editable->False]], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689111252191*^9}],

Cell[BoxData["\<\"NCTeX.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.6966891112587347`*^9}],

Cell[BoxData["\<\"NCMaster.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.6966891112931128`*^9}],

Cell[BoxData["\<\"NCOutput.m loaded\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689111300172*^9}],

Cell["\<\
------------------------------------------------------------
NCAlgebra - Version 4.0.7
Compatible with Mathematica Version 9

Authors:
  J. William Helton*
  Mauricio de Oliveira* 
  Mark Stankus* 
  Robert L. Miller#

* Math Dept, UCSD                
# General Atomics Corp
  La  Jolla, CA 92093

Copyright: 
  Helton and Miller June 1991
  Helton 2002
  All rights reserved.

The program was written by the authors and by:
  David Hurst, Daniel Lamm, Orlando Merino, Robert Obar,
  Henry Pfister, Mike Walker, John Wavrik, Lois Yu,
  J. Camino, J. Griffin, J. Ovall, T. Shaheen, John Shopple. 
  The beginnings of the program come from eran@slac.
  Considerable recent help came from Igor Klep.


This program was written with support from 
  AFOSR, NSF, ONR, Lab for Math and Statistics at UCSD,
  UCSD Faculty Mentor Program,
  and US Department of Education.
  Primary support in 2010 is from the 
    NSF Division of Mathematical Sciences.

If you 
  (1) are a user, 
  (2) want to be a user, 
  (3) refer to NCAlgebra in a publication, or 
  (4) have had an interesting experience with NCAlgebra,
let us know by sending an e-mail message to  

  ncalg@math.ucsd.edu. 

We do not want to restrict access to NCAlgebra, but do 
  want to keep track of how it is being used.

For NCAlgebra updates see the web page:

  www.math.ucsd.edu/~ncalg 
------------------------------------------------------------\
\>", "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689111308216*^9}],

Cell[BoxData["\<\"You have already loaded NCAlgebra.m\"\>"], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.69668911131415*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["LinkObject",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False}, 
    PanelBox[
     PaneSelectorBox[{False->GridBox[{
        {
         PaneBox[
          ButtonBox[
           
           DynamicBox[FEPrivate`FrontEndResource[
            "FEBitmaps", "SquarePlusIconMedium"],
            ImageSizeCache->{12., {0., 12.}}],
           Appearance->None,
           ButtonFunction:>(Typeset`open$$ = True),
           Evaluator->Automatic,
           Method->"Preemptive"],
          Alignment->{Center, Center},
          
          ImageSize->
           Dynamic[{
            Automatic, 3.5 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification]}]], 
         GraphicsBox[
          {Thickness[0.038461538461538464`], 
           {FaceForm[{GrayLevel[0.93], Opacity[1.]}], 
            FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 
             3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}}}, {{{25.499999999999996`,
              2.5}, {25.499999999999996`, 1.3953100000000003`}, {
             24.604699999999998`, 0.49999999999999994`}, {23.5, 
             0.49999999999999994`}, {2.5, 0.49999999999999994`}, {
             1.3953100000000003`, 0.49999999999999994`}, {
             0.49999999999999994`, 1.3953100000000003`}, {
             0.49999999999999994`, 2.5}, {0.49999999999999994`, 23.5}, {
             0.49999999999999994`, 24.604699999999998`}, {1.3953100000000003`,
              25.499999999999996`}, {2.5, 25.499999999999996`}, {23.5, 
             25.499999999999996`}, {24.604699999999998`, 
             25.499999999999996`}, {25.499999999999996`, 
             24.604699999999998`}, {25.499999999999996`, 23.5}, {
             25.499999999999996`, 2.5}}}]}, 
           {FaceForm[{RGBColor[0.5, 0.5, 0.5], Opacity[1.]}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{20.5426, 
             19.116799999999998`}, {16.3832, 21.876199999999997`}, {16.3832, 
             20.021499999999996`}, {6.930469999999999, 20.021499999999996`}, {
             6.930469999999999, 18.212100000000003`}, {16.3832, 
             18.212100000000003`}, {16.3832, 16.357399999999995`}, {20.5426, 
             19.116799999999998`}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {9.46445, 
             11.079700000000003`}, {9.46445, 12.933999999999997`}, {
             18.917199999999998`, 12.933999999999997`}, {18.917199999999998`, 
             14.7438}, {9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 
             13.8391}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {9.46445, 
             11.079700000000003`}, {9.46445, 12.933999999999997`}, {
             18.917199999999998`, 12.933999999999997`}, {18.917199999999998`, 
             14.7438}, {9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 
             13.8391}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
              1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
             0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYC4sIjUTVcAooO8+XdOPpnKDg8YkwNXuen7JA2
W/qycJSgw5sbHEde31CB82PFhGf3n1V1aFVgVz0zR8oBrF9czWFHsFXE/9Wy
Dje0Dj4qiFWDy7cVLYptDVKH65/g6Xbu0HMNOB9sn4I23H6w+SWacD5De8DS
tDQNB7ldC/alskg4aD2+nx6joeFgnPFi/oMZog5B9vlaQa/UHao9k7f0KUhA
+D/UUPVbqML5jCB+oIpDzJHypGv8Eg4eGad3ikiqwM2T57H5LndPGW6eya7m
GzMvKcH1o4cXABG3d/Y=
             "]], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}}}, {{{14.163129999999999`, 4.337966249999999}, {
             16.96813, 4.337966249999999}, {16.96813, 5.047809999999999}, {
             14.98813, 5.047809999999999}, {14.98813, 8.29796625}, {
             14.163129999999999`, 8.29796625}, {14.163129999999999`, 
             4.337966249999999}}}]}},
          AspectRatio->1,
          Axes->False,
          Background->GrayLevel[0.93],
          Frame->True,
          FrameStyle->Directive[
            Thickness[Tiny], 
            GrayLevel[0.7]],
          FrameTicks->None,
          ImageSize->{Automatic, 
            Dynamic[
            3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification]), ImageSizeCache -> {45., {0., 9.}}]}], 
         GridBox[{
           {
            RowBox[{
             TagBox["\<\"Name: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox[
              StyleBox[
               
               PaneBox["\<\"'/Users/michelebackup/Documents/Wolfram \
Mathematica/NC/NCGB/Binary/p9c/MacOSX-x86-64/p9c'\"\>",
                BaselinePosition->Baseline,
                ContentPadding->False,
                FrameMargins->0,
                ImageSize->{{1, 300}, Automatic},
                StripOnInput->True],
               LineBreakWithin->False],
              "SummaryItem"]}]},
           {
            RowBox[{
             TagBox["\<\"Link mode: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["Listen",
              "SummaryItem"]}]}
          },
          AutoDelete->False,
          
          BaseStyle->{
           ShowStringCharacters -> False, NumberMarks -> False, 
            PrintPrecision -> 3, ShowSyntaxStyles -> False},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
          GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}
       },
       AutoDelete->False,
       BaselinePosition->{1, 1},
       GridBoxAlignment->{"Rows" -> {{Top}}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], True->
      GridBox[{
        {
         PaneBox[
          ButtonBox[
           
           DynamicBox[FEPrivate`FrontEndResource[
            "FEBitmaps", "SquareMinusIconMedium"]],
           Appearance->None,
           ButtonFunction:>(Typeset`open$$ = False),
           Evaluator->Automatic,
           Method->"Preemptive"],
          Alignment->{Center, Center},
          
          ImageSize->
           Dynamic[{
            Automatic, 3.5 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification]}]], 
         GraphicsBox[
          {Thickness[0.038461538461538464`], 
           {FaceForm[{GrayLevel[0.93], Opacity[1.]}], 
            FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 
             3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}}}, {{{25.499999999999996`,
              2.5}, {25.499999999999996`, 1.3953100000000003`}, {
             24.604699999999998`, 0.49999999999999994`}, {23.5, 
             0.49999999999999994`}, {2.5, 0.49999999999999994`}, {
             1.3953100000000003`, 0.49999999999999994`}, {
             0.49999999999999994`, 1.3953100000000003`}, {
             0.49999999999999994`, 2.5}, {0.49999999999999994`, 23.5}, {
             0.49999999999999994`, 24.604699999999998`}, {1.3953100000000003`,
              25.499999999999996`}, {2.5, 25.499999999999996`}, {23.5, 
             25.499999999999996`}, {24.604699999999998`, 
             25.499999999999996`}, {25.499999999999996`, 
             24.604699999999998`}, {25.499999999999996`, 23.5}, {
             25.499999999999996`, 2.5}}}]}, 
           {FaceForm[{RGBColor[0.5, 0.5, 0.5], Opacity[1.]}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{20.5426, 
             19.116799999999998`}, {16.3832, 21.876199999999997`}, {16.3832, 
             20.021499999999996`}, {6.930469999999999, 20.021499999999996`}, {
             6.930469999999999, 18.212100000000003`}, {16.3832, 
             18.212100000000003`}, {16.3832, 16.357399999999995`}, {20.5426, 
             19.116799999999998`}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {9.46445, 
             11.079700000000003`}, {9.46445, 12.933999999999997`}, {
             18.917199999999998`, 12.933999999999997`}, {18.917199999999998`, 
             14.7438}, {9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 
             13.8391}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {9.46445, 
             11.079700000000003`}, {9.46445, 12.933999999999997`}, {
             18.917199999999998`, 12.933999999999997`}, {18.917199999999998`, 
             14.7438}, {9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 
             13.8391}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
              1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
             0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYC4sIjUTVcAooO8+XdOPpnKDg8YkwNXuen7JA2
W/qycJSgw5sbHEde31CB82PFhGf3n1V1aFVgVz0zR8oBrF9czWFHsFXE/9Wy
Dje0Dj4qiFWDy7cVLYptDVKH65/g6Xbu0HMNOB9sn4I23H6w+SWacD5De8DS
tDQNB7ldC/alskg4aD2+nx6joeFgnPFi/oMZog5B9vlaQa/UHao9k7f0KUhA
+D/UUPVbqML5jCB+oIpDzJHypGv8Eg4eGad3ikiqwM2T57H5LndPGW6eya7m
GzMvKcH1o4cXABG3d/Y=
             "]], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}}}, {{{14.163129999999999`, 4.337966249999999}, {
             16.96813, 4.337966249999999}, {16.96813, 5.047809999999999}, {
             14.98813, 5.047809999999999}, {14.98813, 8.29796625}, {
             14.163129999999999`, 8.29796625}, {14.163129999999999`, 
             4.337966249999999}}}]}},
          AspectRatio->1,
          Axes->False,
          Background->GrayLevel[0.93],
          Frame->True,
          FrameStyle->Directive[
            Thickness[Tiny], 
            GrayLevel[0.7]],
          FrameTicks->None,
          ImageSize->{Automatic, 
            Dynamic[
            3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification]), ImageSizeCache -> {45., {0., 9.}}]}], 
         GridBox[{
           {
            RowBox[{
             TagBox["\<\"Name: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox[
              
              PaneBox["\<\"'/Users/michelebackup/Documents/Wolfram \
Mathematica/NC/NCGB/Binary/p9c/MacOSX-x86-64/p9c'\"\>",
               BaselinePosition->Baseline,
               ContentPadding->False,
               FrameMargins->0,
               ImageSize->{{1, 500}, Automatic},
               StripOnInput->True],
              "SummaryItem"]}]},
           {
            RowBox[{
             TagBox["\<\"Link mode: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["Listen",
              "SummaryItem"]}]},
           {
            RowBox[{
             TagBox["\<\"Link protocol: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["\<\"SharedMemory\"\>",
              "SummaryItem"]}]}
          },
          AutoDelete->False,
          
          BaseStyle->{
           ShowStringCharacters -> False, NumberMarks -> False, 
            PrintPrecision -> 3, ShowSyntaxStyles -> False},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
          GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}
       },
       AutoDelete->False,
       BaselinePosition->{1, 1},
       GridBoxAlignment->{"Rows" -> {{Top}}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
      Typeset`open$$],
      ImageSize->Automatic],
     BaselinePosition->Baseline],
    DynamicModuleValues:>{}], "]"}],
  LinkObject[
  "'/Users/michelebackup/Documents/Wolfram \
Mathematica/NC/NCGB/Binary/p9c/MacOSX-x86-64/p9c'", 459, 5],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Print",
 CellChangeTimes->{3.6963659803472557`*^9, 3.696689111902728*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Modules of the algebra of paths of quiver without W", "Section",
 CellChangeTimes->{{3.696078306064847*^9, 3.6960783330128098`*^9}, {
  3.6960830659111567`*^9, 3.696083070998489*^9}}],

Cell["\<\
First we construct a set of vectors in the algebra of paths for the conifold \
quiver. The construction is recursive, adding new arrows at each step. We \
call these lists Arrow Monomials AM followed by the number of arrows\
\>", "Text",
 CellChangeTimes->{{3.696079723812104*^9, 3.696079750154804*^9}, {
  3.696079812847447*^9, 3.696079824239641*^9}, {3.696080096441698*^9, 
  3.6960801098965673`*^9}, {3.6960802038624496`*^9, 3.696080212110899*^9}}],

Cell[BoxData[
 RowBox[{"SetNonCommutative", "[", 
  RowBox[{"v", ",", "a1", ",", "a2", ",", "b1", ",", "b2"}], "]"}]], "Input",
 CellChangeTimes->{{3.6944364563900642`*^9, 3.694436473344121*^9}, {
  3.6950421647279053`*^9, 3.695042164910462*^9}}],

Cell[BoxData[
 RowBox[{"SetMonomialOrder", "[", 
  RowBox[{"v", ",", "a1", ",", "a2", ",", "b1", ",", "b2"}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FirstArrows", "=", 
  RowBox[{"{", 
   RowBox[{"a1", ",", "a2"}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"SecondArrows", "=", 
  RowBox[{"{", 
   RowBox[{"b1", ",", "b2"}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.69443841268622*^9, 3.694438434753612*^9}, 
   3.694446936641357*^9, 3.694531390875825*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"a1", ",", "a2"}], "}"}]], "Output",
 CellChangeTimes->{3.696365997009697*^9, 3.6966891122315483`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"b1", ",", "b2"}], "}"}]], "Output",
 CellChangeTimes->{3.696365997009697*^9, 3.696689112238303*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"AM0", "=", 
   RowBox[{"{", "v", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.694446853044943*^9, 3.6944468579054413`*^9}, {
   3.696080113137662*^9, 3.6960801142416563`*^9}, 3.696080399003976*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"AM1", "=", 
   RowBox[{"DeleteCases", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"Reap", "[", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{
             RowBox[{"FirstArrows", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "**", 
             RowBox[{"AM0", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "AM0", "]"}]}], "}"}]}], "]"}], "]"}], 
      "]"}], ",", "Null"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.694446866265691*^9, 3.6944468821773777`*^9}, {
   3.694446915721871*^9, 3.69444692885791*^9}, {3.6960801162496433`*^9, 
   3.696080160873259*^9}, 3.696080400756521*^9, {3.696082313641446*^9, 
   3.696082323304727*^9}, {3.696082368542172*^9, 3.696082371468378*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"AM2", "=", 
   RowBox[{"DeleteCases", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"Reap", "[", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{
             RowBox[{"SecondArrows", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "**", 
             RowBox[{"AM1", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "AM1", "]"}]}], "}"}]}], "]"}], "]"}], 
      "]"}], ",", "Null"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.694446885880877*^9, 3.69444690406581*^9}, 
   3.694446939857502*^9, {3.696080181122265*^9, 3.696080182280858*^9}, {
   3.6960803099666367`*^9, 3.6960803248461246`*^9}, 3.696080402524456*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"AM3", "=", 
   RowBox[{"DeleteCases", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"Reap", "[", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{
             RowBox[{"FirstArrows", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "**", 
             RowBox[{"AM2", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "AM2", "]"}]}], "}"}]}], "]"}], "]"}], 
      "]"}], ",", "Null"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6944469530020237`*^9, 3.694446961552383*^9}, {
   3.696080184008513*^9, 3.6960801846165657`*^9}, {3.696080222457225*^9, 
   3.696080272223153*^9}, {3.6960803495098467`*^9, 3.6960803520531397`*^9}, 
   3.696080404492626*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"AM4", "=", 
   RowBox[{"DeleteCases", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"Reap", "[", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{
             RowBox[{"SecondArrows", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "**", 
             RowBox[{"AM3", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "AM3", "]"}]}], "}"}]}], "]"}], "]"}], 
      "]"}], ",", "Null"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.694443252529624*^9, 3.6944433328231487`*^9}, {
   3.694443369481969*^9, 3.694443380283029*^9}, {3.694446839242278*^9, 
   3.694446844242135*^9}, 3.694446974098028*^9, {3.696080186096465*^9, 
   3.696080186672841*^9}, {3.696080328870071*^9, 3.696080356717806*^9}, 
   3.696080406356653*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"AM5", "=", 
   RowBox[{"DeleteCases", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"Reap", "[", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{
             RowBox[{"FirstArrows", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "**", 
             RowBox[{"AM4", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "AM4", "]"}]}], "}"}]}], "]"}], "]"}], 
      "]"}], ",", "Null"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.694449057323917*^9, 3.694449067818205*^9}, {
   3.696080190256682*^9, 3.696080190752058*^9}, {3.69608028172684*^9, 
   3.696080286606728*^9}, {3.6960803589417543`*^9, 3.696080361813863*^9}, 
   3.696080408588298*^9, {3.696082595049748*^9, 3.696082599440033*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"AM6", "=", 
   RowBox[{"DeleteCases", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"Reap", "[", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{
             RowBox[{"SecondArrows", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "**", 
             RowBox[{"AM5", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "AM5", "]"}]}], "}"}]}], "]"}], "]"}], 
      "]"}], ",", "Null"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6944490781317*^9, 3.6944490880735617`*^9}, {
   3.6960801930245256`*^9, 3.696080193496744*^9}, {3.69608033485385*^9, 
   3.696080366661558*^9}, 3.696080410884754*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"AM7", "=", 
   RowBox[{"DeleteCases", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"Reap", "[", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{
             RowBox[{"FirstArrows", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "**", 
             RowBox[{"AM6", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "AM6", "]"}]}], "}"}]}], "]"}], "]"}], 
      "]"}], ",", "Null"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.695386224450643*^9, 3.6953862367004633`*^9}, {
   3.696080195256547*^9, 3.6960801957606564`*^9}, {3.6960802959267807`*^9, 
   3.696080302262693*^9}, {3.6960803689896193`*^9, 3.696080372045405*^9}, 
   3.696080413388112*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"AM8", "=", 
   RowBox[{"DeleteCases", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"Reap", "[", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{
             RowBox[{"SecondArrows", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "**", 
             RowBox[{"AM7", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "AM7", "]"}]}], "}"}]}], "]"}], "]"}], 
      "]"}], ",", "Null"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.695390175003224*^9, 3.695390185363171*^9}, {
   3.6960801980566063`*^9, 3.696080198968648*^9}, {3.696080340997861*^9, 
   3.696080343430153*^9}, {3.6960803743014708`*^9, 3.6960803775732393`*^9}, 
   3.696080419331387*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"AM9", "=", 
   RowBox[{"DeleteCases", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"Reap", "[", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{
             RowBox[{"FirstArrows", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "**", 
             RowBox[{"AM8", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "AM8", "]"}]}], "}"}]}], "]"}], "]"}], 
      "]"}], ",", "Null"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.696080387950086*^9, 3.696080422260096*^9}, {
  3.696080568742351*^9, 3.696080576651141*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"AMall", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", "AM1", "}"}], ",", 
     RowBox[{"{", "AM2", "}"}], ",", 
     RowBox[{"{", "AM3", "}"}], ",", 
     RowBox[{"{", "AM4", "}"}], ",", 
     RowBox[{"{", "AM5", "}"}], ",", 
     RowBox[{"{", "AM6", "}"}], ",", 
     RowBox[{"{", "AM7", "}"}], ",", 
     RowBox[{"{", "AM8", "}"}], ",", 
     RowBox[{"{", "AM9", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.696080587564233*^9, 3.696080610210466*^9}, 
   3.696082418644086*^9}],

Cell["\<\
Now we construct list of all possible arrow monomials with given degree \
(number of arrows). These are constructed by looking at all possible way one \
can decompose the degree into different vectors, that is the partitions of \
the degree\
\>", "Text",
 CellChangeTimes->{{3.696080907414847*^9, 3.696080909694448*^9}, {
  3.6960809803672447`*^9, 3.6960809818151293`*^9}, {3.696081014875066*^9, 
  3.69608109716483*^9}}],

Cell["\<\
These functions takes a partition and then selects from the list AMall \
various Arrow Monomials of length corresponding to the partition. In doing so \
we also delete repetitions\
\>", "Text",
 CellChangeTimes->{{3.6960811403317633`*^9, 3.6960811464343767`*^9}, {
  3.696081479932749*^9, 3.6960815306135263`*^9}, {3.6960816711573067`*^9, 
  3.696081688308028*^9}, {3.696081863457199*^9, 3.696081864639627*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PartitionToList", "[", 
   RowBox[{"partition_", ",", "list_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"l", "=", 
      RowBox[{"Length", "[", "partition", "]"}]}], "}"}], ",", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"DeleteCases", "[", 
       RowBox[{
        RowBox[{"Reap", "[", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{"list", "[", 
             RowBox[{"[", 
              RowBox[{"partition", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "l"}], "}"}]}], "]"}], "]"}], ",", 
        "Null"}], "]"}], ",", "2"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.695568680745023*^9, 3.695568692606813*^9}, {
  3.695571832463917*^9, 3.695571937818172*^9}, {3.69557196823566*^9, 
  3.6955719715614223`*^9}, {3.695572022959044*^9, 3.6955720537249317`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"GetAllTuplesFromPartition", "[", 
   RowBox[{"partition_", ",", "list_"}], "]"}], ":=", 
  RowBox[{"Tuples", "[", 
   RowBox[{"PartitionToList", "[", 
    RowBox[{"partition", ",", "list"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6956500079553003`*^9, 3.695650008368025*^9}, {
  3.69565042145817*^9, 3.6956504850412073`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"GetAllTuplesNoRep", "[", 
   RowBox[{"partition_", ",", "list_"}], "]"}], ":=", 
  RowBox[{"Flatten", "[", 
   RowBox[{
    RowBox[{"DeleteCases", "[", 
     RowBox[{
      RowBox[{"Reap", "[", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{
              RowBox[{"GetAllTuplesFromPartition", "[", 
               RowBox[{"partition", ",", "list"}], "]"}], "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}], "\[Equal]", 
            RowBox[{"Length", "[", 
             RowBox[{"DeleteDuplicates", "[", 
              RowBox[{
               RowBox[{"GetAllTuplesFromPartition", "[", 
                RowBox[{"partition", ",", "list"}], "]"}], "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}]}], ",", 
           RowBox[{"Sow", "[", 
            RowBox[{
             RowBox[{"GetAllTuplesFromPartition", "[", 
              RowBox[{"partition", ",", "list"}], "]"}], "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "]"}], 
         "\[IndentingNewLine]", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", 
            RowBox[{"GetAllTuplesFromPartition", "[", 
             RowBox[{"partition", ",", "list"}], "]"}], "]"}]}], "}"}]}], 
        "\[IndentingNewLine]", "]"}], "]"}], ",", "Null"}], "]"}], ",", "2"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.695651059846356*^9, 3.695651087128586*^9}, {
  3.695651124935142*^9, 3.695651127160626*^9}, {3.695651172149747*^9, 
  3.6956511910045652`*^9}}],

Cell["\<\
Now we define a function which finds all arrow monomials such that the \
overall number of arrows is n\
\>", "Text",
 CellChangeTimes->{{3.696082025646329*^9, 3.6960820677679367`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListArrowMonomials", "[", "n_", "]"}], ":=", 
  RowBox[{"DeleteDuplicatesBy", "[", 
   RowBox[{
    RowBox[{"DeleteCases", "[", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"DeleteCases", "[", 
         RowBox[{
          RowBox[{"Reap", "[", 
           RowBox[{"Do", "[", 
            RowBox[{
             RowBox[{"Sow", "[", 
              RowBox[{"GetAllTuplesNoRep", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"IntegerPartitions", "[", "n", "]"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", "AMall"}], "]"}], "]"}],
              ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", 
                RowBox[{"IntegerPartitions", "[", "n", "]"}], "]"}]}], 
              "}"}]}], "]"}], "]"}], ",", "Null"}], "]"}], ",", "3"}], "]"}], 
      ",", 
      RowBox[{"{", "}"}]}], "]"}], ",", "Sort"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.69565129033917*^9, 3.695651372788321*^9}, {
   3.6956514284450207`*^9, 3.6956514407404833`*^9}, {3.695651561619482*^9, 
   3.695651579242825*^9}, {3.695651767999301*^9, 3.695651787115448*^9}, {
   3.695652057844742*^9, 3.6956520674590693`*^9}, {3.695652098456532*^9, 
   3.6956521028562813`*^9}, 3.6960818802029753`*^9, {3.696081994925932*^9, 
   3.696082001669836*^9}}],

Cell["\<\
We use this function to construct lists of arrow monomials with given length\
\>", "Text",
 CellChangeTimes->{{3.696082118816729*^9, 3.6960821295917997`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListArrowMonomials1", "=", 
   RowBox[{"ListArrowMonomials", "[", "1", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6960822394527607`*^9, 3.696082262248074*^9}, 
   3.6960826409763527`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListArrowMonomials2", "=", 
   RowBox[{"ListArrowMonomials", "[", "2", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6960822394527607`*^9, 3.696082262248074*^9}, {
  3.6960826409763527`*^9, 3.696082662398726*^9}, {3.696082702821947*^9, 
  3.696082702853365*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListArrowMonomials3", "=", 
   RowBox[{"ListArrowMonomials", "[", "3", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6960822394527607`*^9, 3.696082262248074*^9}, {
  3.6960826409763527`*^9, 3.6960826645185537`*^9}, {3.696082704502117*^9, 
  3.69608270618178*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListArrowMonomials4", "=", 
   RowBox[{"ListArrowMonomials", "[", "4", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6960822394527607`*^9, 3.696082262248074*^9}, {
  3.6960826409763527`*^9, 3.696082665726849*^9}, {3.696082708438126*^9, 
  3.696082708493882*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListArrowMonomials5", "=", 
   RowBox[{"ListArrowMonomials", "[", "5", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6960822394527607`*^9, 3.696082262248074*^9}, {
  3.6960826409763527`*^9, 3.69608266704638*^9}, {3.696082710149516*^9, 
  3.696082710213934*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListArrowMonomials6", "=", 
   RowBox[{"ListArrowMonomials", "[", "6", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6960822394527607`*^9, 3.696082262248074*^9}, {
  3.6960826409763527`*^9, 3.6960826683426037`*^9}, {3.696082711709764*^9, 
  3.696082711757927*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListArrowMonomials7", "=", 
   RowBox[{"ListArrowMonomials", "[", "7", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6960822394527607`*^9, 3.696082262248074*^9}, {
  3.6960826409763527`*^9, 3.696082670206409*^9}, {3.696082713453843*^9, 
  3.696082713517016*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListArrowMonomials8", "=", 
   RowBox[{"ListArrowMonomials", "[", "8", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6960822394527607`*^9, 3.696082262248074*^9}, 
   3.6960826409763527`*^9, {3.696082671526813*^9, 3.696082671598473*^9}, {
   3.6960827147899017`*^9, 3.696082714840433*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListArrowMonomials9", "=", 
   RowBox[{"ListArrowMonomials", "[", "9", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6960822394527607`*^9, 3.696082262248074*^9}, 
   3.6960826409763527`*^9, {3.696082673902576*^9, 3.696082673966264*^9}, {
   3.696082716237795*^9, 3.696082716286718*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Modules of the algebra of paths of quiver with W", "Section",
 CellChangeTimes->{{3.696078306064847*^9, 3.6960783330128098`*^9}, {
  3.6960830659111567`*^9, 3.696083085382119*^9}}],

Cell["\<\
Now we will start working in CQ/ < d W > .  To do so we have to intruduce the \
equations of motions, as relations\
\>", "Text",
 CellChangeTimes->{{3.6960832741265697`*^9, 3.696083302365419*^9}, {
  3.696083773579509*^9, 3.69608377400249*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EOMasREL", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"b1", "**", "a2", "**", "b2"}], "\[Rule]", 
     RowBox[{"b2", "**", "a2", "**", "b1"}]}], ",", 
    RowBox[{
     RowBox[{"a2", "**", "b2", "**", "a1"}], "\[Rule]", 
     RowBox[{"a1", "**", "b2", "**", "a2"}]}], ",", 
    RowBox[{
     RowBox[{"b2", "**", "a1", "**", "b1"}], "\[Rule]", 
     RowBox[{"b1", "**", "a1", "**", "b2"}]}], ",", 
    RowBox[{
     RowBox[{"a1", "**", "b1", "**", "a2"}], "\[Rule]", 
     RowBox[{"a2", "**", "b1", "**", "a1"}]}], ",", 
    RowBox[{
     RowBox[{"b2", "**", "a2", "**", "b1"}], "->", 
     RowBox[{"b1", "**", "a2", "**", "b2"}]}], ",", 
    RowBox[{
     RowBox[{"a1", "**", "b2", "**", "a2"}], "->", 
     RowBox[{"a2", "**", "b2", "**", "a1"}]}], ",", 
    RowBox[{
     RowBox[{"b1", "**", "a1", "**", "b2"}], "->", 
     RowBox[{"b2", "**", "a1", "**", "b1"}]}], ",", 
    RowBox[{
     RowBox[{"a2", "**", "b1", "**", "a1"}], "->", 
     RowBox[{"a1", "**", "b1", "**", "a2"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.694635648647493*^9, 3.694635755359057*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"b1", "**", "a2", "**", "b2"}], "\[Rule]", 
    RowBox[{"b2", "**", "a2", "**", "b1"}]}], ",", 
   RowBox[{
    RowBox[{"a2", "**", "b2", "**", "a1"}], "\[Rule]", 
    RowBox[{"a1", "**", "b2", "**", "a2"}]}], ",", 
   RowBox[{
    RowBox[{"b2", "**", "a1", "**", "b1"}], "\[Rule]", 
    RowBox[{"b1", "**", "a1", "**", "b2"}]}], ",", 
   RowBox[{
    RowBox[{"a1", "**", "b1", "**", "a2"}], "\[Rule]", 
    RowBox[{"a2", "**", "b1", "**", "a1"}]}], ",", 
   RowBox[{
    RowBox[{"b2", "**", "a2", "**", "b1"}], "\[Rule]", 
    RowBox[{"b1", "**", "a2", "**", "b2"}]}], ",", 
   RowBox[{
    RowBox[{"a1", "**", "b2", "**", "a2"}], "\[Rule]", 
    RowBox[{"a2", "**", "b2", "**", "a1"}]}], ",", 
   RowBox[{
    RowBox[{"b1", "**", "a1", "**", "b2"}], "\[Rule]", 
    RowBox[{"b2", "**", "a1", "**", "b1"}]}], ",", 
   RowBox[{
    RowBox[{"a2", "**", "b1", "**", "a1"}], "\[Rule]", 
    RowBox[{"a1", "**", "b1", "**", "a2"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.696083342298593*^9, 3.696366014665637*^9, 
  3.6966891291183167`*^9}]
}, Open  ]],

Cell["\<\
To work in CQ/ < d W > we start from the list of monomials of the previous \
Section and we add the monomials obtained by applying the equations of \
motions. In this way we are preparing the construction of ideals in CQ/ < d W \
>. The following function takes a NC monomials and adds all the copies \
obtained by imposing the equations of motions\
\>", "Text",
 CellChangeTimes->{{3.696083448365149*^9, 3.69608347231593*^9}, {
   3.696083540290093*^9, 3.696083560056962*^9}, {3.696083720636796*^9, 
   3.696083724357018*^9}, {3.69608376097997*^9, 3.6960837799420757`*^9}, {
   3.696084181224518*^9, 3.696084212135277*^9}, 3.696084276743813*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"AddEOMCopies", "[", "list_", "]"}], ":=", 
  RowBox[{"DeleteDuplicates", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"DeleteCases", "[", 
      RowBox[{
       RowBox[{"Reap", "[", 
        RowBox[{"Do", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"SubsetQ", "[", 
             RowBox[{"list", ",", 
              RowBox[{"SubstituteSingleReplace", "[", 
               RowBox[{"list", ",", 
                RowBox[{"EOMasREL", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "]"}], ",", 
            RowBox[{"Sow", "[", "list", "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Sow", "[", 
             RowBox[{"SubstituteSingleReplace", "[", 
              RowBox[{"list", ",", 
               RowBox[{"EOMasREL", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}]}], "]"}], ",", 
          
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "EOMasREL", "]"}]}], "}"}]}], "]"}], "]"}],
        ",", "Null"}], "]"}], ",", "3"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.695481172468844*^9, 3.6954811729385777`*^9}}],

Cell["\<\
To construct ideals we need a function which takes a list of noncommutative \
monomials and finds all the monomials with arrows removed\
\>", "Text",
 CellChangeTimes->{{3.696084285319957*^9, 3.696084349267868*^9}, {
  3.6960843963122797`*^9, 3.696084396928001*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Dismemberf", "[", "ncmonomial_", "]"}], ":=", 
  RowBox[{"Reverse", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{"DeleteCases", "[", 
     RowBox[{
      RowBox[{"Reap", "[", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"Sow", "[", 
          RowBox[{"Drop", "[", 
           RowBox[{"ncmonomial", ",", "i"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", 
           RowBox[{
            RowBox[{"Length", "[", "ncmonomial", "]"}], "-", "1"}]}], "}"}]}],
         "]"}], "]"}], ",", "Null"}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6952119685070972`*^9, 3.695212001537068*^9}, {
   3.695212815156443*^9, 3.695212821500354*^9}, 3.696088367053413*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DismemberListf", "[", "list_", "]"}], ":=", 
  RowBox[{"DeleteDuplicates", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{"DeleteCases", "[", 
     RowBox[{
      RowBox[{"Reap", "[", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"Sow", "[", 
          RowBox[{"Dismemberf", "[", 
           RowBox[{"list", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "list", "]"}]}], "}"}]}], "]"}], "]"}], ",",
       "Null"}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.695212151907083*^9, 3.695212153513612*^9}}],

Cell["\<\
We also construct a series of functions which can check if a list corresponds \
to an ideal or not\
\>", "Text",
 CellChangeTimes->{{3.6960853834827213`*^9, 3.696085397793841*^9}, {
  3.696091341431686*^9, 3.6960913446627493`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EOM", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"b1", "**", "a2", "**", "b2"}], "\[Rule]", 
      RowBox[{"b2", "**", "a2", "**", "b1"}]}], ",", 
     RowBox[{
      RowBox[{"a2", "**", "b2", "**", "a1"}], "\[Rule]", 
      RowBox[{"a1", "**", "b2", "**", "a2"}]}], ",", 
     RowBox[{
      RowBox[{"b2", "**", "a1", "**", "b1"}], "\[Rule]", 
      RowBox[{"b1", "**", "a1", "**", "b2"}]}], ",", 
     RowBox[{
      RowBox[{"a1", "**", "b1", "**", "a2"}], "\[Rule]", 
      RowBox[{"a2", "**", "b1", "**", "a1"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.694438617852241*^9, 3.694438618134637*^9}, {
   3.6944387643999157`*^9, 3.694438789684914*^9}, {3.69443983026794*^9, 
   3.694439861006976*^9}, {3.6944410398885813`*^9, 3.6944410820901937`*^9}, 
   3.6960854672091007`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EOMback", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"b2", "**", "a2", "**", "b1"}], "->", 
      RowBox[{"b1", "**", "a2", "**", "b2"}]}], ",", 
     RowBox[{
      RowBox[{"a1", "**", "b2", "**", "a2"}], "->", 
      RowBox[{"a2", "**", "b2", "**", "a1"}]}], ",", 
     RowBox[{
      RowBox[{"b1", "**", "a1", "**", "b2"}], "->", 
      RowBox[{"b2", "**", "a1", "**", "b1"}]}], ",", 
     RowBox[{
      RowBox[{"a2", "**", "b1", "**", "a1"}], "->", 
      RowBox[{"a1", "**", "b1", "**", "a2"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.694637253821747*^9, 3.6946372652935038`*^9}, 
   3.6960854690478783`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"IsItMember1", "[", 
   RowBox[{"ncmonomial_", ",", "list_"}], "]"}], ":=", 
  RowBox[{"AllTrue", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"DeleteCases", "[", 
      RowBox[{
       RowBox[{"Reap", "[", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"SubsetQ", "[", 
             RowBox[{"list", ",", 
              RowBox[{"DismemberListf", "[", 
               RowBox[{"Substitute", "[", 
                RowBox[{"ncmonomial", ",", "EOM"}], "]"}], "]"}]}], "]"}], 
            ",", 
            RowBox[{"Sow", "[", "0", "]"}], ",", 
            RowBox[{"Sow", "[", "1", "]"}]}], "]"}], "\[IndentingNewLine]", 
          ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "list", "]"}]}], "}"}]}], "]"}], "]"}], 
       ",", "Null"}], "]"}], "]"}], ",", 
    RowBox[{
     RowBox[{"#", "==", "0"}], "&"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IsItMember2", "[", 
   RowBox[{"ncmonomial_", ",", "list_"}], "]"}], ":=", 
  RowBox[{"AllTrue", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"DeleteCases", "[", 
      RowBox[{
       RowBox[{"Reap", "[", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"SubsetQ", "[", 
             RowBox[{"list", ",", 
              RowBox[{"DismemberListf", "[", 
               RowBox[{"Substitute", "[", 
                RowBox[{"ncmonomial", ",", "EOMback"}], "]"}], "]"}]}], "]"}],
             ",", 
            RowBox[{"Sow", "[", "0", "]"}], ",", 
            RowBox[{"Sow", "[", "1", "]"}]}], "]"}], "\[IndentingNewLine]", 
          ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "list", "]"}]}], "}"}]}], "]"}], "]"}], 
       ",", "Null"}], "]"}], "]"}], ",", 
    RowBox[{
     RowBox[{"#", "==", "0"}], "&"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.694862190675912*^9, 3.694862201191827*^9}, {
  3.694866480721037*^9, 3.6948664980139427`*^9}, {3.6960854371478167`*^9, 
  3.69608543901117*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"AmIAnIdeal", "[", "list_", "]"}], ":=", 
  RowBox[{
   RowBox[{"AllTrue", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"DeleteCases", "[", 
       RowBox[{
        RowBox[{"Reap", "[", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{"IsItMember1", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"list", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "}"}], ",", "list"}], "]"}], 
            "]"}], "\[IndentingNewLine]", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "list", "]"}]}], "}"}]}], "]"}], "]"}], 
        ",", "Null"}], "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"#", "==", "True"}], "&"}]}], "]"}], "&&", 
   RowBox[{"AllTrue", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"DeleteCases", "[", 
       RowBox[{
        RowBox[{"Reap", "[", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{"IsItMember2", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"list", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "}"}], ",", "list"}], "]"}], 
            "]"}], "\[IndentingNewLine]", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "list", "]"}]}], "}"}]}], "]"}], "]"}], 
        ",", "Null"}], "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"#", "==", "True"}], "&"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6948646445785913`*^9, 3.694864650745924*^9}}],

Cell["\<\
Now we use the functions defined above to construct ideals in CQ / < d W > . \
An ideal is associated with a cyclic module, and we denote a cyclic module by \
listing all the basis vectors. Each basis vector correspond to a ball in a \
Pyramid Partition. The collection of basis vectors correspond to the full \
Pyramid Partition, which labels a fixed point. There is a redundancy in the \
description since several vectors are identified by the equations d W = 0 . \
As a check we use the function AmIAnIdeal which checks if the module is in CQ \
/ < d W > and is cyclic (this is rather slow).\
\>", "Text",
 CellChangeTimes->{{3.696085684372061*^9, 3.6960857218782377`*^9}, {
  3.6960857696874037`*^9, 3.696085785365965*^9}, {3.69608582353794*^9, 
  3.696085940411621*^9}, {3.696085998760474*^9, 3.696086005968001*^9}, {
  3.696086097211526*^9, 3.696086179723878*^9}, {3.696103267101071*^9, 
  3.696103270604205*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListArrowMonomialsinAdW1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "v", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", 
       RowBox[{"a1", "**", "v"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", 
       RowBox[{"a2", "**", "v"}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.695381920619052*^9, 3.6953819281069183`*^9}, {
  3.696088145765863*^9, 3.696088157269164*^9}, {3.696089007339573*^9, 
  3.696089016625812*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListArrowMonomialsinAdW2", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"DeleteCases", "[", 
      RowBox[{
       RowBox[{"Reap", "[", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{"Sow", "[", 
           RowBox[{"DeleteDuplicates", "[", 
            RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
             RowBox[{"DismemberListf", "[", 
              RowBox[{"DeleteDuplicates", "[", 
               RowBox[{"FixedPoint", "[", 
                RowBox[{"AddEOMCopies", ",", 
                 RowBox[{"ListArrowMonomials2", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}], "]"}], 
             "\[IndentingNewLine]", "]"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "ListArrowMonomials2", "]"}]}], "}"}]}], 
         "]"}], "]"}], ",", "Null"}], "]"}], ",", "2"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.6953185605947123`*^9, {3.695319374626934*^9, 3.695319417977337*^9}, {
   3.695320155966731*^9, 3.695320159011701*^9}, {3.695320201999086*^9, 
   3.695320214024041*^9}, {3.69532038783374*^9, 3.695320390534807*^9}, {
   3.695320799833848*^9, 3.695320800015386*^9}, {3.695322134198882*^9, 
   3.695322145266781*^9}, {3.69608819504996*^9, 3.696088236173609*^9}, 
   3.696088406751504*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AllTrue", "[", 
  RowBox[{
   RowBox[{"AmIAnIdeal", "/@", "ListArrowMonomialsinAdW2"}], ",", 
   RowBox[{
    RowBox[{"#", "==", "True"}], "&"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.69608855017047*^9, 3.6960885502573833`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.696088551121868*^9, 3.696366014981739*^9, 
  3.696689129363563*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListArrowMonomialsinAdW3", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"DeleteCases", "[", 
      RowBox[{
       RowBox[{"Reap", "[", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{"Sow", "[", 
           RowBox[{"DeleteDuplicates", "[", 
            RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
             RowBox[{"DismemberListf", "[", 
              RowBox[{"DeleteDuplicates", "[", 
               RowBox[{"FixedPoint", "[", 
                RowBox[{"AddEOMCopies", ",", 
                 RowBox[{"ListArrowMonomials3", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}], "]"}], 
             "\[IndentingNewLine]", "]"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "ListArrowMonomials3", "]"}]}], "}"}]}], 
         "]"}], "]"}], ",", "Null"}], "]"}], ",", "2"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.6953185605947123`*^9, {3.695319374626934*^9, 3.695319417977337*^9}, {
   3.695320155966731*^9, 3.695320159011701*^9}, {3.695320201999086*^9, 
   3.695320214024041*^9}, {3.69532038783374*^9, 3.695320390534807*^9}, {
   3.695320799833848*^9, 3.695320800015386*^9}, {3.695322134198882*^9, 
   3.695322145266781*^9}, {3.69608819504996*^9, 3.696088236173609*^9}, {
   3.696088406751504*^9, 3.696088425916842*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AllTrue", "[", 
  RowBox[{
   RowBox[{"AmIAnIdeal", "/@", "ListArrowMonomialsinAdW3"}], ",", 
   RowBox[{
    RowBox[{"#", "==", "True"}], "&"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.696088542220516*^9, 3.6960885422574368`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.696088543488792*^9, 3.69636601598237*^9, 
  3.696689130358932*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListArrowMonomialsinAdW4", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"DeleteCases", "[", 
      RowBox[{
       RowBox[{"Reap", "[", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{"Sow", "[", 
           RowBox[{"DeleteDuplicates", "[", 
            RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
             RowBox[{"DismemberListf", "[", 
              RowBox[{"DeleteDuplicates", "[", 
               RowBox[{"FixedPoint", "[", 
                RowBox[{"AddEOMCopies", ",", 
                 RowBox[{"ListArrowMonomials4", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}], "]"}], 
             "\[IndentingNewLine]", "]"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "ListArrowMonomials4", "]"}]}], "}"}]}], 
         "]"}], "]"}], ",", "Null"}], "]"}], ",", "2"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.6953185605947123`*^9, {3.695319374626934*^9, 3.695319417977337*^9}, {
   3.695320155966731*^9, 3.695320159011701*^9}, {3.695320201999086*^9, 
   3.695320214024041*^9}, {3.69532038783374*^9, 3.695320390534807*^9}, {
   3.695320799833848*^9, 3.695320800015386*^9}, {3.695322134198882*^9, 
   3.695322145266781*^9}, {3.69608819504996*^9, 3.696088236173609*^9}, {
   3.696088406751504*^9, 3.696088472436492*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AllTrue", "[", 
  RowBox[{
   RowBox[{"AmIAnIdeal", "/@", "ListArrowMonomialsinAdW4"}], ",", 
   RowBox[{
    RowBox[{"#", "==", "True"}], "&"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.696088488420977*^9, 3.696088490794971*^9}, {
  3.6960885267742*^9, 3.696088526942134*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.696088485836761*^9, 3.696088497268549*^9}, 
   3.696088533357233*^9, 3.6963660223726377`*^9, 3.696689136210129*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListArrowMonomialsinAdW5", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"DeleteCases", "[", 
      RowBox[{
       RowBox[{"Reap", "[", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{"Sow", "[", 
           RowBox[{"DeleteDuplicates", "[", 
            RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
             RowBox[{"DismemberListf", "[", 
              RowBox[{"DeleteDuplicates", "[", 
               RowBox[{"FixedPoint", "[", 
                RowBox[{"AddEOMCopies", ",", 
                 RowBox[{"ListArrowMonomials5", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}], "]"}], 
             "\[IndentingNewLine]", "]"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "ListArrowMonomials5", "]"}]}], "}"}]}], 
         "]"}], "]"}], ",", "Null"}], "]"}], ",", "2"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.6953185605947123`*^9, {3.695319374626934*^9, 3.695319417977337*^9}, {
   3.695320155966731*^9, 3.695320159011701*^9}, {3.695320201999086*^9, 
   3.695320214024041*^9}, {3.69532038783374*^9, 3.695320390534807*^9}, {
   3.695320799833848*^9, 3.695320800015386*^9}, {3.695322134198882*^9, 
   3.695322145266781*^9}, {3.69608819504996*^9, 3.696088236173609*^9}, {
   3.696088406751504*^9, 3.696088472436492*^9}, {3.6960885899884872`*^9, 
   3.69608860118638*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AllTrue", "[", 
  RowBox[{
   RowBox[{"AmIAnIdeal", "/@", "ListArrowMonomialsinAdW5"}], ",", 
   RowBox[{
    RowBox[{"#", "==", "True"}], "&"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.696088488420977*^9, 3.696088490794971*^9}, {
  3.6960885267742*^9, 3.696088526942134*^9}, {3.696088604274531*^9, 
  3.696088604330608*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.6963660641864233`*^9, 3.696689174315095*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListArrowMonomialsinAdW6", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"DeleteCases", "[", 
      RowBox[{
       RowBox[{"Reap", "[", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{"Sow", "[", 
           RowBox[{"DeleteDuplicates", "[", 
            RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
             RowBox[{"DismemberListf", "[", 
              RowBox[{"DeleteDuplicates", "[", 
               RowBox[{"FixedPoint", "[", 
                RowBox[{"AddEOMCopies", ",", 
                 RowBox[{"ListArrowMonomials6", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}], "]"}], 
             "\[IndentingNewLine]", "]"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "ListArrowMonomials6", "]"}]}], "}"}]}], 
         "]"}], "]"}], ",", "Null"}], "]"}], ",", "2"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.6953185605947123`*^9, {3.695319374626934*^9, 3.695319417977337*^9}, {
   3.695320155966731*^9, 3.695320159011701*^9}, {3.695320201999086*^9, 
   3.695320214024041*^9}, {3.69532038783374*^9, 3.695320390534807*^9}, {
   3.695320799833848*^9, 3.695320800015386*^9}, {3.695322134198882*^9, 
   3.695322145266781*^9}, {3.69608819504996*^9, 3.696088236173609*^9}, {
   3.696088406751504*^9, 3.696088472436492*^9}, {3.696088610396235*^9, 
   3.6960886144984818`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AllTrue", "[", 
  RowBox[{
   RowBox[{"AmIAnIdeal", "/@", "ListArrowMonomialsinAdW6"}], ",", 
   RowBox[{
    RowBox[{"#", "==", "True"}], "&"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.696088488420977*^9, 3.696088490794971*^9}, {
  3.6960885267742*^9, 3.696088526942134*^9}, {3.696088616851862*^9, 
  3.696088616898114*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.696366322471696*^9, 3.696689408329211*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListArrowMonomialsinAdW7", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"DeleteCases", "[", 
      RowBox[{
       RowBox[{"Reap", "[", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{"Sow", "[", 
           RowBox[{"DeleteDuplicates", "[", 
            RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
             RowBox[{"DismemberListf", "[", 
              RowBox[{"DeleteDuplicates", "[", 
               RowBox[{"FixedPoint", "[", 
                RowBox[{"AddEOMCopies", ",", 
                 RowBox[{"ListArrowMonomials7", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}], "]"}], 
             "\[IndentingNewLine]", "]"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "ListArrowMonomials7", "]"}]}], "}"}]}], 
         "]"}], "]"}], ",", "Null"}], "]"}], ",", "2"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.6953185605947123`*^9, {3.695319374626934*^9, 3.695319417977337*^9}, {
   3.695320155966731*^9, 3.695320159011701*^9}, {3.695320201999086*^9, 
   3.695320214024041*^9}, {3.69532038783374*^9, 3.695320390534807*^9}, {
   3.695320799833848*^9, 3.695320800015386*^9}, {3.695322134198882*^9, 
   3.695322145266781*^9}, {3.69608819504996*^9, 3.696088236173609*^9}, {
   3.696088406751504*^9, 3.696088472436492*^9}, {3.6960886241147337`*^9, 
   3.6960886280103283`*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"AllTrue", "[", 
   RowBox[{
    RowBox[{"AmIAnIdeal", "/@", "ListArrowMonomialsinAdW7"}], ",", 
    RowBox[{
     RowBox[{"#", "==", "True"}], "&"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.696088488420977*^9, 3.696088490794971*^9}, {
  3.6960885267742*^9, 3.696088526942134*^9}, {3.6960886312431*^9, 
  3.696088631305829*^9}, {3.6963647140202007`*^9, 3.696364714682056*^9}},
 EmphasizeSyntaxErrors->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListArrowMonomialsinAdW8", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"DeleteCases", "[", 
      RowBox[{
       RowBox[{"Reap", "[", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{"Sow", "[", 
           RowBox[{"DeleteDuplicates", "[", 
            RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
             RowBox[{"DismemberListf", "[", 
              RowBox[{"DeleteDuplicates", "[", 
               RowBox[{"FixedPoint", "[", 
                RowBox[{"AddEOMCopies", ",", 
                 RowBox[{"ListArrowMonomials8", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}], "]"}], 
             "\[IndentingNewLine]", "]"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "ListArrowMonomials8", "]"}]}], "}"}]}], 
         "]"}], "]"}], ",", "Null"}], "]"}], ",", "2"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.6953185605947123`*^9, {3.695319374626934*^9, 3.695319417977337*^9}, {
   3.695320155966731*^9, 3.695320159011701*^9}, {3.695320201999086*^9, 
   3.695320214024041*^9}, {3.69532038783374*^9, 3.695320390534807*^9}, {
   3.695320799833848*^9, 3.695320800015386*^9}, {3.695322134198882*^9, 
   3.695322145266781*^9}, {3.69608819504996*^9, 3.696088236173609*^9}, {
   3.696088406751504*^9, 3.696088472436492*^9}, {3.696088639874175*^9, 
   3.6960886449859667`*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"AllTrue", "[", 
   RowBox[{
    RowBox[{"AmIAnIdeal", "/@", "ListArrowMonomialsinAdW8"}], ",", 
    RowBox[{
     RowBox[{"#", "==", "True"}], "&"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.696088488420977*^9, 3.696088490794971*^9}, {
  3.6960885267742*^9, 3.696088526942134*^9}, {3.6960886476577682`*^9, 
  3.6960886477212276`*^9}, {3.6963647171377296`*^9, 3.696364717562091*^9}},
 EmphasizeSyntaxErrors->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListArrowMonomialsinAdW9", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"DeleteCases", "[", 
      RowBox[{
       RowBox[{"Reap", "[", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{"Sow", "[", 
           RowBox[{"DeleteDuplicates", "[", 
            RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
             RowBox[{"DismemberListf", "[", 
              RowBox[{"DeleteDuplicates", "[", 
               RowBox[{"FixedPoint", "[", 
                RowBox[{"AddEOMCopies", ",", 
                 RowBox[{"ListArrowMonomials9", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}], "]"}], 
             "\[IndentingNewLine]", "]"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "ListArrowMonomials9", "]"}]}], "}"}]}], 
         "]"}], "]"}], ",", "Null"}], "]"}], ",", "2"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.6953185605947123`*^9, {3.695319374626934*^9, 3.695319417977337*^9}, {
   3.695320155966731*^9, 3.695320159011701*^9}, {3.695320201999086*^9, 
   3.695320214024041*^9}, {3.69532038783374*^9, 3.695320390534807*^9}, {
   3.695320799833848*^9, 3.695320800015386*^9}, {3.695322134198882*^9, 
   3.695322145266781*^9}, {3.69608819504996*^9, 3.696088236173609*^9}, {
   3.696088406751504*^9, 3.696088472436492*^9}, {3.696088654402783*^9, 
   3.6960886582660627`*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"AllTrue", "[", 
   RowBox[{
    RowBox[{"AmIAnIdeal", "/@", "ListArrowMonomialsinAdW9"}], ",", 
    RowBox[{
     RowBox[{"#", "==", "True"}], "&"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.696088488420977*^9, 3.696088490794971*^9}, {
  3.6960885267742*^9, 3.696088526942134*^9}, {3.696088661834796*^9, 
  3.69608866188173*^9}, {3.696364726537244*^9, 3.6963647269379253`*^9}},
 EmphasizeSyntaxErrors->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListOfModules", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
    "ListArrowMonomialsinAdW1", ",", "ListArrowMonomialsinAdW2", ",", 
     "ListArrowMonomialsinAdW3", ",", "ListArrowMonomialsinAdW4", ",", 
     "ListArrowMonomialsinAdW5", ",", "ListArrowMonomialsinAdW6", ",", 
     "ListArrowMonomialsinAdW7", ",", "ListArrowMonomialsinAdW8", ",", 
     "ListArrowMonomialsinAdW9"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.69608895091691*^9, 3.696088986279904*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["From modules to fixed points", "Section",
 CellChangeTimes->{{3.696078306064847*^9, 3.6960783330128098`*^9}, {
  3.696078469498314*^9, 3.696078473880707*^9}}],

Cell["\<\
Cyclic modules correspond to fixed points. To use in the localization formula \
we need the isoptypical decomposition of the vector spaces V0 and V1 and the \
virtual tangent space. In this section we will write functions which take \
ListOfModules and turns into a list of isotypical dec of the form {V0,V1} at \
each fixed point\
\>", "Text",
 CellChangeTimes->{{3.696089476056698*^9, 3.696089564158605*^9}}],

Cell["\<\
To avoid repetition in {V0,V1} we need to remove the vectors which are \
linearly dependent when using the equations d W = 0. We do this using the \
function NCsimplifyAll\
\>", "Text",
 CellChangeTimes->{{3.696089585303013*^9, 3.696089630342716*^9}, {
  3.696089983962875*^9, 3.6960899907376204`*^9}, {3.6960900288539667`*^9, 
  3.696090033646048*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EOM2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"b1", "**", "a2", "**", "b2"}], "-", 
      RowBox[{"b2", "**", "a2", "**", "b1"}]}], ",", 
     RowBox[{
      RowBox[{"a2", "**", "b2", "**", "a1"}], "-", 
      RowBox[{"a1", "**", "b2", "**", "a2"}]}], ",", 
     RowBox[{
      RowBox[{"b2", "**", "a1", "**", "b1"}], "-", 
      RowBox[{"b1", "**", "a1", "**", "b2"}]}], ",", 
     RowBox[{
      RowBox[{"a1", "**", "b1", "**", "a2"}], "-", 
      RowBox[{"a2", "**", "b1", "**", "a1"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{3.696090000299695*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"LMAsimplified1", "=", 
   RowBox[{"DeleteDuplicates", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"DeleteCases", "[", 
       RowBox[{
        RowBox[{"Reap", "[", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{"DeleteDuplicates", "[", 
             RowBox[{"NCSimplifyAll", "[", 
              RowBox[{
               RowBox[{"ListArrowMonomialsinAdW1", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", "EOM2", ",", "10"}], 
              "]"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "ListArrowMonomialsinAdW1", "]"}]}], 
            "}"}]}], "]"}], "]"}], ",", "Null"}], "]"}], ",", "2"}], "]"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.695549345196331*^9, 3.6955493612468767`*^9}, {
  3.6960900532865753`*^9, 3.6960900707182093`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"LMAsimplified2", "=", 
   RowBox[{"DeleteDuplicates", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"DeleteCases", "[", 
       RowBox[{
        RowBox[{"Reap", "[", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{"DeleteDuplicates", "[", 
             RowBox[{"NCSimplifyAll", "[", 
              RowBox[{
               RowBox[{"ListArrowMonomialsinAdW2", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", "EOM2", ",", "10"}], 
              "]"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "ListArrowMonomialsinAdW2", "]"}]}], 
            "}"}]}], "]"}], "]"}], ",", "Null"}], "]"}], ",", "2"}], "]"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.695549345196331*^9, 3.6955493612468767`*^9}, {
  3.6960900532865753`*^9, 3.696090096708495*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"LMAsimplified3", "=", 
   RowBox[{"DeleteDuplicates", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"DeleteCases", "[", 
       RowBox[{
        RowBox[{"Reap", "[", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{"DeleteDuplicates", "[", 
             RowBox[{"NCSimplifyAll", "[", 
              RowBox[{
               RowBox[{"ListArrowMonomialsinAdW3", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", "EOM2", ",", "10"}], 
              "]"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "ListArrowMonomialsinAdW3", "]"}]}], 
            "}"}]}], "]"}], "]"}], ",", "Null"}], "]"}], ",", "2"}], "]"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.695549345196331*^9, 3.6955493612468767`*^9}, {
  3.6960900532865753`*^9, 3.6960900707182093`*^9}, {3.6960901044609528`*^9, 
  3.6960901098920717`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"LMAsimplified4", "=", 
   RowBox[{"DeleteDuplicates", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"DeleteCases", "[", 
       RowBox[{
        RowBox[{"Reap", "[", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{"DeleteDuplicates", "[", 
             RowBox[{"NCSimplifyAll", "[", 
              RowBox[{
               RowBox[{"ListArrowMonomialsinAdW4", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", "EOM2", ",", "10"}], 
              "]"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "ListArrowMonomialsinAdW4", "]"}]}], 
            "}"}]}], "]"}], "]"}], ",", "Null"}], "]"}], ",", "2"}], "]"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.695549345196331*^9, 3.6955493612468767`*^9}, {
  3.6960900532865753`*^9, 3.6960900707182093`*^9}, {3.696090115636174*^9, 
  3.696090120947281*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"LMAsimplified5", "=", 
   RowBox[{"DeleteDuplicates", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"DeleteCases", "[", 
       RowBox[{
        RowBox[{"Reap", "[", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{"DeleteDuplicates", "[", 
             RowBox[{"NCSimplifyAll", "[", 
              RowBox[{
               RowBox[{"ListArrowMonomialsinAdW5", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", "EOM2", ",", "10"}], 
              "]"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "ListArrowMonomialsinAdW5", "]"}]}], 
            "}"}]}], "]"}], "]"}], ",", "Null"}], "]"}], ",", "2"}], "]"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.695549345196331*^9, 3.6955493612468767`*^9}, {
  3.6960900532865753`*^9, 3.6960900707182093`*^9}, {3.696090130253196*^9, 
  3.696090134659629*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"LMAsimplified6", "=", 
   RowBox[{"DeleteDuplicates", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"DeleteCases", "[", 
       RowBox[{
        RowBox[{"Reap", "[", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{"DeleteDuplicates", "[", 
             RowBox[{"NCSimplifyAll", "[", 
              RowBox[{
               RowBox[{"ListArrowMonomialsinAdW6", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", "EOM2", ",", "10"}], 
              "]"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "ListArrowMonomialsinAdW6", "]"}]}], 
            "}"}]}], "]"}], "]"}], ",", "Null"}], "]"}], ",", "2"}], "]"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.695549345196331*^9, 3.6955493612468767`*^9}, {
  3.6960900532865753`*^9, 3.6960900707182093`*^9}, {3.696090140147744*^9, 
  3.696090145323477*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"LMAsimplified7", "=", 
   RowBox[{"DeleteDuplicates", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"DeleteCases", "[", 
       RowBox[{
        RowBox[{"Reap", "[", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{"DeleteDuplicates", "[", 
             RowBox[{"NCSimplifyAll", "[", 
              RowBox[{
               RowBox[{"ListArrowMonomialsinAdW7", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", "EOM2", ",", "10"}], 
              "]"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "ListArrowMonomialsinAdW7", "]"}]}], 
            "}"}]}], "]"}], "]"}], ",", "Null"}], "]"}], ",", "2"}], "]"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.695549345196331*^9, 3.6955493612468767`*^9}, {
  3.6960900532865753`*^9, 3.6960900707182093`*^9}, {3.696090148123495*^9, 
  3.696090158362143*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"LMAsimplified8", "=", 
   RowBox[{"DeleteDuplicates", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"DeleteCases", "[", 
       RowBox[{
        RowBox[{"Reap", "[", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{"DeleteDuplicates", "[", 
             RowBox[{"NCSimplifyAll", "[", 
              RowBox[{
               RowBox[{"ListArrowMonomialsinAdW8", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", "EOM2", ",", "10"}], 
              "]"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "ListArrowMonomialsinAdW8", "]"}]}], 
            "}"}]}], "]"}], "]"}], ",", "Null"}], "]"}], ",", "2"}], "]"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.695549345196331*^9, 3.6955493612468767`*^9}, {
  3.6960900532865753`*^9, 3.6960900707182093`*^9}, {3.6960901633709507`*^9, 
  3.6960901694034033`*^9}}],

Cell["Next takes about 3 hours", "Text",
 CellChangeTimes->{{3.696104139098236*^9, 3.6961041428413877`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"LMAsimplified9", "=", 
   RowBox[{"DeleteDuplicates", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"DeleteCases", "[", 
       RowBox[{
        RowBox[{"Reap", "[", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{"DeleteDuplicates", "[", 
             RowBox[{"NCSimplifyAll", "[", 
              RowBox[{
               RowBox[{"ListArrowMonomialsinAdW9", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", "EOM2", ",", "10"}], 
              "]"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "ListArrowMonomialsinAdW9", "]"}]}], 
            "}"}]}], "]"}], "]"}], ",", "Null"}], "]"}], ",", "2"}], "]"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.695549345196331*^9, 3.6955493612468767`*^9}, {
  3.6960900532865753`*^9, 3.6960900707182093`*^9}, {3.6960901633709507`*^9, 
  3.696090181897551*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListOfModulesSimplified", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
    "LMAsimplified1", ",", "LMAsimplified2", ",", "LMAsimplified3", ",", 
     "LMAsimplified4", ",", "LMAsimplified5", ",", "LMAsimplified6", ",", 
     "LMAsimplified7", ",", "LMAsimplified8", ",", "LMAsimplified9"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6960902203493977`*^9, 3.696090227294615*^9}, {
   3.696090290397902*^9, 3.6960903083329782`*^9}, 3.696102007568241*^9}],

Cell["\<\
Now we define a function which takes a cyclic module and gives the isotypical \
decomposition in the toric weights of the two vector spaces {V0,V1} at the \
fixed point\
\>", "Text",
 CellChangeTimes->{{3.696090945173283*^9, 3.696090970812146*^9}, {
  3.696091007902482*^9, 3.696091060596233*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"IsoDec", "[", 
   RowBox[{"list_", ",", "ta1_", ",", "ta2_", ",", "tb1_", ",", "tb2_"}], 
   "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"V0", "=", "0"}], ",", 
      RowBox[{"V1", "=", "0"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"EvenQ", "[", 
          RowBox[{"Length", "[", 
           RowBox[{"list", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}], ",", 
         RowBox[{"V1", "+=", 
          RowBox[{
           RowBox[{"CommuteEverything", "[", 
            RowBox[{"list", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}], "/", "v"}]}], ",", 
         RowBox[{"V0", "+=", 
          RowBox[{
           RowBox[{"CommuteEverything", "[", 
            RowBox[{"list", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}], "/", "v"}]}]}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "list", "]"}]}], "}"}]}], "]"}], " ", ";", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"V0", "+", "1"}], ",", 
        RowBox[{"V1", "-", "1"}]}], "}"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a1", "\[Rule]", 
         RowBox[{"1", "/", "ta1"}]}], ",", 
        RowBox[{"a2", "\[Rule]", 
         RowBox[{"1", "/", "ta2"}]}], ",", 
        RowBox[{"b1", "\[Rule]", 
         RowBox[{"1", "/", "tb1"}]}], ",", 
        RowBox[{"b2", "\[Rule]", 
         RowBox[{"1", "/", "tb2"}]}]}], "}"}]}]}]}], "]"}]}]], "Input"],

Cell["\<\
Now we define a function which gives the isotypical decomposition together \
with the dimension (d0,d1)\
\>", "Text",
 CellChangeTimes->{{3.696091081636816*^9, 3.696091110643299*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"InfoFP", "[", 
   RowBox[{"list_", ",", "ta1_", ",", "ta2_", ",", "tb1_", ",", "tb2_"}], 
   "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"IsoDec", "[", 
        RowBox[{"list", ",", "1", ",", "1", ",", "1", ",", "1"}], "]"}], "[", 
       
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"IsoDec", "[", 
        RowBox[{"list", ",", "1", ",", "1", ",", "1", ",", "1"}], "]"}], "[", 
       
       RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"IsoDec", "[", 
        RowBox[{"list", ",", "ta1", ",", "ta2", ",", "tb1", ",", "tb2"}], 
        "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"IsoDec", "[", 
        RowBox[{"list", ",", "ta1", ",", "ta2", ",", "tb1", ",", "tb2"}], 
        "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6950446562894487`*^9, 3.695044754339397*^9}}],

Cell["\<\
Finally we construct a list with all the fixed point, in the format \
{(d0,d1),(V0,V1)}. We save the list for future reference, so that we don\
\[CloseCurlyQuote]t have to redo this Section again\
\>", "Text",
 CellChangeTimes->{{3.696091808263548*^9, 3.696091872798195*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListOfFixedPointsWithDim", "=", 
  RowBox[{"DeleteDuplicates", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"DeleteCases", "[", 
      RowBox[{
       RowBox[{"Reap", "[", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{"Sow", "[", 
           RowBox[{"InfoFP", "[", 
            RowBox[{
             RowBox[{"ListOfModulesSimplified", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", "ta1", ",", "ta2", ",", 
             "tb1", ",", "tb2"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "ListOfModulesSimplified", "]"}]}], 
           "}"}]}], "]"}], "]"}], ",", "Null"}], "]"}], ",", "2"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6951103825774918`*^9, 3.69511039454388*^9}, {
  3.695111878453515*^9, 3.695111977470874*^9}, {3.695112464666562*^9, 
  3.695112468257825*^9}, {3.696102090977523*^9, 3.696102095694419*^9}}],

Cell[BoxData[
 InterpretationBox[
  TagBox[
   FrameBox[GridBox[{
      {
       ItemBox[
        TagBox[
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"1", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "0"}], "}"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"1", ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", 
               FractionBox["1", "ta1"]}], "}"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"1", ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", 
               FractionBox["1", "ta2"]}], "}"}]}], "}"}], ",", 
           TemplateBox[{"775"},
            "OutputSizeLimit`Skeleton",
            DisplayFunction->(FrameBox[
              RowBox[{"\" \[CenterEllipsis]\"", #, "\"\[CenterEllipsis] \""}],
               Background -> GrayLevel[0.75], 
              BaseStyle -> {
               "Deploy", FontColor -> GrayLevel[1], FontSize -> Smaller, 
                ShowStringCharacters -> False}, BaselinePosition -> Baseline, 
              ContentPadding -> False, FrameMargins -> {{1, 1}, {1, 2}}, 
              FrameStyle -> None, RoundingRadius -> 7]& )], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"5", ",", "3"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "+", 
                FractionBox["1", 
                 RowBox[{"ta1", " ", "tb1"}]], "+", 
                FractionBox["1", 
                 RowBox[{"ta2", " ", "tb1"}]], "+", 
                FractionBox["1", 
                 RowBox[{"ta1", " ", "tb2"}]], "+", 
                FractionBox["1", 
                 RowBox[{"ta2", " ", "tb2"}]]}], ",", 
               RowBox[{
                FractionBox["1", "ta1"], "+", 
                FractionBox["1", "ta2"], "+", 
                FractionBox["1", 
                 RowBox[{
                  SuperscriptBox["ta2", "2"], " ", "tb1"}]]}]}], "}"}]}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"5", ",", "3"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "+", 
                FractionBox["1", 
                 RowBox[{"ta1", " ", "tb1"}]], "+", 
                FractionBox["1", 
                 RowBox[{"ta2", " ", "tb1"}]], "+", 
                FractionBox["1", 
                 RowBox[{"ta1", " ", "tb2"}]], "+", 
                FractionBox["1", 
                 RowBox[{"ta2", " ", "tb2"}]]}], ",", 
               RowBox[{
                FractionBox["1", "ta1"], "+", 
                FractionBox["1", "ta2"], "+", 
                FractionBox["1", 
                 RowBox[{
                  SuperscriptBox["ta2", "2"], " ", "tb2"}]]}]}], "}"}]}], 
            "}"}]}], "}"}],
         Short[#, 5]& ],
        BaseStyle->{Deployed -> False},
        StripOnInput->False]},
      {GridBox[{
         {
          TagBox[
           TooltipBox[
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource[
                "FEStrings", "sizeBriefExplanation"], StandardForm],
               ImageSizeCache->{58., {2., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarCategory",
             StripOnInput->False],
            StyleBox[
             DynamicBox[
              ToBoxes[
               FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
               StandardForm]], DynamicUpdating -> True, StripOnInput -> 
             False]],
           Annotation[#, 
            Style[
             Dynamic[
              FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"]], 
             DynamicUpdating -> True], "Tooltip"]& ], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm],
               ImageSizeCache->{50., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            OutputSizeLimit`Defer, 69, 30623606930959070259, 5/2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm],
               ImageSizeCache->{56., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            OutputSizeLimit`Defer, 69, 30623606930959070259, 5 2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm],
               ImageSizeCache->{42., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            OutputSizeLimit`Defer, 69, 30623606930959070259, Infinity],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm],
               ImageSizeCache->{74., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           ButtonFunction:>FrontEndExecute[{
              FrontEnd`SetOptions[
              FrontEnd`$FrontEnd, 
               FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
              FrontEnd`FrontEndToken["PreferencesDialog"]}],
           Evaluator->None,
           Method->"Preemptive"]}
        },
        AutoDelete->False,
        FrameStyle->GrayLevel[0.85],
        GridBoxDividers->{"Columns" -> {False, {True}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{2}}}]}
     },
     DefaultBaseStyle->"Column",
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], 
         Offset[1.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Background->RGBColor[0.9657, 0.9753, 0.9802],
    FrameMargins->{{12, 12}, {0, 15}},
    FrameStyle->GrayLevel[0.85],
    RoundingRadius->5,
    StripOnInput->False],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  Out[69]]], "Output",
 CellChangeTimes->{3.696102046522799*^9, 3.6961021150212803`*^9, 
  3.696377204788081*^9, 3.696700445613041*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{
   "\"\<NCconifoldFixedPoints.mx\>\"", ",", "ListOfFixedPointsWithDim"}], 
   "]"}], "\n"}]], "Input",
 CellChangeTimes->{{3.695495115602536*^9, 3.695495133968495*^9}, {
  3.6954955697129107`*^9, 3.6954955736483803`*^9}, {3.695567560675832*^9, 
  3.69556756223276*^9}, {3.696091899254939*^9, 3.69609190173534*^9}}],

Cell[BoxData[
 InterpretationBox[
  TagBox[
   FrameBox[GridBox[{
      {
       ItemBox[
        TagBox[
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", "0"}], "}"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", 
                FractionBox["1", "ta1"]}], "}"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", 
                FractionBox["1", "ta2"]}], "}"}]}], "}"}], ",", 
            TemplateBox[{"775"},
             "OutputSizeLimit`Skeleton",
             DisplayFunction->(FrameBox[
               
               RowBox[{
                "\" \[CenterEllipsis]\"", #, "\"\[CenterEllipsis] \""}], 
               Background -> GrayLevel[0.75], 
               BaseStyle -> {
                "Deploy", FontColor -> GrayLevel[1], FontSize -> Smaller, 
                 ShowStringCharacters -> False}, BaselinePosition -> Baseline,
                ContentPadding -> False, FrameMargins -> {{1, 1}, {1, 2}}, 
               FrameStyle -> None, RoundingRadius -> 7]& )], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"5", ",", "3"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "+", 
                 FractionBox["1", 
                  RowBox[{"ta1", " ", "tb1"}]], "+", 
                 FractionBox["1", 
                  RowBox[{"ta2", " ", "tb1"}]], "+", 
                 FractionBox["1", 
                  RowBox[{"ta1", " ", "tb2"}]], "+", 
                 FractionBox["1", 
                  RowBox[{"ta2", " ", "tb2"}]]}], ",", 
                RowBox[{
                 FractionBox["1", "ta1"], "+", 
                 FractionBox["1", "ta2"], "+", 
                 FractionBox["1", 
                  RowBox[{
                   SuperscriptBox["ta2", "2"], " ", "tb1"}]]}]}], "}"}]}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"5", ",", "3"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "+", 
                 FractionBox["1", 
                  RowBox[{"ta1", " ", "tb1"}]], "+", 
                 FractionBox["1", 
                  RowBox[{"ta2", " ", "tb1"}]], "+", 
                 FractionBox["1", 
                  RowBox[{"ta1", " ", "tb2"}]], "+", 
                 FractionBox["1", 
                  RowBox[{"ta2", " ", "tb2"}]]}], ",", 
                RowBox[{
                 FractionBox["1", "ta1"], "+", 
                 FractionBox["1", "ta2"], "+", 
                 FractionBox["1", 
                  RowBox[{
                   SuperscriptBox["ta2", "2"], " ", "tb2"}]]}]}], "}"}]}], 
             "}"}]}], "}"}], "}"}],
         Short[#, 5]& ],
        BaseStyle->{Deployed -> False},
        StripOnInput->False]},
      {GridBox[{
         {
          TagBox[
           TooltipBox[
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource[
                "FEStrings", "sizeBriefExplanation"], StandardForm],
               ImageSizeCache->{58., {2., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarCategory",
             StripOnInput->False],
            StyleBox[
             DynamicBox[
              ToBoxes[
               FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
               StandardForm]], DynamicUpdating -> True, StripOnInput -> 
             False]],
           Annotation[#, 
            Style[
             Dynamic[
              FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"]], 
             DynamicUpdating -> True], "Tooltip"]& ], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm],
               ImageSizeCache->{50., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            OutputSizeLimit`Defer, 70, 30623606930959070259, 5/2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm],
               ImageSizeCache->{56., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            OutputSizeLimit`Defer, 70, 30623606930959070259, 5 2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm],
               ImageSizeCache->{42., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            OutputSizeLimit`Defer, 70, 30623606930959070259, Infinity],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm],
               ImageSizeCache->{74., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm],
               ImageSizeCache->{74., {0., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           ButtonFunction:>FrontEndExecute[{
              FrontEnd`SetOptions[
              FrontEnd`$FrontEnd, 
               FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
              FrontEnd`FrontEndToken["PreferencesDialog"]}],
           Evaluator->None,
           Method->"Preemptive"]}
        },
        AutoDelete->False,
        FrameStyle->GrayLevel[0.85],
        GridBoxDividers->{"Columns" -> {False, {True}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{2}}}]}
     },
     DefaultBaseStyle->"Column",
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], 
         Offset[1.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Background->RGBColor[0.9657, 0.9753, 0.9802],
    FrameMargins->{{12, 12}, {0, 15}},
    FrameStyle->GrayLevel[0.85],
    RoundingRadius->5,
    StripOnInput->False],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  Out[70]]], "Output",
 CellChangeTimes->{3.696102145449113*^9, 3.6963772050397*^9, 
  3.696700446112152*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Section 2. Localization", "Chapter",
 CellChangeTimes->{{3.696078281929523*^9, 3.696078283168396*^9}, {
  3.6965363994425373`*^9, 3.696536400890162*^9}}],

Cell[CellGroupData[{

Cell["Virtual tangent space and localization in K-theory", "Section",
 CellChangeTimes->{{3.696078306064847*^9, 3.6960783330128098`*^9}, {
  3.696078469498314*^9, 3.696078496847599*^9}, {3.696090901550275*^9, 
  3.696090908221327*^9}}],

Cell["\<\
First we get the list of fixed points from the last Section. It has the form \
{(d0,d1),(V0,V1)}\
\>", "Text",
 CellChangeTimes->{{3.696100305319282*^9, 3.696100332661668*^9}}],

Cell[BoxData[
 RowBox[{"Get", "[", "\"\<NCconifoldFixedPoints.mx\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.6954956055346327`*^9, 3.6954956127237587`*^9}, 
   3.695567569050885*^9, {3.696091917078689*^9, 3.696091920486793*^9}}],

Cell["\<\
The following function finds all fixed points with fixed dimension (d0,d1)\
\>", "Text",
 CellChangeTimes->{{3.696100346286187*^9, 3.696100362549302*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindFPofDim", "[", 
   RowBox[{"d0_", ",", "d1_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"DeleteDuplicates", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"DeleteCases", "[", 
      RowBox[{
       RowBox[{"Reap", "[", 
        RowBox[{"Do", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"ListOfFixedPointsWithDim", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], "==", 
             RowBox[{"{", 
              RowBox[{"d0", ",", "d1"}], "}"}]}], ",", 
            RowBox[{"Sow", "[", 
             RowBox[{
              RowBox[{"ListOfFixedPointsWithDim", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "[", 
              RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "ListOfFixedPointsWithDim", "]"}]}], 
           "}"}]}], "]"}], "]"}], ",", "Null"}], "]"}], ",", "2"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6951124487063313`*^9, 3.695112452338017*^9}, {
  3.695112489209691*^9, 3.6951124966394777`*^9}, {3.696071818309619*^9, 
  3.696071823027556*^9}}],

Cell["\<\
The next function is the virtual tangent space for the framed conifold \
quiver. Here k is the determinant of the toric action, k=ta1 ta2 tb1 tb2\
\>", "Text",
 CellChangeTimes->{{3.6961003874218082`*^9, 3.6961004148764544`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TvirConifold", "[", 
   RowBox[{"ta1_", ",", "ta2_", ",", "tb1_", ",", "tb2_", ",", "k_"}], "]"}], 
  ":=", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"ta1", "+", "ta2"}], ")"}], " ", 
     RowBox[{"V0", "[", 
      RowBox[{
       RowBox[{"1", "/", "ta1"}], ",", 
       RowBox[{"1", "/", "ta2"}], ",", 
       RowBox[{"1", "/", "tb1"}], ",", 
       RowBox[{"1", "/", "tb2"}]}], "]"}], " ", 
     RowBox[{"V1", "[", 
      RowBox[{"ta1", ",", "ta2", ",", "tb1", ",", "tb2"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"tb1", "+", "tb2"}], ")"}], 
     RowBox[{"V1", "[", 
      RowBox[{
       RowBox[{"1", "/", "ta1"}], ",", 
       RowBox[{"1", "/", "ta2"}], ",", 
       RowBox[{"1", "/", "tb1"}], ",", 
       RowBox[{"1", "/", "tb2"}]}], "]"}], " ", 
     RowBox[{"V0", "[", 
      RowBox[{"ta1", ",", "ta2", ",", "tb1", ",", "tb2"}], "]"}]}], "+", 
    RowBox[{"V0", "[", 
     RowBox[{"ta1", ",", "ta2", ",", "tb1", ",", "tb2"}], "]"}], "-", " ", 
    RowBox[{
     RowBox[{"V0", "[", 
      RowBox[{
       RowBox[{"1", "/", "ta1"}], ",", 
       RowBox[{"1", "/", "ta2"}], ",", 
       RowBox[{"1", "/", "tb1"}], ",", 
       RowBox[{"1", "/", "tb2"}]}], "]"}], " ", 
     RowBox[{"V0", "[", 
      RowBox[{"ta1", ",", "ta2", ",", "tb1", ",", "tb2"}], "]"}]}], "-", " ", 
    
    RowBox[{
     RowBox[{"V1", "[", 
      RowBox[{
       RowBox[{"1", "/", "ta1"}], ",", 
       RowBox[{"1", "/", "ta2"}], ",", 
       RowBox[{"1", "/", "tb1"}], ",", 
       RowBox[{"1", "/", "tb2"}]}], "]"}], " ", 
     RowBox[{"V1", "[", 
      RowBox[{"ta1", ",", "ta2", ",", "tb1", ",", "tb2"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"(", "k", ")"}], 
     RowBox[{"(", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1", "/", "ta1"}], "+", 
          RowBox[{"1", "/", "ta2"}]}], ")"}], " ", 
        RowBox[{"V1", "[", 
         RowBox[{
          RowBox[{"1", "/", "ta1"}], ",", 
          RowBox[{"1", "/", "ta2"}], ",", 
          RowBox[{"1", "/", "tb1"}], ",", 
          RowBox[{"1", "/", "tb2"}]}], "]"}], " ", 
        RowBox[{"V0", "[", 
         RowBox[{"ta1", ",", "ta2", ",", "tb1", ",", "tb2"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1", "/", "tb1"}], "+", 
          RowBox[{"1", "/", "tb2"}]}], ")"}], 
        RowBox[{"V0", "[", 
         RowBox[{
          RowBox[{"1", "/", "ta1"}], ",", 
          RowBox[{"1", "/", "ta2"}], ",", 
          RowBox[{"1", "/", "tb1"}], ",", 
          RowBox[{"1", "/", "tb2"}]}], "]"}], " ", 
        RowBox[{"V1", "[", 
         RowBox[{"ta1", ",", "ta2", ",", "tb1", ",", "tb2"}], "]"}]}], "+", 
       RowBox[{"V0", "[", 
        RowBox[{
         RowBox[{"1", "/", "ta1"}], ",", 
         RowBox[{"1", "/", "ta2"}], ",", 
         RowBox[{"1", "/", "tb1"}], ",", 
         RowBox[{"1", "/", "tb2"}]}], "]"}], "-", " ", 
       RowBox[{
        RowBox[{"V0", "[", 
         RowBox[{
          RowBox[{"1", "/", "ta1"}], ",", 
          RowBox[{"1", "/", "ta2"}], ",", 
          RowBox[{"1", "/", "tb1"}], ",", 
          RowBox[{"1", "/", "tb2"}]}], "]"}], " ", 
        RowBox[{"V0", "[", 
         RowBox[{"ta1", ",", "ta2", ",", "tb1", ",", "tb2"}], "]"}]}], "-", 
       " ", 
       RowBox[{
        RowBox[{"V1", "[", 
         RowBox[{
          RowBox[{"1", "/", "ta1"}], ",", 
          RowBox[{"1", "/", "ta2"}], ",", 
          RowBox[{"1", "/", "tb1"}], ",", 
          RowBox[{"1", "/", "tb2"}]}], "]"}], " ", 
        RowBox[{"V1", "[", 
         RowBox[{"ta1", ",", "ta2", ",", "tb1", ",", "tb2"}], "]"}]}]}], 
      ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.675432265694211*^9, 3.6754322689574337`*^9}, {
   3.675443251199052*^9, 3.6754432591907587`*^9}, 3.675512616990864*^9, {
   3.6755130546537523`*^9, 3.675513058581429*^9}, {3.6755218231446753`*^9, 
   3.67552182904683*^9}, {3.67552187310526*^9, 3.6755219687187567`*^9}, 
   3.675522515206644*^9, {3.675530174414056*^9, 3.67553017819421*^9}, 
   3.675579758045763*^9, {3.695803354347056*^9, 3.695803355267618*^9}, {
   3.69600297450219*^9, 3.696002979549027*^9}}],

Cell["\<\
For the K-theory computation we define a symmtrized a-hat function. This is \
slightly different from Okounkov\[CloseCurlyQuote]s definition; the reason we \
define it this way is that for the conifold Tvir= w_i - k/ w_i    . Therefore \
to speed up the algorithm we can consider only the weights w_i a define a \
version of the a-hat function which already takes into account both \
deformations and obstructions. This function takes a weight of the form n w \
(n an integer) and returns ( (Sqrt[k/w]-Sqrt[w/k])/(Sqrt[w] - Sqrt[1/w]) )^n\
\>", "Text",
 CellChangeTimes->{{3.696100422316991*^9, 3.696100435780157*^9}, {
  3.6961006263444023`*^9, 3.6961007120747433`*^9}, {3.696100794650989*^9, 
  3.696100828053946*^9}, {3.6961013585944653`*^9, 3.696101450491947*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ahatsymm", "[", "list_", "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "/", 
          RowBox[{"list", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"list", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "/", "k"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"list", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"list", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], ")"}], "^", 
   RowBox[{"list", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6959997805839787`*^9, 3.695999781694826*^9}}],

Cell["\<\
The next function shows explicitly the virtual tangent space at a fixed point\
\
\>", "Text",
 CellChangeTimes->{{3.696670480387904*^9, 3.696670491874824*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ShowVirtualT", "[", "list_", "]"}], ":=", 
  RowBox[{"Block", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"temp1", "=", 
       RowBox[{"list", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", 
      RowBox[{"temp2", "=", 
       RowBox[{"list", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]", "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"V0", "[", 
         RowBox[{"ta1_", ",", "ta2_", ",", "tb1_", ",", "tb2_"}], "]"}], ":=", 
        RowBox[{"Evaluate", "[", "temp1", "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"V1", "[", 
         RowBox[{"ta1_", ",", "ta2_", ",", "tb1_", ",", "tb2_"}], "]"}], ":=", 
        RowBox[{"Evaluate", "[", "temp2", "]"}]}]}], "\[IndentingNewLine]", 
      "}"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Expand", "[", 
      RowBox[{"Cancel", "[", 
       RowBox[{"TvirConifold", "[", 
        RowBox[{"ta1", ",", "ta2", ",", "tb1", ",", "tb2", ",", 
         RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}]}], "]"}], "]"}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.696002603907627*^9, 3.696002641027114*^9}, {
   3.6960029899400263`*^9, 3.696003028055235*^9}, {3.696003292980668*^9, 
   3.696003294538052*^9}, {3.6960034236014137`*^9, 3.696003426552991*^9}, {
   3.6960035185256157`*^9, 3.696003521595757*^9}, {3.696003574658676*^9, 
   3.6960035763053837`*^9}, {3.6960038324481363`*^9, 3.696003833104156*^9}, {
   3.696004026522526*^9, 3.696004113291985*^9}, {3.696004193780037*^9, 
   3.696004274530307*^9}, {3.696004378702093*^9, 3.696004404019855*^9}, {
   3.6960044611305656`*^9, 3.696004461624956*^9}, {3.696004495351758*^9, 
   3.6960044974632063`*^9}, {3.696004676531825*^9, 3.6960047258979807`*^9}, {
   3.696005437041889*^9, 3.696005439840397*^9}, {3.6960084772778473`*^9, 
   3.696008589525745*^9}, {3.6960086310375223`*^9, 3.696008631637122*^9}, {
   3.696017034955256*^9, 3.696017039651731*^9}, 3.696017138871464*^9, {
   3.696017946376163*^9, 3.696017947134207*^9}, {3.6960712523936234`*^9, 
   3.6960712788713284`*^9}, {3.696071372793519*^9, 3.696071390052549*^9}, {
   3.696072371607339*^9, 3.696072371950947*^9}, {3.69607250574543*^9, 
   3.696072506742032*^9}, {3.696072548497765*^9, 3.6960725514233103`*^9}, {
   3.696073459955365*^9, 3.6960734605617743`*^9}, {3.69623410191739*^9, 
   3.6962341020499687`*^9}, 3.6962363871019487`*^9, {3.6962408766666393`*^9, 
   3.696240920539071*^9}, {3.6962409846758547`*^9, 3.696240985498617*^9}, {
   3.69624103837434*^9, 3.6962410387022753`*^9}, {3.696241256152297*^9, 
   3.696241311497265*^9}, {3.6962414903443747`*^9, 3.6962415250926313`*^9}, {
   3.6962415590382843`*^9, 3.696241559645265*^9}, {3.696241622872714*^9, 
   3.696241657390448*^9}, 3.696241699688676*^9, 3.696241759226183*^9, {
   3.696242234032023*^9, 3.696242304166627*^9}, 3.696242440434106*^9, {
   3.696670054658979*^9, 3.696670057753995*^9}, {3.6966700984627113`*^9, 
   3.6966701211654663`*^9}, {3.696670158323394*^9, 3.696670160170691*^9}}],

Cell["For example", "Text",
 CellChangeTimes->{{3.696670499627842*^9, 3.696670501114573*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ShowVirtualT", "[", 
  RowBox[{
   RowBox[{"FindFPofDim", "[", 
    RowBox[{"3", ",", "2"}], "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.696670137444084*^9, 3.696670197254568*^9}, {
  3.696670503538661*^9, 3.696670505787015*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", "ta1", " ", "tb1"}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["ta1", "2"], " ", "tb1"}], "ta2"], "+", 
  RowBox[{"2", " ", "ta2", " ", "tb1"}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["ta2", "2"], " ", "tb1"}], "ta1"], "-", 
  RowBox[{
   SuperscriptBox["ta1", "2"], " ", 
   SuperscriptBox["tb1", "2"]}], "-", 
  RowBox[{"2", " ", "ta1", " ", "ta2", " ", 
   SuperscriptBox["tb1", "2"]}], "-", 
  RowBox[{
   SuperscriptBox["ta2", "2"], " ", 
   SuperscriptBox["tb1", "2"]}], "-", 
  RowBox[{"2", " ", "ta1", " ", "tb2"}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["ta1", "2"], " ", "tb2"}], "ta2"], "-", 
  RowBox[{"2", " ", "ta2", " ", "tb2"}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["ta2", "2"], " ", "tb2"}], "ta1"], "+", 
  FractionBox[
   RowBox[{"2", " ", "tb2"}], "tb1"], "+", 
  FractionBox[
   RowBox[{"ta1", " ", "tb2"}], 
   RowBox[{"ta2", " ", "tb1"}]], "+", 
  FractionBox[
   RowBox[{"ta2", " ", "tb2"}], 
   RowBox[{"ta1", " ", "tb1"}]]}]], "Output",
 CellChangeTimes->{3.6966705060709143`*^9, 3.696700446223714*^9}]
}, Open  ]],

Cell["\<\
The next function computes the contribution of a fixed point, of the form \
(V0,V1). The function first extract (V0,V1) from a list. Then the command \
FPListConifold takes the virtual tangent space, checks if a term has a \
positive coefficient n w , and if so it collects the term and the coefficient \
as (n,w). Finally , this function applies a-hat symmetrized to every such \
coefficient and gives as output their products\
\>", "Text",
 CellChangeTimes->{{3.6961009926811447`*^9, 3.6961010550126953`*^9}, {
  3.696101309229299*^9, 3.6961013406313763`*^9}, {3.6961015742091627`*^9, 
  3.696101660640388*^9}, {3.69610170054388*^9, 3.696101740727107*^9}, {
  3.6961018092360888`*^9, 3.696101843655985*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ComputeFPContribution", "[", "list_", "]"}], ":=", 
  RowBox[{"Block", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"temp1", "=", 
       RowBox[{"list", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", 
      RowBox[{"temp2", "=", 
       RowBox[{"list", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ",", 
      RowBox[{"FPListConifold", "=", "0"}]}], "\[IndentingNewLine]", "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"V0", "[", 
         RowBox[{"ta1_", ",", "ta2_", ",", "tb1_", ",", "tb2_"}], "]"}], ":=", 
        RowBox[{"Evaluate", "[", "temp1", "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"V1", "[", 
         RowBox[{"ta1_", ",", "ta2_", ",", "tb1_", ",", "tb2_"}], "]"}], ":=", 
        RowBox[{"Evaluate", "[", "temp2", "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", 
           RowBox[{"Cancel", "[", 
            RowBox[{"TvirConifold", "[", 
             RowBox[{"ta1", ",", "ta2", ",", "tb1", ",", "tb2", ",", 
              RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}]}], "]"}], 
            "]"}], "]"}], "===", "0"}], ",", ",", "\[IndentingNewLine]", 
         RowBox[{"FPListConifold", "=", 
          RowBox[{"Flatten", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Reap", "[", 
              RowBox[{"Do", "[", 
               RowBox[{
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"List", "@@", 
                    RowBox[{"(", 
                    RowBox[{"Expand", "[", 
                    RowBox[{"Cancel", "[", 
                    RowBox[{"TvirConifold", "[", 
                    RowBox[{"ta1", ",", "ta2", ",", "tb1", ",", "tb2", ",", 
                    RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}]}], 
                    "]"}], "]"}], "]"}], ")"}]}], "]"}], "//.", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"ta1", "\[Rule]", "1"}], ",", 
                    RowBox[{"ta2", "->", "1"}], ",", 
                    RowBox[{"tb1", "\[Rule]", "1"}], ",", 
                    RowBox[{"tb2", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ">", "0"}], ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{"Sow", "[", 
                   RowBox[{"{", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
                    RowBox[{"List", "@@", 
                    RowBox[{"(", 
                    RowBox[{"Expand", "[", 
                    RowBox[{"Cancel", "[", 
                    RowBox[{"TvirConifold", "[", 
                    RowBox[{"ta1", ",", "ta2", ",", "tb1", ",", "tb2", ",", 
                    RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}]}], 
                    "]"}], "]"}], "]"}], ")"}]}], "\[IndentingNewLine]", 
                    "]"}], "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "/", 
                    RowBox[{"(", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"List", "@@", 
                    RowBox[{"(", 
                    RowBox[{"Expand", "[", 
                    RowBox[{"Cancel", "[", 
                    RowBox[{"TvirConifold", "[", 
                    RowBox[{"ta1", ",", "ta2", ",", "tb1", ",", "tb2", ",", 
                    RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}]}], 
                    "]"}], "]"}], "]"}], ")"}]}], "]"}], "//.", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"ta1", "\[Rule]", "1"}], ",", 
                    RowBox[{"ta2", "->", "1"}], ",", 
                    RowBox[{"tb1", "\[Rule]", "1"}], ",", 
                    RowBox[{"tb2", "\[Rule]", "1"}], ",", 
                    RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "\[IndentingNewLine]", 
                    ")"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"List", "@@", 
                    RowBox[{"(", 
                    RowBox[{"Expand", "[", 
                    RowBox[{"Cancel", "[", 
                    RowBox[{"TvirConifold", "[", 
                    RowBox[{"ta1", ",", "ta2", ",", "tb1", ",", "tb2", ",", 
                    RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}]}], 
                    "]"}], "]"}], "]"}], ")"}]}], "]"}], "//.", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"ta1", "\[Rule]", "1"}], ",", 
                    RowBox[{"ta2", "->", "1"}], ",", 
                    RowBox[{"tb1", "\[Rule]", "1"}], ",", 
                    RowBox[{"tb2", "\[Rule]", "1"}], ",", 
                    RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "\[IndentingNewLine]", 
                    "}"}], "]"}]}], "\[IndentingNewLine]", "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "1", ",", 
                  RowBox[{"Length", "[", 
                   RowBox[{"Flatten", "[", 
                    RowBox[{"List", "@@", 
                    RowBox[{"(", 
                    RowBox[{"Expand", "[", 
                    RowBox[{"Cancel", "[", 
                    RowBox[{"TvirConifold", "[", 
                    RowBox[{"ta1", ",", "ta2", ",", "tb1", ",", "tb2", ",", 
                    RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}]}], 
                    "]"}], "]"}], "]"}], ")"}]}], "]"}], "]"}]}], "}"}]}], 
               "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "]"}]}]}], 
        "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "}"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"FPListConifold", "===", "0"}], ",", "1", ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Cancel", "[", 
         RowBox[{"PowerExpand", "[", 
          RowBox[{"Times", "@@", 
           RowBox[{"Map", "[", 
            RowBox[{"ahatsymm", ",", 
             RowBox[{"DeleteCases", "[", 
              RowBox[{"FPListConifold", ",", 
               RowBox[{"{", 
                RowBox[{"k", ",", "_"}], "}"}]}], "]"}]}], "]"}]}], "]"}], 
         "]"}]}], "\[IndentingNewLine]", "]"}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.696002603907627*^9, 3.696002641027114*^9}, {
   3.6960029899400263`*^9, 3.696003028055235*^9}, {3.696003292980668*^9, 
   3.696003294538052*^9}, {3.6960034236014137`*^9, 3.696003426552991*^9}, {
   3.6960035185256157`*^9, 3.696003521595757*^9}, {3.696003574658676*^9, 
   3.6960035763053837`*^9}, {3.6960038324481363`*^9, 3.696003833104156*^9}, {
   3.696004026522526*^9, 3.696004113291985*^9}, {3.696004193780037*^9, 
   3.696004274530307*^9}, {3.696004378702093*^9, 3.696004404019855*^9}, {
   3.6960044611305656`*^9, 3.696004461624956*^9}, {3.696004495351758*^9, 
   3.6960044974632063`*^9}, {3.696004676531825*^9, 3.6960047258979807`*^9}, {
   3.696005437041889*^9, 3.696005439840397*^9}, {3.6960084772778473`*^9, 
   3.696008589525745*^9}, {3.6960086310375223`*^9, 3.696008631637122*^9}, {
   3.696017034955256*^9, 3.696017039651731*^9}, 3.696017138871464*^9, {
   3.696017946376163*^9, 3.696017947134207*^9}, {3.6960712523936234`*^9, 
   3.6960712788713284`*^9}, {3.696071372793519*^9, 3.696071390052549*^9}, {
   3.696072371607339*^9, 3.696072371950947*^9}, {3.69607250574543*^9, 
   3.696072506742032*^9}, {3.696072548497765*^9, 3.6960725514233103`*^9}, {
   3.696073459955365*^9, 3.6960734605617743`*^9}, {3.69623410191739*^9, 
   3.6962341020499687`*^9}, 3.6962363871019487`*^9, {3.6962408766666393`*^9, 
   3.696240920539071*^9}, {3.6962409846758547`*^9, 3.696240985498617*^9}, {
   3.69624103837434*^9, 3.6962410387022753`*^9}, {3.696241256152297*^9, 
   3.696241311497265*^9}, {3.6962414903443747`*^9, 3.6962415250926313`*^9}, {
   3.6962415590382843`*^9, 3.696241559645265*^9}, {3.696241622872714*^9, 
   3.696241657390448*^9}, 3.696241699688676*^9, 3.696241759226183*^9, {
   3.696242234032023*^9, 3.696242304166627*^9}, 3.696242440434106*^9}],

Cell["\<\
This function computes the contributon of each fixed point with fixed (d0,d1) \
and adds them. This is the coefficient of q0^d0 q1^d1 in the K-theoretical \
partition function \
\>", "Text",
 CellChangeTimes->{{3.696101932154644*^9, 3.696101995101054*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SumOfFPwithDim", "[", 
   RowBox[{"d0_", ",", "d1_"}], "]"}], ":=", 
  RowBox[{"Total", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{"DeleteCases", "[", 
     RowBox[{
      RowBox[{"Reap", "[", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"Sow", "[", 
          RowBox[{"ComputeFPContribution", "[", 
           RowBox[{
            RowBox[{"FindFPofDim", "[", 
             RowBox[{"d0", ",", "d1"}], "]"}], "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", 
            RowBox[{"FindFPofDim", "[", 
             RowBox[{"d0", ",", "d1"}], "]"}], "]"}]}], "}"}]}], "]"}], "]"}],
       ",", "Null"}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.69607152298916*^9, 3.696071589333712*^9}, {
  3.6960734896728287`*^9, 3.696073517822227*^9}, {3.6960736467129107`*^9, 
  3.6960736710241547`*^9}, {3.696236022516666*^9, 3.696236022626781*^9}}],

Cell["For example:", "Text",
 CellChangeTimes->{{3.696102176863709*^9, 3.696102204464926*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumOfFPwithDim", "[", 
  RowBox[{"2", ",", "1"}], "]"}]], "Input",
 CellChangeTimes->{{3.69610218833573*^9, 3.69610219861548*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"k", " ", "ta1"}], "-", "ta2"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", 
       RowBox[{"ta1", " ", "tb1"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"k", " ", "tb1"}], "-", "tb2"}], ")"}]}], 
    RowBox[{
     SuperscriptBox["k", 
      RowBox[{"3", "/", "2"}]], " ", 
     RowBox[{"(", 
      RowBox[{"ta1", "-", "ta2"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"ta1", " ", "tb1"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"tb1", "-", "tb2"}], ")"}]}]]}], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"ta1", "-", 
      RowBox[{"k", " ", "ta2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      RowBox[{"ta2", " ", "tb1"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "tb1"}], "-", "tb2"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{"ta1", "-", "ta2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"ta2", " ", "tb1"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"tb1", "-", "tb2"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "ta1"}], "-", "ta2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "tb1"}], "+", 
      RowBox[{"k", " ", "tb2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      RowBox[{"ta1", " ", "tb2"}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{"ta1", "-", "ta2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "tb1"}], "+", "tb2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"ta1", " ", "tb2"}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"ta1", "-", 
      RowBox[{"k", " ", "ta2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "tb1"}], "+", 
      RowBox[{"k", " ", "tb2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      RowBox[{"ta2", " ", "tb2"}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{"ta1", "-", "ta2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "tb1"}], "+", "tb2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"ta2", " ", "tb2"}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.696102193265991*^9, 3.6961021991125174`*^9}, 
   3.696377205377799*^9, 3.696528063226139*^9, 3.696663577006015*^9, 
   3.696700446463018*^9}]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The refined limit", "Section",
 CellChangeTimes->{{3.696078306064847*^9, 3.6960783330128098`*^9}, {
  3.696078469498314*^9, 3.696078519496002*^9}}],

Cell["\<\
In this Section we take the refined limit. To do this we define a general \
torus which we will use for the scaling limit. This torus send each toric \
weight to x to some power. The powers have to be chosen in such a way that \
the product of all the toric weights is a constant k, that is n1+n2+n3+n4=0\
\>", "Text",
 CellChangeTimes->{{3.6961022139374857`*^9, 3.6961022218966827`*^9}, {
  3.696102326838835*^9, 3.69610233775871*^9}, {3.696102374715914*^9, 
  3.696102440198969*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"GeneralTorus", "[", 
   RowBox[{"n1_", ",", "n2_", ",", "n3_", ",", "n4_"}], "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ta1", "\[Rule]", 
     RowBox[{"x", "^", "n1"}]}], ",", 
    RowBox[{"ta2", "\[Rule]", 
     RowBox[{"x", "^", "n2"}]}], ",", 
    RowBox[{"tb1", "\[Rule]", 
     RowBox[{"x", "^", "n3"}]}], ",", 
    RowBox[{"tb2", "\[Rule]", 
     RowBox[{"x", "^", "n4"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.696075458432869*^9, 3.696075467600114*^9}, 
   3.696075521516602*^9, {3.696075566506428*^9, 3.6960755968263683`*^9}}],

Cell["\<\
This function computes the contribution of a fixed point in the limit x->0\
\>", "Text",
 CellChangeTimes->{{3.696102470617407*^9, 3.696102489960446*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ComputeFPContributionLimit", "[", 
   RowBox[{"list_", ",", "n1_", ",", "n2_", ",", "n3_", ",", "n4_"}], "]"}], ":=", 
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Cancel", "[", 
      RowBox[{"ComputeFPContribution", "[", "list", "]"}], "]"}], "//.", 
     RowBox[{"GeneralTorus", "[", 
      RowBox[{"n1", ",", "n2", ",", "n3", ",", "n4"}], "]"}]}], ",", 
    RowBox[{"x", "\[Rule]", "0"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.69607591195662*^9, 3.696075947251993*^9}}],

Cell["\<\
This function computes the total contribution of all the fixed points with \
fixed (d0,d1) in the scaling limit. The result is the coefficient of q0^d0 \
q1^d1 in the refined partition function\
\>", "Text",
 CellChangeTimes->{{3.696102495064869*^9, 3.696102546002137*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SumOfFPwithDimLimit", "[", 
   RowBox[{
   "d0_", ",", "d1_", ",", "n1_", ",", "n2_", ",", "n3_", ",", "n4_"}], "]"}],
   ":=", 
  RowBox[{"Total", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"DeleteCases", "[", 
      RowBox[{
       RowBox[{"Reap", "[", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{"Sow", "[", 
           RowBox[{"ComputeFPContributionLimit", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"FindFPofDim", "[", 
               RowBox[{"d0", ",", "d1"}], "]"}], "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", "n1", ",", "n2", ",", "n3",
              ",", "n4"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", 
             RowBox[{"FindFPofDim", "[", 
              RowBox[{"d0", ",", "d1"}], "]"}], "]"}]}], "}"}]}], "]"}], 
        "]"}], ",", "Null"}], "]"}], ",", "3"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.69607608076173*^9, 3.696076084664837*^9}, {
  3.696076204578967*^9, 3.6960762101555023`*^9}, {3.696076258668581*^9, 
  3.696076283280218*^9}}],

Cell["For example:", "Text",
 CellChangeTimes->{{3.6961025526513*^9, 3.696102554042328*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumOfFPwithDimLimit", "[", 
  RowBox[{"2", ",", "1", ",", "1000", ",", "10", ",", "10", ",", 
   RowBox[{"-", "1020"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6961025656352386`*^9, 3.696102577626443*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["2", 
    SqrtBox["k"]]}], "-", 
  RowBox[{"2", " ", 
   SqrtBox["k"]}]}]], "Output",
 CellChangeTimes->{3.696102578229733*^9, 3.6963772058867807`*^9, 
  3.696528073915913*^9, 3.6966635871589622`*^9, 3.69670044701543*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The full partition function", "Section",
 CellChangeTimes->{{3.696078306064847*^9, 3.6960783330128098`*^9}, {
  3.696078469498314*^9, 3.696078519496002*^9}, {3.69636574304283*^9, 
  3.696365745674749*^9}}],

Cell["\<\
Now we make a guess for the full partition function, based on the \
contributions we have computed so far. To do so we take inspiration from \
Nekrasov\[CloseCurlyQuote]s formula for K-theory DT on C^3. Basically the \
idea is that we consider the conifold as two copies of C^3 (with different \
toric weights) with an extra contribution for the P1\
\>", "Text",
 CellChangeTimes->{{3.6963657698830233`*^9, 3.6963657734817677`*^9}, {
  3.696505280719989*^9, 3.696505294428043*^9}, {3.696505423054669*^9, 
  3.696505537919299*^9}, {3.6965055809268837`*^9, 3.696505587223082*^9}, {
  3.69650564780093*^9, 3.696505651824905*^9}}],

Cell["First we define a free energy", "Text",
 CellChangeTimes->{{3.696506395867978*^9, 3.696506406098103*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ahatweight", "[", 
   RowBox[{"t_", ",", "k_"}], "]"}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"t", "/", "k"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"t", "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}]}], "-", 
      RowBox[{"t", "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], ")"}]}]], "Input",\

 CellChangeTimes->{{3.696246842424601*^9, 3.696246842990106*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FConifold", "[", 
   RowBox[{
   "ta1_", ",", "ta2_", ",", "tb1_", ",", "tb2_", ",", "t4_", ",", "t5_", ",",
     "q1_"}], "]"}], ":=", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", "t4", ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}]}], "-", 
           RowBox[{
            RowBox[{"(", "t4", ")"}], "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], " ", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", "t5", ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}]}], "-", 
           RowBox[{
            RowBox[{"(", "t5", ")"}], "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], ")"}]}], 
      ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"ahatweight", "[", 
         RowBox[{
          RowBox[{"ta1", " ", "tb1"}], ",", 
          RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}]}], "]"}], " ", 
        RowBox[{"ahatweight", "[", 
         RowBox[{
          RowBox[{"ta1", " ", "tb2"}], ",", 
          RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}]}], "]"}], " ", 
        RowBox[{"ahatweight", "[", 
         RowBox[{
          RowBox[{"ta2", "/", "ta1"}], ",", 
          RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"ahatweight", "[", 
         RowBox[{
          RowBox[{"ta2", " ", "tb1"}], ",", 
          RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}]}], "]"}], " ", 
        RowBox[{"ahatweight", "[", 
         RowBox[{
          RowBox[{"ta2", " ", "tb2"}], ",", 
          RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}]}], "]"}], " ", 
        RowBox[{"ahatweight", "[", 
         RowBox[{
          RowBox[{"ta1", "/", "ta2"}], ",", 
          RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}]}], "]"}]}]}], 
      ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", "t4", ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}]}], "-", 
           RowBox[{
            RowBox[{"(", "t4", ")"}], "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], " ", 
         "\[IndentingNewLine]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", "t5", ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}]}], "-", 
           RowBox[{
            RowBox[{"(", "t5", ")"}], "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], ")"}]}], 
      ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"q1", "+", 
       RowBox[{"1", "/", "q1"}]}], ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.696261196415264*^9, 3.6962612434459248`*^9}, {
   3.6962761649799232`*^9, 3.696276176994111*^9}, 3.6962762446641207`*^9, {
   3.6963486516244373`*^9, 3.696348655695751*^9}, {3.696348688609108*^9, 
   3.6963486974318333`*^9}, {3.696348831821863*^9, 3.696348857351861*^9}, {
   3.696351197085025*^9, 3.696351197483325*^9}, {3.696351277425008*^9, 
   3.696351329002294*^9}, {3.69635146266192*^9, 3.696351586815125*^9}, 
   3.696351715697976*^9, {3.696352824216737*^9, 3.696352884320984*^9}, {
   3.696353188728696*^9, 3.696353189213277*^9}, 3.696353686956688*^9, {
   3.69635375374189*^9, 3.696353756115013*^9}, 3.696353788367732*^9, {
   3.6963542431054907`*^9, 3.696354272156575*^9}, {3.6963543052015247`*^9, 
   3.696354321110531*^9}, {3.69636028981135*^9, 3.696360294384967*^9}, {
   3.696360762052897*^9, 3.69636076974063*^9}, {3.696360995840164*^9, 
   3.696361011021439*^9}, {3.696361053827677*^9, 3.696361159889638*^9}, {
   3.696361286223338*^9, 3.696361286554138*^9}, {3.696361399891124*^9, 
   3.696361477278512*^9}, 3.696361871988027*^9, {3.6963619056520987`*^9, 
   3.696361919522855*^9}, {3.696361955668722*^9, 3.6963619724059753`*^9}, {
   3.696442930816135*^9, 3.696442937277059*^9}, {3.696443159697205*^9, 
   3.6964431764869623`*^9}, {3.696443336259808*^9, 3.696443341298814*^9}, {
   3.69650597800338*^9, 3.696505982771064*^9}, {3.696506103017436*^9, 
   3.696506129362153*^9}, {3.696506166864378*^9, 3.696506167735373*^9}, 
   3.696506411724143*^9}],

Cell["\<\
Then we symmetrize the free energy to get the full partition function \
\>", "Text",
 CellChangeTimes->{{3.696506423803364*^9, 3.696506449926386*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZNekConifold", "[", 
   RowBox[{
   "ta1_", ",", "ta2_", ",", "tb1_", ",", "tb2_", ",", "t4_", ",", "t5_", ",",
     "q1_"}], "]"}], ":=", 
  RowBox[{"Exp", "[", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", "n"}], " ", 
      RowBox[{"FConifold", "[", 
       RowBox[{
        RowBox[{"ta1", "^", "n"}], ",", 
        RowBox[{"ta2", "^", "n"}], ",", 
        RowBox[{"tb1", "^", "n"}], ",", 
        RowBox[{"tb2", "^", "n"}], ",", 
        RowBox[{"t4", "^", "n"}], ",", 
        RowBox[{"t5", "^", "n"}], ",", 
        RowBox[{"q1", "^", "n"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "14"}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.69650617431807*^9, 3.696506193334509*^9}}],

Cell["\<\
Finally we take the partition function ZNekConifold and check that each \
coefficient matches with the localization computation\
\>", "Text",
 CellChangeTimes->{{3.69650629516928*^9, 3.696506298256543*^9}, {
  3.6965063316981363`*^9, 3.696506356834303*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reap", "[", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"Sow", "[", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"PowerExpand", "[", 
          RowBox[{"Coefficient", "[", 
           RowBox[{
            RowBox[{"SeriesCoefficient", "[", 
             RowBox[{
              RowBox[{"Series", "[", 
               RowBox[{
                RowBox[{"ZNekConifold", "[", 
                 RowBox[{"ta1", ",", "ta2", ",", "tb1", ",", "tb2", ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q0", " ", "q1"}], ")"}], " ", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}], 
                    ")"}], "^", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q0", " ", "q1"}], ")"}], " ", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}], 
                    ")"}], "^", 
                    RowBox[{"(", 
                    RowBox[{"1", "/", "2"}], ")"}]}]}], ")"}], "^", 
                   RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}]}], ",", "q1"}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"q0", ",", "0", ",", "4"}], "}"}]}], "]"}], ",", 
              "i"}], "]"}], ",", "q1", ",", "j"}], "]"}], "]"}], "-", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "^", "i"}], " ", 
          RowBox[{"PowerExpand", "[", 
           RowBox[{
            RowBox[{"SumOfFPwithDim", "[", 
             RowBox[{"i", ",", "j"}], "]"}], "//.", 
            RowBox[{"k", "\[Rule]", 
             RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}]}]}], 
           "]"}]}]}], "]"}], "]"}], "\[IndentingNewLine]", ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "4"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6963637107113247`*^9, 3.696363807364853*^9}, {
   3.696363862089066*^9, 3.6963638682551107`*^9}, {3.696442939084978*^9, 
   3.696442958296892*^9}, {3.696443179322867*^9, 3.696443183368376*^9}, {
   3.69644344060198*^9, 3.6964434458961983`*^9}, 3.696506213214684*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Null", ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
     "1", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
      "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
      "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
      "0", ",", "0", ",", "0", ",", "0"}], "}"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.696377499591164*^9, 3.696506315944022*^9, 
  3.696528397402811*^9, 3.696700748746992*^9}]
}, Open  ]],

Cell["\<\
This function reproduces the localization computation up to the sign of the \
variable q0. \
\>", "Text",
 CellChangeTimes->{{3.696535253979739*^9, 3.696535273803465*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZNekConifoldFull", "=", 
   RowBox[{"Normal", "[", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"ZNekConifold", "[", 
         RowBox[{"ta1", ",", "ta2", ",", "tb1", ",", "tb2", ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"q0", " ", "q1"}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}], ")"}], "^", 
            
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"q0", " ", "q1"}], ")"}], " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}], ")"}], 
              "^", 
              RowBox[{"(", 
               RowBox[{"1", "/", "2"}], ")"}]}]}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}]}], ",", "q1"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"q0", ",", "0", ",", "4"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"q1", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.696514247573094*^9, 3.696514250595187*^9}, {
  3.6965145149708843`*^9, 3.6965145150421352`*^9}, {3.6965146127650146`*^9, 
  3.696514625772332*^9}, {3.696515130856552*^9, 3.6965151352477627`*^9}, {
  3.69651528055191*^9, 3.696515303301035*^9}, {3.69651545505613*^9, 
  3.6965154594550037`*^9}, {3.696519097714546*^9, 3.696519099305478*^9}, {
  3.696521641152042*^9, 3.696521665535534*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"LocalizationFullWithSign", "=", 
   RowBox[{"1", "+", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", "q0"}], ")"}], "^", "i"}], " ", 
         RowBox[{"q1", "^", "j"}], "  ", 
         RowBox[{"PowerExpand", "[", 
          RowBox[{
           RowBox[{"SumOfFPwithDim", "[", 
            RowBox[{"i", ",", "j"}], "]"}], "//.", 
           RowBox[{"k", "\[Rule]", 
            RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}]}]}], "]"}]}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "4"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "0", ",", "4"}], "}"}]}], "]"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.696514265980989*^9, 3.69651427534648*^9}, {
  3.6965145211699753`*^9, 3.696514522847547*^9}, {3.6965147432119207`*^9, 
  3.6965147433067102`*^9}, {3.696514811271432*^9, 3.696514832127171*^9}, {
  3.696515138249407*^9, 3.69651514158351*^9}, {3.696519025983329*^9, 
  3.696519028029908*^9}, {3.696519103497033*^9, 3.696519105547247*^9}, {
  3.6965191518641043`*^9, 3.696519152070326*^9}, {3.696521673314077*^9, 
  3.696521686297855*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"ZNekConifoldFull", "-", "LocalizationFullWithSign"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.696519070643735*^9, 3.696519081392908*^9}, {
  3.6965216920264883`*^9, 3.696521695354418*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.696521994083488*^9, 3.696528723961833*^9, 
  3.696701036240424*^9}]
}, Open  ]],

Cell["\<\
To obtain precisely the localization computation we change variable p0 -> -q0 \
at the end of the series expansion\
\>", "Text",
 CellChangeTimes->{{3.69653529241716*^9, 3.696535350257845*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZNekConifoldFullWithSign", "=", 
   RowBox[{
    RowBox[{"Normal", "[", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"Series", "[", 
        RowBox[{
         RowBox[{"ZNekConifold", "[", 
          RowBox[{"ta1", ",", "ta2", ",", "tb1", ",", "tb2", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"p0", " ", "q1"}], ")"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}], ")"}], "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"p0", " ", "q1"}], ")"}], " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}], ")"}], 
               "^", 
               RowBox[{"(", 
                RowBox[{"1", "/", "2"}], ")"}]}]}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}]}], ",", "q1"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"p0", ",", "0", ",", "4"}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"q1", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], "//.", 
    RowBox[{"p0", "\[Rule]", 
     RowBox[{"-", "q0"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.696514247573094*^9, 3.696514250595187*^9}, {
  3.6965145149708843`*^9, 3.6965145150421352`*^9}, {3.6965146127650146`*^9, 
  3.696514625772332*^9}, {3.696515130856552*^9, 3.6965151352477627`*^9}, {
  3.69651528055191*^9, 3.696515303301035*^9}, {3.69651545505613*^9, 
  3.6965154594550037`*^9}, {3.696519097714546*^9, 3.696519099305478*^9}, {
  3.696519196987075*^9, 3.696519197033559*^9}, {3.696519648087513*^9, 
  3.6965196877760963`*^9}, {3.6965199069789953`*^9, 3.696519947763872*^9}, {
  3.696520439154399*^9, 3.696520450873486*^9}, {3.6965217001534357`*^9, 
  3.6965217248558617`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"LocalizationFull", "=", 
   RowBox[{"1", "+", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", "q0", ")"}], "^", "i"}], " ", 
         RowBox[{"q1", "^", "j"}], "  ", 
         RowBox[{"PowerExpand", "[", 
          RowBox[{
           RowBox[{"SumOfFPwithDim", "[", 
            RowBox[{"i", ",", "j"}], "]"}], "//.", 
           RowBox[{"k", "\[Rule]", 
            RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}]}]}], "]"}]}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "4"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "0", ",", "4"}], "}"}]}], "]"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.696514265980989*^9, 3.69651427534648*^9}, {
  3.6965145211699753`*^9, 3.696514522847547*^9}, {3.6965147432119207`*^9, 
  3.6965147433067102`*^9}, {3.696514811271432*^9, 3.696514832127171*^9}, {
  3.696515138249407*^9, 3.69651514158351*^9}, {3.696519025983329*^9, 
  3.696519028029908*^9}, {3.696519103497033*^9, 3.696519105547247*^9}, {
  3.6965191518641043`*^9, 3.696519152070326*^9}, {3.6965192001250134`*^9, 
  3.696519200167405*^9}, {3.696519640470738*^9, 3.6965196574143333`*^9}, {
  3.69651995030184*^9, 3.6965199521074753`*^9}, {3.696521728376252*^9, 
  3.6965217356880093`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"ZNekConifoldFullWithSign", "-", "LocalizationFull"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.696519070643735*^9, 3.696519081392908*^9}, {
  3.696519203688093*^9, 3.696519205159903*^9}, {3.6965217424581833`*^9, 
  3.696521746609891*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.696522312641687*^9, 3.6965290274410267`*^9, 
  3.696701331271215*^9}]
}, Open  ]],

Cell["\<\
Another possibility is to define the variable so that we only get positive \
coefficients, by changing the sign of q1\
\>", "Text",
 CellChangeTimes->{{3.696665778459969*^9, 3.6966658150997257`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZNekConifoldFullSignq1", "=", 
   RowBox[{"Normal", "[", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"ZNekConifold", "[", 
         RowBox[{"ta1", ",", "ta2", ",", "tb1", ",", "tb2", ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"q0", " ", "q1"}], ")"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}], ")"}], "^", 
            
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"q0", " ", "q1"}], ")"}], " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}], ")"}], 
              "^", 
              RowBox[{"(", 
               RowBox[{"1", "/", "2"}], ")"}]}]}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}]}], ",", 
          RowBox[{"-", "q1"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"q0", ",", "0", ",", "4"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"q1", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.696514247573094*^9, 3.696514250595187*^9}, {
  3.6965145149708843`*^9, 3.6965145150421352`*^9}, {3.6965146127650146`*^9, 
  3.696514625772332*^9}, {3.696515130856552*^9, 3.6965151352477627`*^9}, {
  3.69651528055191*^9, 3.696515303301035*^9}, {3.69651545505613*^9, 
  3.6965154594550037`*^9}, {3.696519097714546*^9, 3.696519099305478*^9}, {
  3.696521641152042*^9, 3.696521665535534*^9}, {3.6966658186282*^9, 
  3.696665823492229*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"LocalizationFullWithSignq1", "=", 
   RowBox[{"1", "+", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", "q0", ")"}], "^", "i"}], " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", "q1"}], ")"}], "^", "j"}], "  ", 
         RowBox[{"PowerExpand", "[", 
          RowBox[{
           RowBox[{"SumOfFPwithDim", "[", 
            RowBox[{"i", ",", "j"}], "]"}], "//.", 
           RowBox[{"k", "\[Rule]", 
            RowBox[{"ta1", " ", "ta2", " ", "tb1", " ", "tb2"}]}]}], "]"}]}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "4"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "0", ",", "4"}], "}"}]}], "]"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.696514265980989*^9, 3.69651427534648*^9}, {
  3.6965145211699753`*^9, 3.696514522847547*^9}, {3.6965147432119207`*^9, 
  3.6965147433067102`*^9}, {3.696514811271432*^9, 3.696514832127171*^9}, {
  3.696515138249407*^9, 3.69651514158351*^9}, {3.696519025983329*^9, 
  3.696519028029908*^9}, {3.696519103497033*^9, 3.696519105547247*^9}, {
  3.6965191518641043`*^9, 3.696519152070326*^9}, {3.696521673314077*^9, 
  3.696521686297855*^9}, {3.6966658274599867`*^9, 3.696665834275876*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"ZNekConifoldFullSignq1", "-", "LocalizationFullWithSignq1"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.696519070643735*^9, 3.696519081392908*^9}, {
  3.6965216920264883`*^9, 3.696521695354418*^9}, {3.696665840693746*^9, 
  3.696665843717758*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6966661754922523`*^9, 3.696701629924767*^9}]
}, Open  ]],

Cell["\<\
Now we look at refined and unrefined limits. First we write down the \
cohomological partition function, as computed by Szendroi. It is the product \
of two Macmahon factors with a Kahler moduli dependent factor\
\>", "Text",
 CellChangeTimes->{{3.696521623270208*^9, 3.6965216281647463`*^9}, {
  3.69652216463056*^9, 3.6965221718381557`*^9}, {3.6965285841172237`*^9, 
  3.6965286320483017`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Zcon", "[", 
   RowBox[{"q0_", ",", "q1_", ",", "N_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Product", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          RowBox[{"q0", "^", "k"}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"-", "q1"}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"k", "-", "1"}], ")"}]}]}]}], ")"}], "^", "k"}], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          RowBox[{"q0", "^", "k"}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"-", "q1"}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"k", "+", "1"}], ")"}]}]}]}], ")"}], "^", "k"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", "14"}], "}"}]}], "]"}], " ", 
   RowBox[{
    RowBox[{"Product", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "q0"}], " ", "q1"}], ")"}], "^", "k"}]}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"-", "k"}], ")"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", "14"}], "}"}]}], "]"}], "^", 
    "2"}]}]}]], "Input",
 CellChangeTimes->{{3.695134407328931*^9, 3.695134407990354*^9}, {
  3.695134541217594*^9, 3.695134554047367*^9}, {3.695134596614175*^9, 
  3.6951346067089167`*^9}, {3.695134723861784*^9, 3.695134817572028*^9}, {
  3.695136012368408*^9, 3.695136012840952*^9}, {3.695136818560645*^9, 
  3.695136818807755*^9}, {3.695995781484906*^9, 3.69599578228251*^9}, {
  3.696175477427923*^9, 3.696175481115856*^9}, {3.6962439469859667`*^9, 
  3.696243947702757*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{"Normal", "[", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"Zcon", "[", 
        RowBox[{"q0", ",", "q1", ",", "4"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"q0", ",", "0", ",", "4"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"q1", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.695135947273396*^9, {3.6965291450287046`*^9, 3.69652916191856*^9}, {
   3.6965293958901377`*^9, 3.696529403328588*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", "q0", "-", 
  RowBox[{"2", " ", "q0", " ", "q1"}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox["q0", "2"], " ", "q1"}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["q0", "3"], " ", "q1"}], "+", 
  RowBox[{"q0", " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  RowBox[{"8", " ", 
   SuperscriptBox["q0", "2"], " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  RowBox[{"14", " ", 
   SuperscriptBox["q0", "3"], " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  RowBox[{"8", " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "2"]}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox["q0", "2"], " ", 
   SuperscriptBox["q1", "3"]}], "-", 
  RowBox[{"24", " ", 
   SuperscriptBox["q0", "3"], " ", 
   SuperscriptBox["q1", "3"]}], "-", 
  RowBox[{"44", " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "3"]}], "+", 
  RowBox[{"14", " ", 
   SuperscriptBox["q0", "3"], " ", 
   SuperscriptBox["q1", "4"]}], "+", 
  RowBox[{"72", " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "4"]}]}]], "Output",
 CellChangeTimes->{{3.6965291354396276`*^9, 3.696529162216969*^9}, 
   3.696529403967815*^9, 3.696701630022719*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"1", "+", 
   RowBox[{"Total", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", "q0", ")"}], "^", "i"}], " ", 
        RowBox[{"q1", "^", "j"}], " ", 
        RowBox[{"SumOfFPwithDimLimit", "[", 
         RowBox[{"i", ",", "j", ",", "1000", ",", "10", ",", "10", ",", 
          RowBox[{"-", "1020"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], "]"}]}], "//.", 
  RowBox[{"k", "\[Rule]", "1"}]}]], "Input",
 CellChangeTimes->{{3.696508798156025*^9, 3.696508829748168*^9}, {
  3.696508916200828*^9, 3.69650896381675*^9}, {3.696509003127708*^9, 
  3.696509004958487*^9}, {3.696509472168909*^9, 3.6965095017273703`*^9}, {
  3.696529186500968*^9, 3.6965291892040977`*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", "q0", "-", 
  RowBox[{"2", " ", "q0", " ", "q1"}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox["q0", "2"], " ", "q1"}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["q0", "3"], " ", "q1"}], "+", 
  RowBox[{"q0", " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  RowBox[{"8", " ", 
   SuperscriptBox["q0", "2"], " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  RowBox[{"14", " ", 
   SuperscriptBox["q0", "3"], " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  RowBox[{"8", " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "2"]}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox["q0", "2"], " ", 
   SuperscriptBox["q1", "3"]}], "-", 
  RowBox[{"24", " ", 
   SuperscriptBox["q0", "3"], " ", 
   SuperscriptBox["q1", "3"]}], "-", 
  RowBox[{"44", " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "3"]}], "+", 
  RowBox[{"14", " ", 
   SuperscriptBox["q0", "3"], " ", 
   SuperscriptBox["q1", "4"]}], "+", 
  RowBox[{"72", " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "4"]}]}]], "Output",
 CellChangeTimes->{{3.696508816952454*^9, 3.696508830560144*^9}, {
   3.696508947271421*^9, 3.6965089656122217`*^9}, 3.696509033921962*^9, {
   3.69650948345198*^9, 3.696509513199257*^9}, 3.6965290549238787`*^9, 
   3.696529392573113*^9, 3.6967018558062572`*^9}]
}, Open  ]],

Cell["The two series are the same up to q0^4 q1^4 terms", "Text",
 CellChangeTimes->{{3.6965292826963577`*^9, 3.6965292954460783`*^9}}],

Cell["\<\
Now we look at the refined limit. It has the following form, where we call L \
the refinement/motivic parameter. The choice of refinement depends on two \
variables, epsilon and delta\
\>", "Text",
 CellChangeTimes->{{3.6965296025245333`*^9, 3.69652962566922*^9}, {
  3.6965296882646303`*^9, 3.696529719350576*^9}, {3.6965298399066753`*^9, 
  3.696529866255559*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Zre", "[", 
   RowBox[{"a0_", ",", "a1_", ",", "y0_", ",", "y1_"}], "]"}], ":=", 
  RowBox[{"Product", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{
       RowBox[{"L", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "a0"}], "/", "2"}], "+", 
          RowBox[{"1", "/", "2"}], "+", "j"}], ")"}]}], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"-", "y0"}], ")"}], "^", "a0"}], " ", 
       RowBox[{"y1", "^", "a1"}]}]}], ")"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", 
      RowBox[{"a0", "-", "1"}]}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Zim", "[", 
   RowBox[{
   "a0_", ",", "a1_", ",", "y0_", ",", "y1_", ",", "epsilon_", ",", 
    "delta_"}], "]"}], ":=", 
  RowBox[{"Product", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"L", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a0"}], "/", "2"}], "+", "epsilon", "+", "j"}], 
           ")"}]}], " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", "y0"}], ")"}], "^", "a0"}], " ", 
         RowBox[{"y1", "^", "a1"}]}]}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}]}], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"L", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a0"}], "/", "2"}], "+", "delta", "+", "j"}], 
           ")"}]}], " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", "y0"}], ")"}], "^", "a0"}], " ", 
         RowBox[{"y1", "^", "a1"}]}]}], " ", ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", 
      RowBox[{"a0", "-", "1"}]}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.675686151987041*^9, 3.6756863061871643`*^9}, {
  3.675686346746666*^9, 3.675686377404379*^9}, {3.6756864371507063`*^9, 
  3.675686439494792*^9}, {3.675687554738285*^9, 3.6756875573543262`*^9}, {
  3.675707821620995*^9, 3.6757078404210043`*^9}, {3.676207007581489*^9, 
  3.6762070223435907`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Zmot", "[", 
   RowBox[{"y0_", ",", "y1_", ",", "N_", ",", "epsilon_", ",", "delta_"}], 
   "]"}], ":=", 
  RowBox[{
   RowBox[{"Product", "[", 
    RowBox[{
     RowBox[{"Zre", "[", 
      RowBox[{"i", ",", 
       RowBox[{"i", "-", "1"}], ",", "y0", ",", "y1"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "N"}], "}"}]}], "]"}], 
   RowBox[{"Product", "[", 
    RowBox[{
     RowBox[{"Zre", "[", 
      RowBox[{
       RowBox[{"i", "-", "1"}], ",", "i", ",", "y0", ",", "y1"}], "]"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "N"}], "}"}]}], "]"}], " ", 
   RowBox[{"Product", "[", 
    RowBox[{
     RowBox[{"Zim", "[", 
      RowBox[{
      "i", ",", "i", ",", "y0", ",", "y1", ",", "epsilon", ",", "delta"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "N"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.675686453536471*^9, 3.6756865329398413`*^9}, {
  3.676207029741981*^9, 3.676207050654202*^9}}],

Cell["Our refined limit corresponds to epsilon=0 and delta=1", "Text",
 CellChangeTimes->{{3.69653496939736*^9, 3.696534980276102*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{"Normal", "[", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"Zmot", "[", 
        RowBox[{"q0", ",", "q1", ",", "5", ",", "0", ",", "1"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"q0", ",", "0", ",", "4"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"q1", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.696529755290697*^9, 3.6965297572174253`*^9}, {
  3.696530129558288*^9, 3.69653013463089*^9}, {3.6965314000842524`*^9, 
  3.696531403650241*^9}, {3.696531533585071*^9, 3.6965315551988564`*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", "q0", "-", 
  FractionBox[
   RowBox[{"q0", " ", "q1"}], 
   SqrtBox["L"]], "-", 
  RowBox[{
   SqrtBox["L"], " ", "q0", " ", "q1"}], "-", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["q0", "2"], " ", "q1"}], 
   SqrtBox["L"]], "-", 
  RowBox[{"2", " ", 
   SqrtBox["L"], " ", 
   SuperscriptBox["q0", "2"], " ", "q1"}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["q0", "3"], " ", "q1"}], 
   SqrtBox["L"]], "-", 
  RowBox[{
   SqrtBox["L"], " ", 
   SuperscriptBox["q0", "3"], " ", "q1"}], "+", 
  RowBox[{"q0", " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["q0", "2"], " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["q0", "2"], " ", 
    SuperscriptBox["q1", "2"]}], "L"], "+", 
  RowBox[{"2", " ", "L", " ", 
   SuperscriptBox["q0", "2"], " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["q0", "3"], " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  FractionBox[
   RowBox[{"4", " ", 
    SuperscriptBox["q0", "3"], " ", 
    SuperscriptBox["q1", "2"]}], "L"], "+", 
  RowBox[{"4", " ", "L", " ", 
   SuperscriptBox["q0", "3"], " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["q0", "4"], " ", 
    SuperscriptBox["q1", "2"]}], "L"], "+", 
  RowBox[{"2", " ", "L", " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "2"]}], "-", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["q0", "2"], " ", 
    SuperscriptBox["q1", "3"]}], 
   SqrtBox["L"]], "-", 
  RowBox[{"2", " ", 
   SqrtBox["L"], " ", 
   SuperscriptBox["q0", "2"], " ", 
   SuperscriptBox["q1", "3"]}], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    SuperscriptBox["q0", "3"], " ", 
    SuperscriptBox["q1", "3"]}], 
   SuperscriptBox["L", 
    RowBox[{"3", "/", "2"}]]], "-", 
  FractionBox[
   RowBox[{"9", " ", 
    SuperscriptBox["q0", "3"], " ", 
    SuperscriptBox["q1", "3"]}], 
   SqrtBox["L"]], "-", 
  RowBox[{"9", " ", 
   SqrtBox["L"], " ", 
   SuperscriptBox["q0", "3"], " ", 
   SuperscriptBox["q1", "3"]}], "-", 
  RowBox[{"3", " ", 
   SuperscriptBox["L", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["q0", "3"], " ", 
   SuperscriptBox["q1", "3"]}], "-", 
  FractionBox[
   RowBox[{"7", " ", 
    SuperscriptBox["q0", "4"], " ", 
    SuperscriptBox["q1", "3"]}], 
   SuperscriptBox["L", 
    RowBox[{"3", "/", "2"}]]], "-", 
  FractionBox[
   RowBox[{"15", " ", 
    SuperscriptBox["q0", "4"], " ", 
    SuperscriptBox["q1", "3"]}], 
   SqrtBox["L"]], "-", 
  RowBox[{"15", " ", 
   SqrtBox["L"], " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "3"]}], "-", 
  RowBox[{"7", " ", 
   SuperscriptBox["L", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "3"]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["q0", "3"], " ", 
   SuperscriptBox["q1", "4"]}], "+", 
  FractionBox[
   RowBox[{"4", " ", 
    SuperscriptBox["q0", "3"], " ", 
    SuperscriptBox["q1", "4"]}], "L"], "+", 
  RowBox[{"4", " ", "L", " ", 
   SuperscriptBox["q0", "3"], " ", 
   SuperscriptBox["q1", "4"]}], "+", 
  RowBox[{"26", " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "4"]}], "+", 
  FractionBox[
   RowBox[{"5", " ", 
    SuperscriptBox["q0", "4"], " ", 
    SuperscriptBox["q1", "4"]}], 
   SuperscriptBox["L", "2"]], "+", 
  FractionBox[
   RowBox[{"18", " ", 
    SuperscriptBox["q0", "4"], " ", 
    SuperscriptBox["q1", "4"]}], "L"], "+", 
  RowBox[{"18", " ", "L", " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "4"]}], "+", 
  RowBox[{"5", " ", 
   SuperscriptBox["L", "2"], " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "4"]}]}]], "Output",
 CellChangeTimes->{
  3.696529757685103*^9, 3.696530135098518*^9, 3.696531404424981*^9, {
   3.696531535704781*^9, 3.6965315558767557`*^9}, 3.6967018559598846`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{"Total", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", "q0", ")"}], "^", "i"}], " ", 
       RowBox[{"q1", "^", "j"}], " ", 
       RowBox[{"SumOfFPwithDimLimit", "[", 
        RowBox[{"i", ",", "j", ",", "1000", ",", "10", ",", "10", ",", 
         RowBox[{"-", "1020"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{3.696529831836742*^9}],

Cell[BoxData[
 RowBox[{"1", "+", "q0", "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       SqrtBox["k"]]}], "-", 
     SqrtBox["k"]}], ")"}], " ", "q0", " ", "q1"}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["2", 
       SqrtBox["k"]]}], "-", 
     RowBox[{"2", " ", 
      SqrtBox["k"]}]}], ")"}], " ", 
   SuperscriptBox["q0", "2"], " ", "q1"}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       SqrtBox["k"]]}], "-", 
     SqrtBox["k"]}], ")"}], " ", 
   SuperscriptBox["q0", "3"], " ", "q1"}], "+", 
  RowBox[{"q0", " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"4", "+", 
     FractionBox["2", "k"], "+", 
     RowBox[{"2", " ", "k"}]}], ")"}], " ", 
   SuperscriptBox["q0", "2"], " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"6", "+", 
     FractionBox["4", "k"], "+", 
     RowBox[{"4", " ", "k"}]}], ")"}], " ", 
   SuperscriptBox["q0", "3"], " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"4", "+", 
     FractionBox["2", "k"], "+", 
     RowBox[{"2", " ", "k"}]}], ")"}], " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["2", 
       SqrtBox["k"]]}], "-", 
     RowBox[{"2", " ", 
      SqrtBox["k"]}]}], ")"}], " ", 
   SuperscriptBox["q0", "2"], " ", 
   SuperscriptBox["q1", "3"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["3", 
       SuperscriptBox["k", 
        RowBox[{"3", "/", "2"}]]]}], "-", 
     FractionBox["9", 
      SqrtBox["k"]], "-", 
     RowBox[{"9", " ", 
      SqrtBox["k"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["k", 
       RowBox[{"3", "/", "2"}]]}]}], ")"}], " ", 
   SuperscriptBox["q0", "3"], " ", 
   SuperscriptBox["q1", "3"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["7", 
       SuperscriptBox["k", 
        RowBox[{"3", "/", "2"}]]]}], "-", 
     FractionBox["15", 
      SqrtBox["k"]], "-", 
     RowBox[{"15", " ", 
      SqrtBox["k"]}], "-", 
     RowBox[{"7", " ", 
      SuperscriptBox["k", 
       RowBox[{"3", "/", "2"}]]}]}], ")"}], " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "3"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"6", "+", 
     FractionBox["4", "k"], "+", 
     RowBox[{"4", " ", "k"}]}], ")"}], " ", 
   SuperscriptBox["q0", "3"], " ", 
   SuperscriptBox["q1", "4"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"26", "+", 
     FractionBox["5", 
      SuperscriptBox["k", "2"]], "+", 
     FractionBox["18", "k"], "+", 
     RowBox[{"18", " ", "k"}], "+", 
     RowBox[{"5", " ", 
      SuperscriptBox["k", "2"]}]}], ")"}], " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "4"]}]}]], "Output",
 CellChangeTimes->{3.6965300354102983`*^9, 3.696701919443554*^9}]
}, Open  ]],

Cell["We check that they are the same with k <---> L", "Text",
 CellChangeTimes->{{3.696531587498086*^9, 3.696531602384726*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"1", "+", 
    RowBox[{"Total", "[", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", "q0", ")"}], "^", "i"}], " ", 
         RowBox[{"q1", "^", "j"}], " ", 
         RowBox[{"SumOfFPwithDimLimit", "[", 
          RowBox[{"i", ",", "j", ",", "1000", ",", "10", ",", "10", ",", 
           RowBox[{"-", "1020"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], "]"}], "-", 
    RowBox[{"Expand", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Zmot", "[", 
           RowBox[{"q0", ",", "q1", ",", "5", ",", "0", ",", "1"}], "]"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"q0", ",", "0", ",", "4"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"q1", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], "]"}]}], "//.", 
   RowBox[{"L", "\[Rule]", "k"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.696531611891449*^9, 3.6965316434772243`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.696531752320807*^9, 3.696701983032381*^9}]
}, Open  ]],

Cell["\<\
Finally we can write the refined partition function in a more compact form, \
by taking the refined limit directly on the full K-theoretical partition \
function\
\>", "Text",
 CellChangeTimes->{{3.6967033081679697`*^9, 3.696703330574202*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"PowerExpand", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"q0", " ", "q1"}], ")"}], " ", 
                RowBox[{
                 RowBox[{"(", "k", ")"}], "^", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"1", "/", "2"}], ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"q0", " ", "q1"}], ")"}], " ", 
                RowBox[{
                 RowBox[{"(", "k", ")"}], "^", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], " ", 
           "\[IndentingNewLine]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"q0", " ", "q1"}], ")"}], " ", 
                  RowBox[{
                   RowBox[{"(", "k", ")"}], "^", 
                   RowBox[{"(", 
                    RowBox[{"1", "/", "2"}], ")"}]}]}], ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"-", "1"}], ")"}]}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"1", "/", "2"}], ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"q0", " ", "q1"}], ")"}], " ", 
                  RowBox[{
                   RowBox[{"(", "k", ")"}], "^", 
                   RowBox[{"(", 
                    RowBox[{"1", "/", "2"}], ")"}]}]}], ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"-", "1"}], ")"}]}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], ")"}]}], 
        ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"ahatweight", "[", 
           RowBox[{
            RowBox[{"ta1", " ", "tb1"}], ",", "k"}], "]"}], " ", 
          RowBox[{"ahatweight", "[", 
           RowBox[{
            RowBox[{"ta1", " ", "tb2"}], ",", "k"}], "]"}], " ", 
          RowBox[{"ahatweight", "[", 
           RowBox[{
            RowBox[{"ta2", "/", "ta1"}], ",", "k"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"ahatweight", "[", 
           RowBox[{
            RowBox[{"ta2", " ", "tb1"}], ",", "k"}], "]"}], " ", 
          RowBox[{"ahatweight", "[", 
           RowBox[{
            RowBox[{"ta2", " ", "tb2"}], ",", "k"}], "]"}], " ", 
          RowBox[{"ahatweight", "[", 
           RowBox[{
            RowBox[{"ta1", "/", "ta2"}], ",", "k"}], "]"}]}]}], ")"}]}], "+", 
      
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"q0", " ", "q1"}], ")"}], " ", 
                RowBox[{
                 RowBox[{"(", "k", ")"}], "^", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"1", "/", "2"}], ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"q0", " ", "q1"}], ")"}], " ", 
                RowBox[{
                 RowBox[{"(", "k", ")"}], "^", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], " ", 
           "\[IndentingNewLine]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"q0", " ", "q1"}], ")"}], " ", 
                  RowBox[{
                   RowBox[{"(", "k", ")"}], "^", 
                   RowBox[{"(", 
                    RowBox[{"1", "/", "2"}], ")"}]}]}], ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"-", "1"}], ")"}]}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"1", "/", "2"}], ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"q0", " ", "q1"}], ")"}], " ", 
                  RowBox[{
                   RowBox[{"(", "k", ")"}], "^", 
                   RowBox[{"(", 
                    RowBox[{"1", "/", "2"}], ")"}]}]}], ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"-", "1"}], ")"}]}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], ")"}]}], 
        ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"q1", "+", 
         RowBox[{"1", "/", "q1"}]}], ")"}]}]}], "]"}], "//.", 
    RowBox[{"GeneralTorus", "[", 
     RowBox[{"1000", ",", "10", ",", "10", ",", 
      RowBox[{"-", "1020"}]}], "]"}]}], ",", 
   RowBox[{"x", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.696702236892672*^9, 3.696702296852551*^9}, {
  3.696702393095563*^9, 3.696702411820972*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"q0", " ", 
    RowBox[{"(", 
     RowBox[{"q1", "+", 
      RowBox[{"k", " ", "q1"}], "-", 
      RowBox[{
       SqrtBox["k"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["q1", "2"]}], ")"}]}]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SqrtBox["k"], "-", 
      RowBox[{"q0", " ", "q1"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       SqrtBox["k"], " ", "q0", " ", "q1"}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{3.696703353291773*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Frefined", "[", 
   RowBox[{"q0_", ",", "q1_", ",", "k_"}], "]"}], ":=", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"q0", " ", 
     RowBox[{"(", 
      RowBox[{"q1", "+", 
       RowBox[{"k", " ", "q1"}], "-", 
       RowBox[{
        SqrtBox["k"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["q1", "2"]}], ")"}]}]}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SqrtBox["k"], "-", 
       RowBox[{"q0", " ", "q1"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SqrtBox["k"], " ", "q0", " ", "q1"}]}], ")"}]}]]}]}]], "Input",
 CellChangeTimes->{{3.696702795552896*^9, 3.696702807565734*^9}, {
  3.6967033507281446`*^9, 3.696703351142818*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Zrefined", "[", 
   RowBox[{"q0_", ",", "q1_", ",", "k_"}], "]"}], ":=", 
  RowBox[{"Exp", "[", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", "n"}], " ", 
      RowBox[{"Frefined", "[", 
       RowBox[{
        RowBox[{"q0", "^", "n"}], ",", 
        RowBox[{"q1", "^", "n"}], ",", 
        RowBox[{"k", "^", "n"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "14"}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.696702847172662*^9, 3.696702881002491*^9}, {
  3.696703368590829*^9, 3.696703372854621*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{"Normal", "[", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"Zrefined", "[", 
         RowBox[{
          RowBox[{"-", "q0"}], ",", "q1", ",", "k"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"q0", ",", "0", ",", "4"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"q1", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6967029011016827`*^9, 3.69670292766556*^9}, {
   3.6967029667474937`*^9, 3.696703004651127*^9}, 3.696703053336257*^9, 
   3.696703086967146*^9, 3.696703118975582*^9, {3.6967033782716713`*^9, 
   3.696703384302001*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", "q0", "-", 
  FractionBox[
   RowBox[{"q0", " ", "q1"}], 
   SqrtBox["k"]], "-", 
  RowBox[{
   SqrtBox["k"], " ", "q0", " ", "q1"}], "-", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["q0", "2"], " ", "q1"}], 
   SqrtBox["k"]], "-", 
  RowBox[{"2", " ", 
   SqrtBox["k"], " ", 
   SuperscriptBox["q0", "2"], " ", "q1"}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["q0", "3"], " ", "q1"}], 
   SqrtBox["k"]], "-", 
  RowBox[{
   SqrtBox["k"], " ", 
   SuperscriptBox["q0", "3"], " ", "q1"}], "+", 
  RowBox[{"q0", " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["q0", "2"], " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["q0", "2"], " ", 
    SuperscriptBox["q1", "2"]}], "k"], "+", 
  RowBox[{"2", " ", "k", " ", 
   SuperscriptBox["q0", "2"], " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["q0", "3"], " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  FractionBox[
   RowBox[{"4", " ", 
    SuperscriptBox["q0", "3"], " ", 
    SuperscriptBox["q1", "2"]}], "k"], "+", 
  RowBox[{"4", " ", "k", " ", 
   SuperscriptBox["q0", "3"], " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "2"]}], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["q0", "4"], " ", 
    SuperscriptBox["q1", "2"]}], "k"], "+", 
  RowBox[{"2", " ", "k", " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "2"]}], "-", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["q0", "2"], " ", 
    SuperscriptBox["q1", "3"]}], 
   SqrtBox["k"]], "-", 
  RowBox[{"2", " ", 
   SqrtBox["k"], " ", 
   SuperscriptBox["q0", "2"], " ", 
   SuperscriptBox["q1", "3"]}], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    SuperscriptBox["q0", "3"], " ", 
    SuperscriptBox["q1", "3"]}], 
   SuperscriptBox["k", 
    RowBox[{"3", "/", "2"}]]], "-", 
  FractionBox[
   RowBox[{"9", " ", 
    SuperscriptBox["q0", "3"], " ", 
    SuperscriptBox["q1", "3"]}], 
   SqrtBox["k"]], "-", 
  RowBox[{"9", " ", 
   SqrtBox["k"], " ", 
   SuperscriptBox["q0", "3"], " ", 
   SuperscriptBox["q1", "3"]}], "-", 
  RowBox[{"3", " ", 
   SuperscriptBox["k", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["q0", "3"], " ", 
   SuperscriptBox["q1", "3"]}], "-", 
  FractionBox[
   RowBox[{"7", " ", 
    SuperscriptBox["q0", "4"], " ", 
    SuperscriptBox["q1", "3"]}], 
   SuperscriptBox["k", 
    RowBox[{"3", "/", "2"}]]], "-", 
  FractionBox[
   RowBox[{"15", " ", 
    SuperscriptBox["q0", "4"], " ", 
    SuperscriptBox["q1", "3"]}], 
   SqrtBox["k"]], "-", 
  RowBox[{"15", " ", 
   SqrtBox["k"], " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "3"]}], "-", 
  RowBox[{"7", " ", 
   SuperscriptBox["k", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "3"]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["q0", "3"], " ", 
   SuperscriptBox["q1", "4"]}], "+", 
  FractionBox[
   RowBox[{"4", " ", 
    SuperscriptBox["q0", "3"], " ", 
    SuperscriptBox["q1", "4"]}], "k"], "+", 
  RowBox[{"4", " ", "k", " ", 
   SuperscriptBox["q0", "3"], " ", 
   SuperscriptBox["q1", "4"]}], "+", 
  RowBox[{"26", " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "4"]}], "+", 
  FractionBox[
   RowBox[{"5", " ", 
    SuperscriptBox["q0", "4"], " ", 
    SuperscriptBox["q1", "4"]}], 
   SuperscriptBox["k", "2"]], "+", 
  FractionBox[
   RowBox[{"18", " ", 
    SuperscriptBox["q0", "4"], " ", 
    SuperscriptBox["q1", "4"]}], "k"], "+", 
  RowBox[{"18", " ", "k", " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "4"]}], "+", 
  RowBox[{"5", " ", 
   SuperscriptBox["k", "2"], " ", 
   SuperscriptBox["q0", "4"], " ", 
   SuperscriptBox["q1", "4"]}]}]], "Output",
 CellChangeTimes->{3.696703385626154*^9}]
}, Open  ]],

Cell["Which indeed agrees with the previous formulae", "Text",
 CellChangeTimes->{{3.6967035748673143`*^9, 3.696703585561789*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"1", "+", 
   RowBox[{"Total", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", "q0", ")"}], "^", "i"}], " ", 
        RowBox[{"q1", "^", "j"}], " ", 
        RowBox[{"SumOfFPwithDimLimit", "[", 
         RowBox[{"i", ",", "j", ",", "1000", ",", "10", ",", "10", ",", 
          RowBox[{"-", "1020"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], "]"}], "-", 
   
   RowBox[{"Expand", "[", 
    RowBox[{"PowerExpand", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"ZrefPROVA", "[", 
           RowBox[{
            RowBox[{"-", "q0"}], ",", "q1", ",", "k"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q0", ",", "0", ",", "4"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"q1", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], "]"}], 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.696703404563533*^9, 3.696703451541553*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6967035179463654`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{808, 620},
WindowMargins->{{50, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (July 28, \
2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 125, 1, 148, "Title"],
Cell[CellGroupData[{
Cell[730, 27, 126, 2, 65, "Chapter"],
Cell[859, 31, 2840, 47, 433, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3736, 83, 182, 2, 65, "Chapter"],
Cell[CellGroupData[{
Cell[3943, 89, 324, 6, 75, "Input"],
Cell[CellGroupData[{
Cell[4292, 99, 159, 2, 24, "Print"],
Cell[4454, 103, 329, 8, 24, "Print"],
Cell[4786, 113, 389, 8, 24, "Print"],
Cell[5178, 123, 125, 1, 24, "Print"],
Cell[5306, 126, 125, 1, 24, "Print"],
Cell[5434, 129, 121, 1, 24, "Print"],
Cell[5558, 132, 121, 1, 24, "Print"],
Cell[5682, 135, 118, 1, 24, "Print"],
Cell[5803, 138, 113, 1, 24, "Print"],
Cell[5919, 141, 116, 1, 24, "Print"],
Cell[6038, 144, 123, 1, 24, "Print"],
Cell[6164, 147, 118, 1, 24, "Print"],
Cell[6285, 150, 121, 1, 24, "Print"],
Cell[6409, 153, 119, 1, 24, "Print"],
Cell[6531, 156, 116, 1, 24, "Print"],
Cell[6650, 159, 118, 1, 24, "Print"],
Cell[6771, 162, 128, 1, 24, "Print"],
Cell[6902, 165, 128, 1, 24, "Print"],
Cell[7033, 168, 127, 1, 24, "Print"],
Cell[7163, 171, 118, 1, 24, "Print"],
Cell[7284, 174, 120, 1, 24, "Print"],
Cell[7407, 177, 117, 1, 24, "Print"],
Cell[7527, 180, 118, 1, 24, "Print"],
Cell[7648, 183, 116, 1, 24, "Print"],
Cell[7767, 186, 116, 1, 24, "Print"],
Cell[7886, 189, 122, 1, 24, "Print"],
Cell[8011, 192, 133, 1, 24, "Print"],
Cell[8147, 195, 133, 1, 24, "Print"],
Cell[8283, 198, 117, 1, 24, "Print"],
Cell[8403, 201, 317, 6, 24, "Print"],
Cell[8723, 209, 116, 1, 24, "Print"],
Cell[8842, 212, 119, 1, 24, "Print"],
Cell[8964, 215, 117, 1, 24, "Print"],
Cell[9084, 218, 1500, 52, 857, "Print"],
Cell[10587, 272, 134, 1, 24, "Print"],
Cell[10724, 275, 12546, 268, 55, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[23319, 549, 189, 2, 64, "Section"],
Cell[23511, 553, 461, 7, 49, "Text"],
Cell[23975, 562, 246, 4, 32, "Input"],
Cell[24224, 568, 126, 2, 32, "Input"],
Cell[CellGroupData[{
Cell[24375, 574, 333, 8, 54, "Input"],
Cell[24711, 584, 141, 3, 32, "Output"],
Cell[24855, 589, 139, 3, 32, "Output"]
}, Open  ]],
Cell[25009, 595, 235, 5, 32, "Input"],
Cell[25247, 602, 1055, 26, 32, "Input"],
Cell[26305, 630, 982, 25, 32, "Input"],
Cell[27290, 657, 1014, 26, 32, "Input"],
Cell[28307, 685, 1081, 27, 32, "Input"],
Cell[29391, 714, 1053, 26, 32, "Input"],
Cell[30447, 742, 958, 25, 32, "Input"],
Cell[31408, 769, 1014, 26, 32, "Input"],
Cell[32425, 797, 1013, 26, 32, "Input"],
Cell[33441, 825, 883, 24, 32, "Input"],
Cell[34327, 851, 542, 15, 32, "Input"],
Cell[34872, 868, 431, 8, 49, "Text"],
Cell[35306, 878, 421, 7, 30, "Text"],
Cell[35730, 887, 1015, 26, 32, "Input"],
Cell[36748, 915, 369, 8, 32, "Input"],
Cell[37120, 925, 1651, 40, 159, "Input"],
Cell[38774, 967, 194, 4, 30, "Text"],
Cell[38971, 973, 1397, 33, 96, "Input"],
Cell[40371, 1008, 168, 3, 30, "Text"],
Cell[40542, 1013, 227, 5, 32, "Input"],
Cell[40772, 1020, 299, 6, 32, "Input"],
Cell[41074, 1028, 300, 6, 32, "Input"],
Cell[41377, 1036, 299, 6, 32, "Input"],
Cell[41679, 1044, 298, 6, 32, "Input"],
Cell[41980, 1052, 301, 6, 32, "Input"],
Cell[42284, 1060, 299, 6, 32, "Input"],
Cell[42586, 1068, 325, 6, 32, "Input"],
Cell[42914, 1076, 323, 6, 32, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43274, 1087, 186, 2, 64, "Section"],
Cell[43463, 1091, 254, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[43742, 1100, 1113, 28, 54, "Input"],
Cell[44858, 1130, 1104, 28, 54, "Output"]
}, Open  ]],
Cell[45977, 1161, 656, 10, 49, "Text"],
Cell[46636, 1173, 1239, 30, 75, "Input"],
Cell[47878, 1205, 276, 5, 30, "Text"],
Cell[48157, 1212, 754, 19, 32, "Input"],
Cell[48914, 1233, 684, 18, 32, "Input"],
Cell[49601, 1253, 241, 5, 30, "Text"],
Cell[49845, 1260, 847, 20, 32, "Input"],
Cell[50695, 1282, 682, 18, 32, "Input"],
Cell[51380, 1302, 2182, 59, 138, "Input"],
Cell[53565, 1363, 1649, 46, 75, "Input"],
Cell[55217, 1411, 929, 14, 87, "Text"],
Cell[56149, 1427, 507, 14, 32, "Input"],
Cell[56659, 1443, 1377, 31, 75, "Input"],
Cell[CellGroupData[{
Cell[58061, 1478, 255, 6, 32, "Input"],
Cell[58319, 1486, 120, 2, 32, "Output"]
}, Open  ]],
Cell[58454, 1491, 1401, 31, 75, "Input"],
Cell[CellGroupData[{
Cell[59880, 1526, 256, 6, 32, "Input"],
Cell[60139, 1534, 119, 2, 32, "Output"]
}, Open  ]],
Cell[60273, 1539, 1401, 31, 75, "Input"],
Cell[CellGroupData[{
Cell[61699, 1574, 301, 7, 32, "Input"],
Cell[62003, 1583, 169, 2, 32, "Output"]
}, Open  ]],
Cell[62187, 1588, 1452, 32, 75, "Input"],
Cell[CellGroupData[{
Cell[63664, 1624, 350, 8, 32, "Input"],
Cell[64017, 1634, 97, 1, 32, "Output"]
}, Open  ]],
Cell[64129, 1638, 1453, 32, 75, "Input"],
Cell[CellGroupData[{
Cell[65607, 1674, 350, 8, 32, "Input"],
Cell[65960, 1684, 95, 1, 32, "Output"]
}, Open  ]],
Cell[66070, 1688, 1455, 32, 75, "Input"],
Cell[67528, 1722, 454, 10, 32, "Input"],
Cell[67985, 1734, 1453, 32, 75, "Input"],
Cell[69441, 1768, 460, 10, 32, "Input"],
Cell[69904, 1780, 1453, 32, 75, "Input"],
Cell[71360, 1814, 455, 10, 32, "Input"],
Cell[71818, 1826, 507, 10, 54, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72362, 1841, 164, 2, 64, "Section"],
Cell[72529, 1845, 420, 7, 49, "Text"],
Cell[72952, 1854, 363, 7, 30, "Text"],
Cell[73318, 1863, 621, 17, 32, "Input"],
Cell[73942, 1882, 952, 24, 117, "Input"],
Cell[74897, 1908, 950, 24, 117, "Input"],
Cell[75850, 1934, 1005, 25, 117, "Input"],
Cell[76858, 1961, 1001, 25, 117, "Input"],
Cell[77862, 1988, 1001, 25, 117, "Input"],
Cell[78866, 2015, 1001, 25, 117, "Input"],
Cell[79870, 2042, 1001, 25, 117, "Input"],
Cell[80874, 2069, 1005, 25, 117, "Input"],
Cell[81882, 2096, 108, 1, 30, "Text"],
Cell[81993, 2099, 1003, 25, 117, "Input"],
Cell[82999, 2126, 497, 10, 54, "Input"],
Cell[83499, 2138, 307, 6, 30, "Text"],
Cell[83809, 2146, 1625, 48, 96, "Input"],
Cell[85437, 2196, 193, 4, 30, "Text"],
Cell[85633, 2202, 1087, 31, 54, "Input"],
Cell[86723, 2235, 285, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[87033, 2244, 973, 23, 75, "Input"],
Cell[88009, 2269, 10175, 265, 128, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[98221, 2539, 378, 8, 54, "Input"],
Cell[98602, 2549, 10336, 269, 128, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[108999, 2825, 159, 2, 65, "Chapter"],
Cell[CellGroupData[{
Cell[109183, 2831, 235, 3, 64, "Section"],
Cell[109421, 2836, 186, 4, 30, "Text"],
Cell[109610, 2842, 229, 3, 32, "Input"],
Cell[109842, 2847, 164, 3, 30, "Text"],
Cell[110009, 2852, 1320, 33, 75, "Input"],
Cell[111332, 2887, 239, 4, 30, "Text"],
Cell[111574, 2893, 4223, 112, 138, "Input"],
Cell[115800, 3007, 778, 11, 68, "Text"],
Cell[116581, 3020, 1160, 37, 32, "Input"],
Cell[117744, 3059, 169, 4, 30, "Text"],
Cell[117916, 3065, 3211, 57, 222, "Input"],
Cell[121130, 3124, 93, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[121248, 3129, 296, 7, 32, "Input"],
Cell[121547, 3138, 1123, 34, 52, "Output"]
}, Open  ]],
Cell[122685, 3175, 719, 11, 68, "Text"],
Cell[123407, 3188, 8954, 180, 579, "Input"],
Cell[132364, 3370, 266, 5, 30, "Text"],
Cell[132633, 3377, 1019, 25, 54, "Input"],
Cell[133655, 3404, 94, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[133774, 3409, 154, 3, 32, "Input"],
Cell[133931, 3414, 2895, 101, 96, "Output"]
}, Open  ]],
Cell[136841, 3518, 26, 0, 32, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[136904, 3523, 153, 2, 64, "Section"],
Cell[137060, 3527, 495, 8, 49, "Text"],
Cell[137558, 3537, 588, 15, 32, "Input"],
Cell[138149, 3554, 164, 3, 30, "Text"],
Cell[138316, 3559, 532, 12, 32, "Input"],
Cell[138851, 3573, 283, 5, 30, "Text"],
Cell[139137, 3580, 1162, 30, 75, "Input"],
Cell[140302, 3612, 92, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[140419, 3617, 230, 4, 32, "Input"],
Cell[140652, 3623, 276, 8, 52, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[140977, 3637, 211, 3, 64, "Section"],
Cell[141191, 3642, 636, 10, 49, "Text"],
Cell[141830, 3654, 111, 1, 30, "Text"],
Cell[141944, 3657, 805, 28, 32, "Input"],
Cell[142752, 3687, 4737, 118, 138, "Input"],
Cell[147492, 3807, 160, 3, 30, "Text"],
Cell[147655, 3812, 790, 22, 32, "Input"],
Cell[148448, 3836, 267, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[148740, 3845, 2636, 63, 222, "Input"],
Cell[151379, 3910, 519, 11, 32, "Output"]
}, Open  ]],
Cell[151913, 3924, 181, 4, 30, "Text"],
Cell[152097, 3930, 1707, 43, 75, "Input"],
Cell[153807, 3975, 1257, 31, 32, "Input"],
Cell[CellGroupData[{
Cell[155089, 4010, 242, 5, 32, "Input"],
Cell[155334, 4017, 117, 2, 32, "Output"]
}, Open  ]],
Cell[155466, 4022, 203, 4, 30, "Text"],
Cell[155672, 4028, 2013, 47, 75, "Input"],
Cell[157688, 4077, 1373, 32, 32, "Input"],
Cell[CellGroupData[{
Cell[159086, 4113, 291, 6, 32, "Input"],
Cell[159380, 4121, 119, 2, 32, "Output"]
}, Open  ]],
Cell[159514, 4126, 209, 4, 30, "Text"],
Cell[159726, 4132, 1786, 45, 75, "Input"],
Cell[161515, 4179, 1338, 32, 32, "Input"],
Cell[CellGroupData[{
Cell[162878, 4215, 299, 6, 32, "Input"],
Cell[163180, 4223, 94, 1, 32, "Output"]
}, Open  ]],
Cell[163289, 4227, 406, 7, 49, "Text"],
Cell[163698, 4236, 1760, 51, 32, "Input"],
Cell[CellGroupData[{
Cell[165483, 4291, 570, 16, 32, "Input"],
Cell[166056, 4309, 1177, 34, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[167270, 4348, 924, 22, 32, "Input"],
Cell[168197, 4372, 1324, 36, 32, "Output"]
}, Open  ]],
Cell[169536, 4411, 135, 1, 30, "Text"],
Cell[169674, 4414, 376, 7, 30, "Text"],
Cell[170053, 4423, 2289, 69, 75, "Input"],
Cell[172345, 4494, 1022, 30, 54, "Input"],
Cell[173370, 4526, 135, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[173530, 4531, 661, 16, 32, "Input"],
Cell[174194, 4549, 4054, 133, 149, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[178285, 4687, 639, 18, 32, "Input"],
Cell[178927, 4707, 3034, 109, 98, "Output"]
}, Open  ]],
Cell[181976, 4819, 128, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[182129, 4824, 1255, 33, 54, "Input"],
Cell[183387, 4859, 92, 1, 32, "Output"]
}, Open  ]],
Cell[183494, 4863, 253, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[183772, 4872, 6126, 171, 138, "Input"],
Cell[189901, 5045, 605, 22, 69, "Output"]
}, Open  ]],
Cell[190521, 5070, 797, 26, 72, "Input"],
Cell[191321, 5098, 608, 17, 32, "Input"],
Cell[CellGroupData[{
Cell[191954, 5119, 746, 19, 32, "Input"],
Cell[192703, 5140, 3931, 131, 149, "Output"]
}, Open  ]],
Cell[196649, 5274, 130, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[196804, 5279, 1232, 34, 54, "Input"],
Cell[198039, 5315, 72, 1, 32, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

