(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    628377,      18033]
NotebookOptionsPosition[    607022,      17390]
NotebookOutlinePosition[    607376,      17406]
CellTagsIndexPosition[    607333,      17403]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["ORBIFOLDS", "Title",
 CellChangeTimes->{{3.716631496923491*^9, 3.7166314989464083`*^9}, {
  3.716632390973617*^9, 3.716632391941204*^9}}],

Cell[CellGroupData[{

Cell["Generalities and Definitions", "Chapter",
 CellChangeTimes->{{3.716812485098357*^9, 3.716812490446499*^9}}],

Cell["\<\
Here we collect some general functions (for example combinatorics...) which \
will be helpful in the following.\
\>", "Text",
 CellChangeTimes->{{3.716632338189068*^9, 3.71663236502175*^9}}],

Cell[CellGroupData[{

Cell["Assumptions", "Subsection",
 CellChangeTimes->{{3.7166328324244967`*^9, 3.716632833830491*^9}}],

Cell["\<\
These assumptionson the formal parameters make it easier to simplify \
expressions\
\>", "Text",
 CellChangeTimes->{{3.717915553411954*^9, 3.717915556757875*^9}, {
  3.7179155901090727`*^9, 3.7179156074979773`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"$Assumptions", "=", 
  RowBox[{
   RowBox[{"Element", "[", 
    RowBox[{"t1", ",", "Reals"}], "]"}], "&&", 
   RowBox[{"t1", ">", "0"}], "&&", 
   RowBox[{"Element", "[", 
    RowBox[{"t2", ",", "Reals"}], "]"}], "&&", 
   RowBox[{"t2", ">", "0"}], "&&", 
   RowBox[{"Element", "[", 
    RowBox[{"t3", ",", "Reals"}], "]"}], "&&", 
   RowBox[{"t3", ">", "0"}], "&&", 
   RowBox[{"Element", "[", 
    RowBox[{"x", ",", "Reals"}], "]"}], "&&", 
   RowBox[{"x", ">", "0"}], "&&", 
   RowBox[{"Element", "[", 
    RowBox[{"k", ",", "Reals"}], "]"}], "&&", 
   RowBox[{"k", ">", "0"}], "&&", 
   RowBox[{"Element", "[", 
    RowBox[{"q", ",", "Reals"}], "]"}], "&&", 
   RowBox[{"q", ">", "0"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t1", "\[Element]", "Reals"}], "&&", 
  RowBox[{"t1", ">", "0"}], "&&", 
  RowBox[{"t2", "\[Element]", "Reals"}], "&&", 
  RowBox[{"t2", ">", "0"}], "&&", 
  RowBox[{"t3", "\[Element]", "Reals"}], "&&", 
  RowBox[{"t3", ">", "0"}], "&&", 
  RowBox[{"x", "\[Element]", "Reals"}], "&&", 
  RowBox[{"x", ">", "0"}], "&&", 
  RowBox[{"k", "\[Element]", "Reals"}], "&&", 
  RowBox[{"k", ">", "0"}], "&&", 
  RowBox[{"q", "\[Element]", "Reals"}], "&&", 
  RowBox[{"q", ">", "0"}]}]], "Output",
 CellChangeTimes->{3.68631024036662*^9, 3.686394937537538*^9, 
  3.709375714380474*^9, 3.7094558144457407`*^9, 3.709472196387844*^9, 
  3.70954442147871*^9, 3.709556420815483*^9, 3.7096188009495277`*^9, 
  3.709799707868971*^9, 3.7099189144283667`*^9, 3.709971764034009*^9, 
  3.710073771619473*^9, 3.710317861685989*^9, 3.710572650147808*^9, 
  3.7106074052756987`*^9, 3.710659557365287*^9, 3.711170532474676*^9, 
  3.71117219296681*^9, 3.7167152446265078`*^9, 3.7167343944406433`*^9, 
  3.716799450079566*^9, 3.7168699759114313`*^9, 3.716897640169744*^9, 
  3.7177471353678427`*^9, 3.717751257385376*^9, 3.717751317839653*^9, 
  3.7178311731724253`*^9, 3.717851888611981*^9, 3.717915893613323*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Combinatorics", "Subsection",
 CellChangeTimes->{{3.7166328085752687`*^9, 3.7166328100590677`*^9}}],

Cell["\<\
These functions introduce the combinatorics of plane partitions\
\>", "Text",
 CellChangeTimes->{{3.7166328874776783`*^9, 3.716632894747633*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"<<", "Combinatorica`"}], "\n"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"coversQ", "[", 
    RowBox[{"parent_", ",", " ", "child_"}], "]"}], " ", ":=", "\n", "  ", 
   RowBox[{"And", " ", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Length", "[", "parent", "]"}], " ", ">=", " ", 
      RowBox[{"Length", "[", "child", "]"}]}], " ", ",", "\n", "    ", 
     RowBox[{
      RowBox[{"Min", "[", 
       RowBox[{
        RowBox[{"Take", "[", " ", 
         RowBox[{"parent", ",", " ", 
          RowBox[{"Length", "@", "child"}]}], "]"}], " ", "-", " ", "child"}],
        "]"}], " ", ">=", " ", "0"}]}], "]"}]}], "\n"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"planepartitionQ", "[", "par_", "]"}], " ", ":=", " ", "\n", "  ", 
   
   RowBox[{
    RowBox[{"MatchQ", "[", 
     RowBox[{"par", ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "___Integer", "}"}], " ", ".."}], "}"}]}], "]"}], " ", "&&",
     " ", "\n", "    ", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Length", "[", "par", "]"}], " ", ">", " ", "1"}], ",", " ", 
      RowBox[{"And", " ", "@@", " ", 
       RowBox[{"MapThread", "[", 
        RowBox[{"coversQ", ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Drop", "[", 
            RowBox[{"par", ",", " ", 
             RowBox[{"-", "1"}]}], "]"}], ",", " ", 
           RowBox[{"Rest", "[", "par", "]"}]}], "}"}]}], "]"}]}], ",", "\n", 
      "       ", "True"}], "]"}]}]}], "\n"}], "\n", 
 RowBox[{
  RowBox[{"PlanePartitions", "[", "n_Integer", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"l1", ",", " ", "l2", ",", " ", "l3", ",", " ", "l4"}], "}"}], 
    ",", "\n", 
    RowBox[{
     RowBox[{"l1", " ", "=", " ", 
      RowBox[{"z", " ", "@@@", " ", 
       RowBox[{"Partitions", "[", "n", "]"}]}]}], " ", ";", "\n", 
     RowBox[{"l2", " ", "=", " ", 
      RowBox[{"l1", " ", "/.", " ", 
       RowBox[{
        RowBox[{"k_Integer", " ", "/;", " ", 
         RowBox[{"(", 
          RowBox[{"k", " ", ">", " ", "1"}], ")"}]}], " ", ":>", " ", 
        RowBox[{"w", " ", "@@", " ", 
         RowBox[{"Partitions", "[", "k", "]"}]}]}]}]}], ";", "\n", 
     RowBox[{"l3", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"l2", " ", "/.", " ", 
          RowBox[{
           RowBox[{"z", "[", 
            RowBox[{"x_w", ",", " ", 
             RowBox[{"y", " ", ":", " ", 
              RowBox[{"(", 
               RowBox[{"1", " ", "..."}], ")"}]}]}], "]"}], " ", ":>", " ", 
           RowBox[{"Thread", "[", 
            RowBox[{
             RowBox[{"z", "[", 
              RowBox[{"x", ",", " ", "y"}], "]"}], ",", " ", "w"}], "]"}]}]}],
          " ", "/.", " ", "\n", "            ", 
         RowBox[{
          RowBox[{"z", "[", "x__w", "]"}], " ", ":>", " ", 
          RowBox[{"Outer", "[", 
           RowBox[{"z", ",", " ", "x"}], "]"}]}]}], " ", "/.", " ", "\n", 
        "          ", 
        RowBox[{
         RowBox[{"z", "[", 
          RowBox[{"x__w", ",", " ", 
           RowBox[{"y", " ", ":", " ", 
            RowBox[{"(", 
             RowBox[{"1", " ", "..."}], ")"}]}]}], "]"}], " ", ":>", " ", 
         "\n", "            ", 
         RowBox[{"Outer", "[", 
          RowBox[{"z", ",", " ", "x", ",", " ", 
           RowBox[{"Sequence", " ", "@@", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"{", "y", "}"}], " ", "/.", " ", 
              RowBox[{"1", " ", "->", " ", 
               RowBox[{"w", "[", "1", "]"}]}]}], ")"}]}]}], "]"}]}]}], " ", "/.",
        " ", 
       RowBox[{"w", " ", "->", " ", "Sequence"}]}]}], ";", "\n", 
     RowBox[{"l4", " ", "=", " ", 
      RowBox[{
       RowBox[{"l3", " ", "/.", " ", 
        RowBox[{
         RowBox[{"z", "[", 
          RowBox[{"x___List", ",", " ", 
           RowBox[{"y", " ", ":", " ", 
            RowBox[{"(", 
             RowBox[{"1", " ", ".."}], ")"}]}]}], "]"}], " ", ":>", " ", 
         RowBox[{"z", "[", 
          RowBox[{"x", ",", " ", 
           RowBox[{"Sequence", " ", "@@", " ", 
            RowBox[{"Transpose", "[", 
             RowBox[{"{", 
              RowBox[{"{", "y", "}"}], "}"}], "]"}]}]}], "]"}]}]}], " ", "/.",
        " ", "\n", "        ", 
       RowBox[{"z", " ", "->", " ", "List"}]}]}], ";", "\n", 
     RowBox[{"Cases", "[", 
      RowBox[{
       RowBox[{"Union", "[", "l4", "]"}], ",", " ", 
       RowBox[{"_", "?", "planepartitionQ"}]}], "]"}]}]}], "]"}]}]}], "Input"],

Cell[BoxData[
 TemplateBox[{
  "General","compat",
   "\"Combinatorica Graph and Permutations functionality has been superseded \
by preloaded functionality. The package now being loaded may conflict with \
this. Please see the Compatibility Guide for details.\"",2,2,1,
   27623743715054181559,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.674670329684252*^9, 3.674985634726863*^9, 
  3.675103193304369*^9, 3.6795769445032883`*^9, 3.6857940137377367`*^9, 
  3.686310281126185*^9, 3.686394938508079*^9, 3.7093757170608263`*^9, 
  3.709455815653338*^9, 3.709472198621266*^9, 3.709544427430182*^9, 
  3.709556420892467*^9, 3.709618800991658*^9, 3.70979971244189*^9, 
  3.709918914473261*^9, 3.709971766674098*^9, 3.710073772612849*^9, 
  3.7103178617158737`*^9, 3.710572650225644*^9, 3.71060740541074*^9, 
  3.7106595573908587`*^9, 3.711170532572278*^9, 3.711172192995782*^9, 
  3.716715244751295*^9, 3.7167343945254927`*^9, 3.716799450249771*^9, 
  3.716869976029167*^9, 3.7168976403324747`*^9, 3.7177471354834538`*^9, 
  3.717751257458664*^9, 3.71775131788701*^9, 3.71783117332493*^9, 
  3.717851888700432*^9, 3.717915893760284*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlanePartitionDiagram", "[", "l_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", "k"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Graphics3D", "[", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Cuboid", "[", 
        RowBox[{"{", 
         RowBox[{"j", ",", 
          RowBox[{"-", "i"}], ",", "k"}], "}"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "l", "]"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"j", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"l", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"k", ",", 
         RowBox[{"l", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "}"}]}], 
      "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Degree of polynomials", "Subsection",
 CellChangeTimes->{{3.7166328518920927`*^9, 3.716632854522056*^9}}],

Cell["\<\
These functions consider polynomials of a certain degree in many variables; \
useful to exctract polymomial of a certain order from multi parameter series \
expansions. BoundDegree gives back monomial of fixed total degree. We will \
use these functions to compare different series expansions up to a certain \
degree.\
\>", "Text",
 CellChangeTimes->{{3.716632908760262*^9, 3.7166329530104113`*^9}, {
  3.7179156378887587`*^9, 3.717915666714826*^9}, {3.717915745703431*^9, 
  3.717915787193078*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"AlgebraicDegree", "[", 
    RowBox[{"eqn_", ",", "vars_List"}], "]"}], ":=", 
   RowBox[{"Max", "[", 
    RowBox[{"Total", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"GroebnerBasis`DistributedTermsList", "[", 
        RowBox[{
         RowBox[{"eqn", "/.", 
          RowBox[{"Equal", "\[RuleDelayed]", "Subtract"}]}], ",", "vars"}], 
        "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "All", ",", "1"}], "]"}], "]"}], ",", 
      RowBox[{"{", "2", "}"}]}], "]"}], "]"}]}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AlgebraicDegree", "[", "eqn_", "]"}], ":=", 
  RowBox[{"AlgebraicDegree", "[", 
   RowBox[{
    RowBox[{"Expand", "[", "eqn", "]"}], ",", 
    RowBox[{"Variables", "[", "eqn", "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.687178031490088*^9, 3.6871780314925957`*^9}, {
  3.687178202822741*^9, 3.687178206063671*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BoundDegree", "[", 
   RowBox[{"list_", ",", "N_"}], "]"}], ":=", 
  RowBox[{"DeleteCases", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Reap", "[", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"Sow", "[", 
          RowBox[{"CheckDegree", "[", 
           RowBox[{
            RowBox[{"list", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", "N"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "list", "]"}]}], "}"}]}], "]"}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], "]"}], ",", "Null"}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.6871799416707277`*^9, 3.6871799601492147`*^9}, {
  3.6872491312555113`*^9, 3.687249138531043*^9}, {3.687251024910243*^9, 
  3.687251026548993*^9}, {3.6872517550351677`*^9, 3.687251795841962*^9}, {
  3.687251841029765*^9, 3.687251843253104*^9}, {3.687255676190999*^9, 
  3.687255737118602*^9}}],

Cell["This function neglects the degree of k", "Text",
 CellChangeTimes->{{3.716721117188221*^9, 3.716721119069055*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BoundDegreeK", "[", 
   RowBox[{"list_", ",", "N_"}], "]"}], ":=", 
  RowBox[{"DeleteCases", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Reap", "[", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"Sow", "[", 
          RowBox[{"CheckDegreeK", "[", 
           RowBox[{
            RowBox[{"list", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", "N"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "list", "]"}]}], "}"}]}], "]"}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], "]"}], ",", "Null"}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.687255939703939*^9, 3.687255942190785*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CheckDegree", "[", 
   RowBox[{"poly_", ",", "N_"}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"AlgebraicDegree", "[", "poly", "]"}], ">", "N"}], ",", "Null", 
    ",", "poly"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.687251040302538*^9, 3.687251081404067*^9}, {
   3.687251127847188*^9, 3.6872511351028347`*^9}, {3.6872516741885433`*^9, 
   3.687251718686469*^9}, 3.687251825981153*^9, {3.6872557055993032`*^9, 
   3.6872557070704927`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CheckDegreeK", "[", 
   RowBox[{"poly_", ",", "N_"}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"AlgebraicDegree", "[", 
      RowBox[{"poly", "//.", 
       RowBox[{"k", "\[Rule]", "1"}]}], "]"}], ">", "N"}], ",", "Null", ",", 
    "poly"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.687255855449782*^9, 3.687255860992613*^9}, {
  3.687255900561749*^9, 3.687255913558909*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Other quiver functions", "Subsection",
 CellChangeTimes->{{3.7166328518920927`*^9, 3.716632854522056*^9}, {
  3.716721045280258*^9, 3.716721049459361*^9}}],

Cell["\<\
This function take an integer n and gives a list of all the k-vectors which \
contains partitions of n. It will make easier to check quiver partition \
functions, where k is the number of nodes and n the overall instanton number\
\>", "Text",
 CellChangeTimes->{{3.7167211289251738`*^9, 3.716721217503706*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"n_", ",", "k_"}], "]"}], ":=", 
  RowBox[{"Flatten", "[", 
   RowBox[{
    RowBox[{"DeleteCases", "[", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"Reap", "[", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"Sow", "[", 
            RowBox[{"Permutations", "[", 
             RowBox[{"PadRight", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"IntegerPartitions", "[", 
                 RowBox[{"n", ",", "k"}], "]"}], "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", "k"}], "]"}], "]"}], 
            "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", 
              RowBox[{"IntegerPartitions", "[", 
               RowBox[{"n", ",", "k"}], "]"}], "]"}]}], "}"}]}], "]"}], "]"}],
         ",", "2"}], "]"}], ",", "Null"}], "]"}], ",", "1"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.7100739395050077`*^9, 3.710073946877993*^9}, {
  3.7100740440442467`*^9, 3.7100740441016903`*^9}, {3.710074256194696*^9, 
  3.710074256240183*^9}, {3.710316422085322*^9, 3.710316425684539*^9}, {
  3.710317292521253*^9, 3.7103174767668552`*^9}, {3.710317511751114*^9, 
  3.710317593586568*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DistributeIntoNodes", "[", 
  RowBox[{"3", ",", "4"}], "]"}]], "Input",
 CellChangeTimes->{{3.716721055981511*^9, 3.71672106160433*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "3", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "3", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "0", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "2", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "2", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "2", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "2", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "2", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "1", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.716721062212593*^9, 3.71673439484231*^9, 
  3.716799450549782*^9, 3.716869976283887*^9, 3.716897640720705*^9, 
  3.71774713573671*^9, 3.717751257761744*^9, 3.7177513180708*^9, 
  3.7178311735943604`*^9, 3.71785188901954*^9, 3.717915894070931*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Tori", "Subsection",
 CellChangeTimes->{{3.7166328518920927`*^9, 3.716632854522056*^9}, {
  3.716721045280258*^9, 3.716721049459361*^9}, {3.7172442139806967`*^9, 
  3.717244214343252*^9}}],

Cell["We define various tori to take the refined limit", "Text",
 CellChangeTimes->{{3.717244235086083*^9, 3.717244241329797*^9}, 
   3.717915808559717*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"TorusT1", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"t1", "\[Rule]", 
     RowBox[{"x", "^", 
      RowBox[{"(", 
       RowBox[{"100", "-", "1"}], ")"}]}]}], ",", 
    RowBox[{"t3", "\[Rule]", 
     RowBox[{"x", "^", 
      RowBox[{"(", 
       RowBox[{"-", "100"}], ")"}]}]}], ",", 
    RowBox[{"t2", "\[Rule]", "x"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"TorusT2", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"t2", "\[Rule]", 
     RowBox[{"x", "^", 
      RowBox[{"(", 
       RowBox[{"100", "-", "1"}], ")"}]}]}], ",", 
    RowBox[{"t1", "\[Rule]", 
     RowBox[{"x", "^", 
      RowBox[{"(", 
       RowBox[{"-", "100"}], ")"}]}]}], ",", 
    RowBox[{"t3", "\[Rule]", "x"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"TorusT3", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"t3", "\[Rule]", 
     RowBox[{"x", "^", 
      RowBox[{"(", 
       RowBox[{"100", "-", "1"}], ")"}]}]}], ",", 
    RowBox[{"t2", "\[Rule]", 
     RowBox[{"x", "^", 
      RowBox[{"(", 
       RowBox[{"-", "100"}], ")"}]}]}], ",", 
    RowBox[{"t1", "\[Rule]", "x"}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.716642322362462*^9, 3.716642353518425*^9}, {
  3.7177512393152113`*^9, 3.717751249439588*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"t1", "\[Rule]", 
    SuperscriptBox["x", "99"]}], ",", 
   RowBox[{"t3", "\[Rule]", 
    FractionBox["1", 
     SuperscriptBox["x", "100"]]}], ",", 
   RowBox[{"t2", "\[Rule]", "x"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.717747135786014*^9, {3.717751250111067*^9, 3.717751257781204*^9}, 
   3.7177513181141157`*^9, 3.717831173643318*^9, 3.717851889080559*^9, 
   3.717915894129039*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"t2", "\[Rule]", 
    SuperscriptBox["x", "99"]}], ",", 
   RowBox[{"t1", "\[Rule]", 
    FractionBox["1", 
     SuperscriptBox["x", "100"]]}], ",", 
   RowBox[{"t3", "\[Rule]", "x"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.717747135786014*^9, {3.717751250111067*^9, 3.717751257781204*^9}, 
   3.7177513181141157`*^9, 3.717831173643318*^9, 3.717851889080559*^9, 
   3.7179158941425343`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"t3", "\[Rule]", 
    SuperscriptBox["x", "99"]}], ",", 
   RowBox[{"t2", "\[Rule]", 
    FractionBox["1", 
     SuperscriptBox["x", "100"]]}], ",", 
   RowBox[{"t1", "\[Rule]", "x"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.717747135786014*^9, {3.717751250111067*^9, 3.717751257781204*^9}, 
   3.7177513181141157`*^9, 3.717831173643318*^9, 3.717851889080559*^9, 
   3.717915894151465*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Flat space", "Chapter",
 CellChangeTimes->{{3.7168125131023283`*^9, 3.716812515734048*^9}}],

Cell["\<\
As a first example we consider flat space and reproduce the computations of \
Nekrasov-Okounkov\
\>", "Text",
 CellChangeTimes->{{3.7166323747512407`*^9, 3.716632380663312*^9}, {
  3.7179158265754557`*^9, 3.7179158348911343`*^9}}],

Cell[CellGroupData[{

Cell["Localization", "Subsection",
 CellChangeTimes->{{3.7166394850120697`*^9, 3.716639487443104*^9}}],

Cell["\<\
We define the weight decomposition of the vector space V at a fixed point\
\>", "Text",
 CellChangeTimes->{{3.716633708732398*^9, 3.7166337256678658`*^9}, {
  3.716633780107216*^9, 3.716633782400063*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PPV", "[", 
   RowBox[{"l_List", ",", "t1_", ",", "t2_", ",", "t3_"}], "]"}], ":=", 
  RowBox[{"Total", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"t1", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "i"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"t2", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "j"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"t3", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "k"}], "+", "1"}], "}"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "l", "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"j", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"l", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"l", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "}"}]}], 
       "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], "]"}], 
   "]"}]}]], "Input"],

Cell["The virtual tangent space at a fixed point decomposes as", "Text",
 CellChangeTimes->{{3.675101835423895*^9, 3.675101844366613*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TvirC3Fixed", "[", 
   RowBox[{"list_", ",", "t1_", ",", "t2_", ",", "t3_", ",", "k_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"PPV", "[", 
    RowBox[{"list", ",", "t1", ",", "t2", ",", "t3"}], "]"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"t1", "+", "t2", "+", "t3", "-", "1"}], ")"}], 
    RowBox[{"PPV", "[", 
     RowBox[{"list", ",", 
      RowBox[{"1", "/", "t1"}], ",", 
      RowBox[{"1", "/", "t2"}], ",", 
      RowBox[{"1", "/", "t3"}]}], "]"}], 
    RowBox[{"PPV", "[", 
     RowBox[{"list", ",", "t1", ",", "t2", ",", "t3"}], "]"}]}], "-", 
   RowBox[{"t1", " ", "t2", " ", "t3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"PPV", "[", 
       RowBox[{"list", ",", 
        RowBox[{"1", "/", "t1"}], ",", 
        RowBox[{"1", "/", "t2"}], ",", 
        RowBox[{"1", "/", "t3"}]}], "]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"1", "/", "t1"}], "+", 
         RowBox[{"1", "/", "t2"}], "+", 
         RowBox[{"1", "/", "t3"}], "-", "1"}], ")"}], " ", 
       RowBox[{"PPV", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}]}], "]"}], " ", 
       RowBox[{"PPV", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3"}], "]"}]}]}], 
     ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.674587994202264*^9, 3.674588008681179*^9}, {
  3.6746547289960318`*^9, 3.6746547329251757`*^9}, {3.674993518039311*^9, 
  3.674993519238812*^9}, {3.6750056749571943`*^9, 3.6750056766999826`*^9}, {
  3.6750059890160027`*^9, 3.675005990235087*^9}}],

Cell["\<\
We define the decomposition of the virtual tangent space as a function of a \
3D partition. This function takes as entry the number of boxes of the \
partition, and the position of the partition in the list \
PlanePartitions[nboxes] of plane partitions with a certain number of boxes. \
\>", "Text",
 CellChangeTimes->{{3.716633818586084*^9, 3.7166338407596483`*^9}, {
  3.716639297436874*^9, 3.7166393692058697`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"VirtualT", "[", 
   RowBox[{"nboxes_", ",", "fixedpoint_"}], "]"}], ":=", 
  RowBox[{"Expand", "[", 
   RowBox[{"TvirC3Fixed", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
      RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", "t2", ",", 
     "t3", ",", "k"}], "]"}], "]"}]}]], "Input"],

Cell["\<\
The virtual tangent space has the form Def-Obs. In this case deformations are \
dual to obstructions, and therefore we don\[CloseCurlyQuote]t need to keep \
track of both. This will speed up the computations.

For simplicity we only focus on the deformations, which are the terms with \
positive coefficients in Tvir. The next function takes the virtual tangent \
space, focuses on the positive monomials and records them in a list, \
containing the monomial without its coefficient and the coefficient \
separately, i.e. t1+2 t2 -> {{t1,1},{t2,2}}. The reason is that the \
coefficient of the monomial will become an exponent in the contribution of \
the fixed point. \
\>", "Text",
 CellChangeTimes->{{3.716639517262541*^9, 3.7166396453302526`*^9}, {
  3.71663975541392*^9, 3.716639846112514*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FPList", "[", 
   RowBox[{"nboxes_", ",", "fixedpoint_"}], "]"}], ":=", 
  RowBox[{"Flatten", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Reap", "[", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Flatten", "[", 
               RowBox[{"List", "@@", 
                RowBox[{"(", 
                 RowBox[{"Expand", "[", 
                  RowBox[{"TvirC3Fixed", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
               "//.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"t1", "\[Rule]", "1"}], ",", 
                RowBox[{"t2", "->", "1"}], ",", 
                RowBox[{"t3", "\[Rule]", "1"}], ",", 
                RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
            RowBox[{"[", "i", "]"}], "]"}], ">", "0"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Sow", "[", 
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
                RowBox[{"List", "@@", 
                 RowBox[{"(", 
                  RowBox[{"Expand", "[", 
                   RowBox[{"TvirC3Fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], 
                "\[IndentingNewLine]", "]"}], "[", 
               RowBox[{"[", "i", "]"}], "]"}], "/", 
              RowBox[{"(", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Flatten", "[", 
                   RowBox[{"List", "@@", 
                    RowBox[{"(", 
                    RowBox[{"Expand", "[", 
                    RowBox[{"TvirC3Fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
                   "//.", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"t1", "\[Rule]", "1"}], ",", 
                    RowBox[{"t2", "->", "1"}], ",", 
                    RowBox[{"t3", "\[Rule]", "1"}], ",", 
                    RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
                RowBox[{"[", "i", "]"}], "]"}], "\[IndentingNewLine]", 
               ")"}]}], ",", 
             RowBox[{
              RowBox[{"(", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"Flatten", "[", 
                 RowBox[{"List", "@@", 
                  RowBox[{"(", 
                   RowBox[{"Expand", "[", 
                    RowBox[{"TvirC3Fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
                 "//.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"t1", "\[Rule]", "1"}], ",", 
                  RowBox[{"t2", "->", "1"}], ",", 
                  RowBox[{"t3", "\[Rule]", "1"}], ",", 
                  RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "\[IndentingNewLine]", "}"}], 
           "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
        
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"Flatten", "[", 
            RowBox[{"List", "@@", 
             RowBox[{"(", 
              RowBox[{"Expand", "[", 
               RowBox[{"TvirC3Fixed", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                  RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                 "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}], 
           "]"}]}], "}"}]}], "]"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "]"}]}]], "Input"],

Cell["\<\
Now we define a function ahatp which computes the contribution of a monomial \
in the virtual tangent spaceto the localization formula. This function is \
similar to Okounkov A-hat function, but slightly different since we are \
pairing deformations and obstructions. This function gives a rational \
function of a monomial in Tvir raised to the power of its coefficient.\
\>", "Text",
 CellChangeTimes->{{3.7166398956204443`*^9, 3.7166399648662777`*^9}, {
   3.7166399949304247`*^9, 3.716640040246209*^9}, 3.716709154121318*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ahatp", "[", "list_", "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "/", 
          RowBox[{"list", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"list", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "/", "k"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"list", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"list", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], ")"}], "^", 
   RowBox[{"list", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input"],

Cell["Localization computes the contribution of a fixed point", "Text",
 CellChangeTimes->{{3.7166400475092497`*^9, 3.716640055176478*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Localization", "[", 
   RowBox[{"nboxes_", ",", "fixedpoint_"}], "]"}], ":=", 
  RowBox[{"Cancel", "[", 
   RowBox[{"PowerExpand", "[", 
    RowBox[{"Times", "@@", 
     RowBox[{"Map", "[", 
      RowBox[{"ahatp", ",", 
       RowBox[{"FPList", "[", 
        RowBox[{"nboxes", ",", "fixedpoint"}], "]"}]}], "]"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.716640043440914*^9, 3.716640043442585*^9}}],

Cell["\<\
The total contribution is obtained by summing over all the fixed points with \
fixed number of boxes\
\>", "Text",
 CellChangeTimes->{{3.7166402424122143`*^9, 3.716640261435092*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TotalContribution", "[", "nboxes_", "]"}], ":=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{"Localization", "[", 
     RowBox[{"nboxes", ",", "i"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", 
       RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "]"}]}], "}"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PartitionFunction", "[", "nboxes_", "]"}], ":=", 
  RowBox[{"1", "+", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"-", "q"}], ")"}], "^", "n"}], " ", 
      RowBox[{"TotalContribution", "[", "n", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "nboxes"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.716641503334228*^9, 3.716641555912848*^9}, {
  3.716715897487673*^9, 3.716715923584886*^9}}],

Cell["\<\
For example (we can also write this function with k=t1 t2 t3)\
\>", "Text",
 CellChangeTimes->{{3.717915871577753*^9, 3.7179158729210176`*^9}, {
  3.717915953828676*^9, 3.717915961642795*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PartitionFunction", "[", "3", "]"}]], "Input",
 CellChangeTimes->{{3.717915877051196*^9, 3.717915877497261*^9}, {
  3.7179159661660013`*^9, 3.7179159662476473`*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", 
  FractionBox[
   RowBox[{"q", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t1"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  RowBox[{
   SuperscriptBox["q", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "k"}], "+", "t1"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "k"}], "+", 
         SuperscriptBox["t1", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"k", "-", "t2"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"k", " ", "t1"}], "-", "t2"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"k", "-", "t3"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"k", " ", "t1"}], "-", "t3"}], ")"}]}], 
      RowBox[{
       SuperscriptBox["k", "3"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "t1"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"t1", "-", "t2"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"t1", "-", "t3"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "k"}], "+", "t1"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"k", "-", "t2"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"t1", "-", 
         RowBox[{"k", " ", "t2"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"k", "-", 
         SuperscriptBox["t2", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"k", "-", "t3"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"k", " ", "t2"}], "-", "t3"}], ")"}]}], 
      RowBox[{
       SuperscriptBox["k", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"t1", "-", "t2"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "t2"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"t2", "-", "t3"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "k"}], "+", "t1"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"k", "-", "t2"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"k", "-", "t3"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"t1", "-", 
         RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "t2"}], "+", 
         RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"k", "-", 
         SuperscriptBox["t3", "2"]}], ")"}]}], 
      RowBox[{
       SuperscriptBox["k", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"t1", "-", "t3"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"t2", "-", "t3"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "t3"}], ")"}]}]]}], ")"}]}], "-", 
  RowBox[{
   SuperscriptBox["q", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "k"}], "+", "t1"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "k"}], "+", 
            SuperscriptBox["t1", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "k"}], "+", 
            SuperscriptBox["t1", "3"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"k", "-", "t2"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", " ", "t1"}], "-", "t2"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", " ", 
             SuperscriptBox["t1", "2"]}], "-", "t2"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"k", "-", "t3"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", " ", "t1"}], "-", "t3"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", " ", 
             SuperscriptBox["t1", "2"]}], "-", "t3"}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["k", 
           RowBox[{"9", "/", "2"}]], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "t1"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "t1", "+", 
            SuperscriptBox["t1", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"t1", "-", "t2"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["t1", "2"], "-", "t2"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"t1", "-", "t3"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["t1", "2"], "-", "t3"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], ")"}]}], ")"}]}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "k"}], "+", "t1"}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"k", "-", "t2"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["t1", "2"], "-", 
         RowBox[{"k", " ", "t2"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"k", " ", "t1"}], "-", 
         SuperscriptBox["t2", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"k", "-", "t3"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"k", " ", "t1"}], "-", "t3"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"k", " ", "t2"}], "-", "t3"}], ")"}]}], 
      RowBox[{
       SuperscriptBox["k", 
        RowBox[{"9", "/", "2"}]], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["t1", "2"], "-", "t2"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"t1", "-", 
         SuperscriptBox["t2", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"t1", "-", "t3"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"t2", "-", "t3"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "k"}], "+", "t1"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"k", "-", "t2"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"t1", "-", 
          RowBox[{"k", " ", "t2"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"k", "-", 
          SuperscriptBox["t2", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"t1", "-", 
          RowBox[{"k", " ", 
           SuperscriptBox["t2", "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"k", "-", 
          SuperscriptBox["t2", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"k", "-", "t3"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"k", " ", "t2"}], "-", "t3"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"k", " ", 
           SuperscriptBox["t2", "2"]}], "-", "t3"}], ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["k", 
         RowBox[{"9", "/", "2"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"t1", "-", "t2"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "t2"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"t1", "-", 
          SuperscriptBox["t2", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "t2", "+", 
          SuperscriptBox["t2", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"t2", "-", "t3"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["t2", "2"], "-", "t3"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], ")"}]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "k"}], "+", "t1"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"k", "-", "t2"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"k", " ", "t1"}], "-", "t2"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"k", "-", "t3"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["t1", "2"], "-", 
         RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "t2"}], "+", 
         RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"k", " ", "t1"}], "-", 
         SuperscriptBox["t3", "2"]}], ")"}]}], 
      RowBox[{
       SuperscriptBox["k", 
        RowBox[{"9", "/", "2"}]], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"t1", "-", "t2"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["t1", "2"], "-", "t3"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"t2", "-", "t3"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"t1", "-", 
         SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "k"}], "+", "t1"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"k", "-", "t2"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"t1", "-", 
         RowBox[{"k", " ", "t2"}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"k", "-", "t3"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"t1", "-", 
         RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["t2", "2"]}], "+", 
         RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"k", " ", "t2"}], "-", 
         SuperscriptBox["t3", "2"]}], ")"}]}], 
      RowBox[{
       SuperscriptBox["k", 
        RowBox[{"9", "/", "2"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"t1", "-", "t2"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"t1", "-", "t3"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["t2", "2"], "-", "t3"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"t2", "-", 
         SuperscriptBox["t3", "2"]}], ")"}]}]], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "k"}], "+", "t1"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"k", "-", "t2"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"k", "-", "t3"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"t1", "-", 
          RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "t2"}], "+", 
          RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"k", "-", 
          SuperscriptBox["t3", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"t1", "-", 
          RowBox[{"k", " ", 
           SuperscriptBox["t3", "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "t2"}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["t3", "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"k", "-", 
          SuperscriptBox["t3", "3"]}], ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["k", 
         RowBox[{"9", "/", "2"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"t1", "-", "t3"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"t2", "-", "t3"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "t3"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"t1", "-", 
          SuperscriptBox["t3", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"t2", "-", 
          SuperscriptBox["t3", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "t3", "+", 
          SuperscriptBox["t3", "2"]}], ")"}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.7179159006187973`*^9, 3.717915966851308*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Refined limit and MacMahon", "Subsection",
 CellChangeTimes->{{3.716641930376919*^9, 3.716641936202071*^9}}],

Cell["\<\
To take the refined limit we define three subtori, parametrized by which \
variable we send to infinity. Other subtori are possible (these are the same \
defined above)\
\>", "Text",
 CellChangeTimes->{{3.716642283501618*^9, 3.716642318436922*^9}, {
  3.716642355801052*^9, 3.7166423608918867`*^9}, {3.7179160097026978`*^9, 
  3.7179160147332573`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"TorusT1", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"t1", "\[Rule]", 
     RowBox[{"x", "^", 
      RowBox[{"(", 
       RowBox[{"100", "-", "1"}], ")"}]}]}], ",", 
    RowBox[{"t3", "\[Rule]", 
     RowBox[{"x", "^", 
      RowBox[{"(", 
       RowBox[{"-", "100"}], ")"}]}]}], ",", 
    RowBox[{"t2", "\[Rule]", "x"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"TorusT2", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"t2", "\[Rule]", 
     RowBox[{"x", "^", 
      RowBox[{"(", 
       RowBox[{"100", "-", "1"}], ")"}]}]}], ",", 
    RowBox[{"t1", "\[Rule]", 
     RowBox[{"x", "^", 
      RowBox[{"(", 
       RowBox[{"-", "100"}], ")"}]}]}], ",", 
    RowBox[{"t3", "\[Rule]", "x"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"TorusT3", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"t3", "\[Rule]", 
     RowBox[{"x", "^", 
      RowBox[{"(", 
       RowBox[{"100", "-", "1"}], ")"}]}]}], ",", 
    RowBox[{"t2", "\[Rule]", 
     RowBox[{"x", "^", 
      RowBox[{"(", 
       RowBox[{"-", "100"}], ")"}]}]}], ",", 
    RowBox[{"t1", "\[Rule]", "x"}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.716642322362462*^9, 3.716642353518425*^9}, {
  3.7177512393152113`*^9, 3.717751249439588*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"t1", "\[Rule]", 
    SuperscriptBox["x", "99"]}], ",", 
   RowBox[{"t3", "\[Rule]", 
    FractionBox["1", 
     SuperscriptBox["x", "100"]]}], ",", 
   RowBox[{"t2", "\[Rule]", "x"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.717747135786014*^9, {3.717751250111067*^9, 3.717751257781204*^9}, 
   3.7177513181141157`*^9, 3.717831173643318*^9, 3.717851889080559*^9, 
   3.717915894129039*^9, 3.7179160533542013`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"t2", "\[Rule]", 
    SuperscriptBox["x", "99"]}], ",", 
   RowBox[{"t1", "\[Rule]", 
    FractionBox["1", 
     SuperscriptBox["x", "100"]]}], ",", 
   RowBox[{"t3", "\[Rule]", "x"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.717747135786014*^9, {3.717751250111067*^9, 3.717751257781204*^9}, 
   3.7177513181141157`*^9, 3.717831173643318*^9, 3.717851889080559*^9, 
   3.717915894129039*^9, 3.717916053380974*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"t3", "\[Rule]", 
    SuperscriptBox["x", "99"]}], ",", 
   RowBox[{"t2", "\[Rule]", 
    FractionBox["1", 
     SuperscriptBox["x", "100"]]}], ",", 
   RowBox[{"t1", "\[Rule]", "x"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.717747135786014*^9, {3.717751250111067*^9, 3.717751257781204*^9}, 
   3.7177513181141157`*^9, 3.717831173643318*^9, 3.717851889080559*^9, 
   3.717915894129039*^9, 3.717916053401012*^9}]
}, Open  ]],

Cell["\<\
Therefore the refined partition function is given by computing the \
localization result on one of these subtori and then taking the x->0 limit\
\>", "Text",
 CellChangeTimes->{{3.716642811294426*^9, 3.7166428389607887`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RefinedPartitionFunction", "[", "nboxes_", "]"}], ":=", 
  RowBox[{"1", "+", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"-", "q"}], ")"}], "^", "n"}], " ", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"TotalContribution", "[", "n", "]"}], "//.", "TorusT3"}], 
        ",", 
        RowBox[{"x", "\[Rule]", "0"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "nboxes"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7166428470336*^9, 3.716642869543565*^9}, {
  3.716715345964735*^9, 3.716715349226616*^9}}],

Cell["\<\
This partition function should coincide with the refined MacMahon function. \
The MacMahon function has a one parameter family of refinements. The non \
uniqueness of the refinement is related to the non-compactness of the Hilber \
scheme of points on C3\
\>", "Text",
 CellChangeTimes->{{3.7167120961646633`*^9, 3.716712196395939*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MacMahonRef", "[", 
   RowBox[{"q1_", ",", "q2_", ",", "N_", ",", "d_"}], "]"}], ":=", 
  RowBox[{"Product", "[", 
   RowBox[{
    RowBox[{"Product", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          RowBox[{"q1", "^", 
           RowBox[{"(", 
            RowBox[{"i", "-", 
             RowBox[{"1", "/", "2"}], "+", 
             RowBox[{"d", "/", "2"}]}], ")"}]}], " ", 
          RowBox[{"q2", "^", 
           RowBox[{"(", 
            RowBox[{"j", "-", 
             RowBox[{"1", "/", "2"}], "-", 
             RowBox[{"d", "/", "2"}]}], ")"}]}]}]}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "N"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "N"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.716712216950686*^9, 3.716712219668832*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Normal", "[", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"MacMahonRef", "[", 
      RowBox[{
       RowBox[{"q", " ", "y"}], ",", 
       RowBox[{"q", "/", "y"}], ",", "10", ",", "1"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.716712222030622*^9, 3.7167122244104147`*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{"q", " ", "y"}], "+", 
  RowBox[{
   SuperscriptBox["q", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["y", "2"]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["q", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["1", "y"], "+", 
     RowBox[{"2", " ", "y"}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["y", "3"]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["q", "4"], " ", 
   RowBox[{"(", 
    RowBox[{"3", "+", 
     FractionBox["1", 
      SuperscriptBox["y", "2"]], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["y", "2"]}], "+", 
     RowBox[{"5", " ", 
      SuperscriptBox["y", "4"]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["q", "5"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["y", "3"]], "+", 
     FractionBox["3", "y"], "+", 
     RowBox[{"6", " ", "y"}], "+", 
     RowBox[{"7", " ", 
      SuperscriptBox["y", "3"]}], "+", 
     RowBox[{"7", " ", 
      SuperscriptBox["y", "5"]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.7167152557046127`*^9, 3.7167994526959267`*^9, 
  3.716869979314662*^9, 3.717747140918571*^9, 3.7177512609386787`*^9, 
  3.7177513200722723`*^9, 3.7178311795595913`*^9, 3.7179160535418873`*^9}]
}, Open  ]],

Cell["The y->1 limit reproduces the ordinary MacMahon function", "Text",
 CellChangeTimes->{{3.716712239363884*^9, 3.716712283481529*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Normal", "[", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"MacMahonRef", "[", 
      RowBox[{"q", ",", "q", ",", "10", ",", "1"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.716712222030622*^9, 3.7167122244104147`*^9}, {
  3.716712255157392*^9, 3.716712257902378*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", "q", "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["q", "2"]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["q", "3"]}], "+", 
  RowBox[{"13", " ", 
   SuperscriptBox["q", "4"]}], "+", 
  RowBox[{"24", " ", 
   SuperscriptBox["q", "5"]}]}]], "Output",
 CellChangeTimes->{3.716715255752256*^9, 3.7167994527336884`*^9, 
  3.716869979359956*^9, 3.717747140973127*^9, 3.717751260991263*^9, 
  3.717751320126259*^9, 3.717831179596245*^9, 3.71791605357335*^9}]
}, Open  ]],

Cell["\<\
We check that our refined partition function agrees with the refined \
MacMahon, for y=Sqrt[k]\
\>", "Text",
 CellChangeTimes->{{3.7167152924689827`*^9, 3.716715303413074*^9}, {
  3.716715379860222*^9, 3.716715387867934*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RefinedPartitionFunction", "[", "4", "]"}]], "Input",
 CellChangeTimes->{{3.716715273334917*^9, 3.7167152782879467`*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{
   SqrtBox["k"], " ", "q"}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"2", " ", "k"}]}], ")"}], " ", 
   SuperscriptBox["q", "2"]}], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "-", 
      RowBox[{"2", " ", "k"}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["k", "2"]}]}], ")"}], " ", 
    SuperscriptBox["q", "3"]}], 
   SqrtBox["k"]], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"3", "+", 
     FractionBox["1", "k"], "+", 
     RowBox[{"4", " ", "k"}], "+", 
     RowBox[{"5", " ", 
      SuperscriptBox["k", "2"]}]}], ")"}], " ", 
   SuperscriptBox["q", "4"]}]}]], "Output",
 CellChangeTimes->{3.716715303772401*^9, 3.716715356210609*^9, 
  3.7167994783503513`*^9, 3.716870003555766*^9, 3.717747166392922*^9, 
  3.7177512759474373`*^9, 3.717751346575554*^9, 3.7178312030017843`*^9, 
  3.717916076141029*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Symmetrization and Nekrasov function", "Subsection",
 CellChangeTimes->{{3.716708484649619*^9, 3.716708491858317*^9}}],

Cell["This is Nekrasov\[CloseCurlyQuote]s function in the case of C3", "Text",
 CellChangeTimes->{{3.716709716720666*^9, 3.716709728923133*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FC3", "[", 
   RowBox[{"t1_", ",", "t2_", ",", "t3_", ",", "t4_", ",", "t5_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"t1", " ", "t2"}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"1", "/", "2"}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"t1", " ", "t2"}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"t1", " ", "t3"}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"1", "/", "2"}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"t1", " ", "t3"}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"t2", " ", "t3"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"t2", " ", "t3"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"t1", "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}], "-", 
        RowBox[{"t1", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"t2", "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}], "-", 
        RowBox[{"t2", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"t3", "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}], "-", 
        RowBox[{"t3", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"t4", "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}], "-", 
        RowBox[{"t4", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"t5", "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}], "-", 
        RowBox[{"t5", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], 
     ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6744033720560493`*^9, 3.674403372806196*^9}, 
   3.674403472934162*^9}],

Cell["\<\
The partition function is defined by symmetrization (or plethystic \
exponential)\
\>", "Text",
 CellChangeTimes->{{3.716709760782259*^9, 3.716709793098098*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZSymmC3", "[", 
   RowBox[{"t1_", ",", "t2_", ",", "t3_", ",", "t4_", ",", "t5_"}], "]"}], ":=", 
  RowBox[{"Exp", "[", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", "n"}], " ", 
      RowBox[{"FC3", "[", 
       RowBox[{
        RowBox[{"t1", "^", "n"}], ",", 
        RowBox[{"t2", "^", "n"}], ",", 
        RowBox[{"t3", "^", "n"}], ",", 
        RowBox[{"t4", "^", "n"}], ",", 
        RowBox[{"t5", "^", "n"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "14"}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.674403491904615*^9, 3.674403527351356*^9}, {
  3.674995586210567*^9, 3.6749955886488037`*^9}, {3.716709802160664*^9, 
  3.7167098050394917`*^9}, {3.717754417178849*^9, 3.717754422236845*^9}}],

Cell["\<\
We look at the first terms with the identification of parameters given on \
page 24 of nekrasov okounkov (typo corrected)\
\>", "Text",
 CellChangeTimes->{{3.674403552227922*^9, 3.6744035810420523`*^9}, {
  3.674403612951662*^9, 3.6744036246301813`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{"ZSymmC3", "[", 
    RowBox[{"t1", ",", "t2", ",", "t3", ",", 
     RowBox[{"q", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"t1", " ", "t2", " ", "t3"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"1", "/", "q"}], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"t1", " ", "t2", " ", "t3"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "0", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.674403628132362*^9, 3.6744036836634407`*^9}, 
   3.7167098250319757`*^9, {3.717754438699802*^9, 3.7177544389250717`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "-", 
   FractionBox[
    RowBox[{
     SqrtBox["t1"], " ", 
     SqrtBox["t2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"t1", " ", "t2"}]}], ")"}], " ", 
     SqrtBox["t3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"t1", " ", "t3"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"t2", " ", "t3"}]}], ")"}], " ", "q"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
     SqrtBox[
      RowBox[{"t1", " ", "t2"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
     SqrtBox[
      RowBox[{"t1", " ", "t3"}]], " ", 
     SqrtBox[
      RowBox[{"t2", " ", "t3"}]]}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"t1", " ", "t2"}]}], ")"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"t1", " ", "t3"}]}], ")"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"t2", " ", "t3"}]}], ")"}], "2"]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", "t1", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", "t2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", "t3"}]], "+", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            SqrtBox[
             SuperscriptBox["t1", "2"]], " ", 
            SqrtBox[
             SuperscriptBox["t2", "2"]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               SuperscriptBox["t1", "2"], " ", 
               SuperscriptBox["t2", "2"]}]}], ")"}], " ", 
            SqrtBox[
             SuperscriptBox["t3", "2"]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               SuperscriptBox["t1", "2"], " ", 
               SuperscriptBox["t3", "2"]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               SuperscriptBox["t2", "2"], " ", 
               SuperscriptBox["t3", "2"]}]}], ")"}]}], 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["t1", "2"]}], ")"}], " ", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["t1", "2"], " ", 
              SuperscriptBox["t2", "2"]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["t2", "2"]}], ")"}], " ", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["t1", "2"], " ", 
              SuperscriptBox["t3", "2"]}]], " ", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["t2", "2"], " ", 
              SuperscriptBox["t3", "2"]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["t3", "2"]}], ")"}]}]]}], "-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"t1", " ", "t2"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"t1", " ", "t3"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"t2", " ", "t3"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SqrtBox[
              RowBox[{"t1", " ", "t2", " ", "t3"}]], "+", 
             RowBox[{"t1", " ", "t2", " ", "t3", " ", 
              SqrtBox[
               RowBox[{"t1", " ", "t2", " ", "t3"}]]}]}], ")"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
           SqrtBox["t1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
           SqrtBox["t2"], " ", 
           SqrtBox[
            RowBox[{"t1", " ", "t2"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
           SqrtBox["t3"], " ", 
           SqrtBox[
            RowBox[{"t1", " ", "t3"}]], " ", 
           SqrtBox[
            RowBox[{"t2", " ", "t3"}]]}]]}], ")"}]}]}], ")"}], " ", 
    SuperscriptBox["q", "2"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "q", "]"}], "3"],
    SeriesData[$CellContext`q, 0, {}, 0, 6, 2],
    Editable->False]}],
  SeriesData[$CellContext`q, 0, {
   1, 0, -(-1 + $CellContext`t1)^(-1) $CellContext`t1^
     Rational[1, 2] (-1 + $CellContext`t2)^(-1) $CellContext`t2^
     Rational[1, 2] ($CellContext`t1 $CellContext`t2)^
     Rational[-1, 
       2] (-1 + $CellContext`t1 $CellContext`t2) (-1 + $CellContext`t3)^(-1) \
$CellContext`t3^Rational[1, 2] ($CellContext`t1 $CellContext`t3)^
     Rational[-1, 2] ($CellContext`t2 $CellContext`t3)^
     Rational[-1, 
       2] (-1 + $CellContext`t1 $CellContext`t3) (-1 + $CellContext`t2 \
$CellContext`t3), 0, 
    Rational[1, 4] (
     2 (-1 + $CellContext`t1)^(-2) $CellContext`t1^(-1) (-1 + \
$CellContext`t2)^(-2) $CellContext`t2^(-1) (-1 + $CellContext`t1 \
$CellContext`t2)^2 (-1 + $CellContext`t3)^(-2) $CellContext`t3^(-1) (-1 + \
$CellContext`t1 $CellContext`t3)^2 (-1 + $CellContext`t2 $CellContext`t3)^2 + 
     4 (Rational[-1, 2] ($CellContext`t1^2)^
         Rational[1, 2] (-1 + $CellContext`t1^2)^(-1) ($CellContext`t2^2)^
         Rational[1, 2] ($CellContext`t1^2 $CellContext`t2^2)^
         Rational[-1, 
           2] (-1 + $CellContext`t2^2)^(-1) (-1 + $CellContext`t1^2 \
$CellContext`t2^2) ($CellContext`t3^2)^
         Rational[1, 2] ($CellContext`t1^2 $CellContext`t3^2)^
         Rational[-1, 2] ($CellContext`t2^2 $CellContext`t3^2)^
         Rational[-1, 
           2] (-1 + $CellContext`t3^2)^(-1) (-1 + $CellContext`t1^2 \
$CellContext`t3^2) (-1 + $CellContext`t2^2 $CellContext`t3^2) - (-1 + \
$CellContext`t1)^(-1) $CellContext`t1^
        Rational[-1, 2] (-1 + $CellContext`t2)^(-1) $CellContext`t2^
        Rational[-1, 2] ($CellContext`t1 $CellContext`t2)^
        Rational[-1, 
          2] (-1 + $CellContext`t1 $CellContext`t2) (-1 + \
$CellContext`t3)^(-1) $CellContext`t3^
        Rational[-1, 2] ($CellContext`t1 $CellContext`t3)^
        Rational[-1, 2] ($CellContext`t2 $CellContext`t3)^
        Rational[-1, 
          2] (-1 + $CellContext`t1 $CellContext`t3) (-1 + $CellContext`t2 \
$CellContext`t3) (($CellContext`t1 $CellContext`t2 $CellContext`t3)^
         Rational[
          1, 2] + $CellContext`t1 $CellContext`t2 $CellContext`t3 \
($CellContext`t1 $CellContext`t2 $CellContext`t3)^Rational[1, 2])))}, 0, 6, 2],
  Editable->False]], "Output",
 CellChangeTimes->{3.7167152562894173`*^9, 3.716799478995713*^9, 
  3.7168700040733624`*^9, 3.717747167096354*^9, 3.717751347019328*^9, 
  3.717831203544635*^9, 3.7179162112932243`*^9}]
}, Open  ]],

Cell["\<\
We check that the symmetrized partition function reproduces the computation \
done using direct localization (where we set k=t1 t2 t3)\
\>", "Text",
 CellChangeTimes->{{3.716715429005137*^9, 3.7167154475424623`*^9}, 
   3.7167158626650543`*^9, {3.7167162969928637`*^9, 3.716716302185555*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"ZSymmC3", "[", 
        RowBox[{"t1", ",", "t2", ",", "t3", ",", 
         RowBox[{"q", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"t1", " ", "t2", " ", "t3"}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{"1", "/", "q"}], " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"t1", " ", "t2", " ", "t3"}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"q", ",", "0", ",", "4"}], "}"}]}], "]"}], "-", 
     RowBox[{"PartitionFunction", "[", "4", "]"}]}], "//.", 
    RowBox[{"k", "\[Rule]", 
     RowBox[{"t1", " ", "t2", " ", "t3"}]}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7167159335046883`*^9, 3.7167159375929203`*^9}, {
  3.716716200046505*^9, 3.716716284140979*^9}}],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "q", "]"}], 
   RowBox[{"9", "/", "2"}]],
  SeriesData[$CellContext`q, 0, {}, 9, 9, 2],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.716715937956061*^9, 3.716716204861773*^9, {3.716716250901246*^9, 
   3.716716276886421*^9}, 3.716716474423229*^9, 3.716799690286375*^9, 
   3.716870181406157*^9, 3.717747360472706*^9, 3.717751543316654*^9, 
   3.7178313776902742`*^9, 3.717916387260022*^9}]
}, Open  ]],

Cell["\<\
One can also check the refined limit by taking the limit directly on Nekrasov \
function FC3. If we do that it becomes  (Okounkov proposition 3.5.15)\
\>", "Text",
 CellChangeTimes->{{3.716717986114283*^9, 3.716718020011519*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FC3", "[", 
   RowBox[{"t1_", ",", "t2_", ",", "t3_", ",", "t4_", ",", "t5_", ",", "k_"}],
    "]"}], ":=", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t1"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t1"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t3"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t3"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "/", "t2"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "/", "t2"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t1", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t1", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t2", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t2", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t3", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t3", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t4", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t4", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t5", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t5", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], ")"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6744033720560493`*^9, 3.674403372806196*^9}, 
   3.674403472934162*^9, {3.685798651440465*^9, 3.685798653178933*^9}, {
   3.709464971485652*^9, 3.709464999637817*^9}, {3.709465033504201*^9, 
   3.709465064467249*^9}, {3.7098117622022123`*^9, 3.7098117675144997`*^9}, {
   3.7177470092131577`*^9, 3.717747036980688*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"FC3", "[", 
      RowBox[{"t1", ",", "t2", ",", "t3", ",", 
       RowBox[{"q", "/", 
        RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"q", " ", 
          RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}]}], ",", "k"}], "]"}], "//.",
      "TorusT3"}], ",", 
    RowBox[{"x", "\[Rule]", "0"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7177544963879137`*^9, 3.717754543068779*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"k", " ", "q"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SqrtBox["k"], "-", "q"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       SqrtBox["k"], " ", "q"}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.717754537194786*^9, 3.717754543594081*^9}, 
   3.7178313778384447`*^9, 3.717916387436311*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"FC3refined", "[", 
   RowBox[{"z_", ",", "k_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"k", "^", 
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}]}], " ", 
   RowBox[{"z", "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Sqrt", "[", "k", "]"}], " ", "z"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"z", "/", 
         RowBox[{"Sqrt", "[", "k", "]"}]}]}], ")"}]}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.674406576332759*^9, 3.674406576867082*^9}, {
  3.716718032801001*^9, 3.71671803599305*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{"Exp", "[", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"1", "/", "n"}], " ", 
        RowBox[{"FC3refined", "[", 
         RowBox[{
          RowBox[{"q", "^", "n"}], ",", 
          RowBox[{"k", "^", "n"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "7"}], "}"}]}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"q", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.675102704880722*^9, 3.6751027052800207`*^9}, 
   3.716718040206039*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "+", 
   RowBox[{
    SqrtBox["k"], " ", "q"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", "k"}]}], ")"}], " ", 
    SuperscriptBox["q", "2"]}], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", "k"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["k", "2"]}]}], ")"}], " ", 
     SuperscriptBox["q", "3"]}], 
    SqrtBox["k"]], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", "+", 
      FractionBox["1", "k"], "+", 
      RowBox[{"4", " ", "k"}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["k", "2"]}]}], ")"}], " ", 
    SuperscriptBox["q", "4"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "q", "]"}], "5"],
    SeriesData[$CellContext`q, 0, {}, 0, 5, 1],
    Editable->False]}],
  SeriesData[$CellContext`q, 0, {
   1, $CellContext`k^Rational[1, 2], 1 + 
    2 $CellContext`k, $CellContext`k^Rational[-1, 2] (1 + 2 $CellContext`k + 
     3 $CellContext`k^2), 3 + $CellContext`k^(-1) + 4 $CellContext`k + 
    5 $CellContext`k^2}, 0, 5, 1],
  Editable->False]], "Output",
 CellChangeTimes->{3.716718043363852*^9, 3.7167996903926573`*^9, 
  3.716870181499318*^9, 3.71774736056151*^9, 3.71775154341612*^9, 
  3.717751801219521*^9, 3.717831377924944*^9, 3.717916387509039*^9}]
}, Open  ]],

Cell["\<\
which indeed reproduces the refined MacMahon function. We could also have the \
minus signs appear differently by changing the sign of q (sometimes this \
definition is used)\
\>", "Text",
 CellChangeTimes->{{3.7167180501875343`*^9, 3.7167180585376472`*^9}, {
  3.717751803403914*^9, 3.7177518597140417`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{"Exp", "[", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"1", "/", "n"}], " ", 
        RowBox[{"FC3refined", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"-", "q"}], ")"}], "^", "n"}], ",", 
          RowBox[{"k", "^", "n"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "7"}], "}"}]}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"q", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.675102704880722*^9, 3.6751027052800207`*^9}, 
   3.716718040206039*^9, {3.7177518207895803`*^9, 3.717751821620797*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "-", 
   RowBox[{
    SqrtBox["k"], " ", "q"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", "k"}]}], ")"}], " ", 
    SuperscriptBox["q", "2"]}], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", "k"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["k", "2"]}]}], ")"}], " ", 
     SuperscriptBox["q", "3"]}], 
    SqrtBox["k"]], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", "+", 
      FractionBox["1", "k"], "+", 
      RowBox[{"4", " ", "k"}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["k", "2"]}]}], ")"}], " ", 
    SuperscriptBox["q", "4"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "q", "]"}], "5"],
    SeriesData[$CellContext`q, 0, {}, 0, 5, 1],
    Editable->False]}],
  SeriesData[$CellContext`q, 0, {
   1, -$CellContext`k^Rational[1, 2], 1 + 
    2 $CellContext`k, -$CellContext`k^Rational[-1, 2] (1 + 2 $CellContext`k + 
     3 $CellContext`k^2), 3 + $CellContext`k^(-1) + 4 $CellContext`k + 
    5 $CellContext`k^2}, 0, 5, 1],
  Editable->False]], "Output",
 CellChangeTimes->{3.717751822074212*^9, 3.717831377958214*^9, 
  3.7179163875553837`*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A-fibered singularities", "Chapter",
 CellChangeTimes->{{3.716812531022464*^9, 3.716812534787472*^9}}],

Cell["\<\
Now we will consider singularities of the form C x C2 / Zn, which are A-type \
singularities fibered over C. These singularities have the property that the \
resolution is a chain of P1\
\>", "Text",
 CellChangeTimes->{{3.7166324054011297`*^9, 3.716632456151668*^9}}],

Cell[CellGroupData[{

Cell["C2/Z2 x C", "Subchapter",
 CellChangeTimes->{{3.716812589315277*^9, 3.716812596497425*^9}}],

Cell[CellGroupData[{

Cell["Localization", "Subsection",
 CellChangeTimes->{{3.7167213095525618`*^9, 3.716721310843902*^9}}],

Cell["\<\
To take into account the orbifold action we decompose the vector spaces V in \
modules with respect to the toric action. We let the orbifold group act on \
the toric weights (t1,t2,t3) as (w t1 , w^(-1) t2 , t3) (so that the \
determinant is constant). Therefore each monomial in the weight decomposition \
of V will transform in the conjugacy classes of the orbifold group. Since for \
Z2 w^2=1, the monomial can be invariant or transform with a w. We implement \
this in the formalism by inserting a Kronecker delta in the definition of V. \
Elements of Vr will be monomials t1^(-i+1) t2^(-j+1) t3^(-k+1) in the toric \
weights with (-i+1)-(-j+1)=r modulo 2   \
\>", "Text",
 CellChangeTimes->{{3.7167297341000423`*^9, 3.7167297396983547`*^9}, {
  3.7167312250581303`*^9, 3.716731236203673*^9}, {3.716731301398726*^9, 
  3.716731550641433*^9}, {3.716731714932044*^9, 3.716731723710896*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PPVC2Z2", "[", 
   RowBox[{"l_List", ",", "t1_", ",", "t2_", ",", "t3_", ",", "r_"}], "]"}], ":=", 
  RowBox[{"Total", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"t1", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "i"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"t2", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "j"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"t3", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "k"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"KroneckerDelta", "[", 
          RowBox[{
           RowBox[{"Mod", "[", 
            RowBox[{
             RowBox[{"j", "-", "i"}], ",", "2"}], "]"}], ",", "r"}], "]"}]}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "l", "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"j", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"l", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"l", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "}"}]}], 
       "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.685794026599243*^9, 3.685794062411702*^9}, {
   3.6857945569193993`*^9, 3.68579456486136*^9}, {3.685794658823471*^9, 
   3.685794661349846*^9}, {3.685794743967721*^9, 3.685794762494817*^9}, {
   3.685795923624857*^9, 3.685795925376687*^9}, {3.686396180192107*^9, 
   3.686396186019744*^9}, 3.6864006439129047`*^9, {3.716731765086728*^9, 
   3.716731765902526*^9}}],

Cell["\<\
The virtual tangent space at fixed points is constructed by taking the \
virtual tangent space for C3 and keeping the Z2 invariant part\
\>", "Text",
 CellChangeTimes->{{3.716731774414606*^9, 3.716731853595142*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TvirC2Z2fixed", "[", 
   RowBox[{"list_", ",", "t1_", ",", "t2_", ",", "t3_", ",", "k_"}], "]"}], ":=",
   "  ", 
  RowBox[{
   RowBox[{"PPVC2Z2", "[", 
    RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], "-", 
   RowBox[{
    RowBox[{"PPVC2Z2", "[", 
     RowBox[{"list", ",", 
      RowBox[{"1", "/", "t1"}], ",", 
      RowBox[{"1", "/", "t2"}], ",", 
      RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}], " ", "t1", " ", "t2", " ", 
    "t3"}], "-", "  ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"PPVC2Z2", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], 
       RowBox[{"PPVC2Z2", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z2", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "1"}], "]"}], 
       RowBox[{"PPVC2Z2", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "1"}], "]"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"t1", " ", "t2"}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", "t3"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"PPVC2Z2", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], 
       RowBox[{"PPVC2Z2", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "1"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z2", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "1"}], "]"}], 
       RowBox[{"PPVC2Z2", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t1"}], "-", "t2"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", "t3"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.674587994202264*^9, 3.674588008681179*^9}, {
  3.6746547289960318`*^9, 3.6746547329251757`*^9}, {3.674993518039311*^9, 
  3.674993519238812*^9}, {3.6750056749571943`*^9, 3.6750056766999826`*^9}, {
  3.6750059890160027`*^9, 3.675005990235087*^9}, {3.6857941088840933`*^9, 
  3.685794343643107*^9}, {3.686396370859964*^9, 3.686396411945922*^9}, {
  3.686397523528788*^9, 3.686397524377611*^9}, {3.686397555647361*^9, 
  3.6863975564117727`*^9}, {3.6863975946782312`*^9, 3.6863975979347754`*^9}, {
  3.686397636808201*^9, 3.686397639159382*^9}, {3.686397818218688*^9, 
  3.686397831729867*^9}, {3.686399127478767*^9, 3.686399186763342*^9}, {
  3.686400691246662*^9, 3.686400699758142*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"PPVC2Z2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"PlanePartitions", "[", "12", "]"}], "[", 
    RowBox[{"[", "4", "]"}], "]"}], ",", "t1", ",", "t2", ",", "t3", ",", 
   "0"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"PPVC2Z2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"PlanePartitions", "[", "12", "]"}], "[", 
    RowBox[{"[", "4", "]"}], "]"}], ",", "t1", ",", "t2", ",", "t3", ",", 
   "1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.686397714373437*^9, 3.6863977742298183`*^9}, {
  3.686398756336615*^9, 3.686398774359968*^9}, {3.686400037990293*^9, 
  3.6864000663604593`*^9}, {3.709799730954965*^9, 3.709799731708467*^9}, {
  3.716731878030596*^9, 3.716731879034527*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", 
  FractionBox["1", 
   SuperscriptBox["t3", "7"]], "+", 
  FractionBox["1", 
   SuperscriptBox["t3", "6"]], "+", 
  FractionBox["1", 
   SuperscriptBox["t3", "5"]], "+", 
  FractionBox["1", 
   SuperscriptBox["t3", "4"]], "+", 
  FractionBox["1", 
   SuperscriptBox["t3", "3"]], "+", 
  FractionBox["1", 
   SuperscriptBox["t3", "2"]], "+", 
  FractionBox["1", "t3"]}]], "Output",
 CellChangeTimes->{3.7167344035810003`*^9, 3.716799690591608*^9, 
  3.717747360728643*^9, 3.7177519020916243`*^9, 3.717831378137755*^9, 
  3.7179165526641073`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "t2"], "+", 
  FractionBox["1", 
   RowBox[{"t2", " ", 
    SuperscriptBox["t3", "3"]}]], "+", 
  FractionBox["1", 
   RowBox[{"t2", " ", 
    SuperscriptBox["t3", "2"]}]], "+", 
  FractionBox["1", 
   RowBox[{"t2", " ", "t3"}]]}]], "Output",
 CellChangeTimes->{3.7167344035810003`*^9, 3.716799690591608*^9, 
  3.717747360728643*^9, 3.7177519020916243`*^9, 3.717831378137755*^9, 
  3.7179165527760353`*^9}]
}, Open  ]],

Cell["\<\
This function counts the number of boxes in the 3d partition in the \
connungacy class r. It is obtained by taking Vr computed on a 3d partition \
and setting the toric weights to 1\
\>", "Text",
 CellChangeTimes->{{3.716734435601859*^9, 3.716734490541175*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"NBC2Z2", "[", 
   RowBox[{"l_List", ",", "r_"}], "]"}], ":=", 
  RowBox[{"PPVC2Z2", "[", 
   RowBox[{"l", ",", "1", ",", "1", ",", "1", ",", "r"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.685795573005415*^9, 3.685795594181725*^9}, 
   3.6857956721339827`*^9, {3.685795713741584*^9, 3.685795814978931*^9}, {
   3.6857958527331142`*^9, 3.6857958683004723`*^9}, {3.685795981600951*^9, 
   3.6857959892875137`*^9}, 3.685796449591515*^9, {3.685796677468938*^9, 
   3.685796685114377*^9}, 3.685796731259357*^9, {3.6863964714823923`*^9, 
   3.6863964807605333`*^9}}],

Cell["\<\
We define the virtual tangent space as a function of the fixed point \
partition for a certain fixed number of boxes\
\>", "Text",
 CellChangeTimes->{{3.71673465220093*^9, 3.716734676597206*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"VirtualTC2Z2", "[", 
   RowBox[{"nboxes_", ",", "fixedpoint_"}], "]"}], ":=", 
  RowBox[{"Expand", "[", 
   RowBox[{"TvirC2Z2fixed", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
      RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", "t2", ",", 
     "t3", ",", "k"}], "]"}], "]"}]}]], "Input"],

Cell["\<\
The definition of the list of fixed points and their contribution to the \
localization formula proceeds as in the C3 case, with the new virtual tangent \
space\
\>", "Text",
 CellChangeTimes->{{3.7167347182852592`*^9, 3.716734744962378*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FPListC2Z2", "[", 
   RowBox[{"nboxes_", ",", "fixedpoint_"}], "]"}], ":=", 
  RowBox[{"Flatten", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Reap", "[", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Flatten", "[", 
               RowBox[{"List", "@@", 
                RowBox[{"(", 
                 RowBox[{"Expand", "[", 
                  RowBox[{"TvirC2Z2fixed", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
               "//.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"t1", "\[Rule]", "1"}], ",", 
                RowBox[{"t2", "->", "1"}], ",", 
                RowBox[{"t3", "\[Rule]", "1"}], ",", 
                RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
            RowBox[{"[", "i", "]"}], "]"}], ">", "0"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Sow", "[", 
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
                RowBox[{"List", "@@", 
                 RowBox[{"(", 
                  RowBox[{"Expand", "[", 
                   RowBox[{"TvirC2Z2fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], 
                "\[IndentingNewLine]", "]"}], "[", 
               RowBox[{"[", "i", "]"}], "]"}], "/", 
              RowBox[{"(", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Flatten", "[", 
                   RowBox[{"List", "@@", 
                    RowBox[{"(", 
                    RowBox[{"Expand", "[", 
                    RowBox[{"TvirC2Z2fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
                   "//.", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"t1", "\[Rule]", "1"}], ",", 
                    RowBox[{"t2", "->", "1"}], ",", 
                    RowBox[{"t3", "\[Rule]", "1"}], ",", 
                    RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
                RowBox[{"[", "i", "]"}], "]"}], "\[IndentingNewLine]", 
               ")"}]}], ",", 
             RowBox[{
              RowBox[{"(", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"Flatten", "[", 
                 RowBox[{"List", "@@", 
                  RowBox[{"(", 
                   RowBox[{"Expand", "[", 
                    RowBox[{"TvirC2Z2fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
                 "//.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"t1", "\[Rule]", "1"}], ",", 
                  RowBox[{"t2", "->", "1"}], ",", 
                  RowBox[{"t3", "\[Rule]", "1"}], ",", 
                  RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "\[IndentingNewLine]", "}"}], 
           "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
        
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"Flatten", "[", 
            RowBox[{"List", "@@", 
             RowBox[{"(", 
              RowBox[{"Expand", "[", 
               RowBox[{"TvirC2Z2fixed", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                  RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                 "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}], 
           "]"}]}], "}"}]}], "]"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ahatp", "[", "list_", "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "/", 
          RowBox[{"list", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"list", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "/", "k"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"list", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"list", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], ")"}], "^", 
   RowBox[{"list", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input"],

Cell["\<\
In the localization formula we weight the contribution of each fixed point \
with p0^pi0 p1^pi1, which count separately the number of boxes transforming \
in the conjugacy classes r=0,1\
\>", "Text",
 CellChangeTimes->{{3.716734840426092*^9, 3.716734889385055*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"LocalizationC2Z2", "[", 
   RowBox[{"nboxes_", ",", "fixedpoint_", ",", "p0_", ",", "p1_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Cancel", "[", 
    RowBox[{"PowerExpand", "[", 
     RowBox[{"Times", "@@", 
      RowBox[{"Map", "[", 
       RowBox[{"ahatp", ",", 
        RowBox[{"FPListC2Z2", "[", 
         RowBox[{"nboxes", ",", "fixedpoint"}], "]"}]}], "]"}]}], "]"}], 
    "]"}], " ", 
   RowBox[{"p0", "^", 
    RowBox[{"NBC2Z2", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
       RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "0"}], "]"}]}], " ", 
   RowBox[{"p1", "^", 
    RowBox[{"NBC2Z2", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
       RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "1"}], "]"}], 
    " "}]}]}]], "Input",
 CellChangeTimes->{{3.67509769824366*^9, 3.675097742433045*^9}, {
   3.675097787395336*^9, 3.67509779944084*^9}, {3.675097856209297*^9, 
   3.675097941379383*^9}, 3.675098012939138*^9, {3.675101981572866*^9, 
   3.675102132977907*^9}, {3.679138392316263*^9, 3.679138397170555*^9}, {
   3.679139098659503*^9, 3.679139114360139*^9}, {3.685794841789722*^9, 
   3.685794885068252*^9}, {3.685797044333329*^9, 3.685797110123225*^9}, {
   3.6857971441185102`*^9, 3.6857971449891253`*^9}, {3.6863964185845757`*^9, 
   3.6863964511875277`*^9}, {3.686396494277749*^9, 3.686396522946504*^9}, 
   3.716734694805983*^9, {3.716734750174404*^9, 3.7167347826276293`*^9}, {
   3.716734822914542*^9, 3.716734823053763*^9}, {3.71673489401716*^9, 
   3.716734931160219*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TotalContributionC2Z2", "[", 
    RowBox[{"nboxes_", ",", "p0_", ",", "p1_"}], "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"LocalizationC2Z2", "[", 
      RowBox[{"nboxes", ",", "i", ",", "p0", ",", "p1"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", 
        RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "]"}]}], "}"}]}], 
    "]"}]}], "\[IndentingNewLine]"}]], "Input"],

Cell["The partition function is", "Text",
 CellChangeTimes->{{3.716734904051325*^9, 3.716734907262677*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PartitionFunctionC2Z2", "[", "nboxes_", "]"}], ":=", 
  RowBox[{"1", "+", 
   RowBox[{"Sum", "[", " ", 
    RowBox[{
     RowBox[{"TotalContributionC2Z2", "[", 
      RowBox[{"n", ",", "p0", ",", "p1"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "nboxes"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.716735080748169*^9, 3.7167350818615313`*^9}, {
  3.716735125331647*^9, 3.716735130487648*^9}, {3.71673516142768*^9, 
  3.716735173440413*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PartitionFunctionC2Z2", "[", "3", "]"}]], "Input",
 CellChangeTimes->{{3.716735151183049*^9, 3.716735155662837*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", 
  FractionBox[
   RowBox[{"p0", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", 
    SuperscriptBox["p1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t1", "2"]}], "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t2", "2"]}], "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t2", "2"], "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", "t2"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "-", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", "t3"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t2"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "-", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t2", "2"], "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t2", "2"], "-", "t3"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "3"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3", "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.716735156168825*^9, 3.716735177531796*^9}, 
   3.716799690996207*^9, 3.71774736109925*^9, 3.7177519025398693`*^9, 
   3.71783137855161*^9, 3.7179165530339947`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Symmetrization and Orbifold Nekrasov function", "Subsection",
 CellChangeTimes->{{3.7167218568656588`*^9, 3.716721869150951*^9}}],

Cell["\<\
Now we find a symmetrized representation for the partition function, by using \
an orbifold generalization of the Nekrasov function. Our formula is \
constructed from two pieces: a series of copies of the C3 function \
parametrizing Z2 invariant monomials and a \[OpenCurlyDoubleQuote]Kahler\
\[CloseCurlyDoubleQuote] term\
\>", "Text",
 CellChangeTimes->{{3.716735647059773*^9, 3.7167356920677357`*^9}, {
  3.716735731597981*^9, 3.716735756320787*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FC3", "[", 
   RowBox[{"t1_", ",", "t2_", ",", "t3_", ",", "t4_", ",", "t5_", ",", "k_"}],
    "]"}], ":=", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t1"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t1"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t3"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t3"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "/", "t2"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "/", "t2"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t1", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t1", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t2", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t2", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t3", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t3", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t4", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t4", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t5", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t5", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], ")"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6744033720560493`*^9, 3.674403372806196*^9}, 
   3.674403472934162*^9, {3.685798651440465*^9, 3.685798653178933*^9}, {
   3.709464971485652*^9, 3.709464999637817*^9}, {3.709465033504201*^9, 
   3.709465064467249*^9}, {3.7098117622022123`*^9, 3.7098117675144997`*^9}, {
   3.7177470092131577`*^9, 3.717747036980688*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FKahlerZ2", "[", 
   RowBox[{"p1_", ",", "t3_", ",", "t4_", ",", "t5_", ",", "k_"}], "]"}], ":=", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"p1", "+", 
      RowBox[{"1", "/", "p1"}]}], ")"}], " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        SqrtBox[
         FractionBox["t3", "k"]]], "-", 
       SqrtBox[
        FractionBox["t3", "k"]]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SqrtBox["t3"]]}], "+", 
         SqrtBox["t3"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SqrtBox["t4"]]}], "+", 
         SqrtBox["t4"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SqrtBox["t5"]]}], "+", 
         SqrtBox["t5"]}], ")"}]}], ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.709800049685461*^9, 3.7098001425906267`*^9}, {
   3.709800282903933*^9, 3.7098002913052387`*^9}, {3.7098010041146803`*^9, 
   3.709801008186751*^9}, {3.709801741383148*^9, 3.709801768415749*^9}, {
   3.709808631439939*^9, 3.7098086335554943`*^9}, {3.716735765312028*^9, 
   3.716735799760202*^9}, {3.717747051802793*^9, 3.7177471082204857`*^9}, 
   3.717747456920499*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZSymmZ2", "[", 
   RowBox[{"t1_", ",", "t2_", ",", "t3_", ",", "t4_", ",", "t5_"}], "]"}], ":=", 
  RowBox[{"Exp", "[", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", "n"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"FC3", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"t1", "/", "t2"}], ")"}], "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"t2", "^", "2"}], ")"}], "^", "m"}], ",", 
          RowBox[{"t3", "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"q", "/", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
          RowBox[{"1", "/", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"q", " ", 
              RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], ",", 
          RowBox[{"k", "^", "m"}]}], "]"}], "+", " ", 
        RowBox[{"FC3", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"t1", "^", "2"}], ")"}], "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"t2", "/", "t1"}], ")"}], "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"q", "/", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
          RowBox[{"1", "/", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"q", " ", 
              RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], ",", 
          RowBox[{"k", "^", "m"}]}], "]"}], "+", 
        RowBox[{"FKahlerZ2", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", "p1", ")"}], "^", "m"}], ",", 
          RowBox[{"t3", "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"q", "/", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
           RowBox[{"(", " ", "m", ")"}]}], ",", 
          RowBox[{"1", "/", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"q", " ", 
              RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
            RowBox[{"(", " ", "m", ")"}]}]}], ",", 
          RowBox[{"k", "^", "m"}]}], "]"}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "7"}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.71674292208926*^9, 3.716742953076577*^9}, {
   3.7167432752667227`*^9, 3.716743292259039*^9}, {3.7167433457899113`*^9, 
   3.71674334641877*^9}, 3.716743669529449*^9, {3.716804724797839*^9, 
   3.71680472488545*^9}, 3.716804819240119*^9, 3.717747119705455*^9}],

Cell["\<\
In order to check this partition function we do the following: first we \
separate the sum of the three terms in the exponential into a product of \
three exponentials, we expand each one separately and then we take the \
coefficient (this is just to have a faster computation). Then we subtract the \
localization computation, and check that each coefficient is separately \
vanishing\
\>", "Text",
 CellChangeTimes->{{3.716743328778887*^9, 3.716743416044753*^9}, {
  3.7167435737619963`*^9, 3.71674359204348*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TotalSymmZ2", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{"PowerExpand", "[", 
     RowBox[{
      RowBox[{"Normal", "[", 
       RowBox[{
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t1", "/", "t2"}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t2", "^", "2"}], ")"}], "^", "m"}], ",", 
                  RowBox[{"t3", "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], 
                  ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "6"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "6"}], "}"}]}], "]"}], " ", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", " ", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t1", "^", "2"}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t2", "/", "t1"}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], 
                  ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "6"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "6"}], "}"}]}], "]"}], " ", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FKahlerZ2", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", "p1", ")"}], "^", "m"}], ",", 
                  RowBox[{"t3", "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
                   RowBox[{"(", " ", "m", ")"}]}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
                    RowBox[{"(", " ", "m", ")"}]}]}], ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "6"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "6"}], "}"}]}], "]"}]}], "]"}], "//.", 
      
      RowBox[{"q", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "p0"}], " ", "p1"}]}]}], "]"}], "]"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.716743547968031*^9, 3.716743560188056*^9}, {
   3.7167436790487823`*^9, 3.716743912696555*^9}, {3.7167439728450737`*^9, 
   3.716743980246004*^9}, {3.716744122209505*^9, 3.71674415677131*^9}, {
   3.7167441899475527`*^9, 3.71674421310176*^9}, {3.716744447215317*^9, 
   3.716744447478372*^9}, {3.71674454084348*^9, 3.7167445585656633`*^9}, {
   3.716744658924059*^9, 3.716744706322913*^9}, {3.716744826823687*^9, 
   3.716744860659793*^9}, 3.716745280128818*^9, {3.7167453651037197`*^9, 
   3.716745373778812*^9}, {3.7177471227024*^9, 3.717747126122335*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CheckcoeffZ2", "[", 
   RowBox[{"order_", ",", "n0_", ",", "n1_"}], "]"}], ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{"TotalSymmZ2", ",", "p0", ",", "n0"}], "]"}], ",", "p1", ",",
         "n1"}], "]"}], "//.", 
      RowBox[{"k", "\[Rule]", 
       RowBox[{"t1", " ", "t2", " ", "t3"}]}]}], "]"}], "-", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{"TotalContributionC2Z2", "[", 
           RowBox[{"order", ",", "p0", ",", "p1"}], "]"}], ",", "p0", ",", 
          "n0"}], "]"}], ",", "p1", ",", "n1"}], "]"}], "//.", 
      RowBox[{"k", "\[Rule]", 
       RowBox[{"t1", " ", "t2", " ", "t3"}]}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.716743547968031*^9, 3.716743560188056*^9}, {
   3.7167436790487823`*^9, 3.716743912696555*^9}, {3.7167439728450737`*^9, 
   3.716743980246004*^9}, {3.716744122209505*^9, 3.71674415677131*^9}, {
   3.7167441899475527`*^9, 3.71674421310176*^9}, {3.716744447215317*^9, 
   3.716744447478372*^9}, {3.71674454084348*^9, 3.7167445585656633`*^9}, 
   3.716745311838509*^9, {3.7168057498275347`*^9, 3.716805772190095*^9}}],

Cell["\<\
To check that the two partition function match order by order,  we write them \
into a list using the function DistributeIntoNodes defined in the first \
Section (Generalities and Definitions - Other quiver functions), which gives \
all the possible ways the instanton number is distributed in the number of \
nodes. Note that to check the partition functions we have to set k=t1 t2 t3 \
explicitly in the formulas\
\>", "Text",
 CellChangeTimes->{{3.716745690460805*^9, 3.716745788155431*^9}, {
  3.717916876780944*^9, 3.717916941971794*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CheckcoeffZ2List", "[", 
   RowBox[{"n_", ",", "list_"}], "]"}], ":=", 
  RowBox[{"CheckcoeffZ2", "[", 
   RowBox[{"n", ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7167439311444817`*^9, 3.716743937953562*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ2List", "[", 
    RowBox[{"1", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"1", ",", "2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.716743959254279*^9, 3.71674396117627*^9}, {
  3.716744415326033*^9, 3.716744457092928*^9}, {3.716745326607234*^9, 
  3.716745328229128*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.716743961762023*^9, 3.7167439829175577`*^9}, 
   3.7167441244162416`*^9, 3.71674416090659*^9, 3.716744216031682*^9, {
   3.7167444181391373`*^9, 3.716744457639382*^9}, 3.7167448106633673`*^9, {
   3.71674532415149*^9, 3.716745328700337*^9}, 3.716745407022099*^9, 
   3.716799729087961*^9, 3.717747394055794*^9, 3.717747493271392*^9, 
   3.7177519360215597`*^9, 3.717831408325203*^9, 3.717916584941412*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ2List", "[", 
    RowBox[{"2", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"2", ",", "2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.716743959254279*^9, 3.71674396117627*^9}, {
  3.716744415326033*^9, 3.716744457092928*^9}, {3.716745326607234*^9, 
  3.7167453484751587`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.716745408262557*^9, 3.7167997304757*^9, 
  3.717747395589641*^9, 3.717747494507531*^9, 3.717751937524167*^9, 
  3.717831409511787*^9, 3.7179165861301813`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ2List", "[", 
    RowBox[{"3", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"3", ",", "2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.716743959254279*^9, 3.71674396117627*^9}, {
  3.716744415326033*^9, 3.716744457092928*^9}, {3.716745326607234*^9, 
  3.716745350047001*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.71674541029395*^9, 3.7167997326749067`*^9, 
  3.7177473979157677`*^9, 3.717747496478611*^9, 3.717751939705233*^9, 
  3.717831411386221*^9, 3.717916588089382*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ2List", "[", 
    RowBox[{"4", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"4", ",", "2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.716743959254279*^9, 3.71674396117627*^9}, {
  3.716744415326033*^9, 3.716744457092928*^9}, {3.716745326607234*^9, 
  3.71674535151757*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.7167454161471453`*^9, 3.7167997388007402`*^9, 
  3.717747404212821*^9, 3.717747519965629*^9, 3.7177519464432573`*^9, 
  3.717831416262266*^9, 3.717916593152203*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ2List", "[", 
    RowBox[{"5", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"5", ",", "2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.716743959254279*^9, 3.71674396117627*^9}, {
  3.716744415326033*^9, 3.716744457092928*^9}, {3.716745326607234*^9, 
  3.7167453532326202`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.716745433325231*^9, 3.716799755321061*^9, 
  3.717747420916656*^9, 3.717747534981695*^9, 3.717751965271142*^9, 
  3.717831430150178*^9, 3.717916607387434*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ2List", "[", 
    RowBox[{"6", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"6", ",", "2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7167453595710077`*^9, 3.7167453614126167`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.716745550565963*^9, 3.7167998872689943`*^9, 
  3.717747426487001*^9, 3.717747653878644*^9, 3.7177520879478207`*^9, 
  3.717831534964671*^9, 3.7179167144937277`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Refined Limit", "Subsection",
 CellChangeTimes->{{3.7167218568656588`*^9, 3.716721869150951*^9}, {
  3.716746495930977*^9, 3.71674649772202*^9}}],

Cell["\<\
We can take the refined limit already at the level of the Orbifold Nekrasov \
function\
\>", "Text",
 CellChangeTimes->{{3.7167468509322166`*^9, 3.716746882145362*^9}, {
  3.7167992545538607`*^9, 3.716799257983963*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"PowerExpand", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"FC3", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"t1", "/", "t2"}], ")"}], ",", 
         RowBox[{"(", 
          RowBox[{"t2", "^", "2"}], ")"}], ",", "t3", ",", 
         RowBox[{"q", "/", " ", 
          RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"q", " ", 
            RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}]}], ",", "k"}], "]"}], 
       "+", 
       RowBox[{"FC3", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"t1", "^", "2"}], ")"}], ",", 
         RowBox[{"(", 
          RowBox[{"t2", "/", "t1"}], ")"}], ",", 
         RowBox[{"(", "t3", ")"}], ",", 
         RowBox[{"(", 
          RowBox[{"q", "/", 
           RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], ",", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"q", " ", 
            RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}]}], ",", "k"}], "]"}], 
       "+", 
       RowBox[{"FKahlerZ2", "[", 
        RowBox[{"p1", ",", "t3", ",", 
         RowBox[{"q", "/", " ", 
          RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"q", " ", 
            RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}]}], ",", "k"}], "]"}]}], 
      ")"}], "//.", "TorusT3"}], "]"}], ",", 
   RowBox[{"x", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.716799260506085*^9, 3.716799276704976*^9}, {
  3.716799985640109*^9, 3.716799993014703*^9}, {3.716800074139658*^9, 
  3.716800088893502*^9}, {3.716800215721901*^9, 3.7168002355496063`*^9}, {
  3.716803452911003*^9, 3.7168034891087933`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "p1"}], ")"}], "2"], " ", "q"}], 
   RowBox[{"p1", " ", 
    RowBox[{"(", 
     RowBox[{
      SqrtBox["k"], "-", "q"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       SqrtBox["k"], " ", "q"}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.7167994403653507`*^9, 3.716799887345582*^9, {3.716799987145741*^9, 
   3.7167999935304117`*^9}, {3.7168000770206747`*^9, 3.716800089477722*^9}, 
   3.716800236169428*^9, 3.716803489926999*^9, 3.717747801915346*^9, 
   3.717752088229148*^9, 3.717831535219129*^9, 3.717916714752284*^9, 
   3.7179169611218348`*^9}]
}, Open  ]],

Cell["Therefore we define", "Text",
 CellChangeTimes->{{3.716803745712994*^9, 3.716803747865363*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FZ2Ref", "[", 
   RowBox[{"q_", ",", "k_", ",", "p1_"}], "]"}], ":=", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"k", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", "p1"}], ")"}], "2"], " ", "q"}], 
    RowBox[{"p1", " ", 
     RowBox[{"(", 
      RowBox[{
       SqrtBox["k"], "-", "q"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SqrtBox["k"], " ", "q"}]}], ")"}]}]]}]}]], "Input",
 CellChangeTimes->{3.7177478162316504`*^9}],

Cell["\<\
By \[OpenCurlyDoubleQuote]undoing\[CloseCurlyDoubleQuote] the plethystic \
exponential it is easy, if a bit involved, to write down a product formula \
for the refined invariants (the parameters epsilon and delta parameterize \
different refinements)\
\>", "Text",
 CellChangeTimes->{{3.71680377251703*^9, 3.716803795203907*^9}, {
  3.7179169714418983`*^9, 3.717916982466845*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ZreoA", "[", 
   RowBox[{"a0_", ",", "a1_", ",", "y0_", ",", "y1_"}], "]"}], ":=", 
  RowBox[{"Product", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{
       RowBox[{"L", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "a0"}], "/", "2"}], "+", 
          RowBox[{"1", "/", "2"}], "+", "j"}], ")"}]}], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"-", "y0"}], ")"}], "^", "a0"}], " ", 
       RowBox[{"y1", "^", "a1"}]}]}], ")"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", 
      RowBox[{"a0", "-", "1"}]}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ZreeA", "[", 
   RowBox[{"a0_", ",", "a1_", ",", "y0_", ",", "y1_"}], "]"}], ":=", 
  RowBox[{"Product", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        RowBox[{"L", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "a0"}], "/", "2"}], "+", "1", "+", "j"}], ")"}]}], 
        " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"-", "y0"}], ")"}], "^", "a0"}], " ", 
        RowBox[{"y1", "^", "a1"}]}]}], ")"}], "^", 
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", 
      RowBox[{"a0", "-", "1"}]}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ZimA", "[", 
   RowBox[{
   "a0_", ",", "a1_", ",", "y0_", ",", "y1_", ",", "epsilon_", ",", "delta_", 
    ",", "N_"}], "]"}], ":=", 
  RowBox[{"Product", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"L", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a0"}], "/", "2"}], "+", "epsilon", "+", "j"}], 
           ")"}]}], " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", "y0"}], ")"}], "^", "a0"}], " ", 
         RowBox[{"y1", "^", "a1"}]}]}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"1", "-", "N"}], ")"}]}], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"L", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a0"}], "/", "2"}], "+", "delta", "+", "j"}], 
           ")"}]}], " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", "y0"}], ")"}], "^", "a0"}], " ", 
         RowBox[{"y1", "^", "a1"}]}]}], " ", ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", 
      RowBox[{"a0", "-", "1"}]}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.675686151987041*^9, 3.6756863061871643`*^9}, {
  3.675686346746666*^9, 3.675686377404379*^9}, {3.6756864371507063`*^9, 
  3.675686439494792*^9}, {3.675687554738285*^9, 3.6756875573543262`*^9}, {
  3.675707821620995*^9, 3.6757078404210043`*^9}, {3.676207007581489*^9, 
  3.6762070223435907`*^9}, {3.68656334329184*^9, 3.686563408901286*^9}, {
  3.6865679438539743`*^9, 3.686567948438442*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZmotA", "[", 
   RowBox[{"y0_", ",", "y1_", ",", "N_", ",", "epsilon_", ",", "delta_"}], 
   "]"}], ":=", 
  RowBox[{
   RowBox[{"Product", "[", 
    RowBox[{
     RowBox[{"ZreeA", "[", 
      RowBox[{"i", ",", 
       RowBox[{"i", "-", "1"}], ",", "y0", ",", "y1"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "N"}], "}"}]}], "]"}], 
   RowBox[{"Product", "[", 
    RowBox[{
     RowBox[{"ZreeA", "[", 
      RowBox[{
       RowBox[{"i", "-", "1"}], ",", "i", ",", "y0", ",", "y1"}], "]"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "N"}], "}"}]}], "]"}], " ", 
   RowBox[{"Product", "[", 
    RowBox[{
     RowBox[{"ZimA", "[", 
      RowBox[{
      "i", ",", "i", ",", "y0", ",", "y1", ",", "epsilon", ",", "delta", ",", 
       "2"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "N"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.675686453536471*^9, 3.6756865329398413`*^9}, {
  3.676207029741981*^9, 3.676207050654202*^9}, {3.6865635241896887`*^9, 
  3.686563548906604*^9}, {3.68656366460399*^9, 3.6865636687957373`*^9}, {
  3.686563737847653*^9, 3.686563737942503*^9}, {3.686567952195078*^9, 
  3.686567958866516*^9}}],

Cell["\<\
We check this formula order by order (the motive L is replaced by k in our \
formulas)\
\>", "Text",
 CellChangeTimes->{{3.7168038218256683`*^9, 3.716803842420607*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PowerExpand", "[", 
  RowBox[{
   RowBox[{"Total", "[", 
    RowBox[{"BoundDegreeK", "[", 
     RowBox[{
      RowBox[{"List", "@@", 
       RowBox[{"Expand", "[", 
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Exp", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "n"}], " ", 
               RowBox[{"PowerExpand", "[", 
                RowBox[{"FZ2Ref", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1"}], ")"}], "^", "n"}], ",", 
                  
                  RowBox[{"k", "^", "n"}], ",", 
                  RowBox[{"p1", "^", "n"}]}], "]"}], "]"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"n", ",", "1", ",", "8"}], "}"}]}], "]"}], "]"}], ",", 
           
           RowBox[{"{", 
            RowBox[{"p0", ",", "0", ",", "7"}], "}"}]}], "]"}], "]"}], 
        "]"}]}], ",", "8"}], "]"}], "]"}], "-", 
   RowBox[{"Total", "[", 
    RowBox[{"BoundDegreeK", "[", 
     RowBox[{
      RowBox[{"List", "@@", 
       RowBox[{"Expand", "[", 
        RowBox[{"PowerExpand", "[", 
         RowBox[{
          RowBox[{"Expand", "[", 
           RowBox[{"Normal", "[", 
            RowBox[{"Series", "[", 
             RowBox[{
              RowBox[{"Series", "[", 
               RowBox[{
                RowBox[{"ZmotA", "[", 
                 RowBox[{"p0", ",", "p1", ",", "9", ",", "1", ",", "1"}], 
                 "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"p0", ",", "0", ",", "7"}], "}"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"p1", ",", "0", ",", "7"}], "}"}]}], "]"}], "]"}], 
           "]"}], "//.", 
          RowBox[{"L", "\[Rule]", "k"}]}], "]"}], "]"}]}], ",", "8"}], "]"}], 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.709461820912931*^9, 3.7094618312652273`*^9}, {
   3.709461880508375*^9, 3.709461935799809*^9}, {3.709625414937348*^9, 
   3.709625495797654*^9}, {3.709625537678051*^9, 3.709625537781795*^9}, {
   3.7096255856459923`*^9, 3.709625667799713*^9}, {3.7168020840816917`*^9, 
   3.716802164222851*^9}, {3.7168022277728653`*^9, 3.716802229946805*^9}, {
   3.716802269201618*^9, 3.7168022957524853`*^9}, {3.71680351534975*^9, 
   3.716803515409442*^9}, 3.7177478256886883`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.716803830002898*^9, 3.7177478290494347`*^9, 
  3.717752088882859*^9, 3.717831535873057*^9, 3.7179167153908854`*^9, 
  3.717916961716539*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["C2/Z3 x C", "Subchapter",
 CellChangeTimes->{{3.709618753392975*^9, 3.709618759771175*^9}}],

Cell[CellGroupData[{

Cell["Localization", "Subsection",
 CellChangeTimes->{{3.7167218568656588`*^9, 3.716721869150951*^9}, {
  3.716831316100327*^9, 3.716831317432575*^9}}],

Cell["\<\
Now we consider the case of C2/Z3 x C, with action on the toric coordinates \
(t1,t2,t3)->(w^(-1) t1, w t2, t3), with w^3=1.
We define the weight decomposition of the spaces into spaces transforming in \
the conjugacy class r\
\>", "Text",
 CellChangeTimes->{{3.675101772407387*^9, 3.6751017958955297`*^9}, {
  3.716811232413663*^9, 3.716811270646744*^9}, {3.716811340863001*^9, 
  3.716811345803772*^9}, {3.7168114027454567`*^9, 3.716811449403644*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PPVr", "[", 
   RowBox[{"l_List", ",", "t1_", ",", "t2_", ",", "t3_", ",", "r_"}], "]"}], ":=", 
  RowBox[{"Total", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"t1", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "i"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"t2", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "j"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"t3", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "k"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"KroneckerDelta", "[", 
          RowBox[{
           RowBox[{"Mod", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "j"}], "+", "i"}], ",", "3"}], "]"}], ",", "r"}], 
          "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "l", "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"j", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"l", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"l", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "}"}]}], 
       "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.685794026599243*^9, 3.685794062411702*^9}, {
  3.6857945569193993`*^9, 3.68579456486136*^9}, {3.685794658823471*^9, 
  3.685794661349846*^9}, {3.685794743967721*^9, 3.685794762494817*^9}, {
  3.685795923624857*^9, 3.685795925376687*^9}}],

Cell["\<\
The virtual tangent space at a fixed point is given by the Z3 invariant part \
of the weight decomposition of the virtual tangent space for C3\
\>", "Text",
 CellChangeTimes->{{3.675101835423895*^9, 3.675101844366613*^9}, {
  3.716811430241415*^9, 3.7168114687246017`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TvirC2Z3fixed", "[", 
   RowBox[{"list_", ",", "t1_", ",", "t2_", ",", "t3_", ",", "k_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"PPVr", "[", 
    RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], "-", 
   RowBox[{
    RowBox[{"PPVr", "[", 
     RowBox[{"list", ",", 
      RowBox[{"1", "/", "t1"}], ",", 
      RowBox[{"1", "/", "t2"}], ",", 
      RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}], " ", "t1", " ", "t2", " ", 
    "t3"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"PPVr", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], 
       RowBox[{"PPVr", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVr", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "1"}], "]"}], 
       RowBox[{"PPVr", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "1"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVr", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "2"}], "]"}], 
       RowBox[{"PPVr", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "2"}], "]"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"t1", " ", "t2"}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", "t3"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"PPVr", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], 
       RowBox[{"PPVr", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "1"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVr", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "1"}], "]"}], 
       RowBox[{"PPVr", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "2"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVr", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "2"}], "]"}], 
       RowBox[{"PPVr", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"-", "t2"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", "t3"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"PPVr", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], 
       RowBox[{"PPVr", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "2"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVr", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "1"}], "]"}], 
       RowBox[{"PPVr", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVr", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "2"}], "]"}], 
       RowBox[{"PPVr", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "1"}], "]"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"-", "t1"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", "t3"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.674587994202264*^9, 3.674588008681179*^9}, {
  3.6746547289960318`*^9, 3.6746547329251757`*^9}, {3.674993518039311*^9, 
  3.674993519238812*^9}, {3.6750056749571943`*^9, 3.6750056766999826`*^9}, {
  3.6750059890160027`*^9, 3.675005990235087*^9}, {3.6857941088840933`*^9, 
  3.685794343643107*^9}}],

Cell["For example", "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.716811476727949*^9, 3.716811477849194*^9}, {
  3.716811534823783*^9, 3.7168115585213127`*^9}, {3.716811602121245*^9, 
  3.716811618447055*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{"TvirC2Z3fixed", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"PlanePartitions", "[", "12", "]"}], "[", 
     RowBox[{"[", "12", "]"}], "]"}], ",", "t1", ",", "t2", ",", "t3", ",", 
    "k"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.68579440343537*^9, 3.685794411986561*^9}, {
   3.685794575683034*^9, 3.68579461889746*^9}, 3.6857947759237843`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["t1", 
   SuperscriptBox["t2", "2"]], "-", 
  RowBox[{"3", " ", "t1", " ", "t2"}], "+", 
  FractionBox[
   SuperscriptBox["t2", "3"], 
   SuperscriptBox["t3", "5"]], "+", 
  FractionBox[
   SuperscriptBox["t2", "3"], 
   SuperscriptBox["t3", "4"]], "+", 
  FractionBox["t1", 
   RowBox[{
    SuperscriptBox["t2", "2"], " ", "t3"}]], "-", 
  FractionBox[
   RowBox[{"3", " ", "t1", " ", "t2"}], "t3"], "+", 
  RowBox[{"3", " ", "t3"}], "-", 
  RowBox[{
   SuperscriptBox["t2", "3"], " ", "t3"}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["t3", "2"]}], "-", 
  RowBox[{
   SuperscriptBox["t2", "3"], " ", 
   SuperscriptBox["t3", "2"]}], "-", 
  FractionBox[
   RowBox[{"t1", " ", 
    SuperscriptBox["t3", "5"]}], 
   SuperscriptBox["t2", "2"]], "-", 
  FractionBox[
   RowBox[{"t1", " ", 
    SuperscriptBox["t3", "6"]}], 
   SuperscriptBox["t2", "2"]]}]], "Output",
 CellChangeTimes->{
  3.68579441238128*^9, {3.685794567647831*^9, 3.68579461933261*^9}, 
   3.6857946643901377`*^9, {3.685794765277047*^9, 3.685794776286975*^9}, {
   3.6859423555802603`*^9, 3.6859423769584227`*^9}, {3.6860285092973003`*^9, 
   3.6860285285096607`*^9}, {3.686032233129039*^9, 3.6860322428396997`*^9}, 
   3.6863104900727663`*^9, 3.6863949493472633`*^9, 3.709455830268592*^9, 
   3.70954444812745*^9, 3.709556421322426*^9, 3.709618801419613*^9, 
   3.709918914884048*^9, 3.716806007221089*^9, 3.717747919083033*^9, 
   3.717752109967977*^9, 3.717831536064983*^9, 3.717918068621352*^9}]
}, Open  ]],

Cell["The number of boxes in a 3d diagram in the conjugacy class r", "Text",
 CellChangeTimes->{{3.716811632927648*^9, 3.716811649072441*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"NBr", "[", 
   RowBox[{"l_List", ",", "r_"}], "]"}], ":=", 
  RowBox[{"PPVr", "[", 
   RowBox[{"l", ",", "1", ",", "1", ",", "1", ",", "r"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.685795573005415*^9, 3.685795594181725*^9}, 
   3.6857956721339827`*^9, {3.685795713741584*^9, 3.685795814978931*^9}, {
   3.6857958527331142`*^9, 3.6857958683004723`*^9}, {3.685795981600951*^9, 
   3.6857959892875137`*^9}, 3.685796449591515*^9, {3.685796677468938*^9, 
   3.685796685114377*^9}, 3.685796731259357*^9}],

Cell["\<\
The localization computation proceeds as before, first we define the virtual \
tangent space as a function of the fixed point, then we collect the monomials \
of the virtual tangent space corresponding to deformation into a list and we \
apply the (modified) A-hat function to get the fixed point contribution. \
Finally we have the full K-theory partition function\
\>", "Text",
 CellChangeTimes->{{3.71681165642875*^9, 3.716811763937697*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"VirtualTC2Z3", "[", 
   RowBox[{"nboxes_", ",", "fixedpoint_"}], "]"}], ":=", 
  RowBox[{"Expand", "[", 
   RowBox[{"TvirC2Z3fixed", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
      RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", "t2", ",", 
     "t3", ",", "k"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FPListC2Z3", "[", 
    RowBox[{"nboxes_", ",", "fixedpoint_"}], "]"}], ":=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Reap", "[", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Flatten", "[", 
                RowBox[{"List", "@@", 
                 RowBox[{"(", 
                  RowBox[{"Expand", "[", 
                   RowBox[{"TvirC2Z3fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
                "//.", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"t1", "\[Rule]", "1"}], ",", 
                 RowBox[{"t2", "->", "1"}], ",", 
                 RowBox[{"t3", "\[Rule]", "1"}], ",", 
                 RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
             RowBox[{"[", "i", "]"}], "]"}], ">", "0"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Sow", "[", 
            RowBox[{"{", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
                 RowBox[{"List", "@@", 
                  RowBox[{"(", 
                   RowBox[{"Expand", "[", 
                    RowBox[{"TvirC2Z3fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], 
                 "\[IndentingNewLine]", "]"}], "[", 
                RowBox[{"[", "i", "]"}], "]"}], "/", 
               RowBox[{"(", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Flatten", "[", 
                    RowBox[{"List", "@@", 
                    RowBox[{"(", 
                    RowBox[{"Expand", "[", 
                    RowBox[{"TvirC2Z3fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
                    "//.", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"t1", "\[Rule]", "1"}], ",", 
                    RowBox[{"t2", "->", "1"}], ",", 
                    RowBox[{"t3", "\[Rule]", "1"}], ",", 
                    RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "\[IndentingNewLine]", 
                ")"}]}], ",", 
              RowBox[{
               RowBox[{"(", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Flatten", "[", 
                  RowBox[{"List", "@@", 
                   RowBox[{"(", 
                    RowBox[{"Expand", "[", 
                    RowBox[{"TvirC2Z3fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
                  "//.", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"t1", "\[Rule]", "1"}], ",", 
                   RowBox[{"t2", "->", "1"}], ",", 
                   RowBox[{"t3", "\[Rule]", "1"}], ",", 
                   RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "\[IndentingNewLine]", "}"}],
             "]"}]}], "\[IndentingNewLine]", "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", 
            RowBox[{"Flatten", "[", 
             RowBox[{"List", "@@", 
              RowBox[{"(", 
               RowBox[{"Expand", "[", 
                RowBox[{"TvirC2Z3fixed", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                   RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                  "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}], 
            "]"}]}], "}"}]}], "]"}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.67509769824366*^9, 3.675097742433045*^9}, {
   3.675097787395336*^9, 3.67509779944084*^9}, {3.675097856209297*^9, 
   3.675097941379383*^9}, 3.675098012939138*^9, {3.675101981572866*^9, 
   3.675102132977907*^9}, {3.679138392316263*^9, 3.679138397170555*^9}, {
   3.679139098659503*^9, 3.679139114360139*^9}, {3.685794841789722*^9, 
   3.685794885068252*^9}, {3.685797044333329*^9, 3.685797110123225*^9}, {
   3.6857971441185102`*^9, 3.6857971449891253`*^9}, {3.716804474939232*^9, 
   3.716804509913105*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ahatp", "[", "list_", "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "/", 
          RowBox[{"list", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"list", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "/", "k"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"list", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"list", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], ")"}], "^", 
   RowBox[{"list", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LocalizationC2Z3", "[", 
   RowBox[{
   "nboxes_", ",", "fixedpoint_", ",", "p0_", ",", "p1_", ",", "p2_"}], "]"}],
   ":=", 
  RowBox[{
   RowBox[{"Cancel", "[", 
    RowBox[{"PowerExpand", "[", 
     RowBox[{"Times", "@@", 
      RowBox[{"Map", "[", 
       RowBox[{"ahatp", ",", 
        RowBox[{"FPListC2Z3", "[", 
         RowBox[{"nboxes", ",", "fixedpoint"}], "]"}]}], "]"}]}], "]"}], 
    "]"}], " ", 
   RowBox[{"p0", "^", 
    RowBox[{"NBr", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
       RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "0"}], "]"}]}], " ", 
   RowBox[{"p1", "^", 
    RowBox[{"NBr", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
       RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "2"}], "]"}]}], " ", 
   RowBox[{"p2", "^", 
    RowBox[{"NBr", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
       RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "1"}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.716804523467095*^9, 3.7168045243027077`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TotalContributionC2Z3", "[", 
    RowBox[{"nboxes_", ",", "p0_", ",", "p1_", ",", "p2_"}], "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"LocalizationC2Z3", "[", 
      RowBox[{"nboxes", ",", "i", ",", "p0", ",", "p1", ",", "p2"}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", 
        RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "]"}]}], "}"}]}], 
    "]"}]}], "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PartitionFunctionC2Z3", "[", "nboxes_", "]"}], ":=", 
  RowBox[{"1", "+", 
   RowBox[{"Sum", "[", " ", 
    RowBox[{
     RowBox[{"TotalContributionC2Z3", "[", 
      RowBox[{"n", ",", "p0", ",", "p1", ",", "p2"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "nboxes"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.716804618813366*^9, 3.716804627198197*^9}, {
  3.716806034437278*^9, 3.716806034503093*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PartitionFunctionC2Z3", "[", "3", "]"}]], "Input",
 CellChangeTimes->{3.716804640930531*^9}],

Cell[BoxData[
 RowBox[{"1", "+", 
  FractionBox[
   RowBox[{"p0", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t1", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t1", "2"]}], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t1", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      RowBox[{"k", " ", "t2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", 
       SuperscriptBox["t2", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t2", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t2", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "3"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3", "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.7168060244467297`*^9, 3.7168060388320017`*^9}, 
   3.717747919418298*^9, 3.717752110330586*^9, 3.7178315363521023`*^9, 
   3.717918068931899*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Symmetrization and Orbifold Nekrasov function", "Subsection",
 CellChangeTimes->{{3.7167218568656588`*^9, 3.716721869150951*^9}, {
  3.717747920365906*^9, 3.717747921621313*^9}}],

Cell["\<\
The logic is the same as before. The Orbifold Nekrasov function has two \
pieces: 1. three copies of the C3 function parametrizing Z3 invariant \
monomials, 2. a \[OpenCurlyDoubleQuote]Kahler term\[CloseCurlyDoubleQuote]\
\>", "Text",
 CellChangeTimes->{{3.7168117855609417`*^9, 3.716811842093212*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FC3", "[", 
   RowBox[{"t1_", ",", "t2_", ",", "t3_", ",", "t4_", ",", "t5_", ",", "k_"}],
    "]"}], ":=", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t1"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t1"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t3"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t3"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "/", "t2"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "/", "t2"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t1", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t1", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t2", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t2", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t3", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t3", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t4", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t4", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t5", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t5", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], ")"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6744033720560493`*^9, 3.674403372806196*^9}, 
   3.674403472934162*^9, {3.685798651440465*^9, 3.685798653178933*^9}, {
   3.709464971485652*^9, 3.709464999637817*^9}, {3.709465033504201*^9, 
   3.709465064467249*^9}, {3.7098117622022123`*^9, 3.7098117675144997`*^9}, {
   3.7177470092131577`*^9, 3.717747036980688*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FKahlerZ3", "[", 
   RowBox[{"p1_", ",", "p2_", ",", "t3_", ",", "t4_", ",", "t5_", ",", "k_"}],
    "]"}], ":=", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"p1", "+", 
      RowBox[{"1", "/", "p1"}], "+", "p2", "+", 
      RowBox[{"1", "/", "p2"}], "+", 
      RowBox[{"p1", " ", "p2"}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"p1", " ", "p2"}], ")"}]}]}], ")"}], " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        SqrtBox[
         FractionBox["t3", "k"]]], "-", 
       SqrtBox[
        FractionBox["t3", "k"]]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SqrtBox["t3"]]}], "+", 
         SqrtBox["t3"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SqrtBox["t4"]]}], "+", 
         SqrtBox["t4"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SqrtBox["t5"]]}], "+", 
         SqrtBox["t5"]}], ")"}]}], ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.709800049685461*^9, 3.7098001425906267`*^9}, {
  3.709800282903933*^9, 3.7098002913052387`*^9}, {3.7098010041146803`*^9, 
  3.709801008186751*^9}, {3.709801741383148*^9, 3.709801768415749*^9}, {
  3.709808631439939*^9, 3.7098086335554943`*^9}, {3.7098111580622053`*^9, 
  3.709811195198132*^9}, {3.7168054055319843`*^9, 3.716805406818409*^9}, {
  3.717747882981153*^9, 3.717747885146311*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZSymmZ3", "[", 
   RowBox[{"t1_", ",", "t2_", ",", "t3_", ",", "t4_", ",", "t5_"}], "]"}], ":=", 
  RowBox[{"Exp", "[", " ", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", "m"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"FC3", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"t1", "/", 
             RowBox[{"t2", "^", "2"}]}], ")"}], "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"t2", "^", "3"}], ")"}], "^", "m"}], ",", 
          RowBox[{"t3", "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"q", "/", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
          RowBox[{"1", "/", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"q", " ", 
              RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], ",", 
          RowBox[{"k", "^", "m"}]}], "]"}], "+", 
        RowBox[{"FC3", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"t1", "^", "3"}], ")"}], "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"t2", "/", 
             RowBox[{"t1", "^", "2"}]}], ")"}], "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"q", "/", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
          RowBox[{"1", "/", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"q", " ", 
              RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], ",", 
          RowBox[{"k", "^", "m"}]}], "]"}], "+", 
        RowBox[{"FC3", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"t1", "^", "2"}], " ", "/", "t2"}], ")"}], "^", "m"}], 
          ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"t2", "^", "2"}], "/", " ", "t1"}], ")"}], "^", "m"}], 
          ",", 
          RowBox[{
           RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"q", "/", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
          RowBox[{"1", "/", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"q", " ", 
              RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], ",", 
          RowBox[{"k", "^", "m"}]}], "]"}], "+", 
        RowBox[{"FKahlerZ3", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", "p1", ")"}], "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", "p2", ")"}], "^", "m"}], ",", 
          RowBox[{"t3", "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"q", "/", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
           RowBox[{"(", " ", "m", ")"}]}], ",", 
          RowBox[{"1", "/", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"q", " ", 
              RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
            RowBox[{"(", " ", "m", ")"}]}]}], ",", 
          RowBox[{"k", "^", "m"}]}], "]"}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.71674292208926*^9, 3.716742953076577*^9}, {
   3.7167432752667227`*^9, 3.716743292259039*^9}, {3.7167433457899113`*^9, 
   3.71674334641877*^9}, 3.716743669529449*^9, {3.716804724797839*^9, 
   3.71680472488545*^9}, 3.716804819240119*^9, {3.7168053547782707`*^9, 
   3.7168054174295464`*^9}, 3.717747887817669*^9}],

Cell["\<\
We check that this is correct: first we separate the terms to speed up the \
computation, then we write a function which checks these coefficients order \
by order with the localization result\
\>", "Text",
 CellChangeTimes->{{3.716811859236095*^9, 3.7168118987835417`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TotalSymmZ3", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{"PowerExpand", "[", 
     RowBox[{
      RowBox[{"Normal", "[", 
       RowBox[{
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t1", "/", 
                    RowBox[{"t2", "^", "2"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t2", "^", "3"}], ")"}], "^", "m"}], ",", 
                  RowBox[{"t3", "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], 
                  ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], " ", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t1", "^", "3"}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t2", "/", 
                    RowBox[{"t1", "^", "2"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], 
                  ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], " ", 
        "\[IndentingNewLine]", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t1", "^", "2"}], " ", "/", "t2"}], ")"}], "^", 
                   "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t2", "^", "2"}], "/", " ", "t1"}], ")"}], "^", 
                   "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], 
                  ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], " ", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FKahlerZ3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", "p1", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "p2", ")"}], "^", "m"}], ",", 
                  RowBox[{"t3", "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
                   RowBox[{"(", " ", "m", ")"}]}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
                    RowBox[{"(", " ", "m", ")"}]}]}], ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}]}], "]"}], "//.", 
      
      RowBox[{"q", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}]}]}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.716743547968031*^9, 3.716743560188056*^9}, {
   3.7167436790487823`*^9, 3.716743912696555*^9}, {3.7167439728450737`*^9, 
   3.716743980246004*^9}, {3.716744122209505*^9, 3.71674415677131*^9}, {
   3.7167441899475527`*^9, 3.71674421310176*^9}, {3.716744447215317*^9, 
   3.716744447478372*^9}, {3.71674454084348*^9, 3.7167445585656633`*^9}, {
   3.716744658924059*^9, 3.716744706322913*^9}, {3.716744826823687*^9, 
   3.716744860659793*^9}, 3.716745280128818*^9, {3.7167453651037197`*^9, 
   3.716745373778812*^9}, {3.7168054463809023`*^9, 3.716805499754425*^9}, {
   3.716814941032033*^9, 3.7168149411030293`*^9}, {3.7168152428817663`*^9, 
   3.716815243477435*^9}, {3.716816235692546*^9, 3.716816251550625*^9}, {
   3.716818034324325*^9, 3.716818037837872*^9}, {3.7177478918495913`*^9, 
   3.7177478976623487`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CheckcoeffZ3", "[", 
   RowBox[{"order_", ",", "n0_", ",", "n1_", ",", "n2_"}], "]"}], ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"PowerExpand", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{"TotalSymmZ3", ",", "p0", ",", "n0"}], "]"}], ",", "p1", 
          ",", "n1"}], "]"}], ",", "p2", ",", "n2"}], "]"}], "//.", 
      RowBox[{"k", "\[Rule]", 
       RowBox[{"t1", " ", "t2", " ", "t3"}]}]}], "]"}], "-", 
    RowBox[{"PowerExpand", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{
            RowBox[{"TotalContributionC2Z3", "[", 
             RowBox[{"order", ",", "p0", ",", "p1", ",", "p2"}], "]"}], ",", 
            "p0", ",", "n0"}], "]"}], ",", "p1", ",", "n1"}], "]"}], ",", 
        "p2", ",", "n2"}], "]"}], "//.", 
      RowBox[{"k", "\[Rule]", 
       RowBox[{"t1", " ", "t2", " ", "t3"}]}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.716743547968031*^9, 3.716743560188056*^9}, {
   3.7167436790487823`*^9, 3.716743912696555*^9}, {3.7167439728450737`*^9, 
   3.716743980246004*^9}, {3.716744122209505*^9, 3.71674415677131*^9}, {
   3.7167441899475527`*^9, 3.71674421310176*^9}, {3.716744447215317*^9, 
   3.716744447478372*^9}, {3.71674454084348*^9, 3.7167445585656633`*^9}, 
   3.716745311838509*^9, {3.716805721940887*^9, 3.716805743650395*^9}, {
   3.716805787212627*^9, 3.71680581189425*^9}, {3.716814933478801*^9, 
   3.716814935482636*^9}, {3.716816100754361*^9, 3.716816106917471*^9}, {
   3.716818169680214*^9, 3.71681817015843*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CheckcoeffZ3List", "[", 
   RowBox[{"n_", ",", "list_"}], "]"}], ":=", 
  RowBox[{"CheckcoeffZ3", "[", 
   RowBox[{"n", ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7167439311444817`*^9, 3.716743937953562*^9}, {
  3.7168058289544086`*^9, 3.716805836671446*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ3List", "[", 
    RowBox[{"1", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"1", ",", "3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.716805858340405*^9, 3.716805860821953*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.716806359462778*^9, 3.71681609252494*^9, 
  3.71681615634543*^9, 3.716817853131633*^9, 3.71681812220854*^9, 
  3.716818175435409*^9, 3.7177479651780376`*^9, 3.71775215215186*^9, 
  3.717831575787672*^9, 3.71791811002164*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ3List", "[", 
    RowBox[{"2", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"2", ",", "3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.716805870100071*^9, 3.716805874951579*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.716806361808864*^9, 3.7168181816109943`*^9, 
  3.7177479683680153`*^9, 3.717752155296976*^9, 3.717831578741027*^9, 
  3.717918113091159*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ3List", "[", 
    RowBox[{"3", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"3", ",", "3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7168058717591867`*^9, 3.7168058765193567`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.716806366401753*^9, 3.716818188984516*^9, 
  3.717747974869585*^9, 3.7177521614383173`*^9, 3.717831584637678*^9, 
  3.717918119285087*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ3List", "[", 
    RowBox[{"4", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"4", ",", "3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.71680587314293*^9, 3.7168058781035147`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7168063806557426`*^9, 3.7168182051393127`*^9, 
  3.717747990794889*^9, 3.717752176649839*^9, 3.7178315980578527`*^9, 
  3.7179181351549797`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ3List", "[", 
    RowBox[{"5", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"5", ",", "3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.716806567834484*^9, 3.7168065698524113`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.716806620562315*^9, 3.7168182556150312`*^9, 
  3.717748039416492*^9, 3.71775222427605*^9, 3.7178316449282017`*^9, 
  3.7179181868347588`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Refined Limit", "Subsection",
 CellChangeTimes->{{3.7167218568656588`*^9, 3.716721869150951*^9}, {
  3.716806896989376*^9, 3.716806898645274*^9}}],

Cell["\<\
To study the refined limit we begin by taking the refined limit of the \
Nekrasov Orbifold function\
\>", "Text",
 CellChangeTimes->{{3.716812060229958*^9, 3.716812077074877*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"PowerExpand", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"FC3", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"t1", "/", 
           RowBox[{"t2", "^", "2"}]}], ")"}], ",", 
         RowBox[{"(", 
          RowBox[{"t2", "^", "3"}], ")"}], ",", "t3", ",", 
         RowBox[{"(", 
          RowBox[{"q", "/", 
           RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], ",", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"q", " ", 
            RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}]}], ",", "k"}], "]"}], 
       "+", 
       RowBox[{"FC3", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"t1", "^", "3"}], ")"}], ",", 
         RowBox[{"(", 
          RowBox[{"t2", "/", 
           RowBox[{"t1", "^", "2"}]}], ")"}], ",", 
         RowBox[{"(", "t3", ")"}], ",", 
         RowBox[{"(", 
          RowBox[{"q", "/", 
           RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], ",", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"q", " ", 
            RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}]}], ",", "k"}], "]"}], 
       "+", 
       RowBox[{"FC3", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"t1", "^", "2"}], " ", "/", "t2"}], ")"}], ",", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"t2", "^", "2"}], "/", " ", "t1"}], ")"}], ",", 
         RowBox[{"(", "t3", ")"}], ",", 
         RowBox[{"(", 
          RowBox[{"q", "/", 
           RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], ",", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"q", " ", 
            RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}]}], ",", "k"}], "]"}], 
       "+", 
       RowBox[{"FKahlerZ3", "[", 
        RowBox[{
         RowBox[{"(", "p1", ")"}], ",", 
         RowBox[{"(", "p2", ")"}], ",", "t3", ",", 
         RowBox[{"(", 
          RowBox[{"q", "/", 
           RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], ",", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"q", " ", 
            RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}]}], ",", "k"}], "]"}]}], 
      ")"}], "//.", "TorusT3"}], "]"}], ",", 
   RowBox[{"x", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.71680858949477*^9, 3.71680865385798*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "p2", "+", 
      RowBox[{
       SuperscriptBox["p1", "2"], " ", "p2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "p2"}], ")"}]}], "+", 
      RowBox[{"p1", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"3", " ", "p2"}], "+", 
         SuperscriptBox["p2", "2"]}], ")"}]}]}], ")"}], " ", "q"}], 
   RowBox[{"p1", " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{
      SqrtBox["k"], "-", "q"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       SqrtBox["k"], " ", "q"}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.716808654605803*^9, 3.7168182709962473`*^9, {3.717748062152416*^9, 
   3.717748079266076*^9}, 3.71775222457904*^9, 3.717831645311479*^9, 
   3.717918187130554*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"FZ3Ref", "[", 
   RowBox[{"q_", ",", "k_", ",", "p1_", ",", "p2_"}], "]"}], ":=", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"k", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "p2", "+", 
       RowBox[{
        SuperscriptBox["p1", "2"], " ", "p2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "p2"}], ")"}]}], "+", 
       RowBox[{"p1", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"3", " ", "p2"}], "+", 
          SuperscriptBox["p2", "2"]}], ")"}]}]}], ")"}], " ", "q"}], 
    RowBox[{"p1", " ", "p2", " ", 
     RowBox[{"(", 
      RowBox[{
       SqrtBox["k"], "-", "q"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SqrtBox["k"], " ", "q"}]}], ")"}]}]]}]}]], "Input",
 CellChangeTimes->{{3.7168086915732727`*^9, 3.716808706221579*^9}, 
   3.717748065870221*^9}],

Cell["\<\
By \[OpenCurlyDoubleQuote]undoing\[CloseCurlyDoubleQuote] the plethystic \
exponential it is easy, if a bit involved, to write down a product formula \
for the refined invariants\
\>", "Text",
 CellChangeTimes->{{3.71680377251703*^9, 3.716803795203907*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ZreoAC2Z3", "[", 
   RowBox[{
   "a0_", ",", "a1_", ",", "a2_", ",", "y0_", ",", "y1_", ",", "y2_"}], "]"}],
   ":=", 
  RowBox[{"Product", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{
       RowBox[{"L", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "a0"}], "/", "2"}], "+", 
          RowBox[{"1", "/", "2"}], "+", "j"}], ")"}]}], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"-", "y0"}], ")"}], "^", "a0"}], " ", 
       RowBox[{"y1", "^", "a1"}], " ", 
       RowBox[{"y2", "^", "a2"}]}]}], ")"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", 
      RowBox[{"a0", "-", "1"}]}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ZreeAC2Z3", "[", 
   RowBox[{
   "a0_", ",", "a1_", ",", "a2_", ",", "y0_", ",", "y1_", ",", "y2_"}], "]"}],
   ":=", 
  RowBox[{"Product", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        RowBox[{"L", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "a0"}], "/", "2"}], "+", "1", "+", "j"}], ")"}]}], 
        " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"-", "y0"}], ")"}], "^", "a0"}], " ", 
        RowBox[{"y1", "^", "a1"}], " ", 
        RowBox[{"y2", "^", "a2"}]}]}], ")"}], "^", 
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", 
      RowBox[{"a0", "-", "1"}]}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ZimAC2Z3", "[", 
   RowBox[{
   "a0_", ",", "a1_", ",", "a2_", ",", "y0_", ",", "y1_", ",", "y2_", ",", 
    "epsilon_", ",", "delta_", ",", "rank_"}], "]"}], ":=", 
  RowBox[{"Product", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"L", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a0"}], "/", "2"}], "+", "epsilon", "+", "j"}], 
           ")"}]}], " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", "y0"}], ")"}], "^", "a0"}], " ", 
         RowBox[{"y1", "^", "a1"}], " ", 
         RowBox[{"y2", "^", "a2"}]}]}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"1", "-", "rank"}], ")"}]}], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"L", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a0"}], "/", "2"}], "+", "delta", "+", "j"}], 
           ")"}]}], " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", "y0"}], ")"}], "^", "a0"}], " ", 
         RowBox[{"y1", "^", "a1"}], " ", 
         RowBox[{"y2", "^", "a2"}]}]}], " ", ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", 
      RowBox[{"a0", "-", "1"}]}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.675686151987041*^9, 3.6756863061871643`*^9}, {
  3.675686346746666*^9, 3.675686377404379*^9}, {3.6756864371507063`*^9, 
  3.675686439494792*^9}, {3.675687554738285*^9, 3.6756875573543262`*^9}, {
  3.675707821620995*^9, 3.6757078404210043`*^9}, {3.676207007581489*^9, 
  3.6762070223435907`*^9}, {3.68656334329184*^9, 3.686563408901286*^9}, {
  3.6865679438539743`*^9, 3.686567948438442*^9}, {3.6866378791614027`*^9, 
  3.686637882231325*^9}, {3.686639915024044*^9, 3.686639964972427*^9}, {
  3.68664006212083*^9, 3.686640066600176*^9}, {3.6866407597920437`*^9, 
  3.68664076258366*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZmotAC2Z3", "[", 
   RowBox[{
   "y0_", ",", "y1_", ",", "y2_", ",", "N_", ",", "epsilon_", ",", "delta_"}],
    "]"}], ":=", 
  RowBox[{
   RowBox[{"Product", "[", 
    RowBox[{
     RowBox[{"ZreeAC2Z3", "[", 
      RowBox[{
       RowBox[{"i", "-", "1"}], ",", 
       RowBox[{"i", "-", "1"}], ",", "i", ",", "y0", ",", "y1", ",", "y2"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "N"}], "}"}]}], "]"}], 
   RowBox[{"Product", "[", 
    RowBox[{
     RowBox[{"ZreeAC2Z3", "[", 
      RowBox[{"i", ",", 
       RowBox[{"i", "-", "1"}], ",", 
       RowBox[{"i", "-", "1"}], ",", "y0", ",", "y1", ",", "y2"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "N"}], "}"}]}], "]"}], 
   RowBox[{"Product", "[", 
    RowBox[{
     RowBox[{"ZreeAC2Z3", "[", 
      RowBox[{
       RowBox[{"i", "-", "1"}], ",", "i", ",", 
       RowBox[{"i", "-", "1"}], ",", "y0", ",", "y1", ",", "y2"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "N"}], "}"}]}], "]"}], " ", 
   RowBox[{"Product", "[", 
    RowBox[{
     RowBox[{"ZreeAC2Z3", "[", 
      RowBox[{
       RowBox[{"i", "-", "1"}], ",", "i", ",", "i", ",", "y0", ",", "y1", ",",
        "y2"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "N"}], "}"}]}], "]"}], 
   RowBox[{"Product", "[", 
    RowBox[{
     RowBox[{"ZreeAC2Z3", "[", 
      RowBox[{"i", ",", 
       RowBox[{"i", "-", "1"}], ",", "i", ",", "y0", ",", "y1", ",", "y2"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "N"}], "}"}]}], "]"}], 
   RowBox[{"Product", "[", 
    RowBox[{
     RowBox[{"ZreeAC2Z3", "[", 
      RowBox[{"i", ",", "i", ",", 
       RowBox[{"i", "-", "1"}], ",", "y0", ",", "y1", ",", "y2"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "N"}], "}"}]}], "]"}], 
   RowBox[{"Product", "[", 
    RowBox[{
     RowBox[{"ZimAC2Z3", "[", 
      RowBox[{
      "i", ",", "i", ",", "i", ",", "y0", ",", "y1", ",", "y2", ",", 
       "epsilon", ",", "delta", ",", "3"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "N"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQA2IQfVRr47ELSa8d9YTnXQDR/vu2fzuX/NrR8n3ITxD9
TrDtRn/5a8dnTHNvg+jHwcKvQPS6splg+qe89WcQ/UfDDkyL2LExTQLSDbtu
g+kXxqvVtwBpQ+MzYFr883aLrUC6I93PCURvrfmVAaLPs2zOBtF8r883guhn
/QXtIFpnwqVJIDo+b9ZkEM18fsUisLpdq5aCaDNLvvUg2sL78l4QrZD38AyI
vs1x4gKIrguVvAaiDy26fBtENzEv+Qqi9eqXfgPRzf5bfoPooiTlvyC65qIn
yzYgrbxXgANEs5vI14LoRxs6wfSx1zNngOgM0e+zQXTgGSfp7UD6WkqhMoj2
edCvAaLPGWtpgWgAxr7BGw==
  "]],

Cell["\<\
We check this formula order by order (the motive L is replaced by k in our \
formulas)\
\>", "Text",
 CellChangeTimes->{{3.7168038218256683`*^9, 3.716803842420607*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{
   RowBox[{"Total", "[", 
    RowBox[{"BoundDegreeK", "[", 
     RowBox[{
      RowBox[{"List", "@@", 
       RowBox[{"Expand", "[", 
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Series", "[", 
            RowBox[{
             RowBox[{"Series", "[", 
              RowBox[{
               RowBox[{"Exp", "[", 
                RowBox[{"Sum", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"1", "/", "m"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"PowerExpand", "[", 
                    RowBox[{"FZ3Ref", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], "^", 
                    "m"}], ",", 
                    RowBox[{"k", "^", "m"}], ",", 
                    RowBox[{"p1", "^", "m"}], ",", 
                    RowBox[{"p2", "^", "m"}]}], "]"}], "]"}], ")"}]}], ",", 
                  RowBox[{"{", 
                   RowBox[{"m", ",", "1", ",", "7"}], "}"}]}], "]"}], "]"}], 
               ",", 
               RowBox[{"{", 
                RowBox[{"p0", ",", "0", ",", "7"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"p1", ",", "0", ",", "7"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"p2", ",", "0", ",", "7"}], "}"}]}], "]"}], "]"}], 
        "]"}]}], ",", "7"}], "]"}], "]"}], "-", 
   RowBox[{"Total", "[", 
    RowBox[{"BoundDegreeK", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"List", "@@", 
        RowBox[{"Expand", "[", "\[IndentingNewLine]", 
         RowBox[{"Normal", "[", 
          RowBox[{"Series", "[", 
           RowBox[{
            RowBox[{"Series", "[", 
             RowBox[{
              RowBox[{"Series", "[", 
               RowBox[{
                RowBox[{"ZmotAC2Z3", "[", 
                 RowBox[{
                 "p0", ",", "p1", ",", "p2", ",", "10", ",", "1", ",", "1"}], 
                 "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"p0", ",", "0", ",", "7"}], "}"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"p1", ",", "0", ",", "7"}], "}"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"p2", ",", "0", ",", "7"}], "}"}]}], "]"}], "]"}], 
         "]"}]}], "//.", 
       RowBox[{"L", "\[Rule]", "k"}]}], ",", "7"}], "]"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.709461820912931*^9, 3.7094618312652273`*^9}, {
   3.709461880508375*^9, 3.709461935799809*^9}, {3.716809246477027*^9, 
   3.716809296256151*^9}, 3.7177480747402782`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.716809310744499*^9, 3.7168182807536592`*^9, 
  3.717748089199263*^9, 3.717752235529513*^9, 3.717831656153101*^9, 
  3.717918197426367*^9}]
}, Open  ]],

Cell["\<\
We can now derive a simpler product expansion. We now that a term of the form \
\>", "Text",
 CellChangeTimes->{{3.7178480745952168`*^9, 3.71784811675602*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MMgen", "[", 
   RowBox[{"x_", ",", "k_", ",", "q_"}], "]"}], ":=", 
  RowBox[{"x", " ", 
   RowBox[{"Sqrt", "[", "k", "]"}], 
   RowBox[{"q", "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Sqrt", "[", "k", "]"}], "q"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"q", "/", 
         RowBox[{"Sqrt", "[", "k", "]"}]}]}], ")"}]}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6858829473591843`*^9, 3.6858829605027122`*^9}, {
  3.709461173363316*^9, 3.709461196779173*^9}, {3.717847527512588*^9, 
  3.717847545858665*^9}}],

Cell["in symmetrized form gives", "Text",
 CellChangeTimes->{{3.717848135874226*^9, 3.717848172173934*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{"Exp", "[", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"1", "/", "n"}], " ", 
        RowBox[{"MMgen", "[", 
         RowBox[{
          RowBox[{"x", "^", "n"}], ",", 
          RowBox[{"k", "^", "n"}], ",", 
          RowBox[{"q", "^", "n"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "7"}], "}"}]}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"q", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7178468408922*^9, 3.717846855531877*^9}, {
  3.717847552061651*^9, 3.717847553480014*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "+", 
   RowBox[{
    SqrtBox["k"], " ", "x", " ", "q"}], "+", 
   RowBox[{"x", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "k", "+", 
      RowBox[{"k", " ", "x"}]}], ")"}], " ", 
    SuperscriptBox["q", "2"]}], "+", 
   FractionBox[
    RowBox[{"x", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"k", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "x"}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "x", "+", 
          SuperscriptBox["x", "2"]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox["q", "3"]}], 
    SqrtBox["k"]], "+", 
   FractionBox[
    RowBox[{"x", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "k", "+", 
       RowBox[{"2", " ", "k", " ", "x"}], "+", 
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "x"}], ")"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["k", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", "x"}], "+", 
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["x", "3"]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox["q", "4"]}], "k"], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "q", "]"}], "5"],
    SeriesData[$CellContext`q, 0, {}, 0, 5, 1],
    Editable->False]}],
  SeriesData[$CellContext`q, 0, {
   1, $CellContext`k^Rational[1, 2] $CellContext`x, $CellContext`x (
     1 + $CellContext`k + $CellContext`k $CellContext`x), $CellContext`k^
     Rational[-1, 2] $CellContext`x (
     1 + $CellContext`k (1 + $CellContext`x) + $CellContext`k^2 (
       1 + $CellContext`x + $CellContext`x^2)), $CellContext`k^(-1) \
$CellContext`x (1 + $CellContext`k + 
     2 $CellContext`k $CellContext`x + $CellContext`k^2 (
        1 + $CellContext`x)^2 + $CellContext`k^3 (1 + 
       2 $CellContext`x + $CellContext`x^2 + $CellContext`x^3))}, 0, 5, 1],
  Editable->False]], "Output",
 CellChangeTimes->{3.7178481746009483`*^9, 3.71791819753716*^9}]
}, Open  ]],

Cell["which corresponds to the product", "Text",
 CellChangeTimes->{{3.717848179335321*^9, 3.717848184244726*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Mfunction", "[", 
   RowBox[{"x_", ",", "q1_", ",", "q2_", ",", "N_", ",", "d_"}], "]"}], ":=", 
  
  RowBox[{"Product", "[", 
   RowBox[{
    RowBox[{"Product", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"x", " ", 
          RowBox[{"q1", "^", 
           RowBox[{"(", 
            RowBox[{"i", "-", 
             RowBox[{"1", "/", "2"}], "+", 
             RowBox[{"d", "/", "2"}]}], ")"}]}], " ", 
          RowBox[{"q2", "^", 
           RowBox[{"(", 
            RowBox[{"j", "-", 
             RowBox[{"1", "/", "2"}], "-", 
             RowBox[{"d", "/", "2"}]}], ")"}]}]}]}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "N"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "N"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.716712216950686*^9, 3.716712219668832*^9}, {
  3.717847300269278*^9, 3.7178473086042557`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Normal", "[", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"Mfunction", "[", 
      RowBox[{"x", ",", 
       RowBox[{"q", " ", 
        RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
       RowBox[{"q", "/", 
        RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], "]"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"q", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.717847323611361*^9, 3.7178473392527943`*^9}, {
  3.717848205023634*^9, 3.717848208157527*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{
   SqrtBox["k"], " ", "q", " ", "x"}], "+", 
  RowBox[{
   SuperscriptBox["q", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"x", "+", 
     RowBox[{"k", " ", "x"}], "+", 
     RowBox[{"k", " ", 
      SuperscriptBox["x", "2"]}]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["q", "3"], " ", 
    RowBox[{"(", 
     RowBox[{"x", "+", 
      RowBox[{"k", " ", "x"}], "+", 
      RowBox[{
       SuperscriptBox["k", "2"], " ", "x"}], "+", 
      RowBox[{"k", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["k", "2"], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["k", "2"], " ", 
       SuperscriptBox["x", "3"]}]}], ")"}]}], 
   SqrtBox["k"]], "+", 
  RowBox[{
   SuperscriptBox["q", "4"], " ", 
   RowBox[{"(", 
    RowBox[{"x", "+", 
     FractionBox["x", "k"], "+", 
     RowBox[{"k", " ", "x"}], "+", 
     RowBox[{
      SuperscriptBox["k", "2"], " ", "x"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"2", " ", "k", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["k", "2"], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"k", " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      SuperscriptBox["x", "4"]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.7178481969903507`*^9, 3.717848208421062*^9}, 
   3.717918197638611*^9}]
}, Open  ]],

Cell["\<\
We use this identity as a building block to write the refined partition \
function in a product form, where the variable x=1,p1,p2,p1p2,1/p1,1/p2,1/p1 \
p2 respectively. This definition gives\
\>", "Text",
 CellChangeTimes->{{3.717848220498411*^9, 3.717848279476719*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{"Normal", "[", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"Series", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Mfunction", "[", 
            RowBox[{"1", ",", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], " ", 
              RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], "/", 
              RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], "]"}],
            "^", "3"}], " ", 
          RowBox[{"Mfunction", "[", 
           RowBox[{"p1", ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], " ", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], "/", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], "]"}], 
          " ", 
          RowBox[{"Mfunction", "[", 
           RowBox[{
            RowBox[{"p1", " ", "p2"}], ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], " ", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], "/", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], "]"}], 
          " ", 
          RowBox[{"Mfunction", "[", 
           RowBox[{"p2", ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], " ", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], "/", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], "]"}], 
          
          RowBox[{"Mfunction", "[", 
           RowBox[{
            RowBox[{"1", "/", "p1"}], ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], " ", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], "/", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], "]"}], 
          " ", 
          RowBox[{"Mfunction", "[", 
           RowBox[{
            RowBox[{"1", "/", 
             RowBox[{"(", 
              RowBox[{"p1", " ", "p2"}], ")"}]}], ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], " ", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], "/", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], "]"}], 
          " ", 
          RowBox[{"Mfunction", "[", 
           RowBox[{
            RowBox[{"1", "/", "p2"}], ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], " ", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], "/", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
           "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"p0", ",", "0", ",", "3"}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"p1", ",", "0", ",", "3"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"p2", ",", "0", ",", "3"}], "}"}]}], "]"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.717847620193548*^9, 3.71784769585384*^9}}],

Cell[BoxData[
 RowBox[{"1", "-", 
  RowBox[{
   SqrtBox["k"], " ", "p0"}], "+", 
  RowBox[{"k", " ", 
   SuperscriptBox["p0", "2"]}], "-", 
  RowBox[{
   SuperscriptBox["k", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["p0", "3"]}], "-", 
  RowBox[{
   SqrtBox["k"], " ", "p0", " ", "p1"}], "+", 
  RowBox[{"k", " ", 
   SuperscriptBox["p0", "2"], " ", "p1"}], "-", 
  RowBox[{
   SuperscriptBox["k", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["p0", "3"], " ", "p1"}], "+", 
  RowBox[{"k", " ", 
   SuperscriptBox["p0", "2"], " ", 
   SuperscriptBox["p1", "2"]}], "-", 
  RowBox[{
   SuperscriptBox["k", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["p0", "3"], " ", 
   SuperscriptBox["p1", "2"]}], "-", 
  RowBox[{
   SuperscriptBox["k", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["p0", "3"], " ", 
   SuperscriptBox["p1", "3"]}], "-", 
  RowBox[{
   SqrtBox["k"], " ", "p0", " ", "p2"}], "+", 
  RowBox[{"k", " ", 
   SuperscriptBox["p0", "2"], " ", "p2"}], "-", 
  RowBox[{
   SuperscriptBox["k", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["p0", "3"], " ", "p2"}], "-", 
  RowBox[{"3", " ", 
   SqrtBox["k"], " ", "p0", " ", "p1", " ", "p2"}], "+", 
  RowBox[{
   SuperscriptBox["p0", "2"], " ", "p1", " ", "p2"}], "+", 
  RowBox[{"5", " ", "k", " ", 
   SuperscriptBox["p0", "2"], " ", "p1", " ", "p2"}], "-", 
  RowBox[{
   SqrtBox["k"], " ", 
   SuperscriptBox["p0", "3"], " ", "p1", " ", "p2"}], "-", 
  RowBox[{"5", " ", 
   SuperscriptBox["k", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["p0", "3"], " ", "p1", " ", "p2"}], "-", 
  RowBox[{
   SqrtBox["k"], " ", "p0", " ", 
   SuperscriptBox["p1", "2"], " ", "p2"}], "+", 
  RowBox[{
   SuperscriptBox["p0", "2"], " ", 
   SuperscriptBox["p1", "2"], " ", "p2"}], "+", 
  RowBox[{"5", " ", "k", " ", 
   SuperscriptBox["p0", "2"], " ", 
   SuperscriptBox["p1", "2"], " ", "p2"}], "-", 
  RowBox[{"2", " ", 
   SqrtBox["k"], " ", 
   SuperscriptBox["p0", "3"], " ", 
   SuperscriptBox["p1", "2"], " ", "p2"}], "-", 
  RowBox[{"7", " ", 
   SuperscriptBox["k", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["p0", "3"], " ", 
   SuperscriptBox["p1", "2"], " ", "p2"}], "+", 
  RowBox[{"k", " ", 
   SuperscriptBox["p0", "2"], " ", 
   SuperscriptBox["p1", "3"], " ", "p2"}], "-", 
  RowBox[{
   SqrtBox["k"], " ", 
   SuperscriptBox["p0", "3"], " ", 
   SuperscriptBox["p1", "3"], " ", "p2"}], "-", 
  RowBox[{"5", " ", 
   SuperscriptBox["k", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["p0", "3"], " ", 
   SuperscriptBox["p1", "3"], " ", "p2"}], "+", 
  RowBox[{"k", " ", 
   SuperscriptBox["p0", "2"], " ", 
   SuperscriptBox["p2", "2"]}], "-", 
  RowBox[{
   SuperscriptBox["k", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["p0", "3"], " ", 
   SuperscriptBox["p2", "2"]}], "-", 
  RowBox[{
   SqrtBox["k"], " ", "p0", " ", "p1", " ", 
   SuperscriptBox["p2", "2"]}], "+", 
  RowBox[{
   SuperscriptBox["p0", "2"], " ", "p1", " ", 
   SuperscriptBox["p2", "2"]}], "+", 
  RowBox[{"5", " ", "k", " ", 
   SuperscriptBox["p0", "2"], " ", "p1", " ", 
   SuperscriptBox["p2", "2"]}], "-", 
  RowBox[{"2", " ", 
   SqrtBox["k"], " ", 
   SuperscriptBox["p0", "3"], " ", "p1", " ", 
   SuperscriptBox["p2", "2"]}], "-", 
  RowBox[{"7", " ", 
   SuperscriptBox["k", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["p0", "3"], " ", "p1", " ", 
   SuperscriptBox["p2", "2"]}], "-", 
  RowBox[{
   SqrtBox["k"], " ", "p0", " ", 
   SuperscriptBox["p1", "2"], " ", 
   SuperscriptBox["p2", "2"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["p0", "2"], " ", 
   SuperscriptBox["p1", "2"], " ", 
   SuperscriptBox["p2", "2"]}], "+", 
  RowBox[{"12", " ", "k", " ", 
   SuperscriptBox["p0", "2"], " ", 
   SuperscriptBox["p1", "2"], " ", 
   SuperscriptBox["p2", "2"]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", 
    SuperscriptBox["p1", "2"], " ", 
    SuperscriptBox["p2", "2"]}], 
   SqrtBox["k"]], "-", 
  RowBox[{"9", " ", 
   SqrtBox["k"], " ", 
   SuperscriptBox["p0", "3"], " ", 
   SuperscriptBox["p1", "2"], " ", 
   SuperscriptBox["p2", "2"]}], "-", 
  RowBox[{"21", " ", 
   SuperscriptBox["k", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["p0", "3"], " ", 
   SuperscriptBox["p1", "2"], " ", 
   SuperscriptBox["p2", "2"]}], "+", 
  RowBox[{
   SuperscriptBox["p0", "2"], " ", 
   SuperscriptBox["p1", "3"], " ", 
   SuperscriptBox["p2", "2"]}], "+", 
  RowBox[{"5", " ", "k", " ", 
   SuperscriptBox["p0", "2"], " ", 
   SuperscriptBox["p1", "3"], " ", 
   SuperscriptBox["p2", "2"]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", 
    SuperscriptBox["p1", "3"], " ", 
    SuperscriptBox["p2", "2"]}], 
   SqrtBox["k"]], "-", 
  RowBox[{"9", " ", 
   SqrtBox["k"], " ", 
   SuperscriptBox["p0", "3"], " ", 
   SuperscriptBox["p1", "3"], " ", 
   SuperscriptBox["p2", "2"]}], "-", 
  RowBox[{"21", " ", 
   SuperscriptBox["k", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["p0", "3"], " ", 
   SuperscriptBox["p1", "3"], " ", 
   SuperscriptBox["p2", "2"]}], "-", 
  RowBox[{
   SuperscriptBox["k", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["p0", "3"], " ", 
   SuperscriptBox["p2", "3"]}], "+", 
  RowBox[{"k", " ", 
   SuperscriptBox["p0", "2"], " ", "p1", " ", 
   SuperscriptBox["p2", "3"]}], "-", 
  RowBox[{
   SqrtBox["k"], " ", 
   SuperscriptBox["p0", "3"], " ", "p1", " ", 
   SuperscriptBox["p2", "3"]}], "-", 
  RowBox[{"5", " ", 
   SuperscriptBox["k", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["p0", "3"], " ", "p1", " ", 
   SuperscriptBox["p2", "3"]}], "+", 
  RowBox[{
   SuperscriptBox["p0", "2"], " ", 
   SuperscriptBox["p1", "2"], " ", 
   SuperscriptBox["p2", "3"]}], "+", 
  RowBox[{"5", " ", "k", " ", 
   SuperscriptBox["p0", "2"], " ", 
   SuperscriptBox["p1", "2"], " ", 
   SuperscriptBox["p2", "3"]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", 
    SuperscriptBox["p1", "2"], " ", 
    SuperscriptBox["p2", "3"]}], 
   SqrtBox["k"]], "-", 
  RowBox[{"9", " ", 
   SqrtBox["k"], " ", 
   SuperscriptBox["p0", "3"], " ", 
   SuperscriptBox["p1", "2"], " ", 
   SuperscriptBox["p2", "3"]}], "-", 
  RowBox[{"21", " ", 
   SuperscriptBox["k", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["p0", "3"], " ", 
   SuperscriptBox["p1", "2"], " ", 
   SuperscriptBox["p2", "3"]}], "+", 
  RowBox[{
   SuperscriptBox["p0", "2"], " ", 
   SuperscriptBox["p1", "3"], " ", 
   SuperscriptBox["p2", "3"]}], "+", 
  RowBox[{"5", " ", "k", " ", 
   SuperscriptBox["p0", "2"], " ", 
   SuperscriptBox["p1", "3"], " ", 
   SuperscriptBox["p2", "3"]}], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    SuperscriptBox["p0", "3"], " ", 
    SuperscriptBox["p1", "3"], " ", 
    SuperscriptBox["p2", "3"]}], 
   SqrtBox["k"]], "-", 
  RowBox[{"18", " ", 
   SqrtBox["k"], " ", 
   SuperscriptBox["p0", "3"], " ", 
   SuperscriptBox["p1", "3"], " ", 
   SuperscriptBox["p2", "3"]}], "-", 
  RowBox[{"39", " ", 
   SuperscriptBox["k", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["p0", "3"], " ", 
   SuperscriptBox["p1", "3"], " ", 
   SuperscriptBox["p2", "3"]}]}]], "Output",
 CellChangeTimes->{3.717918197950135*^9}]
}, Open  ]],

Cell["\<\
and indeed we can check that this product formula is equal to the refined \
partition function obtained via symmetrization\
\>", "Text",
 CellChangeTimes->{{3.717848285047285*^9, 3.7178483163371964`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{
   RowBox[{"Total", "[", 
    RowBox[{"BoundDegreeK", "[", 
     RowBox[{
      RowBox[{"List", "@@", 
       RowBox[{"Expand", "[", 
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Series", "[", 
            RowBox[{
             RowBox[{"Series", "[", 
              RowBox[{
               RowBox[{"Exp", "[", 
                RowBox[{"Sum", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"1", "/", "m"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"PowerExpand", "[", 
                    RowBox[{"FZ3Ref", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], "^", 
                    "m"}], ",", 
                    RowBox[{"k", "^", "m"}], ",", 
                    RowBox[{"p1", "^", "m"}], ",", 
                    RowBox[{"p2", "^", "m"}]}], "]"}], "]"}], ")"}]}], ",", 
                  RowBox[{"{", 
                   RowBox[{"m", ",", "1", ",", "7"}], "}"}]}], "]"}], "]"}], 
               ",", 
               RowBox[{"{", 
                RowBox[{"p0", ",", "0", ",", "7"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"p1", ",", "0", ",", "7"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"p2", ",", "0", ",", "7"}], "}"}]}], "]"}], "]"}], 
        "]"}]}], ",", "7"}], "]"}], "]"}], "-", 
   RowBox[{"Total", "[", 
    RowBox[{"BoundDegreeK", "[", 
     RowBox[{
      RowBox[{"List", "@@", 
       RowBox[{"Expand", "[", 
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Series", "[", 
            RowBox[{
             RowBox[{"Series", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Mfunction", "[", 
                  RowBox[{"1", ",", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                  "]"}], "^", "3"}], " ", 
                RowBox[{"Mfunction", "[", 
                 RowBox[{"p1", ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], " ", 
                   RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], "/", 
                   RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                 "]"}], " ", 
                RowBox[{"Mfunction", "[", 
                 RowBox[{
                  RowBox[{"p1", " ", "p2"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], " ", 
                   RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], "/", 
                   RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                 "]"}], " ", 
                RowBox[{"Mfunction", "[", 
                 RowBox[{"p2", ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], " ", 
                   RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], "/", 
                   RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                 "]"}], 
                RowBox[{"Mfunction", "[", 
                 RowBox[{
                  RowBox[{"1", "/", "p1"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], " ", 
                   RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], "/", 
                   RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                 "]"}], " ", 
                RowBox[{"Mfunction", "[", 
                 RowBox[{
                  RowBox[{"1", "/", 
                   RowBox[{"(", 
                    RowBox[{"p1", " ", "p2"}], ")"}]}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], " ", 
                   RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], "/", 
                   RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                 "]"}], " ", 
                RowBox[{"Mfunction", "[", 
                 RowBox[{
                  RowBox[{"1", "/", "p2"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], " ", 
                   RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2"}], ")"}], "/", 
                   RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                 "]"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"p0", ",", "0", ",", "7"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"p1", ",", "0", ",", "7"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"p2", ",", "0", ",", "7"}], "}"}]}], "]"}], "]"}], 
        "]"}]}], ",", "7"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.717848035317305*^9, 3.717848044351849*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.717848339703587*^9, 3.7179182111498547`*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["C2/Z4 x C", "Subchapter",
 CellChangeTimes->{{3.7099718617654657`*^9, 3.709971866386961*^9}}],

Cell[CellGroupData[{

Cell["Localization", "Subsection",
 CellChangeTimes->{{3.716814763743575*^9, 3.716814766654924*^9}, {
  3.716818291761031*^9, 3.71681829336257*^9}}],

Cell["\<\
Now we redo the same computations in the case of C2/Z4 x C. First we define \
the weight decomposition of the spaces V\
\>", "Text",
 CellChangeTimes->{{3.716814569455907*^9, 3.7168145950757713`*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"CAREFUL", " ", "WITH", " ", 
    RowBox[{"p1", "^", "PI1"}], " ", "and", " ", 
    RowBox[{"p3", "^", "PI3"}]}], ",", " ", 
   RowBox[{
   "they", " ", "are", " ", "switched", " ", "because", " ", "PPV", " ", 
    "transforms", " ", "like", " ", "the", " ", "inverse", " ", "of", " ", 
    "the", " ", "character"}], ",", " ", 
   RowBox[{"since", " ", "it", " ", "is", " ", 
    RowBox[{"ta", "^", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "i"}], "+", "1"}], "}"}]}], " ", "mostly", " ", 
    RowBox[{"negative", ".", " ", "Irrelevant"}], " ", "because", " ", "the", 
    " ", "partition", " ", "function", " ", "is", " ", "symmetric"}], ",", 
   " ", 
   RowBox[{"but", " ", "still", " ", "be", " ", "precise"}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.710576021734963*^9, 3.7105760725023003`*^9}, {
  3.7105765131177692`*^9, 3.710576527910089*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PPVC2Z4", "[", 
   RowBox[{"l_List", ",", "t1_", ",", "t2_", ",", "t3_", ",", "r_"}], "]"}], ":=", 
  RowBox[{"Total", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"t1", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "i"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"t2", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "j"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"t3", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "k"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"KroneckerDelta", "[", 
          RowBox[{
           RowBox[{"Mod", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "j"}], "+", "i"}], ",", "4"}], "]"}], ",", "r"}], 
          "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "l", "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"j", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"l", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"l", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "}"}]}], 
       "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.685794026599243*^9, 3.685794062411702*^9}, {
   3.6857945569193993`*^9, 3.68579456486136*^9}, {3.685794658823471*^9, 
   3.685794661349846*^9}, {3.685794743967721*^9, 3.685794762494817*^9}, {
   3.685795923624857*^9, 3.685795925376687*^9}, {3.686396180192107*^9, 
   3.686396186019744*^9}, 3.6864006439129047`*^9, {3.709971462013809*^9, 
   3.709971467937703*^9}, 3.710326498541847*^9}],

Cell["\<\
The virtual tangent space is given by taking invariant combinations of modules\
\>", "Text",
 CellChangeTimes->{{3.7168146092377157`*^9, 3.7168146222108192`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TvirC2Z4fixed", "[", 
   RowBox[{"list_", ",", "t1_", ",", "t2_", ",", "t3_", ",", "k_"}], "]"}], ":=",
   "  ", 
  RowBox[{
   RowBox[{"PPVC2Z4", "[", 
    RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], "-", 
   RowBox[{
    RowBox[{"PPVC2Z4", "[", 
     RowBox[{"list", ",", 
      RowBox[{"1", "/", "t1"}], ",", 
      RowBox[{"1", "/", "t2"}], ",", 
      RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}], " ", "t1", " ", "t2", " ", 
    "t3"}], "-", "  ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], 
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "1"}], "]"}], 
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "1"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "2"}], "]"}], 
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "2"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "3"}], "]"}], 
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "3"}], "]"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"t1", " ", "t2"}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", "t3"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], 
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "3"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "1"}], "]"}], 
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "3"}], "]"}], 
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "2"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "2"}], "]"}], 
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "1"}], "]"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"-", "t1"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", "t3"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], 
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "1"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "3"}], "]"}], 
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "1"}], "]"}], 
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "2"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "2"}], "]"}], 
       RowBox[{"PPVC2Z4", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "3"}], "]"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"-", "t2"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", "t3"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGCQBmIQ/anCLXtHwmtHizOiuSC67r48400gzTV7LpjmdDqY
W5f42jFyyXMwHbYwLrYFSDulTQPTEs0LWkD01dbjYLrOa466RNlrx9ApX1xA
9OWWaCu78teO/1zq7EH01dcFp0B0imgPmNbbXnIORNvp9oJpoS2hl0H0upd7
wfSJOzNvgOgVkk/BdN1/t/dgddHfP4Bo/qD3k+yBtE9uxCwQveJJepgDkN7s
VBEOouv++rWaLnntqDVJaQKIPiJhuukBkA6abQembxQs3g6itTyEdoDoby9X
nwPRkyZ8ANMZ4jc+gGhl29ovILpF31f9IZA+dvYAmL63ftMUEC1k5zgVRFvx
R80H0VW59gtAdHbyYYFHQPrFXj5BEH1C+IMIiM467yMKonsvbZEC0c/av0qD
6OvtewJBdIKsbwiI7lsgWgGid9xRANMAZRXqOA==
  "]],

Cell["\<\
The number of boxes of a 3d partition in the conjugacy class r\
\>", "Text",
 CellChangeTimes->{{3.716814628249968*^9, 3.7168146434564037`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"NBC2Z4", "[", 
   RowBox[{"l_List", ",", "r_"}], "]"}], ":=", 
  RowBox[{"PPVC2Z4", "[", 
   RowBox[{"l", ",", "1", ",", "1", ",", "1", ",", "r"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.685795573005415*^9, 3.685795594181725*^9}, 
   3.6857956721339827`*^9, {3.685795713741584*^9, 3.685795814978931*^9}, {
   3.6857958527331142`*^9, 3.6857958683004723`*^9}, {3.685795981600951*^9, 
   3.6857959892875137`*^9}, 3.685796449591515*^9, {3.685796677468938*^9, 
   3.685796685114377*^9}, 3.685796731259357*^9, {3.6863964714823923`*^9, 
   3.6863964807605333`*^9}, {3.709971629740869*^9, 3.709971631819234*^9}}],

Cell["\<\
Virtual tangent space, fixed point list, and localization computation\
\>", "Text",
 CellChangeTimes->{{3.71681465039498*^9, 3.71681467000432*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"VirtualTC2Z4", "[", 
    RowBox[{"nboxes_", ",", "fixedpoint_"}], "]"}], ":=", 
   RowBox[{"Expand", "[", 
    RowBox[{"TvirC2Z4fixed", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
       RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", "t2", ",", 
      "t3", ",", "k"}], "]"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FPListC2Z4", "[", 
    RowBox[{"nboxes_", ",", "fixedpoint_"}], "]"}], ":=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Reap", "[", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Flatten", "[", 
                RowBox[{"List", "@@", 
                 RowBox[{"(", 
                  RowBox[{"Expand", "[", 
                   RowBox[{"TvirC2Z4fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
                "//.", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"t1", "\[Rule]", "1"}], ",", 
                 RowBox[{"t2", "->", "1"}], ",", 
                 RowBox[{"t3", "\[Rule]", "1"}], ",", 
                 RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
             RowBox[{"[", "i", "]"}], "]"}], ">", "0"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Sow", "[", 
            RowBox[{"{", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
                 RowBox[{"List", "@@", 
                  RowBox[{"(", 
                   RowBox[{"Expand", "[", 
                    RowBox[{"TvirC2Z4fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], 
                 "\[IndentingNewLine]", "]"}], "[", 
                RowBox[{"[", "i", "]"}], "]"}], "/", 
               RowBox[{"(", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Flatten", "[", 
                    RowBox[{"List", "@@", 
                    RowBox[{"(", 
                    RowBox[{"Expand", "[", 
                    RowBox[{"TvirC2Z4fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
                    "//.", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"t1", "\[Rule]", "1"}], ",", 
                    RowBox[{"t2", "->", "1"}], ",", 
                    RowBox[{"t3", "\[Rule]", "1"}], ",", 
                    RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "\[IndentingNewLine]", 
                ")"}]}], ",", 
              RowBox[{
               RowBox[{"(", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Flatten", "[", 
                  RowBox[{"List", "@@", 
                   RowBox[{"(", 
                    RowBox[{"Expand", "[", 
                    RowBox[{"TvirC2Z4fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
                  "//.", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"t1", "\[Rule]", "1"}], ",", 
                   RowBox[{"t2", "->", "1"}], ",", 
                   RowBox[{"t3", "\[Rule]", "1"}], ",", 
                   RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "\[IndentingNewLine]", "}"}],
             "]"}]}], "\[IndentingNewLine]", "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", 
            RowBox[{"Flatten", "[", 
             RowBox[{"List", "@@", 
              RowBox[{"(", 
               RowBox[{"Expand", "[", 
                RowBox[{"TvirC2Z4fixed", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                   RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                  "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}], 
            "]"}]}], "}"}]}], "]"}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ahatp", "[", "list_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"k", "/", 
           RowBox[{"list", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"list", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "/", "k"}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"list", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"list", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], ")"}], "^", 
    RowBox[{"list", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LocalizationC2Z4", "[", 
    RowBox[{
    "nboxes_", ",", "fixedpoint_", ",", "p0_", ",", "p1_", ",", "p2_", ",", 
     "p3_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Cancel", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{"Times", "@@", 
       RowBox[{"Map", "[", 
        RowBox[{"ahatp", ",", 
         RowBox[{"FPListC2Z4", "[", 
          RowBox[{"nboxes", ",", "fixedpoint"}], "]"}]}], "]"}]}], "]"}], 
     "]"}], " ", 
    RowBox[{"p0", "^", 
     RowBox[{"NBC2Z4", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
        RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "0"}], "]"}]}], " ", 
    RowBox[{"p1", "^", 
     RowBox[{"NBC2Z4", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
        RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "3"}], "]"}]}], " ", 
    RowBox[{"p2", "^", 
     RowBox[{"NBC2Z4", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
        RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "2"}], "]"}]}], " ", 
    RowBox[{"p3", "^", 
     RowBox[{"NBC2Z4", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
        RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "1"}], "]"}]}]}]}], " ",
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TotalContributionC2Z4", "[", 
   RowBox[{"nboxes_", ",", "p0_", ",", "p1_", ",", "p2_", ",", "p3_"}], "]"}],
   ":=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{"LocalizationC2Z4", "[", 
     RowBox[{"nboxes", ",", "i", ",", "p0", ",", "p1", ",", "p2", ",", "p3"}],
      "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", 
       RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "]"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.67509769824366*^9, 3.675097742433045*^9}, {
   3.675097787395336*^9, 3.67509779944084*^9}, {3.675097856209297*^9, 
   3.675097941379383*^9}, 3.675098012939138*^9, {3.675101981572866*^9, 
   3.675102132977907*^9}, {3.679138392316263*^9, 3.679138397170555*^9}, {
   3.679139098659503*^9, 3.679139114360139*^9}, {3.685794841789722*^9, 
   3.685794885068252*^9}, {3.685797044333329*^9, 3.685797110123225*^9}, {
   3.6857971441185102`*^9, 3.6857971449891253`*^9}, {3.6863964185845757`*^9, 
   3.6863964511875277`*^9}, {3.686396494277749*^9, 3.686396522946504*^9}, {
   3.709971666041795*^9, 3.709971739528995*^9}, {3.7105765063648*^9, 
   3.710576509182139*^9}, {3.716814673248526*^9, 3.716814685158873*^9}}],

Cell["Finally the partition function", "Text",
 CellChangeTimes->{{3.716814698115046*^9, 3.716814701699583*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PartitionFunctionC2Z4", "[", "nboxes_", "]"}], ":=", 
  RowBox[{"1", "+", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"TotalContributionC2Z4", "[", 
      RowBox[{"n", ",", "p0", ",", "p1", ",", "p2", ",", "p3"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "nboxes"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.716804618813366*^9, 3.716804627198197*^9}, {
  3.716806034437278*^9, 3.716806034503093*^9}, {3.7168147258786716`*^9, 
  3.716814733736116*^9}, {3.716818331008473*^9, 3.7168183311061287`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PartitionFunctionC2Z4", "[", "5", "]"}]], "Input",
 CellChangeTimes->{
  3.716804640930531*^9, {3.716814736590336*^9, 3.716814740839767*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", 
  FractionBox[
   RowBox[{"p0", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", 
    SuperscriptBox["p1", "2"], " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", 
    SuperscriptBox["p2", "2"], " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", 
    SuperscriptBox["p3", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t1", "4"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t1", "3"]}], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t1", "4"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "3"], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "3"], "-", 
      RowBox[{"k", " ", "t2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t1", "2"]}], "-", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "3"], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      RowBox[{"k", " ", 
       SuperscriptBox["t2", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", 
      SuperscriptBox["t2", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      SuperscriptBox["t2", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", 
       SuperscriptBox["t2", "3"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t2", "4"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      SuperscriptBox["t2", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t2", "4"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t1", "4"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t1", "3"]}], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t1", "4"]}], "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t1", "4"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "3"], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "4"], "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "3"], "-", 
      RowBox[{"k", " ", "t2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t1", "2"]}], "-", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1", " ", "t2"}], "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "3"], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"t1", " ", "t2"}], "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      RowBox[{"k", " ", 
       SuperscriptBox["t2", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", 
      SuperscriptBox["t2", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1", " ", "t2"}], "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      SuperscriptBox["t2", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"t1", " ", "t2"}], "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", 
       SuperscriptBox["t2", "3"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t2", "4"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t2", "4"]}], "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      SuperscriptBox["t2", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t2", "4"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t2", "4"], "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    SuperscriptBox["p1", "2"], " ", "p2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p3", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    SuperscriptBox["p1", "2"], " ", "p3", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p2", " ", "p3", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", 
    SuperscriptBox["p3", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p2", " ", 
    SuperscriptBox["p3", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "k"}], " ", "t1", " ", "t2"}], "+", "t3"}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t1", "3"]}], "-", "t2"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "-", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "4"], "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "3"], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "4"], "-", "t3"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "3"], "-", 
      RowBox[{"k", " ", "t2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t1", "2"]}], "-", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "-", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"t1", " ", "t2"}], "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "3"], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"t1", " ", "t2"}], "-", "t3"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      RowBox[{"k", " ", 
       SuperscriptBox["t2", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", 
      SuperscriptBox["t2", "3"]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "-", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"t1", " ", "t2"}], "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      SuperscriptBox["t2", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"t1", " ", "t2"}], "-", "t3"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", 
       SuperscriptBox["t2", "3"]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "-", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t2", "4"], "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      SuperscriptBox["t2", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t2", "4"], "-", "t3"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p3", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", 
      RowBox[{"k", " ", "t3"}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    SuperscriptBox["p1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    SuperscriptBox["p3", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", "p1", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", 
    SuperscriptBox["p1", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", "p1", " ", "p2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", "p3", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", "p2", " ", "p3", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", 
    SuperscriptBox["p3", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", "p1", " ", "p3", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "k"}], " ", "t1", " ", "t2"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", "p1", " ", "p3", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", 
      RowBox[{"k", " ", 
       SuperscriptBox["t3", "2"]}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"5", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "3"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3", "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "4"], " ", "p1", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "3"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3", "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "4"], " ", "p3", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "3"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3", "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "4"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3", "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "5"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "4"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "5"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"5", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "5"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3", "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3", "+", 
      SuperscriptBox["t3", "2"], "+", 
      SuperscriptBox["t3", "3"], "+", 
      SuperscriptBox["t3", "4"]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.7168183061231413`*^9, 3.716818335360971*^9}, 
   3.71774816716473*^9, 3.71775238726789*^9, 3.717918801141243*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Symmetrization and Orbifold Nekrasov function", "Subsection",
 CellChangeTimes->{{3.716814763743575*^9, 3.716814766654924*^9}}],

Cell["\<\
The orbifold Nekrasov function is given by 4 copies of the flat space answer \
computed on the generators of the ring of invariant monomials, and a \
\[OpenCurlyDoubleQuote]Kahler\[CloseCurlyDoubleQuote] term\
\>", "Text",
 CellChangeTimes->{{3.71681477474713*^9, 3.7168148111409283`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FC3", "[", 
   RowBox[{"t1_", ",", "t2_", ",", "t3_", ",", "t4_", ",", "t5_", ",", "k_"}],
    "]"}], ":=", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t1"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t1"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t3"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t3"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "/", "t2"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "/", "t2"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t1", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t1", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t2", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t2", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t3", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t3", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t4", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t4", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t5", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t5", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], ")"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6744033720560493`*^9, 3.674403372806196*^9}, 
   3.674403472934162*^9, {3.685798651440465*^9, 3.685798653178933*^9}, {
   3.709464971485652*^9, 3.709464999637817*^9}, {3.709465033504201*^9, 
   3.709465064467249*^9}, {3.7098117622022123`*^9, 3.7098117675144997`*^9}, {
   3.7177470092131577`*^9, 3.717747036980688*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FKahlerZ4", "[", 
   RowBox[{
   "p1_", ",", "p2_", ",", "p3_", ",", "t3_", ",", "t4_", ",", "t5_", ",", 
    "k_"}], "]"}], ":=", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"p1", "+", 
      RowBox[{"1", "/", "p1"}], "+", "p2", "+", 
      RowBox[{"1", "/", "p2"}], "+", "p3", "+", 
      RowBox[{"1", "/", "p3"}], "+", 
      RowBox[{"p1", " ", "p2"}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"p1", " ", "p2"}], ")"}]}], "+", 
      RowBox[{"p2", " ", "p3"}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"p2", " ", "p3"}], ")"}]}], "+", "\[IndentingNewLine]", 
      RowBox[{"p1", " ", "p2", " ", "p3"}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"p1", " ", "p2", " ", "p3"}], ")"}]}]}], ")"}], " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        SqrtBox[
         FractionBox["t3", "k"]]], "-", 
       SqrtBox[
        FractionBox["t3", "k"]]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SqrtBox["t3"]]}], "+", 
         SqrtBox["t3"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SqrtBox["t4"]]}], "+", 
         SqrtBox["t4"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SqrtBox["t5"]]}], "+", 
         SqrtBox["t5"]}], ")"}]}], ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.709800049685461*^9, 3.7098001425906267`*^9}, {
   3.709800282903933*^9, 3.7098002913052387`*^9}, {3.7098010041146803`*^9, 
   3.709801008186751*^9}, {3.709801741383148*^9, 3.709801768415749*^9}, {
   3.709808631439939*^9, 3.7098086335554943`*^9}, {3.7098111580622053`*^9, 
   3.709811195198132*^9}, {3.709972738438386*^9, 3.709972738496582*^9}, {
   3.710073838997891*^9, 3.7100738528868628`*^9}, {3.710317887526458*^9, 
   3.7103179142862797`*^9}, {3.71032090835084*^9, 3.710320915343544*^9}, {
   3.710321482043655*^9, 3.7103214844483*^9}, {3.710325903517514*^9, 
   3.710325905984568*^9}, {3.710326033782838*^9, 3.710326103612987*^9}, 
   3.71057384482897*^9, {3.716814819778722*^9, 3.7168148230492268`*^9}, {
   3.7177481321026373`*^9, 3.717748136167802*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZSymmZ4", "[", 
   RowBox[{"t1_", ",", "t2_", ",", "t3_", ",", "t4_", ",", "t5_"}], "]"}], ":=", 
  RowBox[{"Exp", "[", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", "m"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"FC3", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"t1", "/", 
             RowBox[{"t2", "^", "3"}]}], ")"}], "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"t2", "^", "4"}], ")"}], "^", "m"}], ",", 
          RowBox[{"t3", "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"q", "/", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
          RowBox[{"1", "/", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"q", " ", 
              RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], ",", 
          RowBox[{"k", "^", "m"}]}], "]"}], "+", 
        RowBox[{"FC3", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"t1", "^", "2"}], "/", 
             RowBox[{"t2", "^", "2"}]}], ")"}], "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"t2", "^", "3"}], "/", 
             RowBox[{"t1", "^", "1"}]}], ")"}], "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"q", "/", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
          RowBox[{"1", "/", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"q", " ", 
              RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], ",", 
          RowBox[{"k", "^", "m"}]}], "]"}], "+", 
        RowBox[{"FC3", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"t1", "^", "3"}], " ", "/", "t2"}], ")"}], "^", "m"}], 
          ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"t2", "^", "2"}], "/", " ", 
             RowBox[{"t1", "^", "2"}]}], ")"}], "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"q", "/", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
          RowBox[{"1", "/", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"q", " ", 
              RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], ",", 
          RowBox[{"k", "^", "m"}]}], "]"}], "+", 
        RowBox[{"FC3", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"t1", "^", "4"}], ")"}], "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"t2", "/", " ", 
             RowBox[{"t1", "^", "3"}]}], ")"}], "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"q", "/", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
          RowBox[{"1", "/", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"q", " ", 
              RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], ",", 
          RowBox[{"k", "^", "m"}]}], "]"}], "+", 
        RowBox[{"FKahlerZ4", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", "p1", ")"}], "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", "p2", ")"}], "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", "p3", ")"}], "^", "m"}], ",", 
          RowBox[{"t3", "^", "m"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"q", "/", 
             RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
           RowBox[{"(", " ", "m", ")"}]}], ",", 
          RowBox[{"1", "/", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"q", " ", 
              RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
            RowBox[{"(", " ", "m", ")"}]}]}], ",", 
          RowBox[{"k", "^", "m"}]}], "]"}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7168148445009327`*^9, 3.716814873401244*^9}, 
   3.716815069373652*^9, 3.717748140597415*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TotalSymmZ4", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{"PowerExpand", "[", 
     RowBox[{
      RowBox[{"Normal", "[", 
       RowBox[{
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t1", "/", 
                    RowBox[{"t2", "^", "3"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t2", "^", "4"}], ")"}], "^", "m"}], ",", 
                  RowBox[{"t3", "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], 
                  ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], " ", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t1", "^", "2"}], "/", 
                    RowBox[{"t2", "^", "2"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t2", "^", "3"}], "/", 
                    RowBox[{"t1", "^", "1"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], 
                  ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], 
        "\[IndentingNewLine]", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t1", "^", "3"}], " ", "/", "t2"}], ")"}], "^", 
                   "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t2", "^", "2"}], "/", " ", 
                    RowBox[{"t1", "^", "2"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], 
                  ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], " ", 
        "\[IndentingNewLine]", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t1", "^", "4"}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t2", "/", " ", 
                    RowBox[{"t1", "^", "3"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], 
                  ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], " ", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FKahlerZ4", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", "p1", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "p2", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "p3", ")"}], "^", "m"}], ",", 
                  RowBox[{"t3", "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
                   RowBox[{"(", " ", "m", ")"}]}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
                    RowBox[{"(", " ", "m", ")"}]}]}], ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}]}], "]"}], "//.", 
      
      RowBox[{"q", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}]}]}], "]"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.710318725932705*^9, 3.71031876273708*^9}, {
  3.7105750754773912`*^9, 3.7105750766593924`*^9}, {3.71681499170918*^9, 
  3.7168150905980177`*^9}, {3.716818365478356*^9, 3.716818383047757*^9}, {
  3.7177481431720123`*^9, 3.717748154070774*^9}}],

Cell["\<\
To speed up the computation we compute separately the partition function up \
to order 5\
\>", "Text",
 CellChangeTimes->{{3.716815949829966*^9, 3.716815964065909*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TotalLocaZ4", "=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"TotalContributionC2Z4", "[", 
      RowBox[{"i", ",", "p0", ",", "p1", ",", "p2", ",", "p3"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "5"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7103190640552692`*^9, 3.710319119783393*^9}}],

Cell["\<\
Now we check that indeed the computations using Nekrasov orbifold function \
and the direct localization computation agree\
\>", "Text",
 CellChangeTimes->{{3.716815975485141*^9, 3.716815996369084*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CheckcoeffZ4", "[", 
   RowBox[{"order_", ",", "n0_", ",", "n1_", ",", "n2_", ",", "n3_"}], "]"}], 
  ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"PowerExpand", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{
            RowBox[{"Coefficient", "[", 
             RowBox[{"TotalSymmZ4", ",", "p0", ",", "n0"}], "]"}], ",", "p1", 
            ",", "n1"}], "]"}], ",", "p2", ",", "n2"}], "]"}], ",", "p3", ",",
         "n3"}], "]"}], "//.", 
      RowBox[{"k", "\[Rule]", 
       RowBox[{"t1", " ", "t2", " ", "t3"}]}]}], "]"}], " ", "-", "\n", 
    RowBox[{"PowerExpand", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{
            RowBox[{"Coefficient", "[", 
             RowBox[{"TotalLocaZ4", ",", "p0", ",", "n0"}], "]"}], ",", "p1", 
            ",", "n1"}], "]"}], ",", "p2", ",", "n2"}], "]"}], ",", "p3", ",",
         "n3"}], "]"}], "//.", 
      RowBox[{"k", "\[Rule]", 
       RowBox[{"t1", " ", "t2", " ", "t3"}]}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.709801230318844*^9, 3.709801292112351*^9}, 
   3.7098014386962843`*^9, {3.709801512078055*^9, 3.709801584676147*^9}, {
   3.709801658557428*^9, 3.709801712918518*^9}, {3.709801801223412*^9, 
   3.709801811408842*^9}, {3.709802006041431*^9, 3.709802037016217*^9}, {
   3.7098021223158607`*^9, 3.7098021223716593`*^9}, {3.709802308716028*^9, 
   3.709802315360991*^9}, {3.709802399964591*^9, 3.709802409599578*^9}, {
   3.709802440664639*^9, 3.7098024634166737`*^9}, {3.7098025631464157`*^9, 
   3.7098026364575167`*^9}, {3.7098027373052263`*^9, 
   3.7098027502936773`*^9}, {3.70980287397756*^9, 3.709802931392337*^9}, {
   3.7098029840396013`*^9, 3.7098029841459723`*^9}, {3.709803027964568*^9, 
   3.709803030456292*^9}, {3.709803258589994*^9, 3.7098032961555033`*^9}, {
   3.7098050060851097`*^9, 3.709805049994216*^9}, {3.70980510311948*^9, 
   3.709805165391273*^9}, {3.70980521532803*^9, 3.709805228887878*^9}, {
   3.7098056856537447`*^9, 3.709805687434853*^9}, {3.7098066800874443`*^9, 
   3.709806717585905*^9}, {3.7098067606485767`*^9, 3.709806779942554*^9}, {
   3.709807256477849*^9, 3.709807287942749*^9}, {3.709807518393207*^9, 
   3.709807540112265*^9}, {3.709807632071225*^9, 3.709807644936674*^9}, {
   3.7098077092555323`*^9, 3.709807717896744*^9}, {3.709807926332507*^9, 
   3.709807927817779*^9}, {3.709808554146041*^9, 3.709808605385367*^9}, 
   3.70980863894615*^9, {3.709808933563208*^9, 3.709808935559516*^9}, {
   3.709808972265918*^9, 3.709808972319015*^9}, {3.709811241651187*^9, 
   3.709811293242934*^9}, {3.709811340568644*^9, 3.7098113578167067`*^9}, {
   3.7098113938671017`*^9, 3.709811401261002*^9}, {3.709811499165019*^9, 
   3.70981150915385*^9}, {3.7098115399523687`*^9, 3.7098115426787*^9}, {
   3.709811702389453*^9, 3.709811708584779*^9}, 3.709919214027174*^9, {
   3.709919287751693*^9, 3.7099192906814013`*^9}, {3.709919330755711*^9, 
   3.709919356894569*^9}, {3.709919393882804*^9, 3.7099194665185423`*^9}, {
   3.709919962264369*^9, 3.709919990810166*^9}, {3.7099201647229853`*^9, 
   3.709920166933949*^9}, {3.7099727140162277`*^9, 3.7099727140971212`*^9}, {
   3.709972806873467*^9, 3.709972931874864*^9}, {3.710073827448523*^9, 
   3.710073829057536*^9}, {3.710073916984509*^9, 3.71007392250393*^9}, {
   3.7103187918472977`*^9, 3.710318801443994*^9}, 3.710319137985703*^9, {
   3.7105739032216883`*^9, 3.710573908870428*^9}, {3.7168153840680227`*^9, 
   3.716815389450534*^9}, 3.716815926295784*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CheckcoeffZ4List", "[", 
   RowBox[{"n_", ",", "list_"}], "]"}], ":=", 
  RowBox[{"CheckcoeffZ4", "[", 
   RowBox[{"n", ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "3", "]"}], "]"}], ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "4", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7103192660955753`*^9, 3.710319317190687*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ4List", "[", 
    RowBox[{"1", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"1", ",", "4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.710319604850749*^9, 3.710319633592993*^9}, {
  3.710319708824301*^9, 3.7103197454653788`*^9}, {3.710319807180949*^9, 
  3.710319811461013*^9}, {3.710574250497073*^9, 3.710574252304381*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.710574261949972*^9, 3.7105769165045633`*^9, 
  3.7168186337977753`*^9, 3.7177483766090097`*^9, 3.717752611246831*^9, 
  3.717919003534265*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ4List", "[", 
    RowBox[{"2", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"2", ",", "4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.710319604850749*^9, 3.710319633592993*^9}, {
  3.710319708824301*^9, 3.7103197454653788`*^9}, {3.710319807180949*^9, 
  3.710319811461013*^9}, {3.710574250497073*^9, 3.7105742647692137`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.710574285720461*^9, 3.710576940580269*^9, 
  3.716818657963018*^9, 3.7177483996052094`*^9, 3.717752637089884*^9, 
  3.717919028536851*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ4List", "[", 
    RowBox[{"3", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"3", ",", "4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.710319604850749*^9, 3.710319633592993*^9}, {
  3.710319708824301*^9, 3.7103197454653788`*^9}, {3.710319807180949*^9, 
  3.710319811461013*^9}, {3.710574250497073*^9, 3.710574277883547*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.710574334983666*^9, 3.7105769894729033`*^9, 
  3.716818706779801*^9, 3.7177484527567*^9, 3.717752692199411*^9, 
  3.717919080959898*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ4List", "[", 
    RowBox[{"4", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"4", ",", "4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.710319604850749*^9, 3.710319633592993*^9}, {
  3.710319708824301*^9, 3.7103197454653788`*^9}, {3.710319807180949*^9, 
  3.710319811461013*^9}, {3.710574250497073*^9, 3.7105742814820757`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.7105744286175528`*^9, 3.710577088495153*^9, 
  3.716818798490943*^9, 3.717748547519464*^9, 3.717752783102724*^9, 
  3.717919171601521*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ4List", "[", 
    RowBox[{"5", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"5", ",", "4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.710319604850749*^9, 3.710319633592993*^9}, {
  3.710319708824301*^9, 3.7103197454653788`*^9}, {3.710319807180949*^9, 
  3.710319811461013*^9}, {3.710574250497073*^9, 3.710574252304381*^9}, {
  3.710574283277644*^9, 3.710574285155799*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.71057464082224*^9, 3.7105772916165543`*^9, 
  3.716818989953515*^9, 3.7177487550144176`*^9, 3.717752986509878*^9, 
  3.717919366960224*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["C2/Z5 x C", "Subchapter",
 CellChangeTimes->{{3.7099718617654657`*^9, 3.709971866386961*^9}, {
  3.710575329055859*^9, 3.710575329118122*^9}}],

Cell[CellGroupData[{

Cell["Localization", "Subsection",
 CellChangeTimes->{{3.716814763743575*^9, 3.716814766654924*^9}, {
  3.716819327134684*^9, 3.716819328738431*^9}}],

Cell["\<\
The definitions are similar to the other cases. Here the weight decomposition \
of V\
\>", "Text",
 CellChangeTimes->{{3.716819479389678*^9, 3.716819489886305*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PPVC2Z5", "[", 
   RowBox[{"l_List", ",", "t1_", ",", "t2_", ",", "t3_", ",", "r_"}], "]"}], ":=", 
  RowBox[{"Total", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"t1", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "i"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"t2", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "j"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"t3", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "k"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"KroneckerDelta", "[", 
          RowBox[{
           RowBox[{"Mod", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "j"}], "+", "i"}], ",", "5"}], "]"}], ",", "r"}], 
          "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "l", "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"j", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"l", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"l", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "}"}]}], 
       "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.685794026599243*^9, 3.685794062411702*^9}, {
   3.6857945569193993`*^9, 3.68579456486136*^9}, {3.685794658823471*^9, 
   3.685794661349846*^9}, {3.685794743967721*^9, 3.685794762494817*^9}, {
   3.685795923624857*^9, 3.685795925376687*^9}, {3.686396180192107*^9, 
   3.686396186019744*^9}, 3.6864006439129047`*^9, {3.709971462013809*^9, 
   3.709971467937703*^9}, 3.710326498541847*^9, {3.710575330979271*^9, 
   3.710575336436009*^9}}],

Cell["The virtual tangent space", "Text",
 CellChangeTimes->{{3.7168194945106773`*^9, 3.716819497739933*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TvirC2Z5fixed", "[", 
   RowBox[{"list_", ",", "t1_", ",", "t2_", ",", "t3_", ",", "k_"}], "]"}], ":=",
   "  ", 
  RowBox[{
   RowBox[{"PPVC2Z5", "[", 
    RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], "-", 
   RowBox[{
    RowBox[{"PPVC2Z5", "[", 
     RowBox[{"list", ",", 
      RowBox[{"1", "/", "t1"}], ",", 
      RowBox[{"1", "/", "t2"}], ",", 
      RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}], " ", "t1", " ", "t2", " ", 
    "t3"}], "-", "  ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], 
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "1"}], "]"}], 
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "1"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "2"}], "]"}], 
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "2"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "3"}], "]"}], 
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "3"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "4"}], "]"}], 
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "4"}], "]"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"t1", " ", "t2"}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", "t3"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "1"}], "]"}], 
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "2"}], "]"}], 
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "1"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "3"}], "]"}], 
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "2"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "4"}], "]"}], 
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "3"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], 
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "4"}], "]"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"-", "t1"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", "t3"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], 
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "1"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "1"}], "]"}], 
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "2"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "2"}], "]"}], 
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "3"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "3"}], "]"}], 
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "4"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "4"}], "]"}], 
       RowBox[{"PPVC2Z5", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"-", "t2"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", "t3"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGCQAWIQ/anCLXtHwmtHizOiuSC67r48400gzTV7LpjmdDqY
W5f42jFyyXMwHbYwLrYFSDulTQPTEs0LWkD01dbjYLrOa466RNlrx9ApX1xA
9OWWaCu78teO/1zq7EH01dcFp0B0imgPmNbbXnIORNvp9oJpoS2hl0H0upd7
wfSJOzNvgOgVkk/BdN1/t/dgddHfP4Bo/qD3k+yBtE9uxCwQveJJepgDkN7s
VBEOouv++rWaLnntqDVJaQKIPiJhuukBkA6abQembxQs3g6itTyEdoDoby9X
nwPRkyZ8ANMZ4jc+gGhl29ovILpF31f9IZA+dvYAmL63ftMUEC1k5zgVRFvx
R80H0VW59gtAdHbyYYFHQPrFXj5BEH1C+IMIiM467yMKonsvbZEC0c/av0qD
6OvtewJBdIKsbwiI7lsgWgGid9xRANN12+bGxix97Zgrm5YHogFQKPIf
  "]],

Cell[BoxData[
 RowBox[{
  RowBox[{"NBC2Z5", "[", 
   RowBox[{"l_List", ",", "r_"}], "]"}], ":=", 
  RowBox[{"PPVC2Z5", "[", 
   RowBox[{"l", ",", "1", ",", "1", ",", "1", ",", "r"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.685795573005415*^9, 3.685795594181725*^9}, 
   3.6857956721339827`*^9, {3.685795713741584*^9, 3.685795814978931*^9}, {
   3.6857958527331142`*^9, 3.6857958683004723`*^9}, {3.685795981600951*^9, 
   3.6857959892875137`*^9}, 3.685796449591515*^9, {3.685796677468938*^9, 
   3.685796685114377*^9}, 3.685796731259357*^9, {3.6863964714823923`*^9, 
   3.6863964807605333`*^9}, {3.709971629740869*^9, 3.709971631819234*^9}, {
   3.710575484862376*^9, 3.710575488192212*^9}}],

Cell["The localization computation", "Text",
 CellChangeTimes->{{3.7168195072864237`*^9, 3.716819510159823*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"VirtualTC2Z5", "[", 
    RowBox[{"nboxes_", ",", "fixedpoint_"}], "]"}], ":=", 
   RowBox[{"Expand", "[", 
    RowBox[{"TvirC2Z5fixed", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
       RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", "t2", ",", 
      "t3", ",", "k"}], "]"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FPListC2Z5", "[", 
    RowBox[{"nboxes_", ",", "fixedpoint_"}], "]"}], ":=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Reap", "[", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Flatten", "[", 
                RowBox[{"List", "@@", 
                 RowBox[{"(", 
                  RowBox[{"Expand", "[", 
                   RowBox[{"TvirC2Z5fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
                "//.", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"t1", "\[Rule]", "1"}], ",", 
                 RowBox[{"t2", "->", "1"}], ",", 
                 RowBox[{"t3", "\[Rule]", "1"}], ",", 
                 RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
             RowBox[{"[", "i", "]"}], "]"}], ">", "0"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Sow", "[", 
            RowBox[{"{", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
                 RowBox[{"List", "@@", 
                  RowBox[{"(", 
                   RowBox[{"Expand", "[", 
                    RowBox[{"TvirC2Z5fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], 
                 "\[IndentingNewLine]", "]"}], "[", 
                RowBox[{"[", "i", "]"}], "]"}], "/", 
               RowBox[{"(", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Flatten", "[", 
                    RowBox[{"List", "@@", 
                    RowBox[{"(", 
                    RowBox[{"Expand", "[", 
                    RowBox[{"TvirC2Z5fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
                    "//.", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"t1", "\[Rule]", "1"}], ",", 
                    RowBox[{"t2", "->", "1"}], ",", 
                    RowBox[{"t3", "\[Rule]", "1"}], ",", 
                    RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "\[IndentingNewLine]", 
                ")"}]}], ",", 
              RowBox[{
               RowBox[{"(", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Flatten", "[", 
                  RowBox[{"List", "@@", 
                   RowBox[{"(", 
                    RowBox[{"Expand", "[", 
                    RowBox[{"TvirC2Z5fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
                  "//.", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"t1", "\[Rule]", "1"}], ",", 
                   RowBox[{"t2", "->", "1"}], ",", 
                   RowBox[{"t3", "\[Rule]", "1"}], ",", 
                   RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "\[IndentingNewLine]", "}"}],
             "]"}]}], "\[IndentingNewLine]", "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", 
            RowBox[{"Flatten", "[", 
             RowBox[{"List", "@@", 
              RowBox[{"(", 
               RowBox[{"Expand", "[", 
                RowBox[{"TvirC2Z5fixed", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                   RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                  "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}], 
            "]"}]}], "}"}]}], "]"}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ahatp", "[", "list_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"k", "/", 
           RowBox[{"list", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"list", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "/", "k"}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"list", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"list", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], ")"}], "^", 
    RowBox[{"list", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LocalizationC2Z5", "[", 
    RowBox[{
    "nboxes_", ",", "fixedpoint_", ",", "p0_", ",", "p1_", ",", "p2_", ",", 
     "p3_", ",", "p4_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Cancel", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{"Times", "@@", 
       RowBox[{"Map", "[", 
        RowBox[{"ahatp", ",", 
         RowBox[{"FPListC2Z5", "[", 
          RowBox[{"nboxes", ",", "fixedpoint"}], "]"}]}], "]"}]}], "]"}], 
     "]"}], " ", 
    RowBox[{"p0", "^", 
     RowBox[{"NBC2Z5", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
        RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "0"}], "]"}]}], " ", 
    RowBox[{"p1", "^", 
     RowBox[{"NBC2Z5", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
        RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "4"}], "]"}]}], " ", 
    RowBox[{"p2", "^", 
     RowBox[{"NBC2Z5", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
        RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "3"}], "]"}]}], " ", 
    RowBox[{"p3", "^", 
     RowBox[{"NBC2Z5", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
        RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "2"}], "]"}]}], " ", 
    RowBox[{"p4", "^", 
     RowBox[{"NBC2Z5", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
        RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "1"}], "]"}]}]}]}], " ",
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TotalContributionC2Z5", "[", 
   RowBox[{
   "nboxes_", ",", "p0_", ",", "p1_", ",", "p2_", ",", "p3_", ",", "p4_"}], 
   "]"}], ":=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{"LocalizationC2Z5", "[", 
     RowBox[{
     "nboxes", ",", "i", ",", "p0", ",", "p1", ",", "p2", ",", "p3", ",", 
      "p4"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", 
       RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "]"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.67509769824366*^9, 3.675097742433045*^9}, {
   3.675097787395336*^9, 3.67509779944084*^9}, {3.675097856209297*^9, 
   3.675097941379383*^9}, 3.675098012939138*^9, {3.675101981572866*^9, 
   3.675102132977907*^9}, {3.679138392316263*^9, 3.679138397170555*^9}, {
   3.679139098659503*^9, 3.679139114360139*^9}, {3.685794841789722*^9, 
   3.685794885068252*^9}, {3.685797044333329*^9, 3.685797110123225*^9}, {
   3.6857971441185102`*^9, 3.6857971449891253`*^9}, {3.6863964185845757`*^9, 
   3.6863964511875277`*^9}, {3.686396494277749*^9, 3.686396522946504*^9}, {
   3.709971666041795*^9, 3.709971739528995*^9}, {3.710575492442493*^9, 
   3.710575542034099*^9}, {3.7105755802344093`*^9, 3.71057559968292*^9}, {
   3.710577450403566*^9, 3.710577460869803*^9}, {3.716819513224546*^9, 
   3.716819522775031*^9}}],

Cell["The partition function", "Text",
 CellChangeTimes->{{3.716819531263793*^9, 3.7168195335413637`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PartitionFunctionC2Z5", "[", "nboxes_", "]"}], ":=", 
  RowBox[{"1", "+", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"TotalContributionC2Z5", "[", 
      RowBox[{"n", ",", "p0", ",", "p1", ",", "p2", ",", "p3", ",", "p4"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "nboxes"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.716804618813366*^9, 3.716804627198197*^9}, {
  3.716806034437278*^9, 3.716806034503093*^9}, {3.7168147258786716`*^9, 
  3.716814733736116*^9}, {3.716818331008473*^9, 3.7168183311061287`*^9}, {
  3.716819553104373*^9, 3.7168195588853283`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PartitionFunctionC2Z5", "[", "5", "]"}]], "Input",
 CellChangeTimes->{
  3.716804640930531*^9, {3.716814736590336*^9, 3.716814740839767*^9}, {
   3.7168195614985437`*^9, 3.716819561559877*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", 
  FractionBox[
   RowBox[{"p0", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p4", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p4", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", "p4", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p3", " ", "p4", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p3", " ", "p4", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p2", " ", "p3", " ", "p4", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", "p3", " ", "p4", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t1", "5"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t1", "4"]}], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t1", "5"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "4"], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", "p3", " ", "p4", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "4"], "-", 
      RowBox[{"k", " ", "t2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t1", "3"]}], "-", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "4"], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "3"], "-", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", "p3", " ", "p4", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "3"], "-", 
      RowBox[{"k", " ", 
       SuperscriptBox["t2", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t1", "2"]}], "-", 
      SuperscriptBox["t2", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "3"], "-", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      SuperscriptBox["t2", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", "p3", " ", "p4", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      RowBox[{"k", " ", 
       SuperscriptBox["t2", "3"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", 
      SuperscriptBox["t2", "4"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      SuperscriptBox["t2", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      SuperscriptBox["t2", "4"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", "p3", " ", "p4", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", 
       SuperscriptBox["t2", "4"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t2", "5"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      SuperscriptBox["t2", "4"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t2", "5"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    SuperscriptBox["p1", "2"], " ", "p2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p3", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p4", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    SuperscriptBox["p1", "2"], " ", "p4", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p3", " ", "p4", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p2", " ", "p3", " ", "p4", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", 
    SuperscriptBox["p4", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p3", " ", 
    SuperscriptBox["p4", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p4", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "k"}], " ", "t1", " ", "t2"}], "+", "t3"}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p4", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "k"}], " ", "t1", " ", "t2"}], "+", "t3"}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p3", " ", "p4", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "k"}], " ", "t1", " ", "t2"}], "+", "t3"}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p4", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", 
      RowBox[{"k", " ", "t3"}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p4", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", 
      RowBox[{"k", " ", "t3"}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p3", " ", "p4", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", 
      RowBox[{"k", " ", "t3"}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    SuperscriptBox["p1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    SuperscriptBox["p4", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", "p1", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", 
    SuperscriptBox["p1", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", "p1", " ", "p2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", "p4", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", "p3", " ", "p4", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", 
    SuperscriptBox["p4", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", "p1", " ", "p4", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "k"}], " ", "t1", " ", "t2"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", "p1", " ", "p4", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", 
      RowBox[{"k", " ", 
       SuperscriptBox["t3", "2"]}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"5", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "3"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3", "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "4"], " ", "p1", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "3"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3", "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "4"], " ", "p4", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "3"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3", "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "4"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3", "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "5"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "4"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "5"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"5", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "5"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3", "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3", "+", 
      SuperscriptBox["t3", "2"], "+", 
      SuperscriptBox["t3", "3"], "+", 
      SuperscriptBox["t3", "4"]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{3.7168198254129133`*^9, 3.717749028413213*^9, 
  3.717919405665307*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Symmetrization and Orbifold Nekrasov function", "Subsection",
 CellChangeTimes->{{3.716814763743575*^9, 3.716814766654924*^9}}],

Cell["\<\
We define Nekrasov orbifold function as the sum of a piece generating Z5 \
invariant monomials (given by the sum of five copies of the C3 partition \
function, each computed on the generators of the ring of invariants) and a \
Kahler piece\
\>", "Text",
 CellChangeTimes->{{3.7168197361063004`*^9, 3.716819757267432*^9}, {
  3.716830359434987*^9, 3.716830385621089*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FC3", "[", 
   RowBox[{"t1_", ",", "t2_", ",", "t3_", ",", "t4_", ",", "t5_", ",", "k_"}],
    "]"}], ":=", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t1"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t1"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t3"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t3"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "/", "t2"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "/", "t2"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t1", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t1", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t2", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t2", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t3", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t3", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t4", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t4", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t5", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t5", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], ")"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6744033720560493`*^9, 3.674403372806196*^9}, 
   3.674403472934162*^9, {3.685798651440465*^9, 3.685798653178933*^9}, {
   3.709464971485652*^9, 3.709464999637817*^9}, {3.709465033504201*^9, 
   3.709465064467249*^9}, {3.7098117622022123`*^9, 3.7098117675144997`*^9}, {
   3.7177470092131577`*^9, 3.717747036980688*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FKahlerZ5", "[", 
   RowBox[{
   "p1_", ",", "p2_", ",", "p3_", ",", "p4_", ",", "t3_", ",", "t4_", ",", 
    "t5_", ",", "k_"}], "]"}], ":=", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"p1", "+", 
      RowBox[{"1", "/", "p1"}], "+", "p2", "+", 
      RowBox[{"1", "/", "p2"}], "+", "p3", "+", 
      RowBox[{"1", "/", "p3"}], "+", "p4", "+", 
      RowBox[{"1", "/", "p4"}], "+", 
      RowBox[{"p1", " ", "p2"}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"p1", " ", "p2"}], ")"}]}], "+", 
      RowBox[{"p2", " ", "p3"}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"p2", " ", "p3"}], ")"}]}], "+", 
      RowBox[{"p3", " ", "p4"}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"p3", " ", "p4"}], ")"}]}], "+", "\[IndentingNewLine]", 
      RowBox[{"p1", " ", "p2", " ", "p3"}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"p1", " ", "p2", " ", "p3"}], ")"}]}], "+", 
      RowBox[{"p2", " ", "p3", " ", "p4"}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"p2", " ", "p3", " ", "p4"}], ")"}]}], "+", 
      RowBox[{"p1", " ", "p2", " ", "p3", " ", "p4"}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"p1", " ", "p2", " ", "p3", " ", "p4"}], ")"}]}]}], ")"}], 
    " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"+", 
        FractionBox["1", 
         SqrtBox[
          FractionBox["t3", "k"]]]}], "-", 
       SqrtBox[
        FractionBox["t3", "k"]]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SqrtBox["t3"]]}], "+", 
         SqrtBox["t3"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SqrtBox["t4"]]}], "+", 
         SqrtBox["t4"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SqrtBox["t5"]]}], "+", 
         SqrtBox["t5"]}], ")"}]}], ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.709800049685461*^9, 3.7098001425906267`*^9}, {
   3.709800282903933*^9, 3.7098002913052387`*^9}, {3.7098010041146803`*^9, 
   3.709801008186751*^9}, {3.709801741383148*^9, 3.709801768415749*^9}, {
   3.709808631439939*^9, 3.7098086335554943`*^9}, {3.7098111580622053`*^9, 
   3.709811195198132*^9}, {3.709972738438386*^9, 3.709972738496582*^9}, {
   3.710073838997891*^9, 3.7100738528868628`*^9}, {3.710317887526458*^9, 
   3.7103179142862797`*^9}, {3.71032090835084*^9, 3.710320915343544*^9}, {
   3.710321482043655*^9, 3.7103214844483*^9}, {3.710325903517514*^9, 
   3.710325905984568*^9}, {3.710326033782838*^9, 3.710326103612987*^9}, 
   3.71057384482897*^9, {3.710577182750217*^9, 3.7105772292337914`*^9}, {
   3.716819570051013*^9, 3.716819571699686*^9}, {3.71774898608461*^9, 
   3.7177489893009167`*^9}}],

Cell["\<\
To speed up the computation we compute separately the partition function from \
Nekrasov orbifold function and from localization, and then compare\
\>", "Text",
 CellChangeTimes->{{3.716819774194214*^9, 3.716819802166724*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TotalSymmZ5", "=", 
   RowBox[{
    RowBox[{"Expand", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t1", "/", 
                    RowBox[{"t2", "^", "4"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t2", "^", "5"}], ")"}], "^", "m"}], ",", 
                  RowBox[{"t3", "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], 
                  ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], "//.", 
       RowBox[{"q", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3", " ", 
         "p4"}]}]}], "]"}], "]"}], 
    RowBox[{"Expand", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t1", "^", "2"}], "/", 
                    RowBox[{"t2", "^", "3"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t2", "^", "4"}], "/", 
                    RowBox[{"t1", "^", "1"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], 
                  ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], "//.", 
       RowBox[{"q", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3", " ", 
         "p4"}]}]}], "]"}], "]"}], 
    RowBox[{"Expand", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t1", "^", "3"}], " ", "/", 
                    RowBox[{"t2", "^", "2"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t2", "^", "3"}], "/", " ", 
                    RowBox[{"t1", "^", "2"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], 
                  ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], "//.", 
       RowBox[{"q", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3", " ", 
         "p4"}]}]}], "]"}], "]"}], 
    RowBox[{"Expand", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t1", "^", "4"}], "/", "t2"}], ")"}], "^", "m"}], 
                  ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t2", "^", "2"}], "/", " ", 
                    RowBox[{"t1", "^", "3"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], 
                  ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], "//.", 
       RowBox[{"q", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3", " ", 
         "p4"}]}]}], "]"}], "]"}], 
    RowBox[{"Expand", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t1", "^", "5"}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t2", "^", "1"}], "/", " ", 
                    RowBox[{"t1", "^", "4"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], 
                  ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], "//.", 
       RowBox[{"q", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3", " ", 
         "p4"}]}]}], "]"}], "]"}], 
    RowBox[{"Expand", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FKahlerZ5", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", "p1", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "p2", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "p3", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "p4", ")"}], "^", "m"}], ",", 
                  RowBox[{"t3", "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
                   RowBox[{"(", " ", "m", ")"}]}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
                    RowBox[{"(", " ", "m", ")"}]}]}], ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], "//.", 
       RowBox[{"q", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3", " ", 
         "p4"}]}]}], "]"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.710318725932705*^9, 3.71031876273708*^9}, {
  3.7105750754773912`*^9, 3.7105750766593924`*^9}, {3.71681499170918*^9, 
  3.7168150905980177`*^9}, {3.716818365478356*^9, 3.716818383047757*^9}, {
  3.716819625579484*^9, 3.716819696559843*^9}, {3.716828582493938*^9, 
  3.7168287217656527`*^9}, {3.716828776260865*^9, 3.716828805355847*^9}, {
  3.71682892613487*^9, 3.71682894297469*^9}, {3.717748994579082*^9, 
  3.717749005766614*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TotalLocaZ5", "=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"TotalContributionC2Z5", "[", 
      RowBox[{"i", ",", "p0", ",", "p1", ",", "p2", ",", "p3", ",", "p4"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "5"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7103190640552692`*^9, 3.710319119783393*^9}, {
  3.710577345818693*^9, 3.710577350783451*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CheckcoeffZ5", "[", 
   RowBox[{
   "order_", ",", "n0_", ",", "n1_", ",", "n2_", ",", "n3_", ",", "n4_"}], 
   "]"}], ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"PowerExpand", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{
            RowBox[{"Coefficient", "[", 
             RowBox[{
              RowBox[{"Coefficient", "[", 
               RowBox[{"TotalSymmZ5", ",", "p0", ",", "n0"}], "]"}], ",", 
              "p1", ",", "n1"}], "]"}], ",", "p2", ",", "n2"}], "]"}], ",", 
          "p3", ",", "n3"}], "]"}], ",", "p4", ",", "n4"}], "]"}], "//.", 
      RowBox[{"k", "\[Rule]", 
       RowBox[{"t1", " ", "t2", " ", "t3"}]}]}], "]"}], " ", "-", "\n", 
    RowBox[{"PowerExpand", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{
            RowBox[{"Coefficient", "[", 
             RowBox[{
              RowBox[{"Coefficient", "[", 
               RowBox[{"TotalLocaZ5", ",", "p0", ",", "n0"}], "]"}], ",", 
              "p1", ",", "n1"}], "]"}], ",", "p2", ",", "n2"}], "]"}], ",", 
          "p3", ",", "n3"}], "]"}], ",", "p4", ",", "n4"}], "]"}], "//.", 
      RowBox[{"k", "\[Rule]", 
       RowBox[{"t1", " ", "t2", " ", "t3"}]}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.709801230318844*^9, 3.709801292112351*^9}, 
   3.7098014386962843`*^9, {3.709801512078055*^9, 3.709801584676147*^9}, {
   3.709801658557428*^9, 3.709801712918518*^9}, {3.709801801223412*^9, 
   3.709801811408842*^9}, {3.709802006041431*^9, 3.709802037016217*^9}, {
   3.7098021223158607`*^9, 3.7098021223716593`*^9}, {3.709802308716028*^9, 
   3.709802315360991*^9}, {3.709802399964591*^9, 3.709802409599578*^9}, {
   3.709802440664639*^9, 3.7098024634166737`*^9}, {3.7098025631464157`*^9, 
   3.7098026364575167`*^9}, {3.7098027373052263`*^9, 
   3.7098027502936773`*^9}, {3.70980287397756*^9, 3.709802931392337*^9}, {
   3.7098029840396013`*^9, 3.7098029841459723`*^9}, {3.709803027964568*^9, 
   3.709803030456292*^9}, {3.709803258589994*^9, 3.7098032961555033`*^9}, {
   3.7098050060851097`*^9, 3.709805049994216*^9}, {3.70980510311948*^9, 
   3.709805165391273*^9}, {3.70980521532803*^9, 3.709805228887878*^9}, {
   3.7098056856537447`*^9, 3.709805687434853*^9}, {3.7098066800874443`*^9, 
   3.709806717585905*^9}, {3.7098067606485767`*^9, 3.709806779942554*^9}, {
   3.709807256477849*^9, 3.709807287942749*^9}, {3.709807518393207*^9, 
   3.709807540112265*^9}, {3.709807632071225*^9, 3.709807644936674*^9}, {
   3.7098077092555323`*^9, 3.709807717896744*^9}, {3.709807926332507*^9, 
   3.709807927817779*^9}, {3.709808554146041*^9, 3.709808605385367*^9}, 
   3.70980863894615*^9, {3.709808933563208*^9, 3.709808935559516*^9}, {
   3.709808972265918*^9, 3.709808972319015*^9}, {3.709811241651187*^9, 
   3.709811293242934*^9}, {3.709811340568644*^9, 3.7098113578167067`*^9}, {
   3.7098113938671017`*^9, 3.709811401261002*^9}, {3.709811499165019*^9, 
   3.70981150915385*^9}, {3.7098115399523687`*^9, 3.7098115426787*^9}, {
   3.709811702389453*^9, 3.709811708584779*^9}, 3.709919214027174*^9, {
   3.709919287751693*^9, 3.7099192906814013`*^9}, {3.709919330755711*^9, 
   3.709919356894569*^9}, {3.709919393882804*^9, 3.7099194665185423`*^9}, {
   3.709919962264369*^9, 3.709919990810166*^9}, {3.7099201647229853`*^9, 
   3.709920166933949*^9}, {3.7099727140162277`*^9, 3.7099727140971212`*^9}, {
   3.709972806873467*^9, 3.709972931874864*^9}, {3.710073827448523*^9, 
   3.710073829057536*^9}, {3.710073916984509*^9, 3.71007392250393*^9}, {
   3.7103187918472977`*^9, 3.710318801443994*^9}, 3.710319137985703*^9, {
   3.7105739032216883`*^9, 3.710573908870428*^9}, {3.710577357495666*^9, 
   3.7105773914126863`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CheckcoeffZ5List", "[", 
   RowBox[{"n_", ",", "list_"}], "]"}], ":=", 
  RowBox[{"CheckcoeffZ5", "[", 
   RowBox[{"n", ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "3", "]"}], "]"}], ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "4", "]"}], "]"}], ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "5", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7103192660955753`*^9, 3.710319317190687*^9}, {
  3.710577395276349*^9, 3.710577407832775*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ5List", "[", 
    RowBox[{"1", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"1", ",", "5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.710319604850749*^9, 3.710319633592993*^9}, {
  3.710319708824301*^9, 3.7103197454653788`*^9}, {3.710319807180949*^9, 
  3.710319811461013*^9}, {3.710574250497073*^9, 3.710574252304381*^9}, {
  3.710577410425535*^9, 3.710577413482637*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.710574261949972*^9, 3.71057765947336*^9, 
  3.710579384766349*^9, 3.7168209178785067`*^9, 3.7177490600661*^9, 
  3.7179194371850157`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ5List", "[", 
    RowBox[{"2", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"2", ",", "5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.710319604850749*^9, 3.710319633592993*^9}, {
  3.710319708824301*^9, 3.7103197454653788`*^9}, {3.710319807180949*^9, 
  3.710319811461013*^9}, {3.710574250497073*^9, 3.710574252304381*^9}, {
  3.710577410425535*^9, 3.71057742932472*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7105795652205067`*^9, 3.716821081359395*^9, 
  3.717749068289577*^9, 3.717919445390456*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ5List", "[", 
    RowBox[{"3", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"3", ",", "5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.710319604850749*^9, 3.710319633592993*^9}, {
  3.710319708824301*^9, 3.7103197454653788`*^9}, {3.710319807180949*^9, 
  3.710319811461013*^9}, {3.710574250497073*^9, 3.710574252304381*^9}, {
  3.710577410425535*^9, 3.710577432556425*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.7105800079208727`*^9, 3.716821496637212*^9, 
  3.717749092145368*^9, 3.717919469396818*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ5List", "[", 
    RowBox[{"4", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"4", ",", "5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.710319604850749*^9, 3.710319633592993*^9}, {
  3.710319708824301*^9, 3.7103197454653788`*^9}, {3.710319807180949*^9, 
  3.710319811461013*^9}, {3.710574250497073*^9, 3.710574252304381*^9}, {
  3.710577410425535*^9, 3.71057743575952*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.710581131726717*^9, 3.71682238401305*^9, 
  3.7177491550213013`*^9, 3.717919530146247*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ5List", "[", 
    RowBox[{"5", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"5", ",", "5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.710319604850749*^9, 3.710319633592993*^9}, {
  3.710319708824301*^9, 3.7103197454653788`*^9}, {3.710319807180949*^9, 
  3.710319811461013*^9}, {3.710574250497073*^9, 3.710574252304381*^9}, {
  3.710577410425535*^9, 3.710577438849166*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.7105845021979427`*^9, 3.7168245504205637`*^9, 
  3.717749288683126*^9, 3.717919667578855*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["C2/Z6 x C", "Subchapter",
 CellChangeTimes->{{3.7099718617654657`*^9, 3.709971866386961*^9}, {
  3.710575329055859*^9, 3.710575329118122*^9}, {3.710589201975843*^9, 
  3.710589202070959*^9}}],

Cell[CellGroupData[{

Cell["Localization", "Subsection",
 CellChangeTimes->{{3.716814763743575*^9, 3.716814766654924*^9}, {
  3.716830179157219*^9, 3.716830180365514*^9}}],

Cell["Now the example of C2/Z6 x C. The module decomposition is", "Text",
 CellChangeTimes->{{3.716830037076054*^9, 3.716830051310237*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PPVC2Z6", "[", 
   RowBox[{"l_List", ",", "t1_", ",", "t2_", ",", "t3_", ",", "r_"}], "]"}], ":=", 
  RowBox[{"Total", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"t1", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "i"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"t2", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "j"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"t3", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "k"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"KroneckerDelta", "[", 
          RowBox[{
           RowBox[{"Mod", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "j"}], "+", "i"}], ",", "6"}], "]"}], ",", "r"}], 
          "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "l", "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"j", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"l", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"l", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "}"}]}], 
       "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.685794026599243*^9, 3.685794062411702*^9}, {
   3.6857945569193993`*^9, 3.68579456486136*^9}, {3.685794658823471*^9, 
   3.685794661349846*^9}, {3.685794743967721*^9, 3.685794762494817*^9}, {
   3.685795923624857*^9, 3.685795925376687*^9}, {3.686396180192107*^9, 
   3.686396186019744*^9}, 3.6864006439129047`*^9, {3.709971462013809*^9, 
   3.709971467937703*^9}, 3.710326498541847*^9, {3.710575330979271*^9, 
   3.710575336436009*^9}, {3.710589206948867*^9, 3.710589209824654*^9}}],

Cell["The virtual tangent space is invariant under the Z6 action", "Text",
 CellChangeTimes->{{3.7168300581271467`*^9, 3.71683006858457*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TvirC2Z6fixed", "[", 
   RowBox[{"list_", ",", "t1_", ",", "t2_", ",", "t3_", ",", "k_"}], "]"}], ":=",
   "  ", 
  RowBox[{
   RowBox[{"PPVC2Z6", "[", 
    RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], "-", 
   RowBox[{
    RowBox[{"PPVC2Z6", "[", 
     RowBox[{"list", ",", 
      RowBox[{"1", "/", "t1"}], ",", 
      RowBox[{"1", "/", "t2"}], ",", 
      RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}], " ", "t1", " ", "t2", " ", 
    "t3"}], "-", "  ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], 
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "1"}], "]"}], 
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "1"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "2"}], "]"}], 
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "2"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "3"}], "]"}], 
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "3"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "4"}], "]"}], 
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "4"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "5"}], "]"}], 
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "5"}], "]"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"t1", " ", "t2"}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", "t3"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "1"}], "]"}], 
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "2"}], "]"}], 
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "1"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "3"}], "]"}], 
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "2"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "4"}], "]"}], 
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "3"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "5"}], "]"}], 
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "4"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], 
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "5"}], "]"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"-", "t1"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", "t3"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], 
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "1"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "1"}], "]"}], 
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "2"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "2"}], "]"}], 
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "3"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "3"}], "]"}], 
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "4"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "4"}], "]"}], 
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "5"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "5"}], "]"}], 
       RowBox[{"PPVC2Z6", "[", 
        RowBox[{"list", ",", 
         RowBox[{"1", "/", "t1"}], ",", 
         RowBox[{"1", "/", "t2"}], ",", 
         RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"-", "t2"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", "t3"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->CompressedData["
1:eJwdylsoQ3EAx/HxxoMxliF3pWQ8rUQ2ZwnJlOU+NMwl6+BBLOW8OPKCtFi5
ZUIpRSH2YEXEElNYpuSWa+fBScOTy//3f/j2efnGN3Tom/wlEkkMCX5Y8swO
o8BkHMtZyN3G+l0RA6dmqAHaXZarF5iqhRdq+VxdLU/UNtuoin47Dz0Dh1Su
cDpZ0S0wZWO+XHjOGzLVPQLzm8tpoEfoPIIm+RA1bavLDdXKYapso+wcrrw5
qa7rCS9ciniicn957/QzfItQqn+3aohFbOUkXHpsKc8hrmstFZD7KR5QLQhM
ijVhFO4rVGt3RP2UmurtnN+CKQUyB/x6W3ZD66hIbQ33ijAxu88H+XRd8j3x
4GSHerO6NgZlamYcZkqrZ2Evq7FDc+Ne8APx1RkUAl2hYhhsOy2Sw+GzjUj4
PPgZBS8Ht0ugMVpXCkfscgt0XMdRuc2Z2ppFgWGjm9uhNcmV2Ei8cKQqYX6W
1Ay7TDbqP5GyAVs=
  "]],

Cell[BoxData[
 RowBox[{
  RowBox[{"NBC2Z6", "[", 
   RowBox[{"l_List", ",", "r_"}], "]"}], ":=", 
  RowBox[{"PPVC2Z6", "[", 
   RowBox[{"l", ",", "1", ",", "1", ",", "1", ",", "r"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.685795573005415*^9, 3.685795594181725*^9}, 
   3.6857956721339827`*^9, {3.685795713741584*^9, 3.685795814978931*^9}, {
   3.6857958527331142`*^9, 3.6857958683004723`*^9}, {3.685795981600951*^9, 
   3.6857959892875137`*^9}, 3.685796449591515*^9, {3.685796677468938*^9, 
   3.685796685114377*^9}, 3.685796731259357*^9, {3.6863964714823923`*^9, 
   3.6863964807605333`*^9}, {3.709971629740869*^9, 3.709971631819234*^9}, {
   3.710575484862376*^9, 3.710575488192212*^9}, {3.710589294002102*^9, 
   3.710589296571588*^9}}],

Cell["The localization computation:", "Text",
 CellChangeTimes->{{3.716830076790941*^9, 3.716830083896243*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"VirtualTC2Z6", "[", 
    RowBox[{"nboxes_", ",", "fixedpoint_"}], "]"}], ":=", 
   RowBox[{"Expand", "[", 
    RowBox[{"TvirC2Z6fixed", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
       RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", "t2", ",", 
      "t3", ",", "k"}], "]"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FPListC2Z6", "[", 
    RowBox[{"nboxes_", ",", "fixedpoint_"}], "]"}], ":=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Reap", "[", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Flatten", "[", 
                RowBox[{"List", "@@", 
                 RowBox[{"(", 
                  RowBox[{"Expand", "[", 
                   RowBox[{"TvirC2Z6fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
                "//.", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"t1", "\[Rule]", "1"}], ",", 
                 RowBox[{"t2", "->", "1"}], ",", 
                 RowBox[{"t3", "\[Rule]", "1"}], ",", 
                 RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
             RowBox[{"[", "i", "]"}], "]"}], ">", "0"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Sow", "[", 
            RowBox[{"{", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
                 RowBox[{"List", "@@", 
                  RowBox[{"(", 
                   RowBox[{"Expand", "[", 
                    RowBox[{"TvirC2Z6fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], 
                 "\[IndentingNewLine]", "]"}], "[", 
                RowBox[{"[", "i", "]"}], "]"}], "/", 
               RowBox[{"(", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Flatten", "[", 
                    RowBox[{"List", "@@", 
                    RowBox[{"(", 
                    RowBox[{"Expand", "[", 
                    RowBox[{"TvirC2Z6fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
                    "//.", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"t1", "\[Rule]", "1"}], ",", 
                    RowBox[{"t2", "->", "1"}], ",", 
                    RowBox[{"t3", "\[Rule]", "1"}], ",", 
                    RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "\[IndentingNewLine]", 
                ")"}]}], ",", 
              RowBox[{
               RowBox[{"(", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Flatten", "[", 
                  RowBox[{"List", "@@", 
                   RowBox[{"(", 
                    RowBox[{"Expand", "[", 
                    RowBox[{"TvirC2Z6fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
                  "//.", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"t1", "\[Rule]", "1"}], ",", 
                   RowBox[{"t2", "->", "1"}], ",", 
                   RowBox[{"t3", "\[Rule]", "1"}], ",", 
                   RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "\[IndentingNewLine]", "}"}],
             "]"}]}], "\[IndentingNewLine]", "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", 
            RowBox[{"Flatten", "[", 
             RowBox[{"List", "@@", 
              RowBox[{"(", 
               RowBox[{"Expand", "[", 
                RowBox[{"TvirC2Z6fixed", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                   RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                  "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}], 
            "]"}]}], "}"}]}], "]"}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ahatp", "[", "list_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"k", "/", 
           RowBox[{"list", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"list", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "/", "k"}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"list", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"list", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], ")"}], "^", 
    RowBox[{"list", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LocalizationC2Z6", "[", 
    RowBox[{
    "nboxes_", ",", "fixedpoint_", ",", "p0_", ",", "p1_", ",", "p2_", ",", 
     "p3_", ",", "p4_", ",", "p5_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Cancel", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{"Times", "@@", 
       RowBox[{"Map", "[", 
        RowBox[{"ahatp", ",", 
         RowBox[{"FPListC2Z6", "[", 
          RowBox[{"nboxes", ",", "fixedpoint"}], "]"}]}], "]"}]}], "]"}], 
     "]"}], " ", 
    RowBox[{"p0", "^", 
     RowBox[{"NBC2Z6", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
        RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "0"}], "]"}]}], " ", 
    RowBox[{"p1", "^", 
     RowBox[{"NBC2Z6", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
        RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "5"}], "]"}]}], " ", 
    RowBox[{"p2", "^", 
     RowBox[{"NBC2Z6", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
        RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "4"}], "]"}]}], " ", 
    RowBox[{"p3", "^", 
     RowBox[{"NBC2Z6", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
        RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "3"}], "]"}]}], " ", 
    RowBox[{"p4", "^", 
     RowBox[{"NBC2Z6", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
        RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "2"}], "]"}]}], 
    RowBox[{"p5", "^", 
     RowBox[{"NBC2Z6", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
        RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "1"}], "]"}]}]}]}], " ",
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TotalContributionC2Z6", "[", 
   RowBox[{
   "nboxes_", ",", "p0_", ",", "p1_", ",", "p2_", ",", "p3_", ",", "p4_", ",",
     "p5_"}], "]"}], ":=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{"LocalizationC2Z6", "[", 
     RowBox[{
     "nboxes", ",", "i", ",", "p0", ",", "p1", ",", "p2", ",", "p3", ",", 
      "p4", ",", "p5"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", 
       RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "]"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.67509769824366*^9, 3.675097742433045*^9}, {
   3.675097787395336*^9, 3.67509779944084*^9}, {3.675097856209297*^9, 
   3.675097941379383*^9}, 3.675098012939138*^9, {3.675101981572866*^9, 
   3.675102132977907*^9}, {3.679138392316263*^9, 3.679138397170555*^9}, {
   3.679139098659503*^9, 3.679139114360139*^9}, {3.685794841789722*^9, 
   3.685794885068252*^9}, {3.685797044333329*^9, 3.685797110123225*^9}, {
   3.6857971441185102`*^9, 3.6857971449891253`*^9}, {3.6863964185845757`*^9, 
   3.6863964511875277`*^9}, {3.686396494277749*^9, 3.686396522946504*^9}, {
   3.709971666041795*^9, 3.709971739528995*^9}, {3.710575492442493*^9, 
   3.710575542034099*^9}, {3.7105755802344093`*^9, 3.71057559968292*^9}, {
   3.710577450403566*^9, 3.710577460869803*^9}, {3.710589299526602*^9, 
   3.710589384611121*^9}, {3.710589665341288*^9, 3.7105896701410923`*^9}, {
   3.710590334207637*^9, 3.7105903417100763`*^9}, {3.716830087301105*^9, 
   3.716830098593075*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PartitionFunctionC2Z6", "[", "nboxes_", "]"}], ":=", 
  RowBox[{"1", "+", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"TotalContributionC2Z6", "[", 
      RowBox[{
      "n", ",", "p0", ",", "p1", ",", "p2", ",", "p3", ",", "p4", ",", "p5"}],
       "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "nboxes"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.716804618813366*^9, 3.716804627198197*^9}, {
  3.716806034437278*^9, 3.716806034503093*^9}, {3.7168147258786716`*^9, 
  3.716814733736116*^9}, {3.716818331008473*^9, 3.7168183311061287`*^9}, {
  3.716819553104373*^9, 3.7168195588853283`*^9}, {3.716830115413805*^9, 
  3.716830120998564*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PartitionFunctionC2Z6", "[", "5", "]"}]], "Input",
 CellChangeTimes->{
  3.716804640930531*^9, {3.716814736590336*^9, 3.716814740839767*^9}, {
   3.7168195614985437`*^9, 3.716819561559877*^9}, {3.7168301400951643`*^9, 
   3.7168301401467333`*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", 
  FractionBox[
   RowBox[{"p0", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", "p3", " ", "p4", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p5", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p5", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", "p5", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", "p3", " ", "p5", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p4", " ", "p5", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p4", " ", "p5", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", "p4", " ", "p5", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p3", " ", "p4", " ", "p5", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p3", " ", "p4", " ", "p5", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p2", " ", "p3", " ", "p4", " ", "p5", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "t3"}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    SuperscriptBox["p1", "2"], " ", "p2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p3", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p5", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    SuperscriptBox["p1", "2"], " ", "p5", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p4", " ", "p5", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p3", " ", "p4", " ", "p5", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", 
    SuperscriptBox["p5", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p4", " ", 
    SuperscriptBox["p5", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p5", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "k"}], " ", "t1", " ", "t2"}], "+", "t3"}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p5", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "k"}], " ", "t1", " ", "t2"}], "+", "t3"}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p4", " ", "p5", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "k"}], " ", "t1", " ", "t2"}], "+", "t3"}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p5", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", 
      RowBox[{"k", " ", "t3"}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p5", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", 
      RowBox[{"k", " ", "t3"}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p4", " ", "p5", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", 
      RowBox[{"k", " ", "t3"}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    SuperscriptBox["p1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    SuperscriptBox["p5", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", "p1", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", 
    SuperscriptBox["p1", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", "p1", " ", "p2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", "p5", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", "p4", " ", "p5", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", 
    SuperscriptBox["p5", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", "p1", " ", "p5", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "k"}], " ", "t1", " ", "t2"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", "p1", " ", "p5", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", 
      RowBox[{"k", " ", 
       SuperscriptBox["t3", "2"]}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"5", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "t1"}], " ", "t2"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "3"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3", "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "4"], " ", "p1", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "3"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3", "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "4"], " ", "p5", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "k"}], "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "3"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3", "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "4"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3", "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "5"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "4"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "5"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"5", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "t3"}], ")"}], "5"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3", "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t3", "+", 
      SuperscriptBox["t3", "2"], "+", 
      SuperscriptBox["t3", "3"], "+", 
      SuperscriptBox["t3", "4"]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{3.716830142352961*^9, 3.717749406289144*^9, 
  3.717919807533205*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Symmetrization and Orbifold Nekrasov function", "Subsection",
 CellChangeTimes->{{3.716814763743575*^9, 3.716814766654924*^9}}],

Cell["\<\
Nekrasov orbifold function is the sum of a generating function of invariant \
monomials (given by six copies of the C3 function, computed on the generators \
of the ring of Z6-invariants) and a Kahler term\
\>", "Text",
 CellChangeTimes->{{3.716830193820829*^9, 3.71683021124794*^9}, {
  3.716830394326852*^9, 3.716830420962422*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FC3", "[", 
   RowBox[{"t1_", ",", "t2_", ",", "t3_", ",", "t4_", ",", "t5_", ",", "k_"}],
    "]"}], ":=", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t1"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t1"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t3"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t3"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "/", "t2"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "/", "t2"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t1", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t1", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t2", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t2", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t3", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t3", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t4", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t4", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t5", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t5", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], ")"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6744033720560493`*^9, 3.674403372806196*^9}, 
   3.674403472934162*^9, {3.685798651440465*^9, 3.685798653178933*^9}, {
   3.709464971485652*^9, 3.709464999637817*^9}, {3.709465033504201*^9, 
   3.709465064467249*^9}, {3.7098117622022123`*^9, 3.7098117675144997`*^9}, {
   3.7177470092131577`*^9, 3.717747036980688*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FKalZ6", "[", 
   RowBox[{
   "p1_", ",", "p2_", ",", "p3_", ",", "p4_", ",", "p5_", ",", "t3_", ",", 
    "t4_", ",", "t5_", ",", "k_"}], "]"}], ":=", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"p1", "+", 
      RowBox[{"1", "/", "p1"}], "+", "p2", "+", 
      RowBox[{"1", "/", "p2"}], "+", "p3", "+", 
      RowBox[{"1", "/", "p3"}], "+", "p4", "+", 
      RowBox[{"1", "/", "p4"}], "+", "p5", "+", 
      RowBox[{"1", "/", "p5"}], "+", 
      RowBox[{"p1", " ", "p2"}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"p1", " ", "p2"}], ")"}]}], "+", 
      RowBox[{"p2", " ", "p3"}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"p2", " ", "p3"}], ")"}]}], "+", 
      RowBox[{"p3", " ", "p4"}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"p3", " ", "p4"}], ")"}]}], "+", 
      RowBox[{"p4", " ", "p5"}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"p4", " ", "p5"}], ")"}]}], "+", "\[IndentingNewLine]", 
      RowBox[{"p1", " ", "p2", " ", "p3"}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"p1", " ", "p2", " ", "p3"}], ")"}]}], "+", 
      RowBox[{"p2", " ", "p3", " ", "p4"}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"p2", " ", "p3", " ", "p4"}], ")"}]}], "+", 
      RowBox[{"p3", " ", "p4", " ", "p5"}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"p3", " ", "p4", " ", "p5"}], ")"}]}], "+", 
      RowBox[{"p1", " ", "p2", " ", "p3", " ", "p4"}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"p1", " ", "p2", " ", "p3", " ", "p4"}], ")"}]}], "+", 
      RowBox[{"p2", " ", "p3", " ", "p4", " ", "p5"}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"p2", " ", "p3", " ", "p4", " ", "p5"}], ")"}]}], "+", 
      RowBox[{"p1", " ", "p2", " ", "p3", " ", "p4", " ", "p5"}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"p1", " ", "p2", " ", "p3", " ", "p4", " ", "p5"}], ")"}]}]}],
      ")"}], " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        SqrtBox[
         FractionBox["t3", "k"]]], "-", 
       SqrtBox[
        FractionBox["t3", "k"]]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SqrtBox["t3"]]}], "+", 
         SqrtBox["t3"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SqrtBox["t4"]]}], "+", 
         SqrtBox["t4"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SqrtBox["t5"]]}], "+", 
         SqrtBox["t5"]}], ")"}]}], ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.709800049685461*^9, 3.7098001425906267`*^9}, {
   3.709800282903933*^9, 3.7098002913052387`*^9}, {3.7098010041146803`*^9, 
   3.709801008186751*^9}, {3.709801741383148*^9, 3.709801768415749*^9}, {
   3.709808631439939*^9, 3.7098086335554943`*^9}, {3.7098111580622053`*^9, 
   3.709811195198132*^9}, {3.709972738438386*^9, 3.709972738496582*^9}, {
   3.710073838997891*^9, 3.7100738528868628`*^9}, {3.710317887526458*^9, 
   3.7103179142862797`*^9}, {3.71032090835084*^9, 3.710320915343544*^9}, {
   3.710321482043655*^9, 3.7103214844483*^9}, {3.710325903517514*^9, 
   3.710325905984568*^9}, {3.710326033782838*^9, 3.710326103612987*^9}, 
   3.71057384482897*^9, {3.710577182750217*^9, 3.7105772292337914`*^9}, {
   3.710589394525379*^9, 3.71058946003518*^9}, 3.710665102734799*^9, {
   3.717749368847967*^9, 3.717749371089725*^9}}],

Cell["\<\
To speed the computation we compute each partition function separately and \
then compare coefficients. The symmetrized exponential is much faster to \
compute if we split it in several terms\
\>", "Text",
 CellChangeTimes->{{3.716830223435986*^9, 3.716830284236353*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TotalLocaZ6", "=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"TotalContributionC2Z6", "[", 
      RowBox[{
      "i", ",", "p0", ",", "p1", ",", "p2", ",", "p3", ",", "p4", ",", "p5"}],
       "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "5"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7103190640552692`*^9, 3.710319119783393*^9}, {
  3.710577345818693*^9, 3.710577350783451*^9}, {3.710589559064365*^9, 
  3.71058956136864*^9}, {3.710648905961156*^9, 3.710648906575918*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TotalSymmZ6terms", "=", 
   RowBox[{
    RowBox[{"Expand", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t1", "/", 
                    RowBox[{"t2", "^", "5"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t2", "^", "6"}], ")"}], "^", "m"}], ",", 
                  RowBox[{"t3", "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], 
                  ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], "//.", 
       RowBox[{"q", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3", " ", "p4", " ",
          "p5"}]}]}], "]"}], "]"}], " ", 
    RowBox[{"Expand", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t1", "^", "2"}], "/", 
                    RowBox[{"t2", "^", "4"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t2", "^", "5"}], "/", 
                    RowBox[{"t1", "^", "1"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], 
                  ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], "//.", 
       RowBox[{"q", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3", " ", "p4", " ",
          "p5"}]}]}], "]"}], "]"}], " ", 
    RowBox[{"Expand", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t1", "^", "3"}], " ", "/", 
                    RowBox[{"t2", "^", "3"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t2", "^", "4"}], "/", " ", 
                    RowBox[{"t1", "^", "2"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], 
                  ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], "//.", 
       RowBox[{"q", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3", " ", "p4", " ",
          "p5"}]}]}], "]"}], "]"}], " ", 
    RowBox[{"Expand", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t1", "^", "4"}], "/", 
                    RowBox[{"t2", "^", "2"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t2", "^", "3"}], "/", " ", 
                    RowBox[{"t1", "^", "3"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], 
                  ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], "//.", 
       RowBox[{"q", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3", " ", "p4", " ",
          "p5"}]}]}], "]"}], "]"}], " ", 
    RowBox[{"Expand", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t1", "^", "5"}], "/", "t2"}], ")"}], "^", "m"}], 
                  ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t2", "^", "2"}], "/", " ", 
                    RowBox[{"t1", "^", "4"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], 
                  ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], "//.", 
       RowBox[{"q", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3", " ", "p4", " ",
          "p5"}]}]}], "]"}], "]"}], " ", 
    RowBox[{"Expand", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t1", "^", "6"}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t2", "^", "1"}], "/", " ", 
                    RowBox[{"t1", "^", "5"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", "m"}]}], 
                  ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], "//.", 
       RowBox[{"q", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3", " ", "p4", " ",
          "p5"}]}]}], "]"}], "]"}], " ", 
    RowBox[{"Expand", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FKalZ6", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", "p1", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "p2", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "p3", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "p4", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "p5", ")"}], "^", "m"}], ",", 
                  RowBox[{"t3", "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
                   RowBox[{"(", " ", "m", ")"}]}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
                    RowBox[{"(", " ", "m", ")"}]}]}], ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], "//.", 
       RowBox[{"q", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3", " ", "p4", " ",
          "p5"}]}]}], "]"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.710318725932705*^9, 3.71031876273708*^9}, {
   3.7105750754773912`*^9, 3.7105750766593924`*^9}, {3.710577232536888*^9, 
   3.710577355130233*^9}, {3.7105777127770977`*^9, 3.710577717153585*^9}, {
   3.7105894806401987`*^9, 3.710589552552101*^9}, 3.710650462073435*^9, 
   3.710674986893334*^9, {3.7106750763078117`*^9, 3.71067508916467*^9}, {
   3.710675134629632*^9, 3.710675270624291*^9}, {3.716828902926806*^9, 
   3.716828903919957*^9}, {3.717749377020899*^9, 3.717749394172448*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CheckcoeffZ6", "[", 
   RowBox[{
   "order_", ",", "n0_", ",", "n1_", ",", "n2_", ",", "n3_", ",", "n4_", ",", 
    "n5_"}], "]"}], ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"PowerExpand", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{
            RowBox[{"Coefficient", "[", 
             RowBox[{
              RowBox[{"Coefficient", "[", 
               RowBox[{
                RowBox[{"Coefficient", "[", 
                 RowBox[{"TotalSymmZ6terms", ",", "p0", ",", "n0"}], "]"}], 
                ",", "p1", ",", "n1"}], "]"}], ",", "p2", ",", "n2"}], "]"}], 
            ",", "p3", ",", "n3"}], "]"}], ",", "p4", ",", "n4"}], "]"}], ",",
         "p5", ",", "n5"}], "]"}], "//.", 
      RowBox[{"k", "\[Rule]", 
       RowBox[{"t1", " ", "t2", " ", "t3"}]}]}], "]"}], " ", "-", "\n", 
    RowBox[{"PowerExpand", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{
            RowBox[{"Coefficient", "[", 
             RowBox[{
              RowBox[{"Coefficient", "[", 
               RowBox[{
                RowBox[{"Coefficient", "[", 
                 RowBox[{"TotalLocaZ6", ",", "p0", ",", "n0"}], "]"}], ",", 
                "p1", ",", "n1"}], "]"}], ",", "p2", ",", "n2"}], "]"}], ",", 
            "p3", ",", "n3"}], "]"}], ",", "p4", ",", "n4"}], "]"}], ",", 
        "p5", ",", "n5"}], "]"}], "//.", 
      RowBox[{"k", "\[Rule]", 
       RowBox[{"t1", " ", "t2", " ", "t3"}]}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.709801230318844*^9, 3.709801292112351*^9}, 
   3.7098014386962843`*^9, {3.709801512078055*^9, 3.709801584676147*^9}, {
   3.709801658557428*^9, 3.709801712918518*^9}, {3.709801801223412*^9, 
   3.709801811408842*^9}, {3.709802006041431*^9, 3.709802037016217*^9}, {
   3.7098021223158607`*^9, 3.7098021223716593`*^9}, {3.709802308716028*^9, 
   3.709802315360991*^9}, {3.709802399964591*^9, 3.709802409599578*^9}, {
   3.709802440664639*^9, 3.7098024634166737`*^9}, {3.7098025631464157`*^9, 
   3.7098026364575167`*^9}, {3.7098027373052263`*^9, 
   3.7098027502936773`*^9}, {3.70980287397756*^9, 3.709802931392337*^9}, {
   3.7098029840396013`*^9, 3.7098029841459723`*^9}, {3.709803027964568*^9, 
   3.709803030456292*^9}, {3.709803258589994*^9, 3.7098032961555033`*^9}, {
   3.7098050060851097`*^9, 3.709805049994216*^9}, {3.70980510311948*^9, 
   3.709805165391273*^9}, {3.70980521532803*^9, 3.709805228887878*^9}, {
   3.7098056856537447`*^9, 3.709805687434853*^9}, {3.7098066800874443`*^9, 
   3.709806717585905*^9}, {3.7098067606485767`*^9, 3.709806779942554*^9}, {
   3.709807256477849*^9, 3.709807287942749*^9}, {3.709807518393207*^9, 
   3.709807540112265*^9}, {3.709807632071225*^9, 3.709807644936674*^9}, {
   3.7098077092555323`*^9, 3.709807717896744*^9}, {3.709807926332507*^9, 
   3.709807927817779*^9}, {3.709808554146041*^9, 3.709808605385367*^9}, 
   3.70980863894615*^9, {3.709808933563208*^9, 3.709808935559516*^9}, {
   3.709808972265918*^9, 3.709808972319015*^9}, {3.709811241651187*^9, 
   3.709811293242934*^9}, {3.709811340568644*^9, 3.7098113578167067`*^9}, {
   3.7098113938671017`*^9, 3.709811401261002*^9}, {3.709811499165019*^9, 
   3.70981150915385*^9}, {3.7098115399523687`*^9, 3.7098115426787*^9}, {
   3.709811702389453*^9, 3.709811708584779*^9}, 3.709919214027174*^9, {
   3.709919287751693*^9, 3.7099192906814013`*^9}, {3.709919330755711*^9, 
   3.709919356894569*^9}, {3.709919393882804*^9, 3.7099194665185423`*^9}, {
   3.709919962264369*^9, 3.709919990810166*^9}, {3.7099201647229853`*^9, 
   3.709920166933949*^9}, {3.7099727140162277`*^9, 3.7099727140971212`*^9}, {
   3.709972806873467*^9, 3.709972931874864*^9}, {3.710073827448523*^9, 
   3.710073829057536*^9}, {3.710073916984509*^9, 3.71007392250393*^9}, {
   3.7103187918472977`*^9, 3.710318801443994*^9}, 3.710319137985703*^9, {
   3.7105739032216883`*^9, 3.710573908870428*^9}, {3.710577357495666*^9, 
   3.7105773914126863`*^9}, {3.710589564356279*^9, 3.71058959126013*^9}, {
   3.710590427165216*^9, 3.710590429226152*^9}, {3.7106753161275873`*^9, 
   3.71067531652562*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CheckcoeffZ6List", "[", 
   RowBox[{"n_", ",", "list_"}], "]"}], ":=", 
  RowBox[{"CheckcoeffZ6", "[", 
   RowBox[{"n", ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "3", "]"}], "]"}], ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "4", "]"}], "]"}], ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "5", "]"}], "]"}], ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "6", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7103192660955753`*^9, 3.710319317190687*^9}, {
  3.710577395276349*^9, 3.710577407832775*^9}, {3.710589596537298*^9, 
  3.710589598219802*^9}, {3.71059063376313*^9, 3.710590636457033*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ6List", "[", 
    RowBox[{"1", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"1", ",", "6"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.710319604850749*^9, 3.710319633592993*^9}, {
  3.710319708824301*^9, 3.7103197454653788`*^9}, {3.710319807180949*^9, 
  3.710319811461013*^9}, {3.710574250497073*^9, 3.710574252304381*^9}, {
  3.710577410425535*^9, 3.710577413482637*^9}, {3.710589599966507*^9, 
  3.710589603596854*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.710675423492683*^9, 3.71682610688308*^9, 
  3.7177495148524313`*^9, 3.717919923665886*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ6List", "[", 
    RowBox[{"2", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"2", ",", "6"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.710319604850749*^9, 3.710319633592993*^9}, {
  3.710319708824301*^9, 3.7103197454653788`*^9}, {3.710319807180949*^9, 
  3.710319811461013*^9}, {3.710574250497073*^9, 3.710574252304381*^9}, {
  3.710577410425535*^9, 3.710577413482637*^9}, {3.710589599966507*^9, 
  3.710589603596854*^9}, {3.710675338531725*^9, 3.7106753405722437`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.710675456958692*^9, 3.7168261397211323`*^9, 
  3.717749549176958*^9, 3.717919957650544*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ6List", "[", 
    RowBox[{"3", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"3", ",", "6"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.710319604850749*^9, 3.710319633592993*^9}, {
  3.710319708824301*^9, 3.7103197454653788`*^9}, {3.710319807180949*^9, 
  3.710319811461013*^9}, {3.710574250497073*^9, 3.710574252304381*^9}, {
  3.710577410425535*^9, 3.710577413482637*^9}, {3.710589599966507*^9, 
  3.710589603596854*^9}, {3.710675342341401*^9, 3.710675344246108*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.710675565152604*^9, 3.716826246045278*^9, 
  3.717749654743677*^9, 3.717920062910493*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ6List", "[", 
    RowBox[{"4", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"4", ",", "6"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.710319604850749*^9, 3.710319633592993*^9}, {
  3.710319708824301*^9, 3.7103197454653788`*^9}, {3.710319807180949*^9, 
  3.710319811461013*^9}, {3.710574250497073*^9, 3.710574252304381*^9}, {
  3.710577410425535*^9, 3.710577413482637*^9}, {3.710589599966507*^9, 
  3.710589603596854*^9}, {3.710675346263682*^9, 3.710675348036153*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.710675861563532*^9, 3.716826529327655*^9, 
  3.7177499378846407`*^9, 3.7179203369812517`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffZ6List", "[", 
    RowBox[{"5", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"5", ",", "6"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.710319604850749*^9, 3.710319633592993*^9}, {
  3.710319708824301*^9, 3.7103197454653788`*^9}, {3.710319807180949*^9, 
  3.710319811461013*^9}, {3.710574250497073*^9, 3.710574252304381*^9}, {
  3.710577410425535*^9, 3.710577413482637*^9}, {3.710589599966507*^9, 
  3.710589603596854*^9}, {3.710675349951335*^9, 3.710675351898332*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.710676531448029*^9, 3.7168272136616096`*^9, 
  3.717750634883787*^9, 3.71792103182276*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["C3 / Z2 x Z2 orbifold", "Chapter",
 CellChangeTimes->{{3.716812550607292*^9, 3.716812558863729*^9}}],

Cell["\<\
Now we consider C3 / Z2 x Z2 singularities. The resolutions is still made of \
P1.\
\>", "Text",
 CellChangeTimes->{{3.716632463980497*^9, 3.716632484273687*^9}}],

Cell[CellGroupData[{

Cell["Localization", "Subsection",
 CellChangeTimes->{{3.716814763743575*^9, 3.716814766654924*^9}, {
  3.716830179157219*^9, 3.716830180365514*^9}}],

Cell["\<\
The weight decomposition of the vector spaces V is labelled by the conjugacy \
class (r1,r2) with ri=0,1. \
\>", "Text",
 CellChangeTimes->{{3.716892464178721*^9, 3.716892487532125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PPVC3Z2Z2", "[", 
   RowBox[{
   "l_List", ",", "t1_", ",", "t2_", ",", "t3_", ",", "r1_", ",", "r2_"}], 
   "]"}], ":=", 
  RowBox[{"Total", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"t1", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "i"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"t2", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "j"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"t3", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "k"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"KroneckerDelta", "[", 
          RowBox[{
           RowBox[{"Mod", "[", 
            RowBox[{
             RowBox[{"i", "+", "k"}], ",", "2"}], "]"}], ",", "r1"}], "]"}], 
         " ", 
         RowBox[{"KroneckerDelta", "[", 
          RowBox[{
           RowBox[{"Mod", "[", 
            RowBox[{
             RowBox[{"j", "+", "k"}], ",", "2"}], "]"}], ",", "r2"}], "]"}]}],
         ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "l", "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"j", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"l", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"l", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "}"}]}], 
       "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.686379554935748*^9, 3.686379579737492*^9}, {
  3.6863839728856087`*^9, 3.686383977499597*^9}}],

Cell["\<\
The virtual tangent space is given by taking invariant modules\
\>", "Text",
 CellChangeTimes->{{3.7168924936349*^9, 3.716892505803646*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TvirC3Z2Z2fixed", "[", 
   RowBox[{"list_", ",", "t1_", ",", "t2_", ",", "t3_", ",", "k_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"PPVC3Z2Z2", "[", 
    RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0", ",", "0"}], 
    "]"}], "-", 
   RowBox[{
    RowBox[{"PPVC3Z2Z2", "[", 
     RowBox[{"list", ",", 
      RowBox[{"1", "/", "t1"}], ",", 
      RowBox[{"1", "/", "t2"}], ",", 
      RowBox[{"1", "/", "t3"}], ",", "0", ",", "0"}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", " ", "t2", " ", "t3"}], ")"}]}], "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{
          "list", ",", "t1", ",", "t2", ",", "t3", ",", "0", ",", "0"}], 
          "]"}], 
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "0", ",", "0"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{
          "list", ",", "t1", ",", "t2", ",", "t3", ",", "1", ",", "0"}], 
          "]"}], 
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "1", ",", "0"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{
          "list", ",", "t1", ",", "t2", ",", "t3", ",", "0", ",", "1"}], 
          "]"}], 
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "0", ",", "1"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{
          "list", ",", "t1", ",", "t2", ",", "t3", ",", "1", ",", "1"}], 
          "]"}], 
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "1", ",", "1"}], "]"}]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"t1", " ", "t2", " ", "t3"}]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{
          "list", ",", "t1", ",", "t2", ",", "t3", ",", "1", ",", "0"}], 
          "]"}], 
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "0", ",", "0"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{
          "list", ",", "t1", ",", "t2", ",", "t3", ",", "0", ",", "0"}], 
          "]"}], 
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "1", ",", "0"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{
          "list", ",", "t1", ",", "t2", ",", "t3", ",", "0", ",", "1"}], 
          "]"}], 
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "1", ",", "1"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{
          "list", ",", "t1", ",", "t2", ",", "t3", ",", "1", ",", "1"}], 
          "]"}], 
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "0", ",", "1"}], "]"}]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"t1", "-", 
        RowBox[{"t2", " ", "t3"}]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{
          "list", ",", "t1", ",", "t2", ",", "t3", ",", "0", ",", "1"}], 
          "]"}], 
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "0", ",", "0"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{
          "list", ",", "t1", ",", "t2", ",", "t3", ",", "0", ",", "0"}], 
          "]"}], 
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "0", ",", "1"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{
          "list", ",", "t1", ",", "t2", ",", "t3", ",", "1", ",", "0"}], 
          "]"}], 
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "1", ",", "1"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{
          "list", ",", "t1", ",", "t2", ",", "t3", ",", "1", ",", "1"}], 
          "]"}], 
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "1", ",", "0"}], "]"}]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"t2", "-", 
        RowBox[{"t1", "  ", "t3"}]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{
          "list", ",", "t1", ",", "t2", ",", "t3", ",", "0", ",", "0"}], 
          "]"}], 
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "1", ",", "1"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{
          "list", ",", "t1", ",", "t2", ",", "t3", ",", "1", ",", "1"}], 
          "]"}], 
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "0", ",", "0"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{
          "list", ",", "t1", ",", "t2", ",", "t3", ",", "1", ",", "0"}], 
          "]"}], 
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "0", ",", "1"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{
          "list", ",", "t1", ",", "t2", ",", "t3", ",", "0", ",", "1"}], 
          "]"}], 
         RowBox[{"PPVC3Z2Z2", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "1", ",", "0"}], "]"}]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"t3", "-", 
        RowBox[{"t1", " ", "t2"}]}], " ", ")"}]}]}], " ", ")"}]}]}]], "Input",\

 CellChangeTimes->{{3.686384028301819*^9, 3.6863842883889637`*^9}, {
   3.686384324933093*^9, 3.686384328355666*^9}, 3.7110925586440163`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{"TvirC3Z2Z2fixed", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"PlanePartitions", "[", "12", "]"}], "[", 
     RowBox[{"[", "12", "]"}], "]"}], ",", "t1", ",", "t2", ",", "t3", ",", 
    "k"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6863843150879097`*^9, 3.686384317311881*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"t1", " ", 
     SuperscriptBox["t2", "3"]}], 
    SuperscriptBox["t3", "5"]]}], "+", 
  FractionBox["t1", 
   RowBox[{"t2", " ", 
    SuperscriptBox["t3", "3"]}]], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["t2", "2"]}], 
   SuperscriptBox["t3", "2"]], "+", 
  FractionBox["t1", 
   RowBox[{"t2", " ", "t3"}]], "-", 
  FractionBox[
   RowBox[{"3", " ", "t1", " ", "t2"}], "t3"], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["t3", "2"]}], "-", 
  RowBox[{
   SuperscriptBox["t2", "2"], " ", 
   SuperscriptBox["t3", "2"]}], "-", 
  FractionBox[
   RowBox[{"2", " ", "t1", " ", 
    SuperscriptBox["t3", "3"]}], "t2"], "-", 
  RowBox[{
   SuperscriptBox["t2", "2"], " ", 
   SuperscriptBox["t3", "4"]}], "+", 
  FractionBox[
   SuperscriptBox["t3", "6"], 
   SuperscriptBox["t2", "2"]]}]], "Output",
 CellChangeTimes->{3.686384333541026*^9, 3.687610370433063*^9, 
  3.711089520821184*^9, 3.711172203675872*^9, 3.716832249753222*^9, 
  3.716870181730219*^9, 3.717750859421101*^9, 3.717753142574245*^9, 
  3.717850538738628*^9, 3.717921249866416*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"NBC3Z2Z2", "[", 
   RowBox[{"l_List", ",", "r1_", ",", "r2_"}], "]"}], ":=", 
  RowBox[{"PPVC3Z2Z2", "[", 
   RowBox[{"l", ",", "1", ",", "1", ",", "1", ",", "r1", ",", "r2"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.68638439822931*^9, 3.686384418923647*^9}}],

Cell["The localization computation", "Text",
 CellChangeTimes->{{3.71689252018242*^9, 3.716892523349234*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"VirtualTC3Z2Z2", "[", 
    RowBox[{"nboxes_", ",", "fixedpoint_"}], "]"}], ":=", 
   RowBox[{"Expand", "[", 
    RowBox[{"TvirC3Z2Z2fixed", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
       RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", "t2", ",", 
      "t3", ",", "k"}], "]"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FPListC3Z2Z2", "[", 
    RowBox[{"nboxes_", ",", "fixedpoint_"}], "]"}], ":=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Reap", "[", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Flatten", "[", 
                RowBox[{"List", "@@", 
                 RowBox[{"(", 
                  RowBox[{"Expand", "[", 
                   RowBox[{"TvirC3Z2Z2fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
                "//.", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"t1", "\[Rule]", "1"}], ",", 
                 RowBox[{"t2", "->", "1"}], ",", 
                 RowBox[{"t3", "\[Rule]", "1"}], ",", 
                 RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
             RowBox[{"[", "i", "]"}], "]"}], ">", "0"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Sow", "[", 
            RowBox[{"{", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
                 RowBox[{"List", "@@", 
                  RowBox[{"(", 
                   RowBox[{"Expand", "[", 
                    RowBox[{"TvirC3Z2Z2fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], 
                 "\[IndentingNewLine]", "]"}], "[", 
                RowBox[{"[", "i", "]"}], "]"}], "/", 
               RowBox[{"(", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Flatten", "[", 
                    RowBox[{"List", "@@", 
                    RowBox[{"(", 
                    RowBox[{"Expand", "[", 
                    RowBox[{"TvirC3Z2Z2fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
                    "//.", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"t1", "\[Rule]", "1"}], ",", 
                    RowBox[{"t2", "->", "1"}], ",", 
                    RowBox[{"t3", "\[Rule]", "1"}], ",", 
                    RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "\[IndentingNewLine]", 
                ")"}]}], ",", 
              RowBox[{
               RowBox[{"(", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Flatten", "[", 
                  RowBox[{"List", "@@", 
                   RowBox[{"(", 
                    RowBox[{"Expand", "[", 
                    RowBox[{"TvirC3Z2Z2fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
                  "//.", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"t1", "\[Rule]", "1"}], ",", 
                   RowBox[{"t2", "->", "1"}], ",", 
                   RowBox[{"t3", "\[Rule]", "1"}], ",", 
                   RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "\[IndentingNewLine]", "}"}],
             "]"}]}], "\[IndentingNewLine]", "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", 
            RowBox[{"Flatten", "[", 
             RowBox[{"List", "@@", 
              RowBox[{"(", 
               RowBox[{"Expand", "[", 
                RowBox[{"TvirC3Z2Z2fixed", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                   RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                  "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}], 
            "]"}]}], "}"}]}], "]"}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ahatp", "[", "list_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"k", "/", 
           RowBox[{"list", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"list", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "/", "k"}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"list", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"list", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], ")"}], "^", 
    RowBox[{"list", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LocalizationC3Z2Z2", "[", 
    RowBox[{
    "nboxes_", ",", "fixedpoint_", ",", "p0_", ",", "p1_", ",", "p2_", ",", 
     "p3_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Cancel", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{"Times", "@@", 
       RowBox[{"Map", "[", 
        RowBox[{"ahatp", ",", 
         RowBox[{"FPListC3Z2Z2", "[", 
          RowBox[{"nboxes", ",", "fixedpoint"}], "]"}]}], "]"}]}], "]"}], 
     "]"}], " ", 
    RowBox[{"p0", "^", 
     RowBox[{"NBC3Z2Z2", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
        RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "0", ",", "0"}], 
      "]"}]}], " ", 
    RowBox[{"p1", "^", 
     RowBox[{"NBC3Z2Z2", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
        RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "1", ",", "0"}], 
      "]"}]}], 
    RowBox[{"p2", "^", 
     RowBox[{"NBC3Z2Z2", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
        RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "0", ",", "1"}], 
      "]"}]}], 
    RowBox[{"p3", "^", 
     RowBox[{"NBC3Z2Z2", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
        RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "1", ",", "1"}], 
      "]"}]}]}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TotalContributionC3Z2Z2", "[", 
   RowBox[{"nboxes_", ",", "p0_", ",", "p1_", ",", "p2_", ",", "p3_"}], "]"}],
   ":=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{"LocalizationC3Z2Z2", "[", 
     RowBox[{"nboxes", ",", "i", ",", "p0", ",", "p1", ",", "p2", ",", "p3"}],
      "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", 
       RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "]"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.67509769824366*^9, 3.675097742433045*^9}, {
   3.675097787395336*^9, 3.67509779944084*^9}, {3.675097856209297*^9, 
   3.675097941379383*^9}, 3.675098012939138*^9, {3.675101981572866*^9, 
   3.675102132977907*^9}, {3.679138392316263*^9, 3.679138397170555*^9}, {
   3.679139098659503*^9, 3.679139114360139*^9}, {3.685794841789722*^9, 
   3.685794885068252*^9}, {3.685797044333329*^9, 3.685797110123225*^9}, {
   3.6857971441185102`*^9, 3.6857971449891253`*^9}, {3.686384499930094*^9, 
   3.686384609668186*^9}, {3.6863846720672607`*^9, 3.686384675818647*^9}, 
   3.7168321130305367`*^9, {3.716892514651573*^9, 3.716892534327982*^9}}],

Cell["Then we can write the partition function", "Text",
 CellChangeTimes->{{3.716892696878521*^9, 3.716892701296094*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PartitionFunctionC3Z2Z2", "[", "nboxes_", "]"}], ":=", 
  RowBox[{"1", "+", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"TotalContributionC3Z2Z2", "[", 
      RowBox[{"n", ",", "p0", ",", "p1", ",", "p2", ",", "p3"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "nboxes"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.716804618813366*^9, 3.716804627198197*^9}, {
  3.716806034437278*^9, 3.716806034503093*^9}, {3.7168147258786716`*^9, 
  3.716814733736116*^9}, {3.716818331008473*^9, 3.7168183311061287`*^9}, {
  3.716819553104373*^9, 3.7168195588853283`*^9}, {3.716830115413805*^9, 
  3.716830120998564*^9}, {3.716832120846491*^9, 3.716832132409144*^9}}],

Cell["\<\
The \[OpenCurlyQuote]flatten\[CloseCurlyQuote] notices come from instances \
where the virtual tangent space vanishes and the program is trying to flatten \
an empty list (in the partition function they are the terms with coefficient \
1). In principle they could be removed with some cosmetics in the \
localization routine\
\>", "Text",
 CellChangeTimes->{{3.71689271012679*^9, 3.716892797414214*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PartitionFunctionC3Z2Z2", "[", "5", "]"}]], "Input",
 CellChangeTimes->{
  3.716804640930531*^9, {3.716814736590336*^9, 3.716814740839767*^9}, {
   3.7168195614985437`*^9, 3.716819561559877*^9}, {3.7168301400951643`*^9, 
   3.7168301401467333`*^9}, 3.7168321392366447`*^9, 3.716832293932126*^9}],

Cell[BoxData[
 TemplateBox[{
  "Flatten","normal",
   "\"Nonatomic expression expected at position \
\\!\\(\\*RowBox[{\\\"1\\\"}]\\) in \\!\\(\\*RowBox[{\\\"Flatten\\\", \
\\\"[\\\", \\\"0\\\", \\\"]\\\"}]\\).\"",2,193,2,27623743715054181559,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7168322498382463`*^9, 3.716832294780447*^9, 
  3.716870181837551*^9, 3.717750859505374*^9, 3.717753142686668*^9, 
  3.717850538885384*^9, 3.7179212500061817`*^9}],

Cell[BoxData[
 TemplateBox[{
  "Flatten","normal",
   "\"Nonatomic expression expected at position \
\\!\\(\\*RowBox[{\\\"1\\\"}]\\) in \\!\\(\\*RowBox[{\\\"Flatten\\\", \
\\\"[\\\", \\\"0\\\", \\\"]\\\"}]\\).\"",2,193,3,27623743715054181559,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7168322498382463`*^9, 3.716832294780447*^9, 
  3.716870181837551*^9, 3.717750859505374*^9, 3.717753142686668*^9, 
  3.717850538885384*^9, 3.717921250018073*^9}],

Cell[BoxData[
 TemplateBox[{
  "Flatten","normal",
   "\"Nonatomic expression expected at position \
\\!\\(\\*RowBox[{\\\"1\\\"}]\\) in \\!\\(\\*RowBox[{\\\"Flatten\\\", \
\\\"[\\\", \\\"0\\\", \\\"]\\\"}]\\).\"",2,193,4,27623743715054181559,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7168322498382463`*^9, 3.716832294780447*^9, 
  3.716870181837551*^9, 3.717750859505374*^9, 3.717753142686668*^9, 
  3.717850538885384*^9, 3.717921250083386*^9}],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"Flatten\\\", \
\\\"::\\\", \\\"normal\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,193,5,27623743715054181559,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7168322498382463`*^9, 3.716832294780447*^9, 
  3.716870181837551*^9, 3.717750859505374*^9, 3.717753142686668*^9, 
  3.717850538885384*^9, 3.717921250090221*^9}],

Cell[BoxData[
 RowBox[{"1", "+", "p0", "+", 
  RowBox[{"p0", " ", "p1", " ", "p2"}], "+", 
  RowBox[{"p0", " ", "p1", " ", "p3"}], "+", 
  RowBox[{"p0", " ", "p2", " ", "p3"}], "+", 
  RowBox[{"p0", " ", 
   SuperscriptBox["p1", "2"], " ", "p2", " ", "p3"}], "+", 
  RowBox[{"p0", " ", "p1", " ", 
   SuperscriptBox["p2", "2"], " ", "p3"}], "+", 
  RowBox[{"p0", " ", "p1", " ", "p2", " ", 
   SuperscriptBox["p3", "2"]}], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", 
      SuperscriptBox["t1", "2"]}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", 
      SuperscriptBox["t1", "2"]}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    SuperscriptBox["p1", "2"], " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", 
      SuperscriptBox["t1", "2"]}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    SuperscriptBox["p1", "2"], " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", 
      SuperscriptBox["t1", "2"]}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    SuperscriptBox["p1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t1", "4"]}], ")"}]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["t1", "2"]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["t1", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", 
    SuperscriptBox["p1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t1", "4"]}], ")"}]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["t1", "2"]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["t1", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t1", "2"]}], "-", 
      SuperscriptBox["t2", "2"]}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      SuperscriptBox["t2", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", 
      SuperscriptBox["t2", "2"]}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", 
      SuperscriptBox["t2", "2"]}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", 
    SuperscriptBox["p2", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", 
      SuperscriptBox["t2", "2"]}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    SuperscriptBox["p2", "2"], " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", 
      SuperscriptBox["t2", "2"]}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", "p1", " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", 
      SuperscriptBox["t2", "2"]}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["t1", "2"]}], "+", 
      RowBox[{"k", " ", 
       SuperscriptBox["t2", "2"]}]}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["t1", "2"]}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    SuperscriptBox["p2", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t2", "4"]}], ")"}]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["t2", "2"]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["t2", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", 
    SuperscriptBox["p2", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t2", "4"]}], ")"}]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["t2", "2"]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["t2", "2"]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t1", "2"]}], "-", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1", " ", "t2"}], "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"t1", " ", "t2"}], "-", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1", " ", "t2"}], "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"t1", " ", "t2"}], "-", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["t1", "2"]}], "+", 
      RowBox[{"k", " ", 
       SuperscriptBox["t2", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1", " ", "t2"}], "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["t1", "2"]}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"t1", " ", "t2"}], "-", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"t1", " ", "t2"}], "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "k"}], " ", "t2"}], "+", 
      RowBox[{"t1", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", 
      RowBox[{"t2", " ", "t3"}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"t1", " ", "t2"}], "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t2"}], "+", 
      RowBox[{"t1", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"t2", " ", "t3"}]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t1", "2"]}], "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t1", "2"]}], "-", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"t1", " ", "t2"}], "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "k"}], " ", "t2"}], "+", 
      RowBox[{"t1", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t1", "2"]}], "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"5", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"t1", " ", "t2"}], "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t2"}], "+", 
      RowBox[{"t1", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t2"}], "+", 
      RowBox[{"k", " ", "t1", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t1", "2"]}], "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t2"}], "+", 
      RowBox[{"t1", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t2", "2"]}], "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t2", "2"], "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["t1", "2"]}], "+", 
      RowBox[{"k", " ", 
       SuperscriptBox["t2", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"t1", " ", "t2"}], "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "k"}], " ", "t1"}], "+", 
      RowBox[{"t2", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t2", "2"]}], "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"5", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["t1", "2"]}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"t1", " ", "t2"}], "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t1"}], "+", 
      RowBox[{"t2", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t2", "2"], "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t1"}], "+", 
      RowBox[{"k", " ", "t2", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t2", "2"]}], "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t1"}], "+", 
      RowBox[{"t2", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t2", "2"], "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", 
    SuperscriptBox["p3", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p2", " ", 
    SuperscriptBox["p3", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SqrtBox["k"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", "p1", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t2"}], "+", 
      RowBox[{"k", " ", "t1", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t2"}], "+", 
      RowBox[{"t1", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t1"}], "+", 
      RowBox[{"k", " ", "t2", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t1"}], "+", 
      RowBox[{"t2", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t2"}], "+", 
      RowBox[{"k", " ", "t1", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      RowBox[{"k", " ", 
       SuperscriptBox["t3", "2"]}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{"t2", "-", 
      RowBox[{"t1", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t2", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t2", "2"], "-", 
      RowBox[{"k", " ", 
       SuperscriptBox["t3", "2"]}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"t2", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t2", "2"], "-", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "k"}], " ", "t2"}], "+", 
      RowBox[{"t1", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", 
      RowBox[{"t2", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      RowBox[{"k", " ", 
       SuperscriptBox["t3", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t2", "2"], "-", 
      RowBox[{"k", " ", 
       SuperscriptBox["t3", "2"]}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"5", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{"t2", "-", 
      RowBox[{"t1", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t1"}], "+", 
      RowBox[{"t2", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t2", "2"], "-", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["t1", "2"]}], "+", 
      RowBox[{"k", " ", 
       SuperscriptBox["t3", "2"]}]}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["t1", "2"]}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["t2", "2"]}], "+", 
      RowBox[{"k", " ", 
       SuperscriptBox["t3", "2"]}]}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["t2", "2"]}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", 
    SuperscriptBox["p3", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "4"]}], ")"}]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["t3", "2"]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "3"], " ", 
    SuperscriptBox["p3", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "4"]}], ")"}]}], 
   RowBox[{"k", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["t3", "2"]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["t3", "2"]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{3.716832251688496*^9, 3.7168322964410143`*^9, 
  3.716870183577649*^9, 3.717750861152315*^9, 3.717753144649506*^9, 
  3.717850540652706*^9, 3.717921251681632*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Symmetrization and Nekrasov Orbifold function", "Subsection",
 CellChangeTimes->{{3.716814763743575*^9, 3.716814766654924*^9}, {
  3.716830179157219*^9, 3.716830180365514*^9}, {3.716832009423503*^9, 
  3.716832026929304*^9}}],

Cell["\<\
Here we write down Nekrasov orbifold function, given by a kahler term and \
four copies of the C3 function computed on the generators of invariant \
monomials\
\>", "Text",
 CellChangeTimes->{{3.7168928110383453`*^9, 3.7168928535853977`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ahatk", "[", 
   RowBox[{"x_", ",", "k_"}], "]"}], ":=", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{"k", "/", "x"}], "]"}], "-", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"x", "/", "k"}], "]"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Sqrt", "[", "x", "]"}], "-", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "/", "x"}], "]"}]}], ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.711171797177607*^9, 3.71117183410415*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FC3", "[", 
   RowBox[{"t1_", ",", "t2_", ",", "t3_", ",", "t4_", ",", "t5_", ",", "k_"}],
    "]"}], ":=", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t1"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t1"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t3"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", "t3"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "/", "t2"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "/", "t2"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t1", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t1", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t2", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t2", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t3", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t3", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t4", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t4", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t5", "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}]}], "-", 
         RowBox[{"t5", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], ")"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6744033720560493`*^9, 3.674403372806196*^9}, 
   3.674403472934162*^9, {3.685798651440465*^9, 3.685798653178933*^9}, {
   3.709464971485652*^9, 3.709464999637817*^9}, {3.709465033504201*^9, 
   3.709465064467249*^9}, {3.7098117622022123`*^9, 3.7098117675144997`*^9}, {
   3.7177470092131577`*^9, 3.717747036980688*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FKalC3Z2Z2", "[", 
   RowBox[{
   "p1_", ",", "p2_", ",", "p3_", ",", "t1_", ",", "t2_", ",", "t3_", ",", 
    "t4_", ",", "t5_", ",", "k_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"PowerExpand", "[", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SqrtBox["t4"]]}], "+", 
         SqrtBox["t4"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SqrtBox["t5"]]}], "+", 
         SqrtBox["t5"]}], ")"}]}], ")"}]}], "]"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p2", " ", "p3"}], "+", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"p2", " ", "p3"}], ")"}]}]}], ")"}], "  ", 
       RowBox[{"ahatk", "[", " ", 
        RowBox[{
         RowBox[{"t1", "^", "2"}], ",", "k"}], "]"}]}], "]"}], "+", " ", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p1", " ", "p3"}], "+", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"p1", " ", "p3"}], ")"}]}]}], ")"}], "  ", 
       RowBox[{"ahatk", "[", 
        RowBox[{
         RowBox[{"t2", "^", "2"}], ",", "k"}], "]"}]}], "]"}], "+", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p1", " ", "p2"}], "+", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"p1", " ", "p2"}], ")"}]}]}], ")"}], "  ", 
       RowBox[{"ahatk", "[", 
        RowBox[{
         RowBox[{"t3", "^", "2"}], ",", "k"}], "]"}]}], "]"}], "-", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "p1"}], " ", "p2", " ", "p3"}], "-", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"p1", " ", "p2", " ", "p3"}], ")"}]}], "-", "p1", "-", 
        RowBox[{"1", "/", "p1"}], "-", "p2", "-", 
        RowBox[{"1", "/", "p2"}], "-", "p3", "-", 
        RowBox[{"1", "/", "p3"}]}], ")"}], "]"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.7111316576303873`*^9, 3.711131662190271*^9}, {
   3.7111317011665983`*^9, 3.711131710911627*^9}, {3.711131820331976*^9, 
   3.7111318284227457`*^9}, {3.711132011661046*^9, 3.711132039497615*^9}, {
   3.711171109633575*^9, 3.711171218417726*^9}, {3.711171286271162*^9, 
   3.711171303346005*^9}, {3.7111713406412582`*^9, 3.71117135580755*^9}, {
   3.711171716273005*^9, 3.711171733417727*^9}, 3.7111720561417723`*^9, {
   3.711172239612151*^9, 3.7111722519562798`*^9}, {3.7111723108104486`*^9, 
   3.711172402348974*^9}, {3.7111724356898823`*^9, 3.711172468997695*^9}, {
   3.711172542185544*^9, 3.711172592384335*^9}, {3.71117266152417*^9, 
   3.711172781998143*^9}, {3.7111728573907433`*^9, 3.711172881340345*^9}, {
   3.71117322227382*^9, 3.711173233338018*^9}, {3.711173330764266*^9, 
   3.711173343172544*^9}, {3.711183056491228*^9, 3.7111830566998053`*^9}, {
   3.711184998101515*^9, 3.711185019758725*^9}, {3.7111850801014967`*^9, 
   3.711185088135078*^9}, {3.7111851347154207`*^9, 3.7111851457194023`*^9}, {
   3.7111852525859737`*^9, 3.711185260409176*^9}, {3.711185404683519*^9, 
   3.711185420706657*^9}, {3.716834256332378*^9, 3.716834257469205*^9}}],

Cell["\<\
Now we check this formula against the direct localization computation, order \
\
\>", "Text",
 CellChangeTimes->{{3.7168928666008453`*^9, 3.7168928806057863`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TotalSymmC3Z2Z2Terms", "=", 
   RowBox[{
    RowBox[{"Expand", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FKalC3Z2Z2", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", "p1", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "p2", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "p3", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "t1", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "t2", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", "t3", ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
                   RowBox[{"(", " ", "m", ")"}]}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
                    RowBox[{"(", " ", "m", ")"}]}]}], ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], "//.", 
       RowBox[{"q", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}]}]}], "]"}], 
     "]"}], 
    RowBox[{"Expand", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t1", "^", "2"}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t2", "^", "2"}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t3", "/", 
                    RowBox[{"(", 
                    RowBox[{"t1", " ", "t2"}], ")"}]}], ")"}], "^", "m"}], 
                  ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
                   RowBox[{"(", " ", "m", ")"}]}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
                    RowBox[{"(", " ", "m", ")"}]}]}], ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], "//.", 
       RowBox[{"q", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}]}]}], "]"}], 
     "]"}], 
    RowBox[{"Expand", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t1", "^", "2"}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t2", "/", 
                    RowBox[{"(", 
                    RowBox[{"t1", " ", "t3"}], ")"}]}], ")"}], "^", "m"}], 
                  ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t3", "^", "2"}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
                   RowBox[{"(", " ", "m", ")"}]}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
                    RowBox[{"(", " ", "m", ")"}]}]}], ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], "//.", 
       RowBox[{"q", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}]}]}], "]"}], 
     "]"}], 
    RowBox[{"Expand", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t1", "/", 
                    RowBox[{"(", 
                    RowBox[{"t2", " ", "t3"}], ")"}]}], ")"}], "^", "m"}], 
                  ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t2", "^", "2"}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t3", "^", "2"}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
                   RowBox[{"(", " ", "m", ")"}]}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
                    RowBox[{"(", " ", "m", ")"}]}]}], ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], "//.", 
       RowBox[{"q", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}]}]}], "]"}], 
     "]"}], 
    RowBox[{"Expand", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"PowerExpand", "[", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", "m"}], " ", 
               RowBox[{"(", 
                RowBox[{"FC3", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t1", " ", 
                    RowBox[{"t2", "/", "t3"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t1", " ", 
                    RowBox[{"t3", "/", "t2"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t2", " ", 
                    RowBox[{"t3", "/", "t1"}]}], ")"}], "^", "m"}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"q", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
                   RowBox[{"(", " ", "m", ")"}]}], ",", 
                  RowBox[{"1", "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"q", " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], "^", 
                    RowBox[{"(", " ", "m", ")"}]}]}], ",", 
                  RowBox[{"k", "^", "m"}]}], "]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], "//.", 
       RowBox[{"q", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}]}]}], "]"}], 
     "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.711117893309148*^9, 3.711117910472986*^9}, {
   3.711123574273322*^9, 3.7111236109237947`*^9}, {3.711123726367112*^9, 
   3.711123731832601*^9}, {3.7111252875266113`*^9, 3.711125292180871*^9}, {
   3.711125343650147*^9, 3.7111253466527653`*^9}, {3.7111322219888983`*^9, 
   3.711132256282764*^9}, {3.711172897998197*^9, 3.711172928921599*^9}, {
   3.711172995993259*^9, 3.711173001631096*^9}, {3.711173148765994*^9, 
   3.7111731494621553`*^9}, {3.711173405616425*^9, 3.7111734133515387`*^9}, {
   3.711173480818301*^9, 3.7111734904287863`*^9}, 3.711173763272369*^9, {
   3.711185498432626*^9, 3.711185517937372*^9}, {3.711201320435585*^9, 
   3.711201341981575*^9}, {3.711206619155175*^9, 3.711206638103799*^9}, 
   3.716832215254833*^9, {3.716834260311717*^9, 3.7168342610803633`*^9}, {
   3.716895637809854*^9, 3.71689566675711*^9}, {3.717750837055806*^9, 
   3.717750843489542*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"TotalLocaC3Z2Z2", "=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"TotalContributionC3Z2Z2", "[", 
      RowBox[{"i", ",", "p0", ",", "p1", ",", "p2", ",", "p3"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7103190640552692`*^9, 3.710319119783393*^9}, {
  3.710577345818693*^9, 3.710577350783451*^9}, {3.710589559064365*^9, 
  3.71058956136864*^9}, {3.710648905961156*^9, 3.710648906575918*^9}, {
  3.711123699156292*^9, 3.711123715097938*^9}, {3.71120061056236*^9, 
  3.711200610649645*^9}, {3.711201313480599*^9, 3.711201313539197*^9}, {
  3.711206608543038*^9, 3.7112066085958033`*^9}, {3.71683219688483*^9, 
  3.716832196952663*^9}, {3.716895668301559*^9, 3.716895668382637*^9}}],

Cell[BoxData[
 TemplateBox[{
  "Flatten","normal",
   "\"Nonatomic expression expected at position \
\\!\\(\\*RowBox[{\\\"1\\\"}]\\) in \\!\\(\\*RowBox[{\\\"Flatten\\\", \
\\\"[\\\", \\\"0\\\", \\\"]\\\"}]\\).\"",2,198,6,27623743715054181559,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.716834207894937*^9, 3.716871259030429*^9, 
  3.717750872407057*^9, 3.71775315601959*^9, 3.717921266257708*^9}],

Cell[BoxData[
 TemplateBox[{
  "Flatten","normal",
   "\"Nonatomic expression expected at position \
\\!\\(\\*RowBox[{\\\"1\\\"}]\\) in \\!\\(\\*RowBox[{\\\"Flatten\\\", \
\\\"[\\\", \\\"0\\\", \\\"]\\\"}]\\).\"",2,198,7,27623743715054181559,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.716834207894937*^9, 3.716871259030429*^9, 
  3.717750872407057*^9, 3.71775315601959*^9, 3.7179212662716627`*^9}],

Cell[BoxData[
 TemplateBox[{
  "Flatten","normal",
   "\"Nonatomic expression expected at position \
\\!\\(\\*RowBox[{\\\"1\\\"}]\\) in \\!\\(\\*RowBox[{\\\"Flatten\\\", \
\\\"[\\\", \\\"0\\\", \\\"]\\\"}]\\).\"",2,198,8,27623743715054181559,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.716834207894937*^9, 3.716871259030429*^9, 
  3.717750872407057*^9, 3.71775315601959*^9, 3.717921266323062*^9}],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"Flatten\\\", \
\\\"::\\\", \\\"normal\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,198,9,27623743715054181559,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.716834207894937*^9, 3.716871259030429*^9, 
  3.717750872407057*^9, 3.71775315601959*^9, 3.7179212663307447`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"CheckcoeffC3Z2Z2", "[", 
   RowBox[{"order_", ",", "n0_", ",", "n1_", ",", "n2_", ",", "n3_"}], "]"}], 
  ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"PowerExpand", "[", 
    RowBox[{
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{"Coefficient", "[", 
          RowBox[{
           RowBox[{"Coefficient", "[", 
            RowBox[{
             RowBox[{"Coefficient", "[", 
              RowBox[{"TotalSymmC3Z2Z2Terms", ",", "p0", ",", "n0"}], "]"}], 
             ",", "p1", ",", "n1"}], "]"}], ",", "p2", ",", "n2"}], "]"}], 
         ",", "p3", ",", "n3"}], "]"}], "//.", 
       RowBox[{"k", "\[Rule]", 
        RowBox[{"t1", " ", "t2", " ", "t3"}]}]}], "]"}], "-", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{"Coefficient", "[", 
          RowBox[{
           RowBox[{"Coefficient", "[", 
            RowBox[{
             RowBox[{"Coefficient", "[", 
              RowBox[{"TotalLocaC3Z2Z2", ",", "p0", ",", "n0"}], "]"}], ",", 
             "p1", ",", "n1"}], "]"}], ",", "p2", ",", "n2"}], "]"}], ",", 
         "p3", ",", "n3"}], "]"}], "//.", 
       RowBox[{"k", "\[Rule]", 
        RowBox[{"t1", " ", "t2", " ", "t3"}]}]}], "]"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.709801230318844*^9, 3.709801292112351*^9}, 
   3.7098014386962843`*^9, {3.709801512078055*^9, 3.709801584676147*^9}, {
   3.709801658557428*^9, 3.709801712918518*^9}, {3.709801801223412*^9, 
   3.709801811408842*^9}, {3.709802006041431*^9, 3.709802037016217*^9}, {
   3.7098021223158607`*^9, 3.7098021223716593`*^9}, {3.709802308716028*^9, 
   3.709802315360991*^9}, {3.709802399964591*^9, 3.709802409599578*^9}, {
   3.709802440664639*^9, 3.7098024634166737`*^9}, {3.7098025631464157`*^9, 
   3.7098026364575167`*^9}, {3.7098027373052263`*^9, 
   3.7098027502936773`*^9}, {3.70980287397756*^9, 3.709802931392337*^9}, {
   3.7098029840396013`*^9, 3.7098029841459723`*^9}, {3.709803027964568*^9, 
   3.709803030456292*^9}, {3.709803258589994*^9, 3.7098032961555033`*^9}, {
   3.7098050060851097`*^9, 3.709805049994216*^9}, {3.70980510311948*^9, 
   3.709805165391273*^9}, {3.70980521532803*^9, 3.709805228887878*^9}, {
   3.7098056856537447`*^9, 3.709805687434853*^9}, {3.7098066800874443`*^9, 
   3.709806717585905*^9}, {3.7098067606485767`*^9, 3.709806779942554*^9}, {
   3.709807256477849*^9, 3.709807287942749*^9}, {3.709807518393207*^9, 
   3.709807540112265*^9}, {3.709807632071225*^9, 3.709807644936674*^9}, {
   3.7098077092555323`*^9, 3.709807717896744*^9}, {3.709807926332507*^9, 
   3.709807927817779*^9}, {3.709808554146041*^9, 3.709808605385367*^9}, 
   3.70980863894615*^9, {3.709808933563208*^9, 3.709808935559516*^9}, {
   3.709808972265918*^9, 3.709808972319015*^9}, {3.709811241651187*^9, 
   3.709811293242934*^9}, {3.709811340568644*^9, 3.7098113578167067`*^9}, {
   3.7098113938671017`*^9, 3.709811401261002*^9}, {3.709811499165019*^9, 
   3.70981150915385*^9}, {3.7098115399523687`*^9, 3.7098115426787*^9}, {
   3.709811702389453*^9, 3.709811708584779*^9}, 3.709919214027174*^9, {
   3.709919287751693*^9, 3.7099192906814013`*^9}, {3.709919330755711*^9, 
   3.709919356894569*^9}, {3.709919393882804*^9, 3.7099194665185423`*^9}, {
   3.709919962264369*^9, 3.709919990810166*^9}, {3.7099201647229853`*^9, 
   3.709920166933949*^9}, {3.7099727140162277`*^9, 3.7099727140971212`*^9}, {
   3.709972806873467*^9, 3.709972931874864*^9}, {3.710073827448523*^9, 
   3.710073829057536*^9}, {3.710073916984509*^9, 3.71007392250393*^9}, {
   3.7103187918472977`*^9, 3.710318801443994*^9}, 3.710319137985703*^9, {
   3.7105739032216883`*^9, 3.710573908870428*^9}, {3.710577357495666*^9, 
   3.7105773914126863`*^9}, {3.710589564356279*^9, 3.71058959126013*^9}, {
   3.710590427165216*^9, 3.710590429226152*^9}, {3.7106753161275873`*^9, 
   3.71067531652562*^9}, {3.7111237568261833`*^9, 3.711123792518804*^9}, {
   3.711123870426399*^9, 3.711123871925006*^9}, {3.711123926389434*^9, 
   3.7111239833220997`*^9}, {3.711124628705872*^9, 3.711124629085761*^9}, {
   3.71117062014495*^9, 3.7111706294583197`*^9}, {3.7111848664573793`*^9, 
   3.71118490181859*^9}, {3.711185346493019*^9, 3.711185346779771*^9}, {
   3.716834948769815*^9, 3.716834958854402*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CheckcoeffC3Z2Z2List", "[", 
   RowBox[{"n_", ",", "list_"}], "]"}], ":=", 
  RowBox[{"CheckcoeffC3Z2Z2", "[", 
   RowBox[{"n", ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "3", "]"}], "]"}], ",", 
    RowBox[{"list", "[", 
     RowBox[{"[", "4", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7103192660955753`*^9, 3.710319317190687*^9}, {
  3.710577395276349*^9, 3.710577407832775*^9}, {3.710589596537298*^9, 
  3.710589598219802*^9}, {3.71059063376313*^9, 3.710590636457033*^9}, {
  3.711123800303863*^9, 3.7111238154840717`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffC3Z2Z2List", "[", 
    RowBox[{"1", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"1", ",", "4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.710319604850749*^9, 3.710319633592993*^9}, {
   3.710319708824301*^9, 3.7103197454653788`*^9}, {3.710319807180949*^9, 
   3.710319811461013*^9}, {3.710574250497073*^9, 3.710574252304381*^9}, {
   3.710577410425535*^9, 3.710577413482637*^9}, {3.710589599966507*^9, 
   3.710589603596854*^9}, 3.7111238289584*^9, {3.711123889052888*^9, 
   3.711123889090931*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.71112382964535*^9, {3.711123874580453*^9, 3.71112389266753*^9}, 
   3.7111239383354797`*^9, 3.711125328359518*^9, 3.711125365131778*^9, 
   3.7111706110264063`*^9, 3.71117209274113*^9, {3.711172950191092*^9, 
   3.711172961400675*^9}, 3.711173032518834*^9, 3.711173178725618*^9, 
   3.7111732705464687`*^9, 3.711173443348907*^9, 3.7111735198322906`*^9, 
   3.71117379430604*^9, 3.71118310376803*^9, 3.711185047700782*^9, 
   3.711185112895706*^9, 3.71118518114011*^9, 3.711185295006674*^9, 
   3.7111853517350187`*^9, 3.71118544612855*^9, 3.7111856060656633`*^9, 
   3.7168343621355057`*^9, 3.716871417041493*^9, 3.717750875689599*^9, 
   3.7177531589953117`*^9, 3.7179212697033453`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffC3Z2Z2List", "[", 
    RowBox[{"2", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"2", ",", "4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.710319604850749*^9, 3.710319633592993*^9}, {
   3.710319708824301*^9, 3.7103197454653788`*^9}, {3.710319807180949*^9, 
   3.710319811461013*^9}, {3.710574250497073*^9, 3.710574252304381*^9}, {
   3.710577410425535*^9, 3.710577413482637*^9}, {3.710589599966507*^9, 
   3.710589603596854*^9}, 3.7111238289584*^9, {3.71112388519414*^9, 
   3.711123890635099*^9}, {3.711185271591957*^9, 3.711185273903943*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7111238948616123`*^9, {3.711123940223948*^9, 3.711123987316807*^9}, {
   3.711124622061083*^9, 3.711124632723275*^9}, 3.71112533107857*^9, 
   3.711125368086615*^9, 3.7111322709205313`*^9, {3.711170613883093*^9, 
   3.711170624171482*^9}, 3.711172968539948*^9, 3.711173038893216*^9, 
   3.711173185105542*^9, 3.711173276865829*^9, 3.711173449723901*^9, 
   3.711173526191451*^9, 3.711173800614757*^9, 3.711183111225636*^9, 
   3.711185052222052*^9, 3.711185116650679*^9, 3.711185187476509*^9, {
   3.711185301180461*^9, 3.7111853073292503`*^9}, 3.711185357940737*^9, 
   3.711185450355812*^9, 3.7111856231946898`*^9, 3.716834613804093*^9, 
   3.716871697771983*^9, 3.7177508807656307`*^9, 3.7177531628489227`*^9, 
   3.717921274797638*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffC3Z2Z2List", "[", 
    RowBox[{"3", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"3", ",", "4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.710319604850749*^9, 3.710319633592993*^9}, {
   3.710319708824301*^9, 3.7103197454653788`*^9}, {3.710319807180949*^9, 
   3.710319811461013*^9}, {3.710574250497073*^9, 3.710574252304381*^9}, {
   3.710577410425535*^9, 3.710577413482637*^9}, {3.710589599966507*^9, 
   3.710589603596854*^9}, 3.7111238289584*^9, {3.71112388519414*^9, 
   3.711123890635099*^9}, {3.7111321375093527`*^9, 3.711132139230578*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.711132142368462*^9, 3.7111730551300793`*^9, 
  3.71117346622287*^9, 3.711173816714635*^9, 3.711183127998413*^9, 
  3.7111848866217012`*^9, 3.711184921903349*^9, 3.711185062780751*^9, 
  3.711185126340786*^9, 3.7111852037645884`*^9, 3.711185323096889*^9, 
  3.7111853739953403`*^9, 3.711185460686469*^9, 3.7111856674661818`*^9, 
  3.7168349611512003`*^9, 3.7168723342253036`*^9, 3.7177508937716427`*^9, 
  3.717753173539008*^9, 3.717921287969235*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffC3Z2Z2List", "[", 
    RowBox[{"4", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"4", ",", "4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.710319604850749*^9, 3.710319633592993*^9}, {
   3.710319708824301*^9, 3.7103197454653788`*^9}, {3.710319807180949*^9, 
   3.710319811461013*^9}, {3.710574250497073*^9, 3.710574252304381*^9}, {
   3.710577410425535*^9, 3.710577413482637*^9}, {3.710589599966507*^9, 
   3.710589603596854*^9}, 3.7111238289584*^9, {3.71112388519414*^9, 
   3.711123890635099*^9}, {3.711130900717502*^9, 3.711130903042564*^9}, {
   3.711130935060115*^9, 3.711130937208034*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.7111309064263678`*^9, 3.711130944192959*^9, 
  3.711173091825077*^9, 3.711185484214239*^9, 3.711185765359468*^9, 
  3.7168736429802313`*^9, 3.717750923441553*^9, 3.71775319749098*^9, 
  3.717921317832591*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckcoeffC3Z2Z2List", "[", 
    RowBox[{"5", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"DistributeIntoNodes", "[", 
   RowBox[{"5", ",", "4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.710319604850749*^9, 3.710319633592993*^9}, {
   3.710319708824301*^9, 3.7103197454653788`*^9}, {3.710319807180949*^9, 
   3.710319811461013*^9}, {3.710574250497073*^9, 3.710574252304381*^9}, {
   3.710577410425535*^9, 3.710577413482637*^9}, {3.710589599966507*^9, 
   3.710589603596854*^9}, 3.7111238289584*^9, {3.71112388519414*^9, 
   3.711123890635099*^9}, {3.711130900717502*^9, 3.711130903042564*^9}, {
   3.711130935060115*^9, 3.711130937208034*^9}, {3.711185534302866*^9, 
   3.711185535975992*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.71118596176525*^9, 3.716876366607655*^9, 
  3.717750985463921*^9, 3.71775324763491*^9, 3.717921378243223*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Refined limit", "Subsection",
 CellChangeTimes->{{3.716814763743575*^9, 3.716814766654924*^9}, {
  3.716830179157219*^9, 3.716830180365514*^9}, {3.716832009423503*^9, 
  3.716832026929304*^9}, {3.7178505300833387`*^9, 3.717850531615341*^9}}],

Cell["Now we take the refined limit", "Text",
 CellChangeTimes->{{3.71785057633503*^9, 3.717850579716528*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"FKalC3Z2Z2", "[", 
      RowBox[{
       RowBox[{"(", "p1", ")"}], ",", 
       RowBox[{"(", "p2", ")"}], ",", 
       RowBox[{"(", "p3", ")"}], ",", 
       RowBox[{"(", "t1", ")"}], ",", 
       RowBox[{"(", "t2", ")"}], ",", 
       RowBox[{"(", "t3", ")"}], ",", 
       RowBox[{"(", 
        RowBox[{"q", "/", 
         RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], ",", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"q", " ", 
          RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}]}], ",", "k"}], "]"}], "+", 
     
     RowBox[{"FC3", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"t1", "^", "2"}], ")"}], ",", 
       RowBox[{"(", 
        RowBox[{"t2", "^", "2"}], ")"}], ",", 
       RowBox[{"(", 
        RowBox[{"t3", "/", 
         RowBox[{"(", 
          RowBox[{"t1", " ", "t2"}], ")"}]}], ")"}], ",", 
       RowBox[{"(", 
        RowBox[{"q", "/", 
         RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], ",", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"q", " ", 
          RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}]}], ",", "k"}], "]"}], "+", 
     
     RowBox[{"FC3", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"t1", "^", "2"}], ")"}], ",", 
       RowBox[{"(", 
        RowBox[{"t2", "/", 
         RowBox[{"(", 
          RowBox[{"t1", " ", "t3"}], ")"}]}], ")"}], ",", 
       RowBox[{"(", 
        RowBox[{"t3", "^", "2"}], ")"}], ",", 
       RowBox[{"(", 
        RowBox[{"q", "/", 
         RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], ",", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"q", " ", 
          RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}]}], ",", "k"}], "]"}], "+", 
     
     RowBox[{"FC3", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"t1", "/", 
         RowBox[{"(", 
          RowBox[{"t2", " ", "t3"}], ")"}]}], ")"}], ",", 
       RowBox[{"(", 
        RowBox[{"t2", "^", "2"}], ")"}], ",", 
       RowBox[{"(", 
        RowBox[{"t3", "^", "2"}], ")"}], ",", 
       RowBox[{"(", 
        RowBox[{"q", "/", 
         RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], ",", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"q", " ", 
          RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}]}], ",", "k"}], "]"}], "+", 
     
     RowBox[{"FC3", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"t1", " ", 
         RowBox[{"t2", "/", "t3"}]}], ")"}], ",", 
       RowBox[{"(", 
        RowBox[{"t1", " ", 
         RowBox[{"t3", "/", "t2"}]}], ")"}], ",", 
       RowBox[{"(", 
        RowBox[{"t2", " ", 
         RowBox[{"t3", "/", "t1"}]}], ")"}], ",", 
       RowBox[{"(", 
        RowBox[{"q", "/", 
         RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}], ",", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"q", " ", 
          RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}]}], ",", "k"}], "]"}]}], "//.",
     "TorusT3"}], ",", 
   RowBox[{"x", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.711117893309148*^9, 3.711117910472986*^9}, {
   3.711123574273322*^9, 3.7111236109237947`*^9}, {3.711123726367112*^9, 
   3.711123731832601*^9}, {3.7111252875266113`*^9, 3.711125292180871*^9}, {
   3.711125343650147*^9, 3.7111253466527653`*^9}, {3.7111322219888983`*^9, 
   3.711132256282764*^9}, {3.711172897998197*^9, 3.711172928921599*^9}, {
   3.711172995993259*^9, 3.711173001631096*^9}, {3.711173148765994*^9, 
   3.7111731494621553`*^9}, {3.711173405616425*^9, 3.7111734133515387`*^9}, {
   3.711173480818301*^9, 3.7111734904287863`*^9}, 3.711173763272369*^9, {
   3.711185498432626*^9, 3.711185517937372*^9}, {3.711201320435585*^9, 
   3.711201341981575*^9}, {3.711206619155175*^9, 3.711206638103799*^9}, 
   3.716832215254833*^9, {3.716834260311717*^9, 3.7168342610803633`*^9}, {
   3.716895637809854*^9, 3.71689566675711*^9}, {3.717750837055806*^9, 
   3.717750843489542*^9}, {3.7178506315571823`*^9, 3.717850748463629*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox["k"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"p1", " ", "p2"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"p1", " ", "p3"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"p2", " ", "p3"}]}], ")"}]}], "-", 
      RowBox[{"p2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"p1", " ", "p3"}], "+", 
         RowBox[{
          SuperscriptBox["p1", "2"], " ", 
          SuperscriptBox["p3", "2"]}]}], ")"}]}], "-", 
      RowBox[{"k", " ", 
       RowBox[{"(", 
        RowBox[{"p1", "+", "p3", "+", 
         RowBox[{"3", " ", "p1", " ", "p2", " ", "p3"}], "+", 
         RowBox[{
          SuperscriptBox["p1", "2"], " ", 
          SuperscriptBox["p2", "2"], " ", "p3"}], "+", 
         RowBox[{"p1", " ", 
          SuperscriptBox["p2", "2"], " ", 
          SuperscriptBox["p3", "2"]}]}], ")"}]}]}], ")"}], " ", "q"}], ")"}], 
  "/", 
  RowBox[{"(", 
   RowBox[{"p1", " ", "p2", " ", "p3", " ", 
    RowBox[{"(", 
     RowBox[{
      SqrtBox["k"], "-", "q"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       SqrtBox["k"], " ", "q"}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.717850772086121*^9, 3.7179213832432203`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"FZ2Z2ref", "[", 
   RowBox[{"q_", ",", "k_", ",", "p1_", ",", "p2_", ",", "p3_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SqrtBox["k"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"p1", " ", "p2"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"p1", " ", "p3"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"p2", " ", "p3"}]}], ")"}]}], "-", 
       RowBox[{"p2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"p1", " ", "p3"}], "+", 
          RowBox[{
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["p3", "2"]}]}], ")"}]}], "-", 
       RowBox[{"k", " ", 
        RowBox[{"(", 
         RowBox[{"p1", "+", "p3", "+", 
          RowBox[{"3", " ", "p1", " ", "p2", " ", "p3"}], "+", 
          RowBox[{
           SuperscriptBox["p1", "2"], " ", 
           SuperscriptBox["p2", "2"], " ", "p3"}], "+", 
          RowBox[{"p1", " ", 
           SuperscriptBox["p2", "2"], " ", 
           SuperscriptBox["p3", "2"]}]}], ")"}]}]}], ")"}], " ", "q"}], ")"}],
    "/", 
   RowBox[{"(", 
    RowBox[{"p1", " ", "p2", " ", "p3", " ", 
     RowBox[{"(", 
      RowBox[{
       SqrtBox["k"], "-", "q"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SqrtBox["k"], " ", "q"}]}], ")"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.717850804275473*^9, 3.717850848849251*^9}}],

Cell["Define the product function", "Text",
 CellChangeTimes->{{3.717850953034959*^9, 3.7178509563298683`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Mfunction", "[", 
   RowBox[{"x_", ",", "q1_", ",", "q2_", ",", "N_", ",", "d_"}], "]"}], ":=", 
  
  RowBox[{"Product", "[", 
   RowBox[{
    RowBox[{"Product", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"x", " ", 
          RowBox[{"q1", "^", 
           RowBox[{"(", 
            RowBox[{"i", "-", 
             RowBox[{"1", "/", "2"}], "+", 
             RowBox[{"d", "/", "2"}]}], ")"}]}], " ", 
          RowBox[{"q2", "^", 
           RowBox[{"(", 
            RowBox[{"j", "-", 
             RowBox[{"1", "/", "2"}], "-", 
             RowBox[{"d", "/", "2"}]}], ")"}]}]}]}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "N"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "N"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.716712216950686*^9, 3.716712219668832*^9}, {
  3.717847300269278*^9, 3.7178473086042557`*^9}}],

Cell["\<\
We can use this function to write the partition function in product form (not \
particularly illuminating). Indeed we can check that the product form below \
reproduces the symmetrized form\
\>", "Text",
 CellChangeTimes->{{3.7178526964888763`*^9, 3.717852722083946*^9}, {
  3.7179214205281763`*^9, 3.717921426263629*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{
   RowBox[{"Total", "[", 
    RowBox[{"BoundDegreeK", "[", 
     RowBox[{
      RowBox[{"List", "@@", 
       RowBox[{"Expand", "[", 
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Series", "[", 
            RowBox[{
             RowBox[{"Series", "[", 
              RowBox[{
               RowBox[{"Series", "[", 
                RowBox[{
                 RowBox[{"Exp", "[", 
                  RowBox[{"Sum", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"1", "/", "m"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"PowerExpand", "[", 
                    RowBox[{"FZ2Z2ref", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], "^", "m"}], ",", 
                    RowBox[{"k", "^", "m"}], ",", 
                    RowBox[{"p1", "^", "m"}], ",", 
                    RowBox[{"p2", "^", "m"}], ",", 
                    RowBox[{"p3", "^", "m"}]}], "]"}], "]"}], ")"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"m", ",", "1", ",", "7"}], "}"}]}], "]"}], "]"}], 
                 ",", 
                 RowBox[{"{", 
                  RowBox[{"p0", ",", "0", ",", "7"}], "}"}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"p1", ",", "0", ",", "7"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"p2", ",", "0", ",", "7"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"p3", ",", "0", ",", "7"}], "}"}]}], "]"}], "]"}], 
        "]"}]}], ",", "7"}], "]"}], "]"}], "-", 
   RowBox[{"Total", "[", 
    RowBox[{"BoundDegreeK", "[", 
     RowBox[{
      RowBox[{"List", "@@", 
       RowBox[{"Expand", "[", 
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Series", "[", 
            RowBox[{
             RowBox[{"Series", "[", 
              RowBox[{
               RowBox[{"Series", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Mfunction", "[", 
                    RowBox[{
                    RowBox[{"1", "/", "k"}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                    "]"}], "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Mfunction", "[", 
                    RowBox[{"1", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                    "]"}], "^", "3"}], "\[IndentingNewLine]", 
                    RowBox[{"Mfunction", "[", 
                    RowBox[{
                    RowBox[{"1", "/", 
                    RowBox[{"(", 
                    RowBox[{"p1", " ", "p2"}], ")"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                    "]"}], "\[IndentingNewLine]", 
                    RowBox[{"Mfunction", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"p1", " ", "p2"}], ")"}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                    "]"}], "\[IndentingNewLine]", 
                    RowBox[{"Mfunction", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1", "/", "k"}], " ", 
                    RowBox[{"1", "/", 
                    RowBox[{"(", 
                    RowBox[{"p1", " ", "p3"}], ")"}]}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                    "]"}], "\[IndentingNewLine]", 
                    RowBox[{"Mfunction", "[", " ", 
                    RowBox[{
                    RowBox[{"1", "/", 
                    RowBox[{"(", 
                    RowBox[{"p2", " ", "p3"}], ")"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                    "]"}], "\[IndentingNewLine]", 
                    RowBox[{"Mfunction", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"p1", " ", "p3"}], ")"}], 
                    RowBox[{"1", "/", "k"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                    "]"}], " ", "\[IndentingNewLine]", 
                    RowBox[{"Mfunction", "[", 
                    RowBox[{
                    RowBox[{"p2", " ", "p3"}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                    "]"}]}], ")"}], "/", 
                  RowBox[{"(", "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"Mfunction", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], 
                    RowBox[{"1", "/", "p1"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                    "]"}], 
                    RowBox[{"Mfunction", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], " ", "p1"}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                    "]"}], "\[IndentingNewLine]", 
                    RowBox[{"Mfunction", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], 
                    RowBox[{"1", "/", "p2"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                    "]"}], "\[IndentingNewLine]", 
                    RowBox[{"Mfunction", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], "p2"}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                    "]"}], "\[IndentingNewLine]", 
                    RowBox[{"Mfunction", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], 
                    RowBox[{"1", "/", "p3"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                    "]"}], "\[IndentingNewLine]", 
                    RowBox[{"Mfunction", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], "p3"}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                    "]"}], "\[IndentingNewLine]", 
                    RowBox[{"Mfunction", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], "p1", " ", "p2", " ", 
                    "p3"}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                    "]"}], "\[IndentingNewLine]", 
                    RowBox[{"Mfunction", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1", "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], 
                    RowBox[{"1", "/", 
                    RowBox[{"(", 
                    RowBox[{"p1", " ", "p2", " ", "p3"}], ")"}]}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], " ", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "p0"}], " ", "p1", " ", "p2", " ", "p3"}], 
                    ")"}], "/", 
                    RowBox[{"Sqrt", "[", "k", "]"}]}], ",", "10", ",", "1"}], 
                    "]"}]}], "\[IndentingNewLine]", ")"}]}], " ", 
                 "\[IndentingNewLine]", ",", 
                 RowBox[{"{", 
                  RowBox[{"p0", ",", "0", ",", "7"}], "}"}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"p1", ",", "0", ",", "7"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"p2", ",", "0", ",", "7"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"p3", ",", "0", ",", "7"}], "}"}]}], "]"}], "]"}], 
        "]"}]}], ",", "7"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.709461820912931*^9, 3.7094618312652273`*^9}, {
   3.709461880508375*^9, 3.709461935799809*^9}, {3.716809246477027*^9, 
   3.716809296256151*^9}, 3.7177480747402782`*^9, {3.7178516964508877`*^9, 
   3.717851774730604*^9}, {3.717852033574689*^9, 3.717852045848587*^9}, {
   3.717852552178039*^9, 3.717852558693214*^9}, {3.71785259771341*^9, 
   3.717852634171152*^9}, {3.7178526660393248`*^9, 3.7178526850020027`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.71785358869554*^9, 3.717921809431229*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["C3 / Z3 Orbifold", "Chapter",
 CellChangeTimes->{{3.716812682777137*^9, 3.716812693590261*^9}}],

Cell["\<\
Now we consider more complicated orbifolds. The resolution of C3 / Z3 is \
local P2, and does not consist only of P1s.\
\>", "Text",
 CellChangeTimes->{{3.71663249046338*^9, 3.7166325231949463`*^9}}],

Cell[CellGroupData[{

Cell["Localization", "Subsection",
 CellChangeTimes->{{3.716814763743575*^9, 3.716814766654924*^9}, {
  3.716830179157219*^9, 3.716830180365514*^9}, {3.716832009423503*^9, 
  3.716832026929304*^9}, {3.7168957893924932`*^9, 3.71689579063631*^9}}],

Cell["\<\
We decompose the vector spaces according to the orbifold action\
\>", "Text",
 CellChangeTimes->{{3.716897851629984*^9, 3.71689785911696*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PPVC3Z3", "[", 
   RowBox[{"l_List", ",", "t1_", ",", "t2_", ",", "t3_", ",", "r_"}], "]"}], ":=", 
  RowBox[{"Total", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"t1", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "i"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"t2", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "j"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"t3", "^", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "k"}], "+", "1"}], "}"}]}], " ", 
         RowBox[{"KroneckerDelta", "[", 
          RowBox[{
           RowBox[{"Mod", "[", 
            RowBox[{
             RowBox[{"i", "+", "j", "+", "k"}], ",", "3"}], "]"}], ",", "r"}],
           "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "l", "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"j", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"l", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"l", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "}"}]}], 
       "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.685794026599243*^9, 3.685794062411702*^9}, {
  3.6857945569193993`*^9, 3.68579456486136*^9}, {3.685794658823471*^9, 
  3.685794661349846*^9}, {3.685794743967721*^9, 3.685794762494817*^9}, {
  3.685795923624857*^9, 3.685795925376687*^9}, {3.686475669349183*^9, 
  3.6864756731092052`*^9}, {3.6864757035948963`*^9, 3.6864757052271633`*^9}, {
  3.6864758232734737`*^9, 3.686475852094858*^9}}],

Cell["For example", "Text",
 CellChangeTimes->{{3.716897868900385*^9, 3.7168978710697308`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PPVC3Z3", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"PlanePartitions", "[", "12", "]"}], "[", 
    RowBox[{"[", "12", "]"}], "]"}], ",", "t1", ",", "t2", ",", "t3", ",", 
   "1"}], "]"}]], "Input",
 CellChangeTimes->{{3.716897874555092*^9, 3.7168978746490583`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "t2"], "+", 
  FractionBox["1", 
   SuperscriptBox["t3", "4"]], "+", 
  FractionBox["1", 
   RowBox[{"t2", " ", 
    SuperscriptBox["t3", "3"]}]], "+", 
  FractionBox["1", "t3"]}]], "Output",
 CellChangeTimes->{3.716897875114715*^9, 3.717921863490597*^9}]
}, Open  ]],

Cell["\<\
The virtual tangent space is constructed out of invariant combinations of \
deformations and obstructions\
\>", "Text",
 CellChangeTimes->{{3.716897887509946*^9, 3.716897904422885*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TvirC3Z3fixed", "[", 
   RowBox[{"list_", ",", "t1_", ",", "t2_", ",", "t3_", ",", "k_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"PPVC3Z3", "[", 
    RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], "-", 
   RowBox[{
    RowBox[{"PPVC3Z3", "[", 
     RowBox[{"list", ",", 
      RowBox[{"1", "/", "t1"}], ",", 
      RowBox[{"1", "/", "t2"}], ",", 
      RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", " ", "t2", " ", "t3"}], ")"}]}], "-", 
   RowBox[{"(", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"PPVC3Z3", "[", 
          RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], 
         " ", 
         RowBox[{"PPVC3Z3", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"PPVC3Z3", "[", 
          RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "1"}], "]"}], 
         " ", 
         RowBox[{"PPVC3Z3", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "1"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"PPVC3Z3", "[", 
          RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "2"}], "]"}], 
         " ", 
         RowBox[{"PPVC3Z3", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "2"}], "]"}]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"t1", " ", "t2", " ", "t3"}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"PPVC3Z3", "[", 
          RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], 
         " ", 
         RowBox[{"PPVC3Z3", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "2"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"PPVC3Z3", "[", 
          RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "1"}], "]"}], 
         " ", 
         RowBox[{"PPVC3Z3", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"PPVC3Z3", "[", 
          RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "2"}], "]"}], 
         " ", 
         RowBox[{"PPVC3Z3", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "1"}], "]"}]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "t1"}], "-", "t2", "-", "t3"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"PPVC3Z3", "[", 
          RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "0"}], "]"}], 
         " ", 
         RowBox[{"PPVC3Z3", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "1"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"PPVC3Z3", "[", 
          RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "1"}], "]"}], 
         " ", 
         RowBox[{"PPVC3Z3", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "2"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"PPVC3Z3", "[", 
          RowBox[{"list", ",", "t1", ",", "t2", ",", "t3", ",", "2"}], "]"}], 
         " ", 
         RowBox[{"PPVC3Z3", "[", 
          RowBox[{"list", ",", 
           RowBox[{"1", "/", "t1"}], ",", 
           RowBox[{"1", "/", "t2"}], ",", 
           RowBox[{"1", "/", "t3"}], ",", "0"}], "]"}]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"t1", " ", "t2"}], "+", 
        RowBox[{"t1", " ", "t3"}], "+", 
        RowBox[{"t2", " ", "t3"}]}], ")"}]}]}], "\[IndentingNewLine]", 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.6864764204650497`*^9, 3.686476553141616*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{"TvirC3Z3fixed", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"PlanePartitions", "[", "12", "]"}], "[", 
     RowBox[{"[", "12", "]"}], "]"}], ",", "t1", ",", "t2", ",", "t3", ",", 
    "k"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.686476566359111*^9, 3.686476566909521*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["t1", "t2"], "+", 
  FractionBox["t1", 
   SuperscriptBox["t3", "4"]], "-", 
  FractionBox[
   RowBox[{"t1", " ", 
    SuperscriptBox["t2", "3"]}], 
   SuperscriptBox["t3", "4"]], "+", 
  FractionBox["t1", 
   RowBox[{"t2", " ", 
    SuperscriptBox["t3", "3"]}]], "-", 
  FractionBox[
   RowBox[{"2", " ", "t1", " ", 
    SuperscriptBox["t2", "2"]}], 
   SuperscriptBox["t3", "3"]], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["t2", "2"]}], 
   SuperscriptBox["t3", "2"]], "+", 
  FractionBox["t1", "t3"], "+", 
  FractionBox[
   RowBox[{"3", " ", "t2"}], "t3"], "-", 
  RowBox[{
   SuperscriptBox["t2", "2"], " ", "t3"}], "-", 
  RowBox[{"3", " ", "t1", " ", 
   SuperscriptBox["t3", "2"]}], "-", 
  RowBox[{"t2", " ", 
   SuperscriptBox["t3", "2"]}], "-", 
  FractionBox[
   RowBox[{"2", " ", "t1", " ", 
    SuperscriptBox["t3", "3"]}], "t2"], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["t3", "4"]}], "t2"], "-", 
  RowBox[{
   SuperscriptBox["t2", "2"], " ", 
   SuperscriptBox["t3", "4"]}], "+", 
  FractionBox[
   SuperscriptBox["t3", "5"], 
   SuperscriptBox["t2", "2"]], "-", 
  RowBox[{"t2", " ", 
   SuperscriptBox["t3", "5"]}]}]], "Output",
 CellChangeTimes->{3.716897661890684*^9, 3.717921863665798*^9}]
}, Open  ]],

Cell["We define the number of boxes in a certain conjugacy class", "Text",
 CellChangeTimes->{{3.716897916126226*^9, 3.716897926887343*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"NBC3Z3", "[", 
   RowBox[{"l_List", ",", "r_"}], "]"}], ":=", 
  RowBox[{"PPVC3Z3", "[", 
   RowBox[{"l", ",", "1", ",", "1", ",", "1", ",", "r"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.686476578965369*^9, 3.686476586140964*^9}}],

Cell["The localization computation:", "Text",
 CellChangeTimes->{{3.7168979323397493`*^9, 3.716897935736238*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"VirtualTC3Z3", "[", 
   RowBox[{"nboxes_", ",", "fixedpoint_"}], "]"}], ":=", 
  RowBox[{"Expand", "[", 
   RowBox[{"TvirC3Z3fixed", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
      RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", "t2", ",", 
     "t3", ",", "k"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FPListC3Z3", "[", 
   RowBox[{"nboxes_", ",", "fixedpoint_"}], "]"}], ":=", 
  RowBox[{"Flatten", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Reap", "[", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Flatten", "[", 
               RowBox[{"List", "@@", 
                RowBox[{"(", 
                 RowBox[{"Expand", "[", 
                  RowBox[{"TvirC3Z3fixed", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
               "//.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"t1", "\[Rule]", "1"}], ",", 
                RowBox[{"t2", "->", "1"}], ",", 
                RowBox[{"t3", "\[Rule]", "1"}], ",", 
                RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
            RowBox[{"[", "i", "]"}], "]"}], ">", "0"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Sow", "[", 
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
                RowBox[{"List", "@@", 
                 RowBox[{"(", 
                  RowBox[{"Expand", "[", 
                   RowBox[{"TvirC3Z3fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], 
                "\[IndentingNewLine]", "]"}], "[", 
               RowBox[{"[", "i", "]"}], "]"}], "/", 
              RowBox[{"(", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Flatten", "[", 
                   RowBox[{"List", "@@", 
                    RowBox[{"(", 
                    RowBox[{"Expand", "[", 
                    RowBox[{"TvirC3Z3fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
                   "//.", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"t1", "\[Rule]", "1"}], ",", 
                    RowBox[{"t2", "->", "1"}], ",", 
                    RowBox[{"t3", "\[Rule]", "1"}], ",", 
                    RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
                RowBox[{"[", "i", "]"}], "]"}], "\[IndentingNewLine]", 
               ")"}]}], ",", 
             RowBox[{
              RowBox[{"(", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"Flatten", "[", 
                 RowBox[{"List", "@@", 
                  RowBox[{"(", 
                   RowBox[{"Expand", "[", 
                    RowBox[{"TvirC3Z3fixed", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                    RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                    "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}],
                 "//.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"t1", "\[Rule]", "1"}], ",", 
                  RowBox[{"t2", "->", "1"}], ",", 
                  RowBox[{"t3", "\[Rule]", "1"}], ",", 
                  RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}], ")"}], "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "\[IndentingNewLine]", "}"}], 
           "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
        
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"Flatten", "[", 
            RowBox[{"List", "@@", 
             RowBox[{"(", 
              RowBox[{"Expand", "[", 
               RowBox[{"TvirC3Z3fixed", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
                  RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "t1", ",", 
                 "t2", ",", "t3", ",", "k"}], "]"}], "]"}], ")"}]}], "]"}], 
           "]"}]}], "}"}]}], "]"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ahatp", "[", "list_", "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "/", 
          RowBox[{"list", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"list", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "/", "k"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"list", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"list", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}], ")"}]}], ")"}], "^", 
   RowBox[{"list", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LocalizationC3Z3", "[", 
   RowBox[{
   "nboxes_", ",", "fixedpoint_", ",", "p0_", ",", "p1_", ",", "p2_"}], "]"}],
   ":=", 
  RowBox[{
   RowBox[{"Cancel", "[", 
    RowBox[{"PowerExpand", "[", 
     RowBox[{"Times", "@@", 
      RowBox[{"Map", "[", 
       RowBox[{"ahatp", ",", 
        RowBox[{"FPListC3Z3", "[", 
         RowBox[{"nboxes", ",", "fixedpoint"}], "]"}]}], "]"}]}], "]"}], 
    "]"}], " ", 
   RowBox[{"p0", "^", 
    RowBox[{"NBC3Z3", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
       RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "0"}], "]"}]}], " ", 
   RowBox[{"p1", "^", 
    RowBox[{"NBC3Z3", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
       RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "1"}], "]"}]}], " ", 
   RowBox[{"p2", "^", 
    RowBox[{"NBC3Z3", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "[", 
       RowBox[{"[", "fixedpoint", "]"}], "]"}], ",", "2"}], 
     "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TotalContributionC3Z3", "[", 
   RowBox[{"nboxes_", ",", "p0_", ",", "p1_", ",", "p2_"}], "]"}], ":=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{"LocalizationC3Z3", "[", 
     RowBox[{"nboxes", ",", "i", ",", "p0", ",", "p1", ",", "p2"}], "]"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", 
       RowBox[{"PlanePartitions", "[", "nboxes", "]"}], "]"}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{3.716899258665585*^9}],

Cell["Finally the partition function is given by", "Text",
 CellChangeTimes->{{3.716897969694724*^9, 3.716897974678005*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PartitionFunctionC3Z3", "[", "nboxes_", "]"}], ":=", 
  RowBox[{"1", "+", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"TotalContributionC3Z3", "[", 
      RowBox[{"n", ",", "p0", ",", "p1", ",", "p2"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "nboxes"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.716804618813366*^9, 3.716804627198197*^9}, {
  3.716806034437278*^9, 3.716806034503093*^9}, {3.7168147258786716`*^9, 
  3.716814733736116*^9}, {3.716818331008473*^9, 3.7168183311061287`*^9}, {
  3.716819553104373*^9, 3.7168195588853283`*^9}, {3.716830115413805*^9, 
  3.716830120998564*^9}, {3.716832120846491*^9, 3.716832132409144*^9}, {
  3.716895870277895*^9, 3.7168958794752617`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PartitionFunctionC3Z3", "[", "4", "]"}]], "Input",
 CellChangeTimes->{
  3.716804640930531*^9, {3.716814736590336*^9, 3.716814740839767*^9}, {
   3.7168195614985437`*^9, 3.716819561559877*^9}, {3.7168301400951643`*^9, 
   3.7168301401467333`*^9}, 3.7168321392366447`*^9, 3.716832293932126*^9, 
   3.716895883329319*^9, {3.71689829940829*^9, 3.7168983058010263`*^9}}],

Cell[BoxData[
 TemplateBox[{
  "Flatten","normal",
   "\"Nonatomic expression expected at position \
\\!\\(\\*RowBox[{\\\"1\\\"}]\\) in \\!\\(\\*RowBox[{\\\"Flatten\\\", \
\\\"[\\\", \\\"0\\\", \\\"]\\\"}]\\).\"",2,221,10,27623743715054181559,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.716898299745544*^9, 3.716898306097746*^9}, 
   3.717921863937352*^9}],

Cell[BoxData[
 TemplateBox[{
  "Flatten","normal",
   "\"Nonatomic expression expected at position \
\\!\\(\\*RowBox[{\\\"1\\\"}]\\) in \\!\\(\\*RowBox[{\\\"Flatten\\\", \
\\\"[\\\", \\\"0\\\", \\\"]\\\"}]\\).\"",2,221,11,27623743715054181559,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.716898299745544*^9, 3.716898306097746*^9}, 
   3.717921863952071*^9}],

Cell[BoxData[
 TemplateBox[{
  "Flatten","normal",
   "\"Nonatomic expression expected at position \
\\!\\(\\*RowBox[{\\\"1\\\"}]\\) in \\!\\(\\*RowBox[{\\\"Flatten\\\", \
\\\"[\\\", \\\"0\\\", \\\"]\\\"}]\\).\"",2,221,12,27623743715054181559,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.716898299745544*^9, 3.716898306097746*^9}, 
   3.717921864397538*^9}],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"Flatten\\\", \
\\\"::\\\", \\\"normal\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,221,13,27623743715054181559,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.716898299745544*^9, 3.716898306097746*^9}, 
   3.7179218644050703`*^9}],

Cell[BoxData[
 RowBox[{"1", "+", "p0", "+", 
  RowBox[{"p0", " ", 
   SuperscriptBox["p1", "3"]}], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", "t3"}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t1", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t1", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t1", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t1", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t2"}], "-", "t3"}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t2", "-", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t2", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t2"}], "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t2", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t2", "-", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t2", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t2"}], "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t2", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t2", "-", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", 
    SuperscriptBox["p1", "2"], " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t2"}], "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t2", "-", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", 
    SuperscriptBox["p1", "2"], " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t1", "2"]}], "-", 
      SuperscriptBox["t2", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t2"}], "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "+", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t2", "-", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", 
    SuperscriptBox["p1", "2"], " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      RowBox[{"k", " ", 
       SuperscriptBox["t2", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t2"}], "-", "t3"}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "+", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t2", "-", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", 
    SuperscriptBox["p1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "k"}], " ", "t2"}], "+", "t3"}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t2"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", 
    SuperscriptBox["p1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", 
    SuperscriptBox["p1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t2", "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t2", "-", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", 
    SuperscriptBox["p1", "2"], " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t2", "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t2"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"t1", "-", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"t2", "-", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", 
    SuperscriptBox["p1", "2"], " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t2"}], "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t2", "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t3"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"t2", "-", "t3"}], ")"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t2"}], "+", 
      RowBox[{"k", " ", "t3"}]}], ")"}]}], 
   RowBox[{"k", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t2"}], "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", 
    SuperscriptBox["p1", "2"], " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t2", "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t1", "2"]}], "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t2"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"t1", "-", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"t2", "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", 
    SuperscriptBox["p1", "2"], " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t2"}], "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", 
       SuperscriptBox["t2", "2"]}], "-", 
      SuperscriptBox["t3", "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t3"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"t2", "-", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"t2", "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", 
    SuperscriptBox["p1", "2"], " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", " ", "t1"}], "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t2", "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t1", "2"], "-", 
      RowBox[{"k", " ", 
       SuperscriptBox["t3", "2"]}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t2"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"t1", "-", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"t2", "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "+", "t3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"p0", " ", 
    SuperscriptBox["p1", "2"], " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t2", "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t2", "2"], "-", 
      RowBox[{"k", " ", 
       SuperscriptBox["t3", "2"]}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t3"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"t2", "-", "t3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"t2", "+", "t3"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"p0", " ", "p1", " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t2"}], "+", 
      RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "3"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t2"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t3", "3"]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["p0", "2"], " ", "p1", " ", "p2", " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", 
      RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t2"}], "+", 
      RowBox[{"k", " ", "t3"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      SuperscriptBox["t3", "3"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{"t1", "-", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t2"}], "+", "t3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["t3", "3"]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.716898299892722*^9, 3.716898306737926*^9}, 
   3.7179218645774593`*^9}]
}, Open  ]],

Cell["\<\
REMARK: The \[OpenCurlyQuote]flatten\[CloseCurlyQuote] message comes from the \
cases where the virtual tangent space vanishes and could be removed with some \
cosmetics. However they do not affect the final result. For example for the \
fixed point\
\>", "Text",
 CellChangeTimes->{{3.716898960839957*^9, 3.7168990191401787`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlanePartitions", "[", "4", "]"}], "[", 
  RowBox[{"[", "9", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.716899020881423*^9, 3.7168990250820847`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], ",", 
   RowBox[{"{", "1", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.716899025401229*^9, 3.7179218646760283`*^9}]
}, Open  ]],

Cell["the virtual tangent space is zero", "Text",
 CellChangeTimes->{{3.716899030661083*^9, 3.716899037284996*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VirtualTC3Z3", "[", 
  RowBox[{"4", ",", "9"}], "]"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.716899053410863*^9, 3.7179218647497272`*^9}]
}, Open  ]],

Cell["\<\
and so the list of monomials is empty. The message comes from trying to \
flatten and empty list\
\>", "Text",
 CellChangeTimes->{{3.716899058005712*^9, 3.716899094355233*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FPListC3Z3", "[", 
  RowBox[{"4", ",", "9"}], "]"}]], "Input"],

Cell[BoxData[
 TemplateBox[{
  "Flatten","normal",
   "\"Nonatomic expression expected at position \
\\!\\(\\*RowBox[{\\\"1\\\"}]\\) in \\!\\(\\*RowBox[{\\\"Flatten\\\", \
\\\"[\\\", \\\"0\\\", \\\"]\\\"}]\\).\"",2,224,14,27623743715054181559,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.716899077392458*^9, 3.7179218648284693`*^9}],

Cell[BoxData[
 TemplateBox[{
  "Flatten","normal",
   "\"Nonatomic expression expected at position \
\\!\\(\\*RowBox[{\\\"1\\\"}]\\) in \\!\\(\\*RowBox[{\\\"Flatten\\\", \
\\\"[\\\", \\\"0\\\", \\\"]\\\"}]\\).\"",2,224,15,27623743715054181559,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.716899077392458*^9, 3.7179218648581448`*^9}],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{3.7168990774100447`*^9, 3.717921864877097*^9}]
}, Open  ]],

Cell["\<\
However in mathematica the action of Times on an empty list gives 1, which is \
the contribution of a fixed point with vanishing virtual tangent space\
\>", "Text",
 CellChangeTimes->{{3.716899134796049*^9, 3.71689918970183*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Times", "@@", 
  RowBox[{"Map", "[", 
   RowBox[{"ahatp", ",", 
    RowBox[{"FPListC3Z3", "[", 
     RowBox[{"4", ",", "9"}], "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 TemplateBox[{
  "Flatten","normal",
   "\"Nonatomic expression expected at position \
\\!\\(\\*RowBox[{\\\"1\\\"}]\\) in \\!\\(\\*RowBox[{\\\"Flatten\\\", \
\\\"[\\\", \\\"0\\\", \\\"]\\\"}]\\).\"",2,225,16,27623743715054181559,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.716899210694613*^9, 3.71792186496106*^9}],

Cell[BoxData[
 TemplateBox[{
  "Flatten","normal",
   "\"Nonatomic expression expected at position \
\\!\\(\\*RowBox[{\\\"1\\\"}]\\) in \\!\\(\\*RowBox[{\\\"Flatten\\\", \
\\\"[\\\", \\\"0\\\", \\\"]\\\"}]\\).\"",2,225,17,27623743715054181559,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.716899210694613*^9, 3.717921864990548*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.716899210712336*^9, 3.717921865008863*^9}]
}, Open  ]],

Cell["\<\
Therefore removing the error message is purely cosmetics and introducing an \
IF cycle could slow down the program\
\>", "Text",
 CellChangeTimes->{{3.71689921845383*^9, 3.7168992445489693`*^9}}],

Cell["\<\
No closed formula is known in the unrefined (ordinaty topological string) \
case, therefore none is expected in the K-theory computation\
\>", "Text",
 CellChangeTimes->{{3.7169000531760178`*^9, 3.716900087184084*^9}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{808, 711},
WindowMargins->{{197, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (July 28, \
2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 143, 2, 92, "Title"],
Cell[CellGroupData[{
Cell[748, 28, 113, 1, 65, "Chapter"],
Cell[864, 31, 200, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[1089, 39, 101, 1, 44, "Subsection"],
Cell[1193, 42, 225, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[1443, 51, 728, 20, 75, "Input"],
Cell[2174, 73, 1221, 23, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3444, 102, 105, 1, 36, "Subsection"],
Cell[3552, 105, 155, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[3732, 112, 4554, 121, 453, "Input"],
Cell[8289, 235, 1158, 19, 70, "Message"]
}, Open  ]],
Cell[9462, 257, 1111, 31, 201, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[10610, 293, 111, 1, 36, "Subsection"],
Cell[10724, 296, 510, 9, 68, "Text"],
Cell[11237, 307, 923, 25, 117, "Input"],
Cell[12163, 334, 998, 25, 75, "Input"],
Cell[13164, 361, 120, 1, 30, "Text"],
Cell[13287, 364, 750, 21, 75, "Input"],
Cell[14040, 387, 510, 12, 32, "Input"],
Cell[14553, 401, 443, 12, 32, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[15033, 418, 161, 2, 36, "Subsection"],
Cell[15197, 422, 320, 5, 49, "Text"],
Cell[15520, 429, 1315, 33, 117, "Input"],
Cell[CellGroupData[{
Cell[16860, 466, 160, 3, 32, "Input"],
Cell[17023, 471, 1901, 46, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[18973, 523, 194, 3, 36, "Subsection"],
Cell[19170, 528, 156, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[19351, 534, 1228, 38, 75, "Input"],
Cell[20582, 574, 444, 12, 49, "Output"],
Cell[21029, 588, 446, 12, 49, "Output"],
Cell[21478, 602, 444, 12, 49, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21983, 621, 97, 1, 65, "Chapter"],
Cell[22083, 624, 240, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[22348, 633, 102, 1, 44, "Subsection"],
Cell[22453, 636, 214, 4, 30, "Text"],
Cell[22670, 642, 1424, 42, 159, "Input"],
Cell[24097, 686, 138, 1, 30, "Text"],
Cell[24238, 689, 1640, 42, 138, "Input"],
Cell[25881, 733, 428, 7, 68, "Text"],
Cell[26312, 742, 379, 10, 54, "Input"],
Cell[26694, 754, 809, 14, 144, "Text"],
Cell[27506, 770, 4811, 112, 537, "Input"],
Cell[32320, 884, 539, 8, 87, "Text"],
Cell[32862, 894, 1089, 36, 75, "Input"],
Cell[33954, 932, 139, 1, 30, "Text"],
Cell[34096, 935, 446, 12, 54, "Input"],
Cell[34545, 949, 192, 4, 30, "Text"],
Cell[34740, 955, 380, 11, 54, "Input"],
Cell[35123, 968, 515, 14, 32, "Input"],
Cell[35641, 984, 202, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[35868, 992, 189, 3, 32, "Input"],
Cell[36060, 997, 15087, 474, 619, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[51196, 1477, 114, 1, 36, "Subsection"],
Cell[51313, 1480, 362, 7, 49, "Text"],
Cell[CellGroupData[{
Cell[51700, 1491, 1228, 38, 75, "Input"],
Cell[52931, 1531, 468, 12, 49, "Output"],
Cell[53402, 1545, 466, 12, 49, "Output"],
Cell[53871, 1559, 466, 12, 49, "Output"]
}, Open  ]],
Cell[54352, 1574, 235, 4, 49, "Text"],
Cell[54590, 1580, 668, 19, 54, "Input"],
Cell[55261, 1601, 346, 6, 68, "Text"],
Cell[55610, 1609, 966, 28, 54, "Input"],
Cell[CellGroupData[{
Cell[56601, 1641, 435, 12, 32, "Input"],
Cell[57039, 1655, 1303, 41, 53, "Output"]
}, Open  ]],
Cell[58357, 1699, 138, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[58520, 1704, 428, 11, 32, "Input"],
Cell[58951, 1717, 487, 12, 32, "Output"]
}, Open  ]],
Cell[59453, 1732, 235, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[59713, 1741, 145, 2, 32, "Input"],
Cell[59861, 1745, 943, 30, 57, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[60853, 1781, 124, 1, 36, "Subsection"],
Cell[60980, 1784, 144, 1, 30, "Text"],
Cell[61127, 1787, 2732, 94, 117, "Input"],
Cell[63862, 1883, 171, 4, 30, "Text"],
Cell[64036, 1889, 807, 20, 54, "Input"],
Cell[64846, 1911, 264, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[65135, 1920, 815, 23, 54, "Input"],
Cell[65953, 1945, 7863, 215, 251, "Output"]
}, Open  ]],
Cell[73831, 2163, 302, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[74158, 2172, 1114, 30, 96, "Input"],
Cell[75275, 2204, 472, 11, 32, "Output"]
}, Open  ]],
Cell[75762, 2218, 239, 4, 49, "Text"],
Cell[76004, 2224, 3113, 99, 117, "Input"],
Cell[CellGroupData[{
Cell[79142, 2327, 547, 15, 32, "Input"],
Cell[79692, 2344, 414, 14, 60, "Output"]
}, Open  ]],
Cell[80121, 2361, 644, 20, 32, "Input"],
Cell[CellGroupData[{
Cell[80790, 2385, 624, 18, 32, "Input"],
Cell[81417, 2405, 1375, 40, 57, "Output"]
}, Open  ]],
Cell[82807, 2448, 319, 6, 49, "Text"],
Cell[CellGroupData[{
Cell[83151, 2458, 732, 20, 32, "Input"],
Cell[83886, 2480, 1266, 39, 91, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[85213, 2526, 108, 1, 65, "Chapter"],
Cell[85324, 2529, 277, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[85626, 2538, 97, 1, 63, "Subchapter"],
Cell[CellGroupData[{
Cell[85748, 2543, 102, 1, 44, "Subsection"],
Cell[85853, 2546, 902, 13, 125, "Text"],
Cell[86758, 2561, 2021, 53, 159, "Input"],
Cell[88782, 2616, 225, 4, 49, "Text"],
Cell[89010, 2622, 2938, 72, 180, "Input"],
Cell[CellGroupData[{
Cell[91973, 2698, 704, 16, 54, "Input"],
Cell[92680, 2716, 578, 17, 50, "Output"],
Cell[93261, 2735, 449, 13, 50, "Output"]
}, Open  ]],
Cell[93725, 2751, 271, 5, 49, "Text"],
Cell[93999, 2758, 595, 11, 32, "Input"],
Cell[94597, 2771, 205, 4, 49, "Text"],
Cell[94805, 2777, 385, 10, 54, "Input"],
Cell[95193, 2789, 252, 5, 49, "Text"],
Cell[95448, 2796, 4825, 112, 558, "Input"],
Cell[100276, 2910, 1089, 36, 75, "Input"],
Cell[101368, 2948, 275, 5, 49, "Text"],
Cell[101646, 2955, 1632, 36, 96, "Input"],
Cell[103281, 2993, 495, 13, 75, "Input"],
Cell[103779, 3008, 107, 1, 30, "Text"],
Cell[103889, 3011, 511, 12, 54, "Input"],
Cell[CellGroupData[{
Cell[104425, 3027, 140, 2, 32, "Input"],
Cell[104568, 3031, 6262, 220, 272, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[110879, 3257, 135, 1, 36, "Subsection"],
Cell[111017, 3260, 463, 8, 68, "Text"],
Cell[111483, 3270, 3113, 99, 117, "Input"],
Cell[114599, 3371, 1398, 42, 157, "Input"],
Cell[116000, 3415, 2700, 72, 159, "Input"],
Cell[118703, 3489, 525, 9, 87, "Text"],
Cell[119231, 3500, 4910, 120, 348, "Input"],
Cell[124144, 3622, 1376, 31, 117, "Input"],
Cell[125523, 3655, 553, 9, 87, "Text"],
Cell[126079, 3666, 381, 10, 32, "Input"],
Cell[CellGroupData[{
Cell[126485, 3680, 370, 9, 32, "Input"],
Cell[126858, 3691, 501, 8, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[127396, 3704, 372, 9, 32, "Input"],
Cell[127771, 3715, 263, 5, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[128071, 3725, 370, 9, 32, "Input"],
Cell[128444, 3736, 276, 5, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[128757, 3746, 369, 9, 32, "Input"],
Cell[129129, 3757, 289, 5, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[129455, 3767, 372, 9, 32, "Input"],
Cell[129830, 3778, 296, 6, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[130163, 3789, 277, 7, 32, "Input"],
Cell[130443, 3798, 312, 6, 32, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[130804, 3810, 151, 2, 36, "Subsection"],
Cell[130958, 3814, 229, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[131212, 3823, 1775, 48, 117, "Input"],
Cell[132990, 3873, 736, 21, 62, "Output"]
}, Open  ]],
Cell[133741, 3897, 101, 1, 30, "Text"],
Cell[133845, 3900, 551, 19, 64, "Input"],
Cell[134399, 3921, 390, 7, 49, "Text"],
Cell[134792, 3930, 3138, 94, 159, "Input"],
Cell[137933, 4026, 1235, 33, 75, "Input"],
Cell[139171, 4061, 178, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[139374, 4069, 2463, 61, 306, "Input"],
Cell[141840, 4132, 190, 3, 32, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[142091, 4142, 97, 1, 63, "Subchapter"],
Cell[CellGroupData[{
Cell[142213, 4147, 151, 2, 44, "Subsection"],
Cell[142367, 4151, 463, 8, 68, "Text"],
Cell[142833, 4161, 1923, 52, 159, "Input"],
Cell[144759, 4215, 283, 5, 49, "Text"],
Cell[145045, 4222, 4260, 112, 243, "Input"],
Cell[149308, 4336, 220, 4, 30, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[149553, 4344, 402, 9, 32, "Input"],
Cell[149958, 4355, 1509, 40, 53, "Output"]
}, Open  ]],
Cell[151482, 4398, 142, 1, 30, "Text"],
Cell[151627, 4401, 535, 10, 32, "Input"],
Cell[152165, 4413, 454, 7, 87, "Text"],
Cell[152622, 4422, 385, 10, 54, "Input"],
Cell[153010, 4434, 5480, 122, 579, "Input"],
Cell[158493, 4558, 1089, 36, 75, "Input"],
Cell[159585, 4596, 1168, 34, 117, "Input"],
Cell[160756, 4632, 524, 14, 75, "Input"],
Cell[161283, 4648, 472, 11, 54, "Input"],
Cell[CellGroupData[{
Cell[161780, 4663, 116, 2, 32, "Input"],
Cell[161899, 4667, 4841, 172, 213, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[166789, 4845, 184, 2, 36, "Subsection"],
Cell[166976, 4849, 312, 5, 49, "Text"],
Cell[167291, 4856, 3113, 99, 117, "Input"],
Cell[170407, 4957, 1619, 48, 157, "Input"],
Cell[172029, 5007, 3714, 101, 180, "Input"],
Cell[175746, 5110, 284, 5, 49, "Text"],
Cell[176033, 5117, 6905, 168, 432, "Input"],
Cell[182941, 5287, 1794, 39, 159, "Input"],
Cell[184738, 5328, 501, 13, 32, "Input"],
Cell[CellGroupData[{
Cell[185264, 5345, 273, 7, 32, "Input"],
Cell[185540, 5354, 329, 6, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[185906, 5365, 273, 7, 32, "Input"],
Cell[186182, 5374, 278, 6, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[186497, 5385, 277, 7, 32, "Input"],
Cell[186777, 5394, 320, 7, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[187134, 5406, 274, 7, 32, "Input"],
Cell[187411, 5415, 379, 8, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[187827, 5428, 275, 7, 32, "Input"],
Cell[188105, 5437, 437, 8, 32, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[188591, 5451, 152, 2, 36, "Subsection"],
Cell[188746, 5455, 189, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[188960, 5463, 2353, 68, 159, "Input"],
Cell[191316, 5533, 874, 27, 64, "Output"]
}, Open  ]],
Cell[192205, 5563, 908, 28, 66, "Input"],
Cell[193116, 5593, 267, 5, 49, "Text"],
Cell[193386, 5600, 3602, 105, 159, "Input"],
Cell[196991, 5707, 2611, 71, 180, "Input"],
Cell[199605, 5780, 178, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[199808, 5788, 2746, 70, 285, "Input"],
Cell[202557, 5860, 188, 3, 32, "Output"]
}, Open  ]],
Cell[202760, 5866, 169, 3, 30, "Text"],
Cell[202932, 5871, 656, 19, 32, "Input"],
Cell[203591, 5892, 107, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[203723, 5897, 679, 19, 32, "Input"],
Cell[204405, 5918, 2112, 58, 102, "Output"]
}, Open  ]],
Cell[206532, 5979, 114, 1, 30, "Text"],
Cell[206649, 5982, 1039, 30, 75, "Input"],
Cell[CellGroupData[{
Cell[207713, 6016, 572, 16, 32, "Input"],
Cell[208288, 6034, 1600, 52, 94, "Output"]
}, Open  ]],
Cell[209903, 6089, 281, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[210209, 6098, 4340, 115, 243, "Input"],
Cell[214552, 6215, 7232, 229, 366, "Output"]
}, Open  ]],
Cell[221799, 6447, 214, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[222038, 6455, 6716, 160, 516, "Input"],
Cell[228757, 6617, 94, 1, 32, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[228912, 6625, 99, 1, 63, "Subchapter"],
Cell[CellGroupData[{
Cell[229036, 6630, 148, 2, 44, "Subsection"],
Cell[229187, 6634, 210, 4, 49, "Text"],
Cell[229400, 6640, 932, 21, 117, "Input"],
Cell[230335, 6663, 2075, 54, 159, "Input"],
Cell[232413, 6719, 172, 3, 30, "Text"],
Cell[232588, 6724, 5516, 142, 327, "Input"],
Cell[238107, 6868, 154, 3, 30, "Text"],
Cell[238264, 6873, 641, 11, 32, "Input"],
Cell[238908, 6886, 157, 3, 30, "Text"],
Cell[239068, 6891, 9217, 228, 957, "Input"],
Cell[248288, 7121, 112, 1, 30, "Text"],
Cell[248403, 7124, 577, 12, 54, "Input"],
Cell[CellGroupData[{
Cell[249005, 7140, 165, 3, 32, "Input"],
Cell[249173, 7145, 27398, 963, 1087, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[276620, 8114, 133, 1, 36, "Subsection"],
Cell[276756, 8117, 299, 5, 49, "Text"],
Cell[277058, 8124, 3113, 99, 117, "Input"],
Cell[280174, 8225, 2371, 63, 177, "Input"],
Cell[282548, 8290, 4444, 124, 222, "Input"],
Cell[286995, 8416, 8045, 202, 537, "Input"],
Cell[295043, 8620, 178, 4, 30, "Text"],
Cell[295224, 8626, 376, 9, 32, "Input"],
Cell[295603, 8637, 212, 4, 49, "Text"],
Cell[295818, 8643, 3751, 68, 180, "Input"],
Cell[299572, 8713, 519, 14, 54, "Input"],
Cell[CellGroupData[{
Cell[300116, 8731, 419, 9, 32, "Input"],
Cell[300538, 8742, 257, 5, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[300832, 8752, 421, 9, 32, "Input"],
Cell[301256, 8763, 320, 7, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[301613, 8775, 419, 9, 32, "Input"],
Cell[302035, 8786, 422, 8, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[302494, 8799, 421, 9, 32, "Input"],
Cell[302918, 8810, 582, 10, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[303537, 8825, 468, 10, 32, "Input"],
Cell[304008, 8837, 805, 13, 54, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[304874, 8857, 148, 2, 63, "Subchapter"],
Cell[CellGroupData[{
Cell[305047, 8863, 149, 2, 44, "Subsection"],
Cell[305199, 8867, 174, 4, 30, "Text"],
Cell[305376, 8873, 2125, 55, 159, "Input"],
Cell[307504, 8930, 109, 1, 30, "Text"],
Cell[307616, 8933, 6522, 166, 390, "Input"],
Cell[314141, 9101, 691, 12, 32, "Input"],
Cell[314835, 9115, 112, 1, 30, "Text"],
Cell[314950, 9118, 9590, 238, 978, "Input"],
Cell[324543, 9358, 106, 1, 30, "Text"],
Cell[324652, 9361, 646, 14, 54, "Input"],
Cell[CellGroupData[{
Cell[325323, 9379, 217, 4, 32, "Input"],
Cell[325543, 9385, 24014, 851, 959, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[349606, 10242, 133, 1, 36, "Subsection"],
Cell[349742, 10245, 380, 7, 68, "Text"],
Cell[350125, 10254, 3113, 99, 117, "Input"],
Cell[353241, 10355, 2983, 79, 219, "Input"],
Cell[356227, 10436, 236, 4, 49, "Text"],
Cell[356466, 10442, 11237, 284, 957, "Input"],
Cell[367706, 10728, 443, 11, 32, "Input"],
Cell[368152, 10741, 3950, 73, 222, "Input"],
Cell[372105, 10816, 637, 17, 54, "Input"],
Cell[CellGroupData[{
Cell[372767, 10837, 468, 10, 32, "Input"],
Cell[373238, 10849, 262, 5, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[373537, 10859, 467, 10, 32, "Input"],
Cell[374007, 10871, 326, 7, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[374370, 10883, 468, 10, 32, "Input"],
Cell[374841, 10895, 535, 9, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[375413, 10909, 467, 10, 32, "Input"],
Cell[375883, 10921, 904, 14, 75, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[376824, 10940, 468, 10, 32, "Input"],
Cell[377295, 10952, 1495, 21, 117, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[378851, 10980, 197, 3, 63, "Subchapter"],
Cell[CellGroupData[{
Cell[379073, 10987, 149, 2, 44, "Subsection"],
Cell[379225, 10991, 139, 1, 30, "Text"],
Cell[379367, 10994, 2171, 55, 159, "Input"],
Cell[381541, 11051, 141, 1, 30, "Text"],
Cell[381685, 11054, 7533, 191, 453, "Input"],
Cell[389221, 11247, 741, 13, 32, "Input"],
Cell[389965, 11262, 111, 1, 30, "Text"],
Cell[390079, 11265, 9994, 246, 999, "Input"],
Cell[400076, 11513, 713, 16, 54, "Input"],
Cell[CellGroupData[{
Cell[400814, 11533, 271, 5, 32, "Input"],
Cell[401088, 11540, 21472, 766, 834, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[422609, 12312, 133, 1, 36, "Subsection"],
Cell[422745, 12315, 343, 6, 49, "Text"],
Cell[423091, 12323, 3113, 99, 117, "Input"],
Cell[426207, 12424, 3708, 95, 261, "Input"],
Cell[429918, 12521, 281, 5, 49, "Text"],
Cell[430202, 12528, 555, 13, 32, "Input"],
Cell[430760, 12543, 13324, 333, 1209, "Input"],
Cell[444087, 12878, 4344, 81, 264, "Input"],
Cell[448434, 12961, 800, 20, 54, "Input"],
Cell[CellGroupData[{
Cell[449259, 12985, 517, 11, 32, "Input"],
Cell[449779, 12998, 228, 5, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[450044, 13008, 565, 11, 32, "Input"],
Cell[450612, 13021, 387, 7, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[451036, 13033, 563, 11, 32, "Input"],
Cell[451602, 13046, 755, 12, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[452394, 13063, 563, 11, 32, "Input"],
Cell[452960, 13076, 1495, 21, 117, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[454492, 13102, 563, 11, 32, "Input"],
Cell[455058, 13115, 2820, 38, 201, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[457951, 13161, 106, 1, 65, "Chapter"],
Cell[458060, 13164, 172, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[458257, 13172, 149, 2, 44, "Subsection"],
Cell[458409, 13176, 196, 4, 30, "Text"],
Cell[458608, 13182, 1981, 57, 180, "Input"],
Cell[460592, 13241, 150, 3, 30, "Text"],
Cell[460745, 13246, 7660, 204, 474, "Input"],
Cell[CellGroupData[{
Cell[468430, 13454, 334, 8, 32, "Input"],
Cell[468767, 13464, 1134, 35, 53, "Output"]
}, Open  ]],
Cell[469916, 13502, 299, 7, 32, "Input"],
Cell[470218, 13511, 109, 1, 30, "Text"],
Cell[470330, 13514, 9227, 230, 957, "Input"],
Cell[479560, 13746, 122, 1, 30, "Text"],
Cell[479685, 13749, 727, 14, 54, "Input"],
Cell[480415, 13765, 413, 7, 68, "Text"],
Cell[CellGroupData[{
Cell[480853, 13776, 319, 5, 32, "Input"],
Cell[481175, 13783, 476, 9, 24, "Message"],
Cell[481654, 13794, 474, 9, 24, "Message"],
Cell[482131, 13805, 474, 9, 24, "Message"],
Cell[482608, 13816, 482, 9, 24, "Message"],
Cell[483093, 13827, 26003, 912, 1131, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[509145, 14745, 231, 3, 36, "Subsection"],
Cell[509379, 14750, 252, 5, 49, "Text"],
Cell[509634, 14757, 561, 17, 32, "Input"],
Cell[510198, 14776, 3113, 99, 117, "Input"],
Cell[513314, 14877, 3381, 84, 165, "Input"],
Cell[516698, 14963, 173, 4, 30, "Text"],
Cell[516874, 14969, 10401, 256, 810, "Input"],
Cell[CellGroupData[{
Cell[527300, 15229, 813, 15, 32, "Input"],
Cell[528116, 15246, 424, 8, 24, "Message"],
Cell[528543, 15256, 426, 8, 24, "Message"],
Cell[528972, 15266, 424, 8, 24, "Message"],
Cell[529399, 15276, 434, 8, 24, "Message"]
}, Open  ]],
Cell[529848, 15287, 4347, 77, 201, "Input"],
Cell[534198, 15366, 721, 17, 54, "Input"],
Cell[CellGroupData[{
Cell[534944, 15387, 595, 12, 32, "Input"],
Cell[535542, 15401, 805, 13, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[536384, 15419, 640, 12, 32, "Input"],
Cell[537027, 15433, 924, 16, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[537988, 15454, 642, 12, 32, "Input"],
Cell[538633, 15468, 735, 12, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[539405, 15485, 690, 13, 32, "Input"],
Cell[540098, 15500, 652, 11, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[540787, 15516, 740, 14, 32, "Input"],
Cell[541530, 15532, 775, 12, 54, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[542354, 15550, 247, 3, 36, "Subsection"],
Cell[542604, 15555, 110, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[542739, 15560, 3981, 107, 138, "Input"],
Cell[546723, 15669, 1428, 45, 81, "Output"]
}, Open  ]],
Cell[548166, 15717, 1591, 48, 106, "Input"],
Cell[549760, 15767, 111, 1, 30, "Text"],
Cell[549874, 15770, 1039, 30, 75, "Input"],
Cell[550916, 15802, 332, 6, 49, "Text"],
Cell[CellGroupData[{
Cell[551273, 15812, 16409, 372, 915, "Input"],
Cell[567685, 16186, 91, 1, 32, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[567837, 16194, 101, 1, 65, "Chapter"],
Cell[567941, 16197, 209, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[568175, 16205, 245, 3, 44, "Subsection"],
Cell[568423, 16210, 152, 3, 30, "Text"],
Cell[568578, 16215, 2058, 53, 159, "Input"],
Cell[570639, 16270, 95, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[570759, 16275, 288, 7, 32, "Input"],
Cell[571050, 16284, 298, 9, 50, "Output"]
}, Open  ]],
Cell[571363, 16296, 195, 4, 30, "Text"],
Cell[571561, 16302, 4493, 119, 285, "Input"],
Cell[CellGroupData[{
Cell[576079, 16425, 330, 8, 32, "Input"],
Cell[576412, 16435, 1290, 43, 98, "Output"]
}, Open  ]],
Cell[577717, 16481, 140, 1, 30, "Text"],
Cell[577860, 16484, 267, 6, 32, "Input"],
Cell[578130, 16492, 113, 1, 30, "Text"],
Cell[578246, 16495, 385, 10, 54, "Input"],
Cell[578634, 16507, 4825, 112, 537, "Input"],
Cell[583462, 16621, 1089, 36, 75, "Input"],
Cell[584554, 16659, 1109, 33, 117, "Input"],
Cell[585666, 16694, 518, 14, 54, "Input"],
Cell[586187, 16710, 124, 1, 30, "Text"],
Cell[586314, 16713, 763, 15, 54, "Input"],
Cell[CellGroupData[{
Cell[587102, 16732, 390, 6, 32, "Input"],
Cell[587495, 16740, 389, 9, 24, "Message"],
Cell[587887, 16751, 389, 9, 24, "Message"],
Cell[588279, 16762, 389, 9, 24, "Message"],
Cell[588671, 16773, 395, 8, 24, "Message"],
Cell[589069, 16783, 13903, 475, 703, "Output"]
}, Open  ]],
Cell[602987, 17261, 341, 6, 49, "Text"],
Cell[CellGroupData[{
Cell[603353, 17271, 187, 4, 32, "Input"],
Cell[603543, 17277, 212, 6, 32, "Output"]
}, Open  ]],
Cell[603770, 17286, 115, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[603910, 17291, 88, 2, 32, "Input"],
Cell[604001, 17295, 94, 1, 32, "Output"]
}, Open  ]],
Cell[604110, 17299, 186, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[604321, 17307, 86, 2, 32, "Input"],
Cell[604410, 17311, 363, 8, 24, "Message"],
Cell[604776, 17321, 363, 8, 24, "Message"],
Cell[605142, 17331, 111, 2, 32, "Output"]
}, Open  ]],
Cell[605268, 17336, 239, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[605532, 17344, 177, 5, 32, "Input"],
Cell[605712, 17351, 360, 8, 24, "Message"],
Cell[606075, 17361, 361, 8, 24, "Message"],
Cell[606439, 17371, 92, 1, 32, "Output"]
}, Open  ]],
Cell[606546, 17375, 205, 4, 49, "Text"],
Cell[606754, 17381, 228, 4, 49, "Text"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

